%macro apply_rdbms_data_model_changes(
m_di_trans_vendor=di_trans_vendor,    /* Database vendor */
m_di_trans=di_trans,                  /* libref for rdbms data mart library*/
m_di_data=di_data,                    /* libref for sas data mart library*/
m_di_mon=di_mon,                      /* libref for monitor library */
m_didm_stg=didm_stg,                  /* libref for stage library */
m_DTTMFMT=NLDATM21.,                  /* Date time format */
m_DTFMT=DATE9.,                       /* Date format */
m_experimental_changes=FALSE,         /* For developers only */
m_user=&sysuserid                     /* User Applying Change */
) / minoperator;
 
/* Use libref macro variable for legacy code */
%let dtfmt=&m_DTFMT;
%let DTTMFMT=&m_DTTMFMT;
 
*Check if libref &m_di_trans. is assigned;
%let didmExists = %sysfunc(libref(&m_di_trans.));
 
%if not (&didmExists = 0) %then
%do;
%put ERROR: Library referenced by libref "&m_di_trans." is not assigned.;
%put ERROR- Please assign the library for RDBMS data mart and rerun!;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
*Check if libref &m_di_data. is assigned;
%let didmExists = %sysfunc(libref(&m_di_data.));
 
%if not (&didmExists = 0) %then
%do;
%put ERROR: Library referenced by libref "&m_di_data." is not assigned.;
%put ERROR- Please assign the library for SAS data mart and rerun!;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
%local m_user_lib;
%let m_user_lib = %sysfunc(getoption(user));
options user = &m_di_trans;
 
 
*Create rdbms_DM_change_management table if it does not exist;
%*macro create_chg_mgmt_table(m_di_trans=di_trans);
%let m_chgTable=rdbms_DM_change_management;
 
*  Create &m_chgTable table if it does not exist;
%if not %sysfunc(exist(&m_di_trans..&m_chgTable)) %then
%do;
%put NOTE:  Table &m_di_trans..&m_chgTable table does not exist.  Creating new!;
%if (&m_di_trans_vendor in (SAS)) %then %do;
proc sql noprint;
create table &m_chgTable
(
CHANGE_ID varchar(32) NOT NULL,
CHANGE_DESC varchar(100),
DATE_CHANGE_APPLIED date format datetime18. informat datetime18.,
USER_APPLYING_CHANGE varchar(32)
 
);
 
quit;
 
%end;
 
 
%else %if (&m_di_trans_vendor in (DB2)) %then %do;
%let m_sql_statement=%str(
create table &m_chgTable
(
CHANGE_ID varchar(32) NOT NULL,
CHANGE_DESC varchar(100),
DATE_CHANGE_APPLIED timestamp,
USER_APPLYING_CHANGE varchar(32),
primary key (CHANGE_ID)
)
);
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
%end;
 
 
%else %do;
%let m_sql_statement=%str(
create table &m_chgTable
(
CHANGE_ID varchar(32) NOT NULL,
CHANGE_DESC varchar(100),
DATE_CHANGE_APPLIED date,
USER_APPLYING_CHANGE varchar(32),
primary key (CHANGE_ID)
)
);
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
%end;
 
 
%end;
 
 
 
 
%*mend;
 
%*create_chg_mgmt_table(m_di_trans=di_trans);
 
 
 
 
 
 
*Check baseline data model version;
%*macro check_baseline_dm_version(m_di_data=di_data);
%let m_baseline_dm_spec_name=BASELINE_DATA_MODEL_VERSION;
%let m_baseline_dm_spec_value=;
 
*  Code value in Global_setting if it does not exist;
%if not %sysfunc(exist(&m_di_data..global_setting)) %then
%do;
* quit if global_setting table is not present;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
%else
%do;
 
proc sql noprint;
select spec_value
into :m_baseline_dm_spec_value
from &m_di_data..global_setting
where spec_nm="&m_baseline_dm_spec_name"
;
quit;
 
%put NOTE: The value of BASELINE_DATA_MODEL_VERSION global setting is &m_baseline_dm_spec_value
*If BASELINE_DATA_MODEL_VERSION is missing in global_setting table then quit;
%if (&m_baseline_dm_spec_value=) %then
%do;
%put ERROR: &m_di_data..global_setting table must have a spec_value for spec_nm=BASELINE_DATA_MODEL_VERSION and app=ALL.;
%put ERROR- Current valid values are M1MI42 and D2TKMI42;
 
* if fa_spec table exists in di_trans then it is M1MI42 else it is D2TKMI42;
%if %sysfunc(exist(&m_di_trans..fa_spec)) %then
%do;
%let m_baseline_dm_spec_value=M1MI42;
%end;
%else
%do;
%let m_baseline_dm_spec_value=D2TKMI42;
%end;
 
%put NOTE:  Based on current state of schema BASELINE_DATA_MODEL_VERSION is &m_baseline_dm_spec_value;
%put NOTE-  This value is being inserted into global_setting table for spec_nm=BASELINE_DATA_MODEL_VERSION and app=ALL.;
%put NOTE-  Please ensure that this is correct and rerun.;
 
proc sql;
delete from &m_di_data..global_setting
where upper(spec_nm)="BASELINE_DATA_MODEL_VERSION"
and upper(app)="ALL";
 
insert into &m_di_data..global_setting
(spec_nm,app,spec_value,spec_desc)
values
("BASELINE_DATA_MODEL_VERSION","ALL","&m_baseline_dm_spec_value",
"Baseline (original) version of the data model before changes were applied")
;
quit;
 
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
%else
%do;
%let m_baseline_dm_spec_value=&m_baseline_dm_spec_value;
%put NOTE: BASELINE_DATA_MODEL_VERSION from di_trans.global_setting table is &m_baseline_dm_spec_value;
%end;
 
%end;
 
run;
 
%*mend;
 
%*check_baseline_dm_version(m_di_trans=di_trans);
 
 
 
 
***********************************************************************************************;
************************************  Begin Change DATA_MODEL_VERSION_MGMT ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: DATA_MODEL_VERSION_MGMT;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("DATA_MODEL_VERSION_MGMT")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%put NOTE: This change will be applied on every run : DATA_MODEL_VERSION_MGMT;
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
data &m_di_data..DATA_MODEL_VERSION_MANAGEMENT;
 
 
attrib VERSION          length=$10  ;
 
 
attrib VERSION_INCLUDED length=$10  ;
 
 
 
VERSION='D2TKMI42'; VERSION_INCLUDED='D2TKMI42'; output;
 
 
VERSION='M1MI42';   VERSION_INCLUDED='M1MI42'; output;
 
 
VERSION='F1MI42';   VERSION_INCLUDED='M1MI42'; output;
 
 
 
VERSION='M2MI42';   VERSION_INCLUDED='M1MI42'; output;
 
 
VERSION='M2MI42';   VERSION_INCLUDED='F1MI42'; output;
 
 
VERSION='M2MI42';   VERSION_INCLUDED='M2MI42'; output;
 
 
 
VERSION='M1TKMI43'; VERSION_INCLUDED='M1TKMI43'; output;
 
 
VERSION='M1TKMI43'; VERSION_INCLUDED='D2TKMI42'; output;
 
 
 
VERSION='M2TKMI43'; VERSION_INCLUDED='M2TKMI43'; output;
 
 
VERSION='M2TKMI43'; VERSION_INCLUDED='M1TKMI43'; output;
 
 
VERSION='M2TKMI43'; VERSION_INCLUDED='D2TKMI42'; output;
 
 
 
VERSION='F2TKMI43'; VERSION_INCLUDED='F2TKMI43'; output;
 
 
VERSION='F2TKMI43'; VERSION_INCLUDED='M2TKMI43'; output;
 
 
VERSION='F2TKMI43'; VERSION_INCLUDED='M1TKMI43'; output;
 
 
VERSION='F2TKMI43'; VERSION_INCLUDED='D2TKMI42'; output;
 
 
run;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
data &m_di_data..DATA_MODEL_VERSION_MANAGEMENT;
 
 
attrib VERSION          length=$10  ;
 
 
attrib VERSION_INCLUDED length=$10  ;
 
 
 
VERSION='D2TKMI42'; VERSION_INCLUDED='D2TKMI42'; output;
 
 
VERSION='M1MI42';   VERSION_INCLUDED='M1MI42'; output;
 
 
VERSION='F1MI42';   VERSION_INCLUDED='M1MI42'; output;
 
 
 
VERSION='M2MI42';   VERSION_INCLUDED='M1MI42'; output;
 
 
VERSION='M2MI42';   VERSION_INCLUDED='F1MI42'; output;
 
 
VERSION='M2MI42';   VERSION_INCLUDED='M2MI42'; output;
 
 
 
VERSION='M1TKMI43'; VERSION_INCLUDED='M1TKMI43'; output;
 
 
VERSION='M1TKMI43'; VERSION_INCLUDED='D2TKMI42'; output;
 
 
 
VERSION='M2TKMI43'; VERSION_INCLUDED='M2TKMI43'; output;
 
 
VERSION='M2TKMI43'; VERSION_INCLUDED='M1TKMI43'; output;
 
 
VERSION='M2TKMI43'; VERSION_INCLUDED='D2TKMI42'; output;
 
 
 
VERSION='F2TKMI43'; VERSION_INCLUDED='F2TKMI43'; output;
 
 
VERSION='F2TKMI43'; VERSION_INCLUDED='M2TKMI43'; output;
 
 
VERSION='F2TKMI43'; VERSION_INCLUDED='M1TKMI43'; output;
 
 
VERSION='F2TKMI43'; VERSION_INCLUDED='D2TKMI42'; output;
 
 
run;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: DATA_MODEL_VERSION_MGMT;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: DATA_MODEL_VERSION_MGMT;
%put ERROR- Description                              : Data model versions to enable migration from one version to another;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 24JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: DATA_MODEL_VERSION_MGMT;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DATA_MODEL_VERSION_MGMT",
"Data model versions to enable migration from one version to another",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%DATA_MODEL_VERSION_MGMT:;
 
 
* End of changes for CHANGE_ID:DATA_MODEL_VERSION_MGMT;
 
 
***********************************************************************************************;
*************************************  End Change DATA_MODEL_VERSION_MGMT ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change GET_DM_VERSIONS_FROM_BASE ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: GET_DM_VERSIONS_FROM_BASE;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("GET_DM_VERSIONS_FROM_BASE")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%put NOTE: This change will be applied on every run : GET_DM_VERSIONS_FROM_BASE;
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
proc sql noprint;
 
 
select version_included into :m_baseline_versions
separated by ","
from &m_di_data..DATA_MODEL_VERSION_MANAGEMENT
where version="&m_baseline_dm_spec_value"
;
 
 
 
quit;
 
 
 
%put NOTE: Baseline Version from global settings table is &m_baseline_dm_spec_value;
 
 
%put NOTE: This baseline version includes changes in tracks: &m_baseline_versions;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
proc sql noprint;
 
 
select version_included into :m_baseline_versions
separated by ","
from &m_di_data..DATA_MODEL_VERSION_MANAGEMENT
where version="&m_baseline_dm_spec_value"
;
 
 
 
quit;
 
 
 
%put NOTE: Baseline Version from global settings table is &m_baseline_dm_spec_value;
 
 
%put NOTE: This baseline version includes changes in tracks: &m_baseline_versions;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: GET_DM_VERSIONS_FROM_BASE;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: GET_DM_VERSIONS_FROM_BASE;
%put ERROR- Description                              : Data model versions to enable migration from one version to another;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 24JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: GET_DM_VERSIONS_FROM_BASE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"GET_DM_VERSIONS_FROM_BASE",
"Data model versions to enable migration from one version to another",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%GET_DM_VERSIONS_FROM_BASE:;
 
 
* End of changes for CHANGE_ID:GET_DM_VERSIONS_FROM_BASE;
 
 
***********************************************************************************************;
*************************************  End Change GET_DM_VERSIONS_FROM_BASE ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change RDBMS_DM_DROP_CONSTRAINTS ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: RDBMS_DM_DROP_CONSTRAINTS;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("RDBMS_DM_DROP_CONSTRAINTS")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :RDBMS_DM_DROP_CONSTRAINTS;
%goto RDBMS_DM_DROP_CONSTRAINTS;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..RDBMS_DM_CHANGE_MANAGEMENT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..RDBMS_DM_CHANGE_MANAGEMENT;
%put NOTE: Change ID                             :RDBMS_DM_DROP_CONSTRAINTS;
%goto RDBMS_DM_DROP_CONSTRAINTS;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : RDBMS_DM_DROP_CONSTRAINTS;
%goto RDBMS_DM_DROP_CONSTRAINTS;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : RDBMS_DM_DROP_CONSTRAINTS;
* Insert record into change management table for CHANGE_ID: RDBMS_DM_DROP_CONSTRAINTS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"RDBMS_DM_DROP_CONSTRAINTS",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto RDBMS_DM_DROP_CONSTRAINTS;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
alter table RDBMS_DM_CHANGE_MANAGEMENT drop primary key
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
data &m_di_trans..rdbms_dm_change_management;
 
 
set &m_di_trans..rdbms_dm_change_management;
 
 
run;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: RDBMS_DM_DROP_CONSTRAINTS;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: RDBMS_DM_DROP_CONSTRAINTS;
%put ERROR- Description                              : Drop Constraints on RDBMS_DM_CHANGE_MANAGEMENT table;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 11APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: RDBMS_DM_DROP_CONSTRAINTS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"RDBMS_DM_DROP_CONSTRAINTS",
"Drop Constraints on RDBMS_DM_CHANGE_MANAGEMENT table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%RDBMS_DM_DROP_CONSTRAINTS:;
 
 
* End of changes for CHANGE_ID:RDBMS_DM_DROP_CONSTRAINTS;
 
 
***********************************************************************************************;
*************************************  End Change RDBMS_DM_DROP_CONSTRAINTS ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID00000A ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID00000A;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID00000A")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID00000A;
%goto ID00000A;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID00000A;
* Insert record into change management table for CHANGE_ID: ID00000A;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID00000A",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID00000A;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
%if not (%sysfunc(exist(&m_di_trans..TABLE_PARTITION_META))) %then
%do;
 
 
 
%let m_sql_statement = %str(
CREATE TABLE TABLE_PARTITION_META
(
TABLE_NM                           VARCHAR(32) NOT NULL,
FULL_COPY_FLG                      INTEGER NOT NULL,
PARTITION_FLG                      INTEGER NOT NULL,
ESTIMATION_FLG                     INTEGER NOT NULL
)
 
);
 
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE TABLE_PARTITION_META  add CONSTRAINT TABLE_PARTITION_META_SK  PRIMARY KEY (TABLE_NM)
);
 
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
 
 
 
%if not (%sysfunc(exist(&m_di_trans..TKMI_GRID_DATA_MAP))) %then
%do;
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE TKMI_GRID_DATA_MAP
(
PROD_HIER_ASSOC_CD                 INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
CAPTAIN_NM                         VARCHAR(255),
PARTITION_SIZE                     NUMERIC(20,3)
)
 
);
 
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%let m_sql_statement = %str(
ALTER TABLE TKMI_GRID_DATA_MAP  add CONSTRAINT TKMI_GRID_DATA_MAP_SK  PRIMARY KEY (PROD_HIER_ASSOC_CD,PROD_HIER_SK)
);
 
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%if not (%sysfunc(exist(&m_di_trans..TABLE_PARTITION_META))) %then
%do;
 
 
 
proc sql;
 
 
 
CREATE TABLE TABLE_PARTITION_META
(
TABLE_NM                           VARCHAR(32) NOT NULL,
FULL_COPY_FLG                      INTEGER NOT NULL,
PARTITION_FLG                      INTEGER NOT NULL,
ESTIMATION_FLG                     INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE TABLE_PARTITION_META  add CONSTRAINT PRIM_KEY  PRIMARY KEY (TABLE_NM);
 
 
quit;
 
 
%end;
 
 
 
%if not (%sysfunc(exist(&m_di_trans..TKMI_GRID_DATA_MAP))) %then
%do;
 
 
 
proc sql;
 
 
 
 
CREATE TABLE TKMI_GRID_DATA_MAP
(
PROD_HIER_ASSOC_CD                 INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
CAPTAIN_NM                         VARCHAR(255),
PARTITION_SIZE                     NUMERIC(20,3)
)
;
 
 
 
ALTER TABLE TKMI_GRID_DATA_MAP  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PROD_HIER_ASSOC_CD,PROD_HIER_SK);
 
 
 
quit;
 
 
%end;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID00000A;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID00000A;
%put ERROR- Description                              : Table partition metadata;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID00000A;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID00000A",
"Table partition metadata",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID00000A:;
 
 
* End of changes for CHANGE_ID:ID00000A;
 
 
***********************************************************************************************;
*************************************  End Change ID00000A ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID00000B ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID00000B;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID00000B")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID00000B;
%goto ID00000B;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID00000B;
* Insert record into change management table for CHANGE_ID: ID00000B;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID00000B",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID00000B;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_ALERT
(
ALERT_SK                           INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL,
DEMAND_MODEL_TYPE                  VARCHAR(20) NOT NULL,
SCORE                              NUMERIC(12,2) NOT NULL,
SCORE_DATE_SK                      INTEGER NOT NULL,
BENCHMARK_SCORE                    NUMERIC(12,2) NOT NULL,
BENCHMARK_DTTM                     DATE NOT NULL,
DEVIATION_FROM_SCORE               NUMERIC(12,2) NOT NULL,
CREATED_DTTM                       DATE NOT NULL,
PRIMARY KEY (ALERT_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_ALERT_STATUS
(
ALERT_SK                           INTEGER NOT NULL,
USER_NM                            VARCHAR(40) NOT NULL,
ACTIVE_FLG                         INTEGER NOT NULL,
PRIMARY KEY (ALERT_SK,USER_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_MODEL_GROUP
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SEASON                             VARCHAR(20),
TAG                                VARCHAR(40),
DEMAND_MODEL_TYPE                  VARCHAR(20),
PRIMARY KEY (MODEL_GROUP_ID)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_MONITORING_FILTER_PROD_GEO
(
PROD_GEO_SK                        INTEGER NOT NULL,
PROD_GEO_FLG                       INTEGER NOT NULL,
PRIMARY KEY (PROD_GEO_SK,PROD_GEO_FLG)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_MONITORING_GEO
(
GEO_HIER_SK                        INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL,
PRIMARY KEY (GEO_HIER_SK,MODEL_GROUP_ID)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX MDL_GRP_ID_IX1 ON FA_MONITORING_GEO
(
MODEL_GROUP_ID
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_MONITORING_PROD
(
PROD_HIER_SK                       INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL,
PRIMARY KEY (PROD_HIER_SK,MODEL_GROUP_ID)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX MDL_GRP_ID_IX2 ON FA_MONITORING_PROD
(
MODEL_GROUP_ID
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_PRESEASON_FILTER_PROD_GEO
(
PROD_GEO_SK                        INTEGER NOT NULL,
PROD_GEO_FLG                       INTEGER NOT NULL,
PRIMARY KEY (PROD_GEO_SK,PROD_GEO_FLG)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX PROD_GEO_FLG_IX1 ON FA_PRESEASON_FILTER_PROD_GEO
(
PROD_GEO_FLG
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_PRESEASON_GEO
(
GEO_HIER_SK                        INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL,
PRIMARY KEY (GEO_HIER_SK,MODEL_GROUP_ID)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX MDL_GRP_ID_IX4 ON FA_PRESEASON_GEO
(
MODEL_GROUP_ID
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_PRESEASON_PROD
(
PROD_HIER_SK                       INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL,
PRIMARY KEY (PROD_HIER_SK,MODEL_GROUP_ID)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX MDL_GRP_ID_IX5 ON FA_PRESEASON_PROD
(
MODEL_GROUP_ID
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_SCENARIO
(
SCENARIO_NM                        VARCHAR(40) NOT NULL,
SCENARIO_DESC                      VARCHAR(100),
SCENARIO_TYPE                      VARCHAR(20),
BASE_SCENARIO_FLG                  INTEGER NOT NULL,
DISABLED_FLG                       INTEGER,
PRIMARY KEY (SCENARIO_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_SCENARIO_SPEC
(
SCENARIO_NM                        VARCHAR(40) NOT NULL,
SPEC_NM                            VARCHAR(32) NOT NULL,
SPEC_TYPE                          VARCHAR(5) NOT NULL,
SPEC_TABLE_NM                      VARCHAR(32) NOT NULL,
MODEL_COMP_NM                      VARCHAR(20) NOT NULL,
SPEC_VALUE                         VARCHAR(100) NOT NULL,
PRIMARY KEY (SCENARIO_NM,SPEC_NM,SPEC_TYPE,SPEC_TABLE_NM,MODEL_COMP_NM,SPEC_VALUE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_SCENARIO_STATUS
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
DEMAND_MODEL_TYPE                  VARCHAR(20) NOT NULL,
SCORE                              NUMERIC(12,2),
WEIGHTED_MAPE                      NUMERIC(12,2),
MEDIAN_PE                          NUMERIC(12,2),
ELASTICITY_TAIL                    NUMERIC(12,2),
STATUS                             VARCHAR(10),
PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,DEMAND_MODEL_TYPE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_SCORE
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
DEMAND_MODEL_TYPE                  VARCHAR(20) NOT NULL,
BENCHMARK_FLG                      INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
SCORE                              NUMERIC(12,2),
WEIGHTED_MAPE                      NUMERIC(12,2),
MEDIAN_PE                          NUMERIC(12,2),
ELASTICITY_TAIL                    NUMERIC(12,2),
PRIMARY KEY (MODEL_GROUP_ID,DEMAND_MODEL_TYPE,BENCHMARK_FLG,DATE_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_SPEC
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SPEC_NM                            VARCHAR(32) NOT NULL,
SPEC_VALUE                         VARCHAR(100),
PRIMARY KEY (MODEL_GROUP_ID,SPEC_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
CREATE TABLE FA_ALERT
(
ALERT_SK                           INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL,
DEMAND_MODEL_TYPE                  VARCHAR(20) NOT NULL,
SCORE                              NUMERIC(12,2) NOT NULL,
SCORE_DATE_SK                      INTEGER NOT NULL,
BENCHMARK_SCORE                    NUMERIC(12,2) NOT NULL,
BENCHMARK_DTTM                     DATE      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT   NOT NULL,
DEVIATION_FROM_SCORE               NUMERIC(12,2) NOT NULL,
CREATED_DTTM                       DATE      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT   NOT NULL
)
;
 
 
 
ALTER TABLE FA_ALERT  add CONSTRAINT PRIM_KEY  PRIMARY KEY (ALERT_SK);
 
 
 
 
CREATE TABLE FA_ALERT_STATUS
(
ALERT_SK                           INTEGER NOT NULL,
USER_NM                            VARCHAR(40) NOT NULL,
ACTIVE_FLG                         INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE FA_ALERT_STATUS  add CONSTRAINT PRIM_KEY  PRIMARY KEY (ALERT_SK,USER_NM);
 
 
 
 
CREATE TABLE FA_MODEL_GROUP
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SEASON                             VARCHAR(20),
TAG                                VARCHAR(40),
DEMAND_MODEL_TYPE                  VARCHAR(20)
)
;
 
 
 
ALTER TABLE FA_MODEL_GROUP  add CONSTRAINT PRIM_KEY  PRIMARY KEY (MODEL_GROUP_ID);
 
 
 
 
CREATE TABLE FA_MONITORING_FILTER_PROD_GEO
(
PROD_GEO_SK                        INTEGER NOT NULL,
PROD_GEO_FLG                       INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE FA_MONITORING_FILTER_PROD_GEO  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PROD_GEO_SK,PROD_GEO_FLG);
 
 
 
 
CREATE TABLE FA_MONITORING_GEO
(
GEO_HIER_SK                        INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE FA_MONITORING_GEO  add CONSTRAINT PRIM_KEY  PRIMARY KEY (GEO_HIER_SK,MODEL_GROUP_ID);
 
 
 
CREATE INDEX MODEL_GROUP_ID ON FA_MONITORING_GEO
(
MODEL_GROUP_ID
)
;
 
 
 
 
CREATE TABLE FA_MONITORING_PROD
(
PROD_HIER_SK                       INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE FA_MONITORING_PROD  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PROD_HIER_SK,MODEL_GROUP_ID);
 
 
 
CREATE INDEX MODEL_GROUP_ID ON FA_MONITORING_PROD
(
MODEL_GROUP_ID
)
;
 
 
 
 
CREATE TABLE FA_PRESEASON_FILTER_PROD_GEO
(
PROD_GEO_SK                        INTEGER NOT NULL,
PROD_GEO_FLG                       INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE FA_PRESEASON_FILTER_PROD_GEO  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PROD_GEO_SK,PROD_GEO_FLG);
 
 
 
CREATE INDEX PROD_GEO_FLG ON FA_PRESEASON_FILTER_PROD_GEO
(
PROD_GEO_FLG
)
;
 
 
 
 
CREATE TABLE FA_PRESEASON_GEO
(
GEO_HIER_SK                        INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE FA_PRESEASON_GEO  add CONSTRAINT PRIM_KEY  PRIMARY KEY (GEO_HIER_SK,MODEL_GROUP_ID);
 
 
 
CREATE INDEX MODEL_GROUP_ID ON FA_PRESEASON_GEO
(
MODEL_GROUP_ID
)
;
 
 
 
 
CREATE TABLE FA_PRESEASON_PROD
(
PROD_HIER_SK                       INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE FA_PRESEASON_PROD  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PROD_HIER_SK,MODEL_GROUP_ID);
 
 
 
CREATE INDEX MODEL_GROUP_ID ON FA_PRESEASON_PROD
(
MODEL_GROUP_ID
)
;
 
 
 
 
CREATE TABLE FA_SCENARIO
(
SCENARIO_NM                        VARCHAR(40) NOT NULL,
SCENARIO_DESC                      VARCHAR(100),
SCENARIO_TYPE                      VARCHAR(20),
BASE_SCENARIO_FLG                  INTEGER NOT NULL,
DISABLED_FLG                       INTEGER
)
;
 
 
 
ALTER TABLE FA_SCENARIO  add CONSTRAINT PRIM_KEY  PRIMARY KEY (SCENARIO_NM);
 
 
 
 
CREATE TABLE FA_SCENARIO_SPEC
(
SCENARIO_NM                        VARCHAR(40) NOT NULL,
SPEC_NM                            VARCHAR(32) NOT NULL,
SPEC_TYPE                          VARCHAR(5) NOT NULL,
SPEC_TABLE_NM                      VARCHAR(32) NOT NULL,
MODEL_COMP_NM                      VARCHAR(20) NOT NULL,
SPEC_VALUE                         VARCHAR(100) NOT NULL
)
;
 
 
 
ALTER TABLE FA_SCENARIO_SPEC  add CONSTRAINT PRIM_KEY  PRIMARY KEY (SCENARIO_NM,SPEC_NM,SPEC_TYPE,SPEC_TABLE_NM,MODEL_COMP_NM,SPEC_VALUE);
 
 
 
 
CREATE TABLE FA_SCENARIO_STATUS
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
DEMAND_MODEL_TYPE                  VARCHAR(20) NOT NULL,
SCORE                              NUMERIC(12,2),
WEIGHTED_MAPE                      NUMERIC(12,2),
MEDIAN_PE                          NUMERIC(12,2),
ELASTICITY_TAIL                    NUMERIC(12,2),
STATUS                             VARCHAR(10),
PCT_ELASTICITY_DEFAULTED           NUMERIC(12,4)
 
)
;
 
 
 
ALTER TABLE FA_SCENARIO_STATUS  add CONSTRAINT PRIM_KEY  PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,DEMAND_MODEL_TYPE);
 
 
 
 
CREATE TABLE FA_SCORE
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
DEMAND_MODEL_TYPE                  VARCHAR(20) NOT NULL,
BENCHMARK_FLG                      INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
SCORE                              NUMERIC(12,2),
WEIGHTED_MAPE                      NUMERIC(12,2),
MEDIAN_PE                          NUMERIC(12,2),
ELASTICITY_TAIL                    NUMERIC(12,2),
PCT_ELASTICITY_DEFAULTED           NUMERIC(12,4)
)
;
 
 
 
ALTER TABLE FA_SCORE  add CONSTRAINT PRIM_KEY  PRIMARY KEY (MODEL_GROUP_ID,DEMAND_MODEL_TYPE,BENCHMARK_FLG,DATE_SK);
 
 
 
 
CREATE TABLE FA_SPEC
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SPEC_NM                            VARCHAR(32) NOT NULL,
SPEC_VALUE                         VARCHAR(200)
)
;
 
 
 
ALTER TABLE FA_SPEC  add CONSTRAINT PRIM_KEY  PRIMARY KEY (MODEL_GROUP_ID,SPEC_NM);
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_ALERT
(
ALERT_SK                           INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL,
DEMAND_MODEL_TYPE                  VARCHAR(20) NOT NULL,
SCORE                              NUMERIC(12,2) NOT NULL,
SCORE_DATE_SK                      INTEGER NOT NULL,
BENCHMARK_SCORE                    NUMERIC(12,2) NOT NULL,
BENCHMARK_DTTM                     TIMESTAMP NOT NULL,
DEVIATION_FROM_SCORE               NUMERIC(12,2) NOT NULL,
CREATED_DTTM                       TIMESTAMP NOT NULL,
PRIMARY KEY (ALERT_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_ALERT_STATUS
(
ALERT_SK                           INTEGER NOT NULL,
USER_NM                            VARCHAR(40) NOT NULL,
ACTIVE_FLG                         INTEGER NOT NULL,
PRIMARY KEY (ALERT_SK,USER_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_MODEL_GROUP
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SEASON                             VARCHAR(20),
TAG                                VARCHAR(40),
DEMAND_MODEL_TYPE                  VARCHAR(20),
PRIMARY KEY (MODEL_GROUP_ID)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_MONITORING_FILTER_PROD_GEO
(
PROD_GEO_SK                        INTEGER NOT NULL,
PROD_GEO_FLG                       INTEGER NOT NULL,
PRIMARY KEY (PROD_GEO_SK,PROD_GEO_FLG)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_MONITORING_GEO
(
GEO_HIER_SK                        INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL,
PRIMARY KEY (GEO_HIER_SK,MODEL_GROUP_ID)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX MDL_GRP_ID_IX1 ON FA_MONITORING_GEO
(
MODEL_GROUP_ID
)ALLOW REVERSE SCANS
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_MONITORING_PROD
(
PROD_HIER_SK                       INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL,
PRIMARY KEY (PROD_HIER_SK,MODEL_GROUP_ID)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX MDL_GRP_ID_IX2 ON FA_MONITORING_PROD
(
MODEL_GROUP_ID
)ALLOW REVERSE SCANS
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_PRESEASON_FILTER_PROD_GEO
(
PROD_GEO_SK                        INTEGER NOT NULL,
PROD_GEO_FLG                       INTEGER NOT NULL,
PRIMARY KEY (PROD_GEO_SK,PROD_GEO_FLG)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX PROD_GEO_FLG_IX1 ON FA_PRESEASON_FILTER_PROD_GEO
(
PROD_GEO_FLG
)ALLOW REVERSE SCANS
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_PRESEASON_GEO
(
GEO_HIER_SK                        INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL,
PRIMARY KEY (GEO_HIER_SK,MODEL_GROUP_ID)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX MDL_GRP_ID_IX4 ON FA_PRESEASON_GEO
(
MODEL_GROUP_ID
)ALLOW REVERSE SCANS
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_PRESEASON_PROD
(
PROD_HIER_SK                       INTEGER NOT NULL,
MODEL_GROUP_ID                     INTEGER NOT NULL,
PRIMARY KEY (PROD_HIER_SK,MODEL_GROUP_ID)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX MDL_GRP_ID_IX5 ON FA_PRESEASON_PROD
(
MODEL_GROUP_ID
)ALLOW REVERSE SCANS
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_SCENARIO
(
SCENARIO_NM                        VARCHAR(40) NOT NULL,
SCENARIO_DESC                      VARCHAR(100),
SCENARIO_TYPE                      VARCHAR(20),
BASE_SCENARIO_FLG                  INTEGER NOT NULL,
DISABLED_FLG                       INTEGER,
PRIMARY KEY (SCENARIO_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_SCENARIO_SPEC
(
SCENARIO_NM                        VARCHAR(40) NOT NULL,
SPEC_NM                            VARCHAR(32) NOT NULL,
SPEC_TYPE                          VARCHAR(5) NOT NULL,
SPEC_TABLE_NM                      VARCHAR(32) NOT NULL,
MODEL_COMP_NM                      VARCHAR(20) NOT NULL,
SPEC_VALUE                         VARCHAR(100) NOT NULL,
PRIMARY KEY (SCENARIO_NM,SPEC_NM,SPEC_TYPE,SPEC_TABLE_NM,MODEL_COMP_NM,SPEC_VALUE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_SCENARIO_STATUS
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
DEMAND_MODEL_TYPE                  VARCHAR(20) NOT NULL,
SCORE                              NUMERIC(12,2),
WEIGHTED_MAPE                      NUMERIC(12,2),
MEDIAN_PE                          NUMERIC(12,2),
ELASTICITY_TAIL                    NUMERIC(12,2),
STATUS                             VARCHAR(10),
PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,DEMAND_MODEL_TYPE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_SCORE
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
DEMAND_MODEL_TYPE                  VARCHAR(20) NOT NULL,
BENCHMARK_FLG                      INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
SCORE                              NUMERIC(12,2),
WEIGHTED_MAPE                      NUMERIC(12,2),
MEDIAN_PE                          NUMERIC(12,2),
ELASTICITY_TAIL                    NUMERIC(12,2),
PRIMARY KEY (MODEL_GROUP_ID,DEMAND_MODEL_TYPE,BENCHMARK_FLG,DATE_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_SPEC
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SPEC_NM                            VARCHAR(32) NOT NULL,
SPEC_VALUE                         VARCHAR(100),
PRIMARY KEY (MODEL_GROUP_ID,SPEC_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID00000B;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID00000B;
%put ERROR- Description                              : Add FA Tables (Moving from SAS to RDBMS);
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID00000B;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID00000B",
"Add FA Tables (Moving from SAS to RDBMS)",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID00000B:;
 
 
* End of changes for CHANGE_ID:ID00000B;
 
 
***********************************************************************************************;
*************************************  End Change ID00000B ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID00000C ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID00000C;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID00000C")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID00000C;
%goto ID00000C;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID00000C;
* Insert record into change management table for CHANGE_ID: ID00000C;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID00000C",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID00000C;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE PROCESS_STATUS ADD SCOPE_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PROCESS_STATUS ADD SCOPE_ASSOC_CD INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PROCESS_STATUS ADD PROCESS_TYPE VARCHAR(80)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
 
ALTER TABLE PROCESS_STATUS ADD SCOPE_SK INTEGER;
 
 
ALTER TABLE PROCESS_STATUS ADD SCOPE_ASSOC_CD INTEGER;
 
 
ALTER TABLE PROCESS_STATUS ADD PROCESS_TYPE VARCHAR(80);
 
 
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE PROCESS_STATUS ADD COLUMN SCOPE_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PROCESS_STATUS ADD COLUMN SCOPE_ASSOC_CD INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PROCESS_STATUS ADD COLUMN PROCESS_TYPE VARCHAR(80)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID00000C;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID00000C;
%put ERROR- Description                              : Update PROCESS_... tables to support request persistence;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID00000C;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID00000C",
"Update PROCESS_... tables to support request persistence",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID00000C:;
 
 
* End of changes for CHANGE_ID:ID00000C;
 
 
***********************************************************************************************;
*************************************  End Change ID00000C ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID669058 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID669058;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID669058")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID669058;
%goto ID669058;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID669058;
* Insert record into change management table for CHANGE_ID: ID669058;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID669058",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID669058;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS ADD (MEAN_PE NUMERIC(12,2))
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE ADD (MEAN_PE NUMERIC(12,2))
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD MEAN_PE NUMERIC(12,2);
 
 
ALTER TABLE FA_SCORE ADD MEAN_PE NUMERIC(12,2);
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS ADD COLUMN MEAN_PE NUMERIC(12,2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE ADD COLUMN MEAN_PE NUMERIC(12,2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
REORG TABLE FA_SCENARIO
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
REORG TABLE FA_SCORE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID669058;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID669058;
%put ERROR- Description                              : Add MEAN_PE column to FA tables;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID669058;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID669058",
"Add MEAN_PE column to FA tables",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID669058:;
 
 
* End of changes for CHANGE_ID:ID669058;
 
 
***********************************************************************************************;
*************************************  End Change ID669058 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID669442 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID669442;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID669442")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID669442;
%goto ID669442;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID669442;
* Insert record into change management table for CHANGE_ID: ID669442;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID669442",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID669442;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE MA_SCENARIO
(
SCENARIO_NM                        VARCHAR(40) NOT NULL,
USER_NM                            VARCHAR(60) NOT NULL,
SCENARIO_DESC                      VARCHAR(100),
SCENARIO_TYPE                      VARCHAR(20),
BASE_SCENARIO_FLG                  INTEGER NOT NULL,
DISABLED_FLG                       INTEGER,
PRIMARY KEY (SCENARIO_NM,USER_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MA_SCENARIO_SPEC
(
SCENARIO_NM                        VARCHAR(40) NOT NULL,
SPEC_NM                            VARCHAR(32) NOT NULL,
SPEC_TYPE                          VARCHAR(5) NOT NULL,
SPEC_TABLE_NM                      VARCHAR(32) NOT NULL,
MODEL_COMP_NM                      VARCHAR(20) NOT NULL,
SPEC_VALUE                         VARCHAR(100) NOT NULL,
USER_NM                            VARCHAR(60) NOT NULL,
PRIMARY KEY (SCENARIO_NM,SPEC_NM,SPEC_TYPE,SPEC_TABLE_NM,MODEL_COMP_NM,SPEC_VALUE,USER_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MA_MODEL_GROUP
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
USER_NM                            VARCHAR(60) NOT NULL,
SEASON                             VARCHAR(20),
TAG                                VARCHAR(40),
DEMAND_MODEL_TYPE                  VARCHAR(20),
PRIMARY KEY (MODEL_GROUP_ID,USER_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
CREATE TABLE MA_MODEL_GROUP
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
USER_NM                            VARCHAR(60) NOT NULL,
SEASON                             VARCHAR(20),
TAG                                VARCHAR(40),
DEMAND_MODEL_TYPE                  VARCHAR(20)
)
;
 
 
 
ALTER TABLE MA_MODEL_GROUP  add CONSTRAINT PRIM_KEY  PRIMARY KEY (MODEL_GROUP_ID,USER_NM);
 
 
 
 
CREATE TABLE MA_SCENARIO
(
SCENARIO_NM                        VARCHAR(40) NOT NULL,
USER_NM                            VARCHAR(60) NOT NULL,
SCENARIO_DESC                      VARCHAR(100),
SCENARIO_TYPE                      VARCHAR(20),
BASE_SCENARIO_FLG                  INTEGER NOT NULL,
DISABLED_FLG                       INTEGER
)
;
 
 
 
ALTER TABLE MA_SCENARIO  add CONSTRAINT PRIM_KEY  PRIMARY KEY (SCENARIO_NM,USER_NM);
 
 
 
 
CREATE TABLE MA_SCENARIO_SPEC
(
SCENARIO_NM                        VARCHAR(40) NOT NULL,
SPEC_NM                            VARCHAR(32) NOT NULL,
SPEC_TYPE                          VARCHAR(5) NOT NULL,
SPEC_TABLE_NM                      VARCHAR(32) NOT NULL,
MODEL_COMP_NM                      VARCHAR(20) NOT NULL,
SPEC_VALUE                         VARCHAR(100) NOT NULL,
USER_NM                            VARCHAR(60) NOT NULL
)
;
 
 
 
ALTER TABLE MA_SCENARIO_SPEC  add CONSTRAINT PRIM_KEY  PRIMARY KEY (SCENARIO_NM,SPEC_NM,SPEC_TYPE,SPEC_TABLE_NM,MODEL_COMP_NM,SPEC_VALUE,USER_NM);
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MA_SCENARIO
(
SCENARIO_NM                        VARCHAR(40) NOT NULL,
USER_NM                            VARCHAR(60) NOT NULL,
SCENARIO_DESC                      VARCHAR(100),
SCENARIO_TYPE                      VARCHAR(20),
BASE_SCENARIO_FLG                  INTEGER NOT NULL,
DISABLED_FLG                       INTEGER,
PRIMARY KEY (SCENARIO_NM,USER_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MA_SCENARIO_SPEC
(
SCENARIO_NM                        VARCHAR(40) NOT NULL,
SPEC_NM                            VARCHAR(32) NOT NULL,
SPEC_TYPE                          VARCHAR(5) NOT NULL,
SPEC_TABLE_NM                      VARCHAR(32) NOT NULL,
MODEL_COMP_NM                      VARCHAR(20) NOT NULL,
SPEC_VALUE                         VARCHAR(100) NOT NULL,
USER_NM                            VARCHAR(60) NOT NULL,
PRIMARY KEY (SCENARIO_NM,SPEC_NM,SPEC_TYPE,SPEC_TABLE_NM,MODEL_COMP_NM,SPEC_VALUE,USER_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MA_MODEL_GROUP
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
USER_NM                            VARCHAR(60) NOT NULL,
SEASON                             VARCHAR(20),
TAG                                VARCHAR(40),
DEMAND_MODEL_TYPE                  VARCHAR(20),
PRIMARY KEY (MODEL_GROUP_ID,USER_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID669442;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID669442;
%put ERROR- Description                              : MA tables;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID669442;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID669442",
"MA tables",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID669442:;
 
 
* End of changes for CHANGE_ID:ID669442;
 
 
***********************************************************************************************;
*************************************  End Change ID669442 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID661595 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID661595;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID661595")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID661595;
%goto ID661595;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID661595;
* Insert record into change management table for CHANGE_ID: ID661595;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID661595",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID661595;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE TABLE HISTORICAL_FIT
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
SALES_UNITS                        NUMERIC(12,2),
PRICE_RATIO                        NUMERIC(12,2),
SALES_FITTING_UNITS                NUMERIC(12,2),
BASE_UNITS                         NUMERIC(12,2),
DEMAND_MODEL_TYPE                  VARCHAR(20),
PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,GEO_HIER_SK,PROD_HIER_SK,DATE_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE HISTORICAL_FIT_ACCURACY
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
DATA_LVL_ID                        INTEGER,
SALES_FITTING_UNITS                NUMERIC(12,2),
SALES_UNITS                        NUMERIC(12,2),
FIT_MAPE                           NUMERIC(12,2),
FIT_APE                            NUMERIC(12,2),
FIT_RMSE                           NUMERIC(12,2),
DEMAND_MODEL_TYPE                  VARCHAR(20),
PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,GEO_HIER_SK,PROD_HIER_SK,DATE_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE HOLDOUT_FORECAST
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
SALES_UNC_FCST_UNITS               NUMERIC(12,2),
SALES_UNITS                        NUMERIC(12,2),
CLOSE_INV_UNITS                    NUMERIC(12,2),
PRICE_RATIO                        NUMERIC(12,2),
RECEIPT_UNITS                      NUMERIC(12,2),
SALES_FCST_UNITS                   NUMERIC(12,2),
BASE_UNITS                         NUMERIC(12,2),
START_DT                           DATE,
DEMAND_MODEL_TYPE                  VARCHAR(20),
PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,GEO_HIER_SK,PROD_HIER_SK,DATE_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE HOLDOUT_FORECAST_ACCURACY
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
SALES_UNC_FCST_UNITS               NUMERIC(12,2),
SALES_FCST_UNITS                   NUMERIC(12,2),
SALES_UNITS                        NUMERIC(12,2),
CLOSE_INV_UNITS                    NUMERIC(12,2),
ACTUAL_SELL_THROUGH                NUMERIC(12,2),
CONSTRAINED_SELL_THROUGH           NUMERIC(12,2),
CONSTRAINED_FCST_APE               NUMERIC(12,2),
CONSTRAINED_FCST_MAPE              NUMERIC(12,2),
CONSTRAINED_FCST_RMSE              NUMERIC(12,2),
UNCONSTRAINED_SELL_THROUGH         NUMERIC(12,2),
UNCONSTRAINED_FCST_APE             NUMERIC(12,2),
UNCONSTRAINED_FCST_MAPE            NUMERIC(12,2),
UNCONSTRAINED_FCST_RMSE            NUMERIC(12,2),
UNACCOUNTED_SALES_UNITS            NUMERIC(12,2),
DEMAND_MODEL_TYPE                  VARCHAR(20),
PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,GEO_HIER_SK,PROD_HIER_SK,DATE_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
CREATE TABLE HISTORICAL_FIT
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
SALES_UNITS                        NUMERIC(12,2),
PRICE_RATIO                        NUMERIC(12,2),
SALES_FITTING_UNITS                NUMERIC(12,2),
BASE_UNITS                         NUMERIC(12,2),
DEMAND_MODEL_TYPE                  VARCHAR(20),
SALES_UNITS_UNACCOUNTED            NUMERIC(12,2)
)
;
 
 
 
ALTER TABLE HISTORICAL_FIT  add CONSTRAINT PRIM_KEY  PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,GEO_HIER_SK,PROD_HIER_SK,DATE_SK);
 
 
 
 
CREATE TABLE HISTORICAL_FIT_ACCURACY
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
DATA_LVL_ID                        INTEGER,
SALES_FITTING_UNITS                NUMERIC(12,2),
SALES_UNITS                        NUMERIC(12,2),
FIT_MAPE                           NUMERIC(12,2),
FIT_APE                            NUMERIC(12,2),
FIT_RMSE                           NUMERIC(12,2),
DEMAND_MODEL_TYPE                  VARCHAR(20)
)
;
 
 
 
ALTER TABLE HISTORICAL_FIT_ACCURACY  add CONSTRAINT PRIM_KEY  PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,GEO_HIER_SK,PROD_HIER_SK,DATE_SK);
 
 
 
 
CREATE TABLE HOLDOUT_FORECAST
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
SALES_UNC_FCST_UNITS               NUMERIC(12,2),
SALES_UNITS                        NUMERIC(12,2),
CLOSE_INV_UNITS                    NUMERIC(12,2),
PRICE_RATIO                        NUMERIC(12,2),
RECEIPT_UNITS                      NUMERIC(12,2),
SALES_FCST_UNITS                   NUMERIC(12,2),
BASE_UNITS                         NUMERIC(12,2),
START_DT                           DATE      FORMAT=&DTFMT    INFORMAT=&DTFMT  ,
DEMAND_MODEL_TYPE                  VARCHAR(20)
)
;
 
 
 
ALTER TABLE HOLDOUT_FORECAST  add CONSTRAINT PRIM_KEY  PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,GEO_HIER_SK,PROD_HIER_SK,DATE_SK);
 
 
 
 
CREATE TABLE HOLDOUT_FORECAST_ACCURACY
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
SALES_UNC_FCST_UNITS               NUMERIC(12,2),
SALES_FCST_UNITS                   NUMERIC(12,2),
SALES_UNITS                        NUMERIC(12,2),
CLOSE_INV_UNITS                    NUMERIC(12,2),
ACTUAL_SELL_THROUGH                NUMERIC(12,2),
CONSTRAINED_SELL_THROUGH           NUMERIC(12,2),
CONSTRAINED_FCST_APE               NUMERIC(12,2),
CONSTRAINED_FCST_MAPE              NUMERIC(12,2),
CONSTRAINED_FCST_RMSE              NUMERIC(12,2),
UNCONSTRAINED_SELL_THROUGH         NUMERIC(12,2),
UNCONSTRAINED_FCST_APE             NUMERIC(12,2),
UNCONSTRAINED_FCST_MAPE            NUMERIC(12,2),
UNCONSTRAINED_FCST_RMSE            NUMERIC(12,2),
UNACCOUNTED_SALES_UNITS            NUMERIC(12,2),
DEMAND_MODEL_TYPE                  VARCHAR(20)
)
;
 
 
 
ALTER TABLE HOLDOUT_FORECAST_ACCURACY  add CONSTRAINT PRIM_KEY  PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,GEO_HIER_SK,PROD_HIER_SK,DATE_SK);
 
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE TABLE HISTORICAL_FIT
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
SALES_UNITS                        NUMERIC(12,2),
PRICE_RATIO                        NUMERIC(12,2),
SALES_FITTING_UNITS                NUMERIC(12,2),
BASE_UNITS                         NUMERIC(12,2),
DEMAND_MODEL_TYPE                  VARCHAR(20),
PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,GEO_HIER_SK,PROD_HIER_SK,DATE_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE HISTORICAL_FIT_ACCURACY
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
DATA_LVL_ID                        INTEGER,
SALES_FITTING_UNITS                NUMERIC(12,2),
SALES_UNITS                        NUMERIC(12,2),
FIT_MAPE                           NUMERIC(12,2),
FIT_APE                            NUMERIC(12,2),
FIT_RMSE                           NUMERIC(12,2),
DEMAND_MODEL_TYPE                  VARCHAR(20),
PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,GEO_HIER_SK,PROD_HIER_SK,DATE_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE HOLDOUT_FORECAST
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
SALES_UNC_FCST_UNITS               NUMERIC(12,2),
SALES_UNITS                        NUMERIC(12,2),
CLOSE_INV_UNITS                    NUMERIC(12,2),
PRICE_RATIO                        NUMERIC(12,2),
RECEIPT_UNITS                      NUMERIC(12,2),
SALES_FCST_UNITS                   NUMERIC(12,2),
BASE_UNITS                         NUMERIC(12,2),
START_DT                           DATE,
DEMAND_MODEL_TYPE                  VARCHAR(20),
PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,GEO_HIER_SK,PROD_HIER_SK,DATE_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE HOLDOUT_FORECAST_ACCURACY
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SCENARIO_NM                        VARCHAR(40) NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
DATE_SK                            INTEGER NOT NULL,
SALES_UNC_FCST_UNITS               NUMERIC(12,2),
SALES_FCST_UNITS                   NUMERIC(12,2),
SALES_UNITS                        NUMERIC(12,2),
CLOSE_INV_UNITS                    NUMERIC(12,2),
ACTUAL_SELL_THROUGH                NUMERIC(12,2),
CONSTRAINED_SELL_THROUGH           NUMERIC(12,2),
CONSTRAINED_FCST_APE               NUMERIC(12,2),
CONSTRAINED_FCST_MAPE              NUMERIC(12,2),
CONSTRAINED_FCST_RMSE              NUMERIC(12,2),
UNCONSTRAINED_SELL_THROUGH         NUMERIC(12,2),
UNCONSTRAINED_FCST_APE             NUMERIC(12,2),
UNCONSTRAINED_FCST_MAPE            NUMERIC(12,2),
UNCONSTRAINED_FCST_RMSE            NUMERIC(12,2),
UNACCOUNTED_SALES_UNITS            NUMERIC(12,2),
DEMAND_MODEL_TYPE                  VARCHAR(20),
PRIMARY KEY (MODEL_GROUP_ID,SCENARIO_NM,GEO_HIER_SK,PROD_HIER_SK,DATE_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID661595;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID661595;
%put ERROR- Description                              : FA tables Historical Fit and Holdout Forecast;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID661595;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID661595",
"FA tables Historical Fit and Holdout Forecast",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID661595:;
 
 
* End of changes for CHANGE_ID:ID661595;
 
 
***********************************************************************************************;
*************************************  End Change ID661595 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID661123_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID661123_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID661123_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID661123_1;
%goto ID661123_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID661123_1;
* Insert record into change management table for CHANGE_ID: ID661123_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID661123_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID661123_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM FA_SPEC WHERE SPEC_NM = 'HOLDOUT_DETAILS_PROD_LVL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO FA_SPEC (MODEL_GROUP_ID, SPEC_NM, SPEC_VALUE) VALUES (-1,'HOLDOUT_DETAILS_PROD_LVL','1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
DELETE FROM FA_SPEC WHERE SPEC_NM = 'HOLDOUT_DETAILS_GEO_LVL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO FA_SPEC (MODEL_GROUP_ID, SPEC_NM, SPEC_VALUE) VALUES (-1,'HOLDOUT_DETAILS_GEO_LVL','1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM FA_SPEC WHERE SPEC_NM = 'HOLDOUT_DETAILS_PROD_LVL';
 
 
INSERT INTO FA_SPEC (MODEL_GROUP_ID, SPEC_NM, SPEC_VALUE) VALUES (-1,'HOLDOUT_DETAILS_PROD_LVL','1');
 
 
DELETE FROM FA_SPEC WHERE SPEC_NM = 'HOLDOUT_DETAILS_GEO_LVL';
 
 
INSERT INTO FA_SPEC (MODEL_GROUP_ID, SPEC_NM, SPEC_VALUE) VALUES (-1,'HOLDOUT_DETAILS_GEO_LVL','1');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID661123_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID661123_1;
%put ERROR- Description                              : Add HOLDOUT_DETAILS_PROD_LVL and HOLDOUT_DETAILS_GEO_LVL FA specs;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID661123_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID661123_1",
"Add HOLDOUT_DETAILS_PROD_LVL and HOLDOUT_DETAILS_GEO_LVL FA specs",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID661123_1:;
 
 
* End of changes for CHANGE_ID:ID661123_1;
 
 
***********************************************************************************************;
*************************************  End Change ID661123_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID673040 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID673040;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID673040")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID673040;
%goto ID673040;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID673040;
* Insert record into change management table for CHANGE_ID: ID673040;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID673040",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID673040;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE FCST_EXPORT_INPUT
(
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
GEO_HIER_ASSOC_CD                  INTEGER NOT NULL,
UNCONSTR_FLG                       INTEGER,
FCST_WEEKS                         INTEGER,
PRIMARY KEY (GEO_HIER_SK,PROD_HIER_SK,GEO_HIER_ASSOC_CD)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
CREATE TABLE FCST_EXPORT_INPUT
(
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
GEO_HIER_ASSOC_CD                  INTEGER NOT NULL,
UNCONSTR_FLG                       INTEGER,
FCST_WEEKS                         INTEGER
)
;
 
 
 
ALTER TABLE FCST_EXPORT_INPUT  add CONSTRAINT PRIM_KEY  PRIMARY KEY (GEO_HIER_SK,PROD_HIER_SK,GEO_HIER_ASSOC_CD);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID673040;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID673040;
%put ERROR- Description                              : Input into C code for Forecast Export;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID673040;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID673040",
"Input into C code for Forecast Export",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID673040:;
 
 
* End of changes for CHANGE_ID:ID673040;
 
 
***********************************************************************************************;
*************************************  End Change ID673040 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID674812 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID674812;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID674812")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID674812;
%goto ID674812;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID674812;
* Insert record into change management table for CHANGE_ID: ID674812;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID674812",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID674812;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE PROCESS_STATUS ADD RESULT_VALUE VARCHAR(1024)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PROCESS_STATUS ADD RESULT_EXCEPTION VARCHAR(255)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
 
ALTER TABLE PROCESS_STATUS ADD RESULT_VALUE VARCHAR(1024);
 
 
ALTER TABLE PROCESS_STATUS ADD RESULT_EXCEPTION VARCHAR(255);
 
 
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE PROCESS_STATUS ADD COLUMN RESULT_VALUE VARCHAR(1024)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PROCESS_STATUS ADD COLUMN RESULT_EXCEPTION VARCHAR(255)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID674812;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID674812;
%put ERROR- Description                              : Added persistence of TKMIServer requests results;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID674812;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID674812",
"Added persistence of TKMIServer requests results",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID674812:;
 
 
* End of changes for CHANGE_ID:ID674812;
 
 
***********************************************************************************************;
*************************************  End Change ID674812 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID679163 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID679163;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID679163")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID679163;
%goto ID679163;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID679163;
* Insert record into change management table for CHANGE_ID: ID679163;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID679163",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID679163;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN DROP COLUMN AUTO_EVAL_OPT_FLG
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%di_util_drop_constraint(m_lib=di_trans, m_table=mdo_plan, m_column=%str(auto_eval_opt_flg), m_constraint=%str(not null));
 
 
 
proc sql;
 
 
ALTER TABLE MDO_PLAN DROP COLUMN AUTO_EVAL_OPT_FLG;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN DROP COLUMN AUTO_EVAL_OPT_FLG
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID679163;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID679163;
%put ERROR- Description                              : Remove the plan settings AUTO_EVAL_OPT_FLG from MDO_PLAN;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID679163;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID679163",
"Remove the plan settings AUTO_EVAL_OPT_FLG from MDO_PLAN",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID679163:;
 
 
* End of changes for CHANGE_ID:ID679163;
 
 
***********************************************************************************************;
*************************************  End Change ID679163 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID675652 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID675652;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID675652")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID675652;
%goto ID675652;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID675652;
* Insert record into change management table for CHANGE_ID: ID675652;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID675652",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID675652;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
 
%let m_sql_statement = %str(
alter table GEO_PROD_AGG drop primary key drop index
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Create Unique Index Geo_Prod_Agg_PK On Geo_Prod_Agg(Prod_Hier_Sk, Geo_Hier_Sk) Nologging Parallel 20
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Alter Table Geo_Prod_Agg Add Constraint Geo_Prod_Agg_Pk Primary Key (Prod_Hier_Sk, Geo_Hier_Sk) using index Geo_Prod_Agg_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table GEO_PROD_MTS drop primary key drop index
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Create Unique Index Geo_Prod_Mts_PK On Geo_Prod_Mts(Prod_Hier_Sk, Geo_Hier_Sk) Nologging Parallel 20
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Alter Table Geo_Prod_Mts Add Constraint Geo_Prod_Mts_Pk Primary Key (Prod_Hier_Sk, Geo_Hier_Sk) using index Geo_Prod_Mts_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table MPLN_RESULT drop primary key drop index
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Create Unique Index Mpln_Result_PK On Mpln_Result(Agg_Cd, Mdo_Plan_Sk) Nologging Parallel
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Alter Table Mpln_Result Add Constraint Mpln_Result_Pk Primary Key (Agg_Cd, Mdo_Plan_Sk) using Index Mpln_Result_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table MPLN_GEO_PROD_RESULT drop primary key drop index
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Create Unique Index Mpln_Geo_Prod_Result_PK On Mpln_Geo_Prod_Result(Agg_Cd, Mdo_Plan_Sk, Geo_Hier_Sk,Prod_Hier_Sk) Nologging Parallel 20
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Alter Table Mpln_Geo_Prod_Result Add Constraint Mpln_Geo_Prod_Result_Pk Primary Key (Agg_Cd, Mdo_Plan_Sk, Geo_Hier_Sk,Prod_Hier_Sk)  using index Mpln_Geo_Prod_Result_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table mpln_actual_mts drop primary key drop index
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Create Unique Index Mpln_Actual_Mts_PK On Mpln_Actual_Mts(Agg_Cd, Mdo_Plan_Group_Sk) Nologging Parallel
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Alter Table Mpln_Actual_Mts Add Constraint Mpln_Actual_Mts_Pk Primary Key (Agg_Cd, Mdo_Plan_Group_Sk) using Index Mpln_Actual_Mts_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table mpln_geo_prod_faw_mts drop primary key drop index
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Create Unique Index Mpln_Geo_Prod_Faw_Mts_PK On Mpln_Geo_Prod_Faw_Mts(Mdo_Plan_Sk, Prod_Hier_Sk, Geo_Hier_Sk) Nologging Parallel
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Alter Table Mpln_Geo_Prod_Faw_Mts Add Constraint Mpln_Geo_Prod_Faw_Mts_Pk Primary Key (Mdo_Plan_Sk, Prod_Hier_Sk, Geo_Hier_Sk) using Index Mpln_Geo_Prod_Faw_Mts_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table mpln_geo_prod_mts drop primary key drop index
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Create Unique Index Mpln_Geo_Prod_Mts_PK On Mpln_Geo_Prod_Mts(Agg_Cd, Mdo_Plan_Sk, Geo_Hier_Sk,Prod_Hier_Sk) Nologging Parallel 20
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Alter Table Mpln_Geo_Prod_Mts Add Constraint Mpln_Geo_Prod_Mts_Pk Primary Key (Agg_Cd, Mdo_Plan_Sk, Geo_Hier_Sk,Prod_Hier_Sk) using index Mpln_Geo_Prod_Mts_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table mpln_geo_prod_agg drop primary key drop index
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Create Unique Index Mpln_Geo_Prod_Agg_PK On Mpln_Geo_Prod_Agg(Agg_Cd, Mdo_Plan_Sk, Geo_Hier_Sk,Prod_Hier_Sk) Nologging Parallel 20
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Alter Table Mpln_Geo_Prod_Agg Add Constraint Mpln_Geo_Prod_Agg_Pk Primary Key (Agg_Cd, Mdo_Plan_Sk, Geo_Hier_Sk,Prod_Hier_Sk) using index Mpln_Geo_Prod_Agg_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table mpln_geo_prod_actual_mts drop primary key drop index
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Create Unique Index Mpln_Geo_Prod_Actual_Mts_PK On Mpln_Geo_Prod_Actual_Mts(Agg_Cd, Mdo_Plan_Group_Sk, Geo_Hier_Sk,Prod_Hier_Sk) Nologging Parallel 20
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Alter Table Mpln_Geo_Prod_Actual_Mts  Add Constraint Mpln_Geo_Prod_Actual_Mts_Pk Primary Key (Agg_Cd, Mdo_Plan_Group_Sk, Geo_Hier_Sk, Prod_Hier_Sk)  using Index Mpln_Geo_Prod_Actual_Mts_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table mpln_period_awr_mts drop primary key drop index
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Create Unique Index Mpln_Period_Awr_Mts_PK
On Mpln_Period_Awr_Mts(Mdo_Plan_Sk, Prod_Hier_Sk, Start_Dt)
Nologging Parallel 20
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Alter Table Mpln_Period_Awr_Mts
Add Constraint Mpln_Period_Awr_Mts_Pk Primary Key (Mdo_Plan_Sk, Prod_Hier_Sk, Start_Dt)  using Index Mpln_Period_Awr_Mts_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table mpln_price_chg drop primary key drop index
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Create Unique Index Mpln_Price_Chg_PK On Mpln_Price_Chg(Mdo_Plan_Sk, Geo_Hier_Sk, Prod_Hier_Sk, Start_Dt) Nologging Parallel
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Alter Table Mpln_Price_Chg
Add Constraint Mpln_Price_Chg_Pk Primary Key (Mdo_Plan_Sk, Geo_Hier_Sk, Prod_Hier_Sk, Start_Dt) using Index Mpln_Price_Chg_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table mpln_price_chg_appr drop primary key drop index
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Create Unique Index Mpln_Price_Chg_Appr_PK
On Mpln_Price_Chg_Appr(Mdo_Plan_Sk, Geo_Hier_Sk, Start_Dt, Prod_Hier_Sk)
Nologging Parallel 20
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Alter Table Mpln_Price_Chg_Appr
Add Constraint Mpln_Price_Chg_Appr_Pk Primary Key (Mdo_Plan_Sk, Geo_Hier_Sk, Start_Dt, Prod_Hier_Sk) using Index Mpln_Price_Chg_Appr_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
/* This change only applies to Oracle.  Not needed in DB2. */
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID675652;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID675652;
%put ERROR- Description                              : Rename PK and index names (mdo optimization target tables);
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID675652;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID675652",
"Rename PK and index names (mdo optimization target tables)",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID675652:;
 
 
* End of changes for CHANGE_ID:ID675652;
 
 
***********************************************************************************************;
*************************************  End Change ID675652 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID684088 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID684088;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID684088")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID684088;
%goto ID684088;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID684088;
* Insert record into change management table for CHANGE_ID: ID684088;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID684088",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID684088;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS ADD CREATED_DTTM DATE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD CREATED_DTTM DATE;
 
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS ADD COLUMN CREATED_DTTM TIMESTAMP
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
REORG TABLE FA_SCENARIO_STATUS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID684088;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID684088;
%put ERROR- Description                              : Add column to FA_SCENARIO_STATUS table;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID684088;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID684088",
"Add column to FA_SCENARIO_STATUS table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID684088:;
 
 
* End of changes for CHANGE_ID:ID684088;
 
 
***********************************************************************************************;
*************************************  End Change ID684088 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID687879 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID687879;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID687879")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID687879;
%goto ID687879;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID687879;
* Insert record into change management table for CHANGE_ID: ID687879;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID687879",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID687879;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE HISTORICAL_FIT ADD SALES_UNITS_UNACCOUNTED NUMERIC(12,2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE HISTORICAL_FIT ADD SALES_UNITS_UNACCOUNTED NUMERIC(12,2);
 
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE HISTORICAL_FIT ADD COLUMN SALES_UNITS_UNACCOUNTED NUMERIC(12,2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
REORG TABLE HISTORICAL_FIT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID687879;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID687879;
%put ERROR- Description                              : Add column to HISTORICAL_FIT table;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID687879;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID687879",
"Add column to HISTORICAL_FIT table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID687879:;
 
 
* End of changes for CHANGE_ID:ID687879;
 
 
***********************************************************************************************;
*************************************  End Change ID687879 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID688960 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID688960;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID688960")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID688960;
%goto ID688960;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID688960;
* Insert record into change management table for CHANGE_ID: ID688960;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID688960",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID688960;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM FA_SPEC WHERE SPEC_NM = 'PCT_TAIL_CUTOFF'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO FA_SPEC (MODEL_GROUP_ID, SPEC_NM, SPEC_VALUE) VALUES (-1,'PCT_TAIL_CUTOFF','1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM FA_SPEC WHERE SPEC_NM = 'PCT_TAIL_CUTOFF';
 
 
INSERT INTO FA_SPEC (MODEL_GROUP_ID, SPEC_NM, SPEC_VALUE) VALUES (-1,'PCT_TAIL_CUTOFF','1');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID688960;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID688960;
%put ERROR- Description                              : Add PCT_TAIL_CUTOFF FA spec;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID688960;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID688960",
"Add PCT_TAIL_CUTOFF FA spec",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID688960:;
 
 
* End of changes for CHANGE_ID:ID688960;
 
 
***********************************************************************************************;
*************************************  End Change ID688960 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID688967 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID688967;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID688967")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID688967;
%goto ID688967;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID688967;
* Insert record into change management table for CHANGE_ID: ID688967;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID688967",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID688967;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM FA_SPEC WHERE SPEC_NM = 'MIN_LIFE_FILTER'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO FA_SPEC (MODEL_GROUP_ID, SPEC_NM, SPEC_VALUE) VALUES (-1,'MIN_LIFE_FILTER','8')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM FA_SPEC WHERE SPEC_NM = 'MIN_LIFE_FILTER';
 
 
INSERT INTO FA_SPEC (MODEL_GROUP_ID, SPEC_NM, SPEC_VALUE) VALUES (-1,'MIN_LIFE_FILTER','8');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID688967;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID688967;
%put ERROR- Description                              : Add MIN_LIFE_FILTER FA spec;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID688967;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID688967",
"Add MIN_LIFE_FILTER FA spec",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID688967:;
 
 
* End of changes for CHANGE_ID:ID688967;
 
 
***********************************************************************************************;
*************************************  End Change ID688967 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID690047 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID690047;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID690047")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID690047;
%goto ID690047;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID690047;
* Insert record into change management table for CHANGE_ID: ID690047;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID690047",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID690047;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS ADD PCT_ELASTICITY_DEFAULTED NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS RENAME COLUMN MEAN_PE TO WEIGHTED_MEAN_PE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SPEC MODIFY SPEC_VALUE VARCHAR(200)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD PCT_ELASTICITY_DEFAULTED NUMERIC(12,4);
 
 
ALTER TABLE FA_SPEC MODIFY SPEC_VALUE VARCHAR(200);
 
 
quit;
 
 
 
proc datasets library=&m_di_trans nolist;
 
 
modify FA_SCENARIO_STATUS ;
 
 
rename MEAN_PE=WEIGHTED_MEAN_PE;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS ADD COLUMN PCT_ELASTICITY_DEFAULTED NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS DROP COLUMN MEAN_PE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS ADD  COLUMN WEIGHTED_MEAN_PE NUMERIC(12,2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SPEC ALTER COLUMN SPEC_VALUE SET DATA TYPE VARCHAR(200)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
REORG TABLE FA_SCENARIO_STATUS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID690047;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID690047;
%put ERROR- Description                              : Add new column PCT_ELASTICITY_DEFAULTED;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID690047;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID690047",
"Add new column PCT_ELASTICITY_DEFAULTED",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID690047:;
 
 
* End of changes for CHANGE_ID:ID690047;
 
 
***********************************************************************************************;
*************************************  End Change ID690047 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID693691 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID693691;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID693691")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID693691;
%goto ID693691;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID693691;
* Insert record into change management table for CHANGE_ID: ID693691;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID693691",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID693691;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM FA_SPEC WHERE SPEC_NM = 'RUN_FA_MONITORING'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO FA_SPEC (MODEL_GROUP_ID, SPEC_NM, SPEC_VALUE) VALUES (-1,'RUN_FA_MONITORING','0')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM FA_SPEC WHERE SPEC_NM = 'RUN_FA_MONITORING';
 
 
INSERT INTO FA_SPEC (MODEL_GROUP_ID, SPEC_NM, SPEC_VALUE) VALUES (-1,'RUN_FA_MONITORING','0');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID693691;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID693691;
%put ERROR- Description                              : Add RUN_FA_MONITORING FA spec;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID693691;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID693691",
"Add RUN_FA_MONITORING FA spec",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID693691:;
 
 
* End of changes for CHANGE_ID:ID693691;
 
 
***********************************************************************************************;
*************************************  End Change ID693691 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID690047_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID690047_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID690047_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID690047_1;
%goto ID690047_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID690047_1;
* Insert record into change management table for CHANGE_ID: ID690047_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID690047_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID690047_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE ADD PCT_ELASTICITY_DEFAULTED NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE RENAME COLUMN MEAN_PE TO WEIGHTED_MEAN_PE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
ALTER TABLE FA_SCORE ADD PCT_ELASTICITY_DEFAULTED NUMERIC(12,4);
 
 
quit;
 
 
 
proc datasets library=&m_di_trans nolist;
 
 
modify FA_SCORE ;
 
 
rename MEAN_PE=WEIGHTED_MEAN_PE;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE ADD PCT_ELASTICITY_DEFAULTED NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE DROP COLUMN MEAN_PE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE ADD  COLUMN WEIGHTED_MEAN_PE NUMERIC(12,2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
REORG TABLE FA_SCORE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID690047_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID690047_1;
%put ERROR- Description                              : Add new column PCT_ELASTICITY_DEFAULTED;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID690047_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID690047_1",
"Add new column PCT_ELASTICITY_DEFAULTED",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID690047_1:;
 
 
* End of changes for CHANGE_ID:ID690047_1;
 
 
***********************************************************************************************;
*************************************  End Change ID690047_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID695994 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID695994;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID695994")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID695994;
%goto ID695994;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID695994;
* Insert record into change management table for CHANGE_ID: ID695994;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID695994",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID695994;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE PRODUCT_ATTRIBUTES
(
PROD_HIER_SK          INTEGER NOT NULL,
PROD_ATTR_SK          INTEGER NOT NULL,
PROD_ATTR_VALUE       VARCHAR(40) NOT NULL,
PRIMARY KEY(PROD_HIER_SK, PROD_ATTR_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE GEOGRAPHY_ATTRIBUTES
(
GEO_HIER_SK          INTEGER NOT NULL,
GEO_ATTR_SK          INTEGER NOT NULL,
GEO_ATTR_VALUE       VARCHAR(40) NOT NULL,
PRIMARY KEY(GEO_HIER_SK, GEO_ATTR_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
 
CREATE TABLE PRODUCT_ATTRIBUTES
(
PROD_HIER_SK                       INTEGER NOT NULL,
PROD_ATTR_SK                       INTEGER NOT NULL,
PROD_ATTR_VALUE                    VARCHAR(40) NOT NULL
)
;
 
 
 
ALTER TABLE PRODUCT_ATTRIBUTES  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PROD_HIER_SK,PROD_ATTR_SK);
 
 
 
 
CREATE TABLE GEOGRAPHY_ATTRIBUTES
(
GEO_HIER_SK                        INTEGER NOT NULL,
GEO_ATTR_SK                        INTEGER NOT NULL,
GEO_ATTR_VALUE                     VARCHAR(40) NOT NULL
)
;
 
 
 
ALTER TABLE GEOGRAPHY_ATTRIBUTES  add CONSTRAINT PRIM_KEY  PRIMARY KEY (GEO_HIER_SK,GEO_ATTR_SK);
 
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE TABLE PRODUCT_ATTRIBUTES
(
PROD_HIER_SK          INTEGER NOT NULL,
PROD_ATTR_SK          INTEGER NOT NULL,
PROD_ATTR_VALUE       VARCHAR(40) NOT NULL,
PRIMARY KEY(PROD_HIER_SK, PROD_ATTR_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE GEOGRAPHY_ATTRIBUTES
(
GEO_HIER_SK          INTEGER NOT NULL,
GEO_ATTR_SK          INTEGER NOT NULL,
GEO_ATTR_VALUE       VARCHAR(40) NOT NULL,
PRIMARY KEY(GEO_HIER_SK, GEO_ATTR_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID695994;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID695994;
%put ERROR- Description                              : CRP PERFORMANCE Copy attributes tables to rdbms;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID695994;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID695994",
"CRP PERFORMANCE Copy attributes tables to rdbms",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID695994:;
 
 
* End of changes for CHANGE_ID:ID695994;
 
 
***********************************************************************************************;
*************************************  End Change ID695994 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID695068 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID695068;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID695068")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID695068;
%goto ID695068;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID695068;
* Insert record into change management table for CHANGE_ID: ID695068;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID695068",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID695068;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE TABLE MA_SPEC
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SPEC_NM                            VARCHAR(32) NOT NULL,
SPEC_VALUE                         VARCHAR(200),
USER_NM                            VARCHAR(60) NOT NULL,
PRIMARY KEY (MODEL_GROUP_ID,SPEC_NM,USER_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
CREATE TABLE MA_SPEC
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SPEC_NM                            VARCHAR(32) NOT NULL,
SPEC_VALUE                         VARCHAR(200),
USER_NM                            VARCHAR(60) NOT NULL
)
;
 
 
 
ALTER TABLE MA_SPEC  add CONSTRAINT PRIM_KEY  PRIMARY KEY (MODEL_GROUP_ID,SPEC_NM,USER_NM);
 
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE TABLE MA_SPEC
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
SPEC_NM                            VARCHAR(32) NOT NULL,
SPEC_VALUE                         VARCHAR(200),
USER_NM                            VARCHAR(60) NOT NULL,
PRIMARY KEY (MODEL_GROUP_ID,SPEC_NM,USER_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID695068;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID695068;
%put ERROR- Description                              : ADD MA_SPEC table;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID695068;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID695068",
"ADD MA_SPEC table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID695068:;
 
 
* End of changes for CHANGE_ID:ID695068;
 
 
***********************************************************************************************;
*************************************  End Change ID695068 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID699258 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID699258;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID699258")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID699258;
%goto ID699258;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID699258;
* Insert record into change management table for CHANGE_ID: ID699258;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID699258",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID699258;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM FA_SPEC WHERE SPEC_NM = 'HOLDOUT_DETAILS_TABLES'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO FA_SPEC (MODEL_GROUP_ID, SPEC_NM, SPEC_VALUE) VALUES (-1,'HOLDOUT_DETAILS_TABLES','HAA_PPE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM FA_SPEC WHERE SPEC_NM = 'HOLDOUT_DETAILS_TABLES';
 
 
INSERT INTO FA_SPEC (MODEL_GROUP_ID, SPEC_NM, SPEC_VALUE) VALUES (-1,'HOLDOUT_DETAILS_TABLES','HAA_PPE');
 
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
%let m_sql_statement = %str(
DELETE FROM FA_SPEC WHERE SPEC_NM = 'HOLDOUT_DETAILS_TABLES'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO FA_SPEC (MODEL_GROUP_ID, SPEC_NM, SPEC_VALUE) VALUES (-1,'HOLDOUT_DETAILS_TABLES','HAA_PPE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID699258;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID699258;
%put ERROR- Description                              : Add HOLDOUT_DETAILS_TABLES FA spec;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID699258;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID699258",
"Add HOLDOUT_DETAILS_TABLES FA spec",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID699258:;
 
 
* End of changes for CHANGE_ID:ID699258;
 
 
***********************************************************************************************;
*************************************  End Change ID699258 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID700983 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID700983;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID700983")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID700983;
%goto ID700983;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D2TKMI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID700983;
* Insert record into change management table for CHANGE_ID: ID700983;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID700983",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID700983;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
UPDATE FA_SPEC SET SPEC_VALUE = '8' WHERE SPEC_NM = 'HOLDOUT_PERIODS' AND MODEL_GROUP_ID = -1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
UPDATE FA_SPEC SET SPEC_VALUE = '8' WHERE SPEC_NM = 'HOLDOUT_PERIODS' AND MODEL_GROUP_ID = -1;
 
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
%let m_sql_statement = %str(
UPDATE FA_SPEC SET SPEC_VALUE = '8' WHERE SPEC_NM = 'HOLDOUT_PERIODS' AND MODEL_GROUP_ID = -1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID700983;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID700983;
%put ERROR- Description                              : Change default value to 8 for HOLDOUT_PERIODS;
%put ERROR- Version                                  : D2TKMI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID700983;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID700983",
"Change default value to 8 for HOLDOUT_PERIODS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID700983:;
 
 
* End of changes for CHANGE_ID:ID700983;
 
 
***********************************************************************************************;
*************************************  End Change ID700983 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID693806 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID693806;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID693806")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID693806;
%goto ID693806;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID693806;
* Insert record into change management table for CHANGE_ID: ID693806;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID693806",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID693806;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
alter table mdo_plan_alt_hier_prod drop primary key drop index
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Create Unique Index mdo_plan_alt_hier_prod_PK On mdo_plan_alt_hier_prod(Mdo_Plan_Sk, Prod_Hier_Sk) Nologging Parallel 20
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Alter Table mdo_plan_alt_hier_prod Add Constraint mdo_plan_alt_hier_prod_Pk Primary Key (Mdo_Plan_Sk, Prod_Hier_Sk) using index mdo_plan_alt_hier_prod_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
/* No Change */
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID693806;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID693806;
%put ERROR- Description                              : Alter table mdo_plan_alt_hier_prod;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID693806;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID693806",
"Alter table mdo_plan_alt_hier_prod",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID693806:;
 
 
* End of changes for CHANGE_ID:ID693806;
 
 
***********************************************************************************************;
*************************************  End Change ID693806 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID684780 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID684780;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID684780")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID684780;
%goto ID684780;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID684780;
* Insert record into change management table for CHANGE_ID: ID684780;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID684780",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID684780;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_PKO_PO_IMPORT START WITH 100
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
/* No Change */
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_PKO_PO_IMPORT
START WITH 100
CYCLE
MAXVALUE    2147483647
MINVALUE    1
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID684780;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID684780;
%put ERROR- Description                              : Add batch import of purchase order plans;
%put ERROR- Version                                  : M1MI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID684780;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID684780",
"Add batch import of purchase order plans",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID684780:;
 
 
* End of changes for CHANGE_ID:ID684780;
 
 
***********************************************************************************************;
*************************************  End Change ID684780 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID704238 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID704238;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID704238")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PRF_PROFILE))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_PROFILE;
%put NOTE: Change ID                             :ID704238;
%goto ID704238;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID704238;
%goto ID704238;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID704238;
* Insert record into change management table for CHANGE_ID: ID704238;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID704238",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID704238;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE PRF_PROFILE SET MANUAL_FLG = 3 WHERE MANUAL_FLG = 1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
UPDATE PRF_PROFILE SET MANUAL_FLG = 3 WHERE MANUAL_FLG = 1;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID704238;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID704238;
%put ERROR- Description                              : Avoid setting PRF_PROFILE.MANUAL_FLG = 1;
%put ERROR- Version                                  : M1MI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID704238;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID704238",
"Avoid setting PRF_PROFILE.MANUAL_FLG = 1",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID704238:;
 
 
* End of changes for CHANGE_ID:ID704238;
 
 
***********************************************************************************************;
*************************************  End Change ID704238 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID703394 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID703394;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID703394")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PRF_RSLT_SC_ACCURACY))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_RSLT_SC_ACCURACY;
%put NOTE: Change ID                             :ID703394;
%goto ID703394;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID703394;
%goto ID703394;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID703394;
* Insert record into change management table for CHANGE_ID: ID703394;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID703394",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID703394;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE PRF_RSLT_SC_ACCURACY SET TRN_ACCURACY = 1 WHERE TRN_ACCURACY IS NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
UPDATE PRF_RSLT_SC_ACCURACY SET TRN_ACCURACY = 1 WHERE TRN_ACCURACY IS NULL;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID703394;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID703394;
%put ERROR- Description                              : SZPF - Missing TRN_ACCURACY value causing UI to crash;
%put ERROR- Version                                  : M1MI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID703394;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID703394",
"SZPF - Missing TRN_ACCURACY value causing UI to crash",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID703394:;
 
 
* End of changes for CHANGE_ID:ID703394;
 
 
***********************************************************************************************;
*************************************  End Change ID703394 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID721016 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID721016;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID721016")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID721016;
%goto ID721016;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID721016;
* Insert record into change management table for CHANGE_ID: ID721016;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID721016",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID721016;
 
%end;
 
 
 
 
%put NOTE: Skipping this change since this change should never be applied.;
%put NOTE- Change ID                             :ID721016;
%goto ID721016;
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
CREATE INDEX RPP_PLAN_PROD_METRICS_IX1 ON RPP_PLAN_PROD_METRICS
(
PLAN_SK
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
CREATE INDEX PLAN_SK ON RPP_PLAN_PROD_METRICS
(
PLAN_SK
)
;
 
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE INDEX RPP_PLAN_PROD_METRICS_IX1 ON RPP_PLAN_PROD_METRICS
(
PLAN_SK
) ALLOW REVERSE SCANS
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID721016;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID721016;
%put ERROR- Description                              : Need RPP indices for performance;
%put ERROR- Version                                  : M1MI42;
%put ERROR- Date of Change                           : 31DEC2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID721016;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID721016",
"Need RPP indices for performance",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID721016:;
 
 
* End of changes for CHANGE_ID:ID721016;
 
 
***********************************************************************************************;
*************************************  End Change ID721016 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID744028 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID744028;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID744028")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID744028;
%goto ID744028;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M1TKMI43);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID744028;
* Insert record into change management table for CHANGE_ID: ID744028;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
'ID744028',
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID744028;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
CREATE INDEX MPLN_GPR_AGG_CD_PHSK_IX ON MPLN_GEO_PROD_RESULT
(
AGG_CD,
PROD_HIER_SK
)
NOLOGGING
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
CREATE INDEX MPLN_GPR_AGG_CD_PHSK_IX ON MPLN_GEO_PROD_RESULT
(
AGG_CD,
PROD_HIER_SK
)
;
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE INDEX MPLN_GPR_AGG_CD_PHSK_IX ON MPLN_GEO_PROD_RESULT
(
AGG_CD,
PROD_HIER_SK
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID744028;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID744028;
%put ERROR- Description                              : MDO Approvals: Fix non-performant query for "all items" filter;
%put ERROR- Version                                  : D3MICM52,M1TKMI43;
%put ERROR- Date of Change                           : 17MAR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID744028;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
'ID744028',
'MDO Approvals: Fix non-performant query for "all items" filter',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID744028:;
 
 
* End of changes for CHANGE_ID:ID744028;
 
 
***********************************************************************************************;
*************************************  End Change ID744028 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID741532 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID741532;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID741532")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID741532;
%goto ID741532;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID741532;
* Insert record into change management table for CHANGE_ID: ID741532;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID741532",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID741532;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='GEO_PROD';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('GEO_PROD', 'SAS', 13, 91, '%di_purge_geo_prod(libref=DI_DM,dsn=GEO_PROD);', 1103,1,'ALL');
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='GEO_PROD_STATUS';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('GEO_PROD_STATUS', 'SAS', 12, 91, '%di_purge_geo_prod_status(libref=DI_DM,dsn=GEO_PROD_STATUS);', 1103,1,'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='FUTURE_RECEIPT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('FUTURE_RECEIPT ', 'SAS',  4, 91,'%di_purge_future_receipt(libref=DI_DM); ',1103 ,1,'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='RETURN_FACT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('RETURN_FACT', 'SAS',  1, 91,'%di_purge_return_fact(libref=di_dm); ',1103,1,'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='DOW_SALES_FACT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('DOW_SALES_FACT', 'SAS', 2, 7, '%di_purge_dow_sales_fact(libref=DI_DM);', 180,1,'ALL');
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='DOW_EVENT_SALES_FACT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('DOW_EVENT_SALES_FACT', 'SAS', 2, 7, '%di_purge_dow_event_sales_fact(libref=DI_DM);', 365,1,'ALL');
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='GEO_PROD';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('GEO_PROD', 'SAS', 13, 91, '%di_purge_geo_prod(libref=DI_DM,dsn=GEO_PROD);', 1103,1,'ALL');
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='GEO_PROD_STATUS';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('GEO_PROD_STATUS', 'SAS', 12, 91, '%di_purge_geo_prod_status(libref=DI_DM,dsn=GEO_PROD_STATUS);', 1103,1,'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='FUTURE_RECEIPT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('FUTURE_RECEIPT ', 'SAS',  4, 91,'%di_purge_future_receipt(libref=DI_DM); ',1103 ,1,'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='RETURN_FACT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('RETURN_FACT', 'SAS',  1, 91,'%di_purge_return_fact(libref=di_dm); ',1103,1,'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='DOW_SALES_FACT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('DOW_SALES_FACT', 'SAS', 2, 7, '%di_purge_dow_sales_fact(libref=DI_DM);', 180,1,'ALL');
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='DOW_EVENT_SALES_FACT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('DOW_EVENT_SALES_FACT', 'SAS', 2, 7, '%di_purge_dow_event_sales_fact(libref=DI_DM);', 365,1,'ALL');
 
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID741532;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID741532;
%put ERROR- Description                              : Time base purge routine macro required for SZPF partitioned tables;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 24MAR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID741532;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID741532",
"Time base purge routine macro required for SZPF partitioned tables",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID741532:;
 
 
* End of changes for CHANGE_ID:ID741532;
 
 
***********************************************************************************************;
*************************************  End Change ID741532 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change MOVE_RPP_AGG_TO_RDBMS ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: MOVE_RPP_AGG_TO_RDBMS;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("MOVE_RPP_AGG_TO_RDBMS")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : MOVE_RPP_AGG_TO_RDBMS;
%goto MOVE_RPP_AGG_TO_RDBMS;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : MOVE_RPP_AGG_TO_RDBMS;
* Insert record into change management table for CHANGE_ID: MOVE_RPP_AGG_TO_RDBMS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"MOVE_RPP_AGG_TO_RDBMS",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto MOVE_RPP_AGG_TO_RDBMS;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE AGGREGATION_METRICS (
OBJECT_CAT_TYPE INTEGER NOT NULL,
OBJECT_CAT_SK INTEGER NOT NULL,
 
PROD_LVL INTEGER NOT NULL,
GEO_LVL INTEGER NOT NULL,
 
ORIG_FISCAL_START_DT DATE,
FISCAL_START_DT DATE NOT NULL,
 
PARENT_PROD_HIER_SK INTEGER NOT NULL,
PARENT_GEO_HIER_SK INTEGER NOT NULL,
 
LY_SALES_AMT NUMERIC(20,3),
LY_UNITS NUMERIC(12,2),
LY_GM_PCT NUMERIC(12,4),
LY_GM_AMT NUMERIC(20,3),
LY_PROMO_MARKDN_AMT NUMERIC(20,3),
LY_PROMO_BLEND_PCT NUMERIC(12,4),
LY_CLOSE_INV_UNITS NUMERIC(20,3),
LY_CLOSE_INV_VAL_RETAIL_AMT NUMERIC(20,3),
LY_N_PROMO_ITEMS NUMERIC(12,2),
 
CURR_UNITS NUMERIC(12,2),
CURR_SALES_AMT NUMERIC(20,3),
CURR_GM_PCT NUMERIC(12,4),
CURR_GM_AMT NUMERIC(20,3),
CURR_PROMO_MARKDN_AMT NUMERIC(20,3),
CURR_PROMO_BLEND_PCT NUMERIC(12,4),
CURR_CLOSE_INV_UNITS NUMERIC(12,2),
CURR_CLOSE_INV_VAL_RETAIL_AMT NUMERIC(20,3),
CURR_N_PROMO_ITEMS NUMERIC(20,3),
 
TA_UNITS NUMERIC(12,2),
TA_SALES_AMT NUMERIC(20,3),
TA_GM_AMT NUMERIC(20,3),
TA_GM_PCT NUMERIC(12,4),
TA_PROMO_MARKDN_AMT NUMERIC(20,3),
TA_PROMO_BLEND_PCT NUMERIC(12,4),
TA_N_PROMO_ITEMS NUMERIC(12,2),
TA_CLOSE_INV_UNITS NUMERIC(12,2),
TA_CLOSE_INV_VAL_RETAIL_AMT NUMERIC(20,3),
 
FCST_UNITS NUMERIC(12,2),
FCST_SALES_AMT NUMERIC(20,3),
FCST_GM_AMT NUMERIC(20,3),
FCST_GM_PCT NUMERIC(12,4),
FCST_PROMO_MARKDN_AMT NUMERIC(20,3),
FCST_PROMO_BLEND_PCT NUMERIC(12,4),
FCST_N_PROMO_ITEMS NUMERIC(12,2),
FCST_CLOSE_INV_UNITS NUMERIC(12,2),
FCST_CLOSE_INV_VAL_RETAIL_AMT NUMERIC(20,3),
 
PRIMARY KEY (OBJECT_CAT_TYPE, OBJECT_CAT_SK, PARENT_PROD_HIER_SK, PARENT_GEO_HIER_SK, FISCAL_START_DT)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
CREATE TABLE AGGREGATION_METRICS (
OBJECT_CAT_TYPE INTEGER NOT NULL,
OBJECT_CAT_SK INTEGER NOT NULL,
 
PROD_LVL INTEGER NOT NULL,
GEO_LVL INTEGER NOT NULL,
 
ORIG_FISCAL_START_DT DATE,
FISCAL_START_DT DATE NOT NULL,
 
PARENT_PROD_HIER_SK INTEGER NOT NULL,
PARENT_GEO_HIER_SK INTEGER NOT NULL,
 
LY_SALES_AMT NUMERIC(20,3),
LY_UNITS NUMERIC(12,2),
LY_GM_PCT NUMERIC(12,4),
LY_GM_AMT NUMERIC(20,3),
LY_PROMO_MARKDN_AMT NUMERIC(20,3),
LY_PROMO_BLEND_PCT NUMERIC(12,4),
LY_CLOSE_INV_UNITS NUMERIC(20,3),
LY_CLOSE_INV_VAL_RETAIL_AMT NUMERIC(20,3),
LY_N_PROMO_ITEMS NUMERIC(12,2),
 
CURR_UNITS NUMERIC(12,2),
CURR_SALES_AMT NUMERIC(20,3),
CURR_GM_PCT NUMERIC(12,4),
CURR_GM_AMT NUMERIC(20,3),
CURR_PROMO_MARKDN_AMT NUMERIC(20,3),
CURR_PROMO_BLEND_PCT NUMERIC(12,4),
CURR_CLOSE_INV_UNITS NUMERIC(12,2),
CURR_CLOSE_INV_VAL_RETAIL_AMT NUMERIC(20,3),
CURR_N_PROMO_ITEMS NUMERIC(20,3),
 
TA_UNITS NUMERIC(12,2),
TA_SALES_AMT NUMERIC(20,3),
TA_GM_AMT NUMERIC(20,3),
TA_GM_PCT NUMERIC(12,4),
TA_PROMO_MARKDN_AMT NUMERIC(20,3),
TA_PROMO_BLEND_PCT NUMERIC(12,4),
TA_N_PROMO_ITEMS NUMERIC(12,2),
TA_CLOSE_INV_UNITS NUMERIC(12,2),
TA_CLOSE_INV_VAL_RETAIL_AMT NUMERIC(20,3),
 
FCST_UNITS NUMERIC(12,2),
FCST_SALES_AMT NUMERIC(20,3),
FCST_GM_AMT NUMERIC(20,3),
FCST_GM_PCT NUMERIC(12,4),
FCST_PROMO_MARKDN_AMT NUMERIC(20,3),
FCST_PROMO_BLEND_PCT NUMERIC(12,4),
FCST_N_PROMO_ITEMS NUMERIC(12,2),
FCST_CLOSE_INV_UNITS NUMERIC(12,2),
FCST_CLOSE_INV_VAL_RETAIL_AMT NUMERIC(20,3)
 
);
 
 
 
ALTER TABLE AGGREGATION_METRICS  add CONSTRAINT PRIM_KEY  PRIMARY KEY
(OBJECT_CAT_TYPE, OBJECT_CAT_SK, PARENT_PROD_HIER_SK, PARENT_GEO_HIER_SK, FISCAL_START_DT);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: MOVE_RPP_AGG_TO_RDBMS;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: MOVE_RPP_AGG_TO_RDBMS;
%put ERROR- Description                              : Move RPP_CAL_AGG and RPP_CAT_AGG tables to RDMBS;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 23MAR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: MOVE_RPP_AGG_TO_RDBMS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"MOVE_RPP_AGG_TO_RDBMS",
"Move RPP_CAL_AGG and RPP_CAT_AGG tables to RDMBS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%MOVE_RPP_AGG_TO_RDBMS:;
 
 
* End of changes for CHANGE_ID:MOVE_RPP_AGG_TO_RDBMS;
 
 
***********************************************************************************************;
*************************************  End Change MOVE_RPP_AGG_TO_RDBMS ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID739114 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID739114;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID739114")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID739114;
%goto ID739114;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID739114;
* Insert record into change management table for CHANGE_ID: ID739114;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID739114",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID739114;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='MPLN_MTS';
 
 
INSERT INTO purge_query
(table_nm, database_nm, purge_order, purge_frequency,purge_query_txt, num_days_preserved, partition_flg, app_nm)
VALUES ('MPLN_MTS', 'SAS', 1, 7, '%di_purge_mpln_metrics(libref=di_data);', 30,1, 'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='GEO_PROD';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('GEO_PROD', 'SAS', 13, 91, '%di_purge_geo_prod(libref=DI_DM,dsn=GEO_PROD);', 1103,1,'ALL');
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='GEO_PROD_STATUS';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('GEO_PROD_STATUS', 'SAS', 12, 91, '%di_purge_geo_prod_status(libref=DI_DM,dsn=GEO_PROD_STATUS);', 1103,1,'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='FUTURE_RECEIPT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('FUTURE_RECEIPT ', 'SAS',  4, 91,'%di_purge_future_receipt(libref=DI_DM); ',1103 ,1,'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='RETURN_FACT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('RETURN_FACT', 'SAS',  1, 91,'%di_purge_return_fact(libref=di_dm); ',1103,1,'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='DOW_SALES_FACT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('DOW_SALES_FACT', 'SAS', 2, 7, '%di_purge_dow_sales_fact(libref=DI_DM);', 180,1,'ALL');
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='DOW_EVENT_SALES_FACT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('DOW_EVENT_SALES_FACT', 'SAS', 2, 7, '%di_purge_dow_event_sales_fact(libref=DI_DM);', 365,1,'ALL');
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='MPLN_MTS';
 
 
INSERT INTO purge_query
(table_nm, database_nm, purge_order, purge_frequency,purge_query_txt, num_days_preserved, partition_flg, app_nm)
VALUES ('MPLN_MTS', 'SAS', 1, 7, '%di_purge_mpln_metrics(libref=di_data);', 30,1, 'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='GEO_PROD';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('GEO_PROD', 'SAS', 13, 91, '%di_purge_geo_prod(libref=DI_DM,dsn=GEO_PROD);', 1103,1,'ALL');
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='GEO_PROD_STATUS';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('GEO_PROD_STATUS', 'SAS', 12, 91, '%di_purge_geo_prod_status(libref=DI_DM,dsn=GEO_PROD_STATUS);', 1103,1,'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='FUTURE_RECEIPT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('FUTURE_RECEIPT ', 'SAS',  4, 91,'%di_purge_future_receipt(libref=DI_DM); ',1103 ,1,'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='RETURN_FACT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('RETURN_FACT', 'SAS',  1, 91,'%di_purge_return_fact(libref=di_dm); ',1103,1,'ALL');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='DOW_SALES_FACT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('DOW_SALES_FACT', 'SAS', 2, 7, '%di_purge_dow_sales_fact(libref=DI_DM);', 180,1,'ALL');
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='DOW_EVENT_SALES_FACT';
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('DOW_EVENT_SALES_FACT', 'SAS', 2, 7, '%di_purge_dow_event_sales_fact(libref=DI_DM);', 365,1,'ALL');
 
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID739114;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID739114;
%put ERROR- Description                              : Seed_rdbms needs any entry for purging mpln* tables;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 24MAR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID739114;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID739114",
"Seed_rdbms needs any entry for purging mpln* tables",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID739114:;
 
 
* End of changes for CHANGE_ID:ID739114;
 
 
***********************************************************************************************;
*************************************  End Change ID739114 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0735224 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0735224;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0735224")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PROFILE_CLUSTER))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PROFILE_CLUSTER;
%put NOTE: Change ID                             :ID0735224;
%goto ID0735224;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..PROFILE_SCORE_SETTING))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PROFILE_SCORE_SETTING;
%put NOTE: Change ID                             :ID0735224;
%goto ID0735224;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0735224;
%goto ID0735224;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0735224;
* Insert record into change management table for CHANGE_ID: ID0735224;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0735224",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0735224;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE PROFILE_CLUSTER ADD CLASSIFIED_FLG SMALLINT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PROFILE_SCORE_SETTING ADD CLASSIFIED_STORE_PENALTY INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PROFILE_SCORE ADD CLASSIFIED_STORE_PENALTY INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
ALTER TABLE &m_di_trans..PROFILE_SCORE_SETTING ADD CLASSIFIED_STORE_PENALTY INTEGER;
 
 
ALTER TABLE &m_di_trans..REQ_PROFILE_SCORE ADD CLASSIFIED_STORE_PENALTY INTEGER;
 
 
quit;
 
 
 
data work.PROFILE_CLUSTER_OLD;
 
 
set &m_di_trans..PROFILE_CLUSTER;
 
 
attrib CLASSIFIED_FLG length=3;
 
 
run;
 
 
 
data &m_di_trans..PROFILE_CLUSTER;
 
 
attrib   PROFILE_ID      length=8;
 
 
attrib   GEO_HIER_SK     length=8;
 
 
attrib   CLUSTER_ID      length=8;
 
 
attrib   CLASSIFIED_FLG  length=3;
 
 
stop; run;
 
 
 
proc sql;
 
 
ALTER TABLE &m_di_trans..PROFILE_CLUSTER  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PROFILE_ID,GEO_HIER_SK);
 
 
quit;
 
 
 
proc append base=&m_di_trans..PROFILE_CLUSTER
data= work.PROFILE_CLUSTER_OLD force;
 
 
quit;
 
 
 
proc sql;
 
 
drop table work.PROFILE_CLUSTER_OLD;
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE PROFILE_CLUSTER ADD CLASSIFIED_FLG SMALLINT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PROFILE_SCORE_SETTING ADD CLASSIFIED_STORE_PENALTY INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PROFILE_SCORE ADD CLASSIFIED_STORE_PENALTY INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0735224;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0735224;
%put ERROR- Description                              : Penalize classified stores in profile scoring;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 04APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0735224;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0735224",
"Penalize classified stores in profile scoring",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0735224:;
 
 
* End of changes for CHANGE_ID:ID0735224;
 
 
***********************************************************************************************;
*************************************  End Change ID0735224 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID738983 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID738983;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID738983")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID738983;
%goto ID738983;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID738983;
* Insert record into change management table for CHANGE_ID: ID738983;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID738983",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID738983;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE PRODUCT_DM DROP COLUMN MIN_INV_LVL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
ALTER TABLE PRODUCT_DM DROP COLUMN MIN_INV_LVL;
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE PRODUCT_DM DROP COLUMN MIN_INV_LVL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID738983;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID738983;
%put ERROR- Description                              : Move min_inv_lvl from PRODUCT_DM to GEO_PROD;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 05APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID738983;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID738983",
"Move min_inv_lvl from PRODUCT_DM to GEO_PROD",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID738983:;
 
 
* End of changes for CHANGE_ID:ID738983;
 
 
***********************************************************************************************;
*************************************  End Change ID738983 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change DROP_MIN_INV_LVL ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: DROP_MIN_INV_LVL;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("DROP_MIN_INV_LVL")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : DROP_MIN_INV_LVL;
%goto DROP_MIN_INV_LVL;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : DROP_MIN_INV_LVL;
* Insert record into change management table for CHANGE_ID: DROP_MIN_INV_LVL;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_MIN_INV_LVL",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto DROP_MIN_INV_LVL;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE PKO_PRODUCT_DM DROP COLUMN MIN_INV_LVL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DROP VIEW PKO_PRODUCT_DM_ALL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE VIEW PKO_PRODUCT_DM_ALL AS
SELECT PROD_HIER_SK,PROD_ID,PROD_NM,STD_HIER_PROD_LVL,PROD_DESC,PROD_INTRODUCTION_DT,PROD_DISCONTINUED_DT,
VOLUME,VOLUME_BASE_UOM,BRAND_NM,STD_HIER_LEAF_NODE_FLG,MODEL_PROD_FLG,CREATED_DTTM
FROM PRODUCT_DM
UNION SELECT PROD_HIER_SK,PROD_ID,PROD_NM,STD_HIER_PROD_LVL,PROD_DESC,PROD_INTRODUCTION_DT,PROD_DISCONTINUED_DT,
VOLUME,VOLUME_BASE_UOM,BRAND_NM,STD_HIER_LEAF_NODE_FLG,MODEL_PROD_FLG,CREATED_DTTM
FROM PKO_PRODUCT_DM
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
DROP TABLE PKO_PRODUCT_DM_ALL;
 
 
 
ALTER TABLE PKO_PRODUCT_DM DROP COLUMN MIN_INV_LVL;
 
 
 
DROP VIEW PKO_PRODUCT_DM_ALL;
 
 
 
 
CREATE VIEW PKO_PRODUCT_DM_ALL AS
SELECT PROD_HIER_SK,PROD_ID,PROD_NM,STD_HIER_PROD_LVL,PROD_DESC,PROD_INTRODUCTION_DT,PROD_DISCONTINUED_DT,
VOLUME,VOLUME_BASE_UOM,BRAND_NM,STD_HIER_LEAF_NODE_FLG,MODEL_PROD_FLG,CREATED_DTTM
FROM PRODUCT_DM
UNION SELECT PROD_HIER_SK,PROD_ID,PROD_NM,STD_HIER_PROD_LVL,PROD_DESC,PROD_INTRODUCTION_DT,PROD_DISCONTINUED_DT,
VOLUME,VOLUME_BASE_UOM,BRAND_NM,STD_HIER_LEAF_NODE_FLG,MODEL_PROD_FLG,CREATED_DTTM
FROM PKO_PRODUCT_DM;
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE PKO_PRODUCT_DM DROP COLUMN MIN_INV_LVL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DROP VIEW PKO_PRODUCT_DM_ALL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE VIEW PKO_PRODUCT_DM_ALL AS
SELECT PROD_HIER_SK,PROD_ID,PROD_NM,STD_HIER_PROD_LVL,PROD_DESC,PROD_INTRODUCTION_DT,PROD_DISCONTINUED_DT,
VOLUME,VOLUME_BASE_UOM,BRAND_NM,STD_HIER_LEAF_NODE_FLG,MODEL_PROD_FLG,CREATED_DTTM
FROM PRODUCT_DM
UNION SELECT PROD_HIER_SK,PROD_ID,PROD_NM,STD_HIER_PROD_LVL,PROD_DESC,PROD_INTRODUCTION_DT,PROD_DISCONTINUED_DT,
VOLUME,VOLUME_BASE_UOM,BRAND_NM,STD_HIER_LEAF_NODE_FLG,MODEL_PROD_FLG,CREATED_DTTM
FROM PKO_PRODUCT_DM
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: DROP_MIN_INV_LVL;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: DROP_MIN_INV_LVL;
%put ERROR- Description                              : Drop min_inv_lvl from PKO_PRODUCT_DM table and view;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 13APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: DROP_MIN_INV_LVL;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_MIN_INV_LVL",
"Drop min_inv_lvl from PKO_PRODUCT_DM table and view",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%DROP_MIN_INV_LVL:;
 
 
* End of changes for CHANGE_ID:DROP_MIN_INV_LVL;
 
 
***********************************************************************************************;
*************************************  End Change DROP_MIN_INV_LVL ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID750213 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID750213;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID750213")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID750213;
%goto ID750213;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID750213;
* Insert record into change management table for CHANGE_ID: ID750213;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID750213",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID750213;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE DI_JOB_RO_STATUS ADD PARTITION_NUMBER VARCHAR(32)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
ALTER TABLE DI_JOB_RO_STATUS ADD PARTITION_NUMBER VARCHAR(32);
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE DI_JOB_RO_STATUS ADD PARTITION_NUMBER VARCHAR(32)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID750213;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID750213;
%put ERROR- Description                              : Adding new column PARTITION_NUMBER in DI_JOB_RO_STATUS.;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 05APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID750213;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID750213",
"Adding new column PARTITION_NUMBER in DI_JOB_RO_STATUS.",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID750213:;
 
 
* End of changes for CHANGE_ID:ID750213;
 
 
***********************************************************************************************;
*************************************  End Change ID750213 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID746931_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID746931_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID746931_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID746931_1;
%goto ID746931_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID746931_1;
* Insert record into change management table for CHANGE_ID: ID746931_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID746931_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID746931_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%if (%di_util_varexist(dsname=&m_di_trans..REQUEST, varname=ALLOW_MULTI_STYLE_PACK_REC)=0) %then
%do;
 
 
 
%let m_sql_statement = %str(
ALTER TABLE REQUEST ADD ALLOW_MULTI_STYLE_PACK_REC INTEGER
);
 
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
%if (%di_util_varexist(dsname=&m_di_trans..REQUEST, varname=ALLOW_MULTI_STYLE_PACK_REC)=0) %then
%do;
 
 
proc sql;
 
 
ALTER TABLE REQUEST ADD ALLOW_MULTI_STYLE_PACK_REC INTEGER;
 
 
quit;
 
 
%end;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID746931_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID746931_1;
%put ERROR- Description                              : TABLE REQUEST ADD COLUMN ALLOW_MULTI_STYLE_PACK_REC;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 12APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID746931_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID746931_1",
"TABLE REQUEST ADD COLUMN ALLOW_MULTI_STYLE_PACK_REC",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID746931_1:;
 
 
* End of changes for CHANGE_ID:ID746931_1;
 
 
***********************************************************************************************;
*************************************  End Change ID746931_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID746931 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID746931;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID746931")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..REQUEST))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..REQUEST;
%put NOTE: Change ID                             :ID746931;
%goto ID746931;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..REQ_PACKREC_SETTING))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..REQ_PACKREC_SETTING;
%put NOTE: Change ID                             :ID746931;
%goto ID746931;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID746931;
%goto ID746931;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID746931;
* Insert record into change management table for CHANGE_ID: ID746931;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID746931",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID746931;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE REQUEST DROP COLUMN ALLOW_MULTI_STYLE_PACK_REC
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_SETTING ADD PROD_ID VARCHAR(32)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE REQ_PACKREC_SETTING SET PROD_ID = (select prod_id from PRODUCT_DM where std_hier_prod_lvl=1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_SETTING ADD ALLOW_MULTI_STYLE_PACK_REC INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_SETTING ADD ALLOW_PRIOR_DELIVERY_PACKS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_SETTING MODIFY PROD_ID VARCHAR(32) NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_SETTING DROP PRIMARY KEY DROP INDEX
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE UNIQUE INDEX REQ_PACKREC_SETTING_PK on REQ_PACKREC_SETTING (REQUEST_ID, DELIVERY_ID, PROD_ID) nologging parallel
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_SETTING ADD CONSTRAINT REQ_PACKREC_SETTING_PK PRIMARY KEY (REQUEST_ID, DELIVERY_ID, PROD_ID) USING INDEX REQ_PACKREC_SETTING_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_INNER ADD PROD_ID VARCHAR(32)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE REQ_PACKREC_INNER SET PROD_ID = (select prod_id from PRODUCT_DM where std_hier_prod_lvl=1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_INNER MODIFY PROD_ID VARCHAR(32) NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_INNER DROP PRIMARY KEY DROP INDEX
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE UNIQUE INDEX REQ_PACKREC_INNER_PK on REQ_PACKREC_INNER (REQUEST_ID, DELIVERY_ID, PROD_ID, SIZE_OF_INNER) nologging parallel
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_INNER ADD CONSTRAINT REQ_PACKREC_INNER_PK PRIMARY KEY (REQUEST_ID, DELIVERY_ID, PROD_ID, SIZE_OF_INNER) USING INDEX REQ_PACKREC_INNER_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_GEO_COST ADD PROD_ID VARCHAR(32)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE REQ_PACKREC_GEO_COST SET PROD_ID = (select prod_id from PRODUCT_DM where std_hier_prod_lvl=1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_GEO_COST MODIFY PROD_ID VARCHAR(32) NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_GEO_COST DROP PRIMARY KEY DROP INDEX
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE UNIQUE INDEX REQ_PACKREC_GEO_COST_PK on REQ_PACKREC_GEO_COST (REQUEST_ID, DELIVERY_ID, PROD_ID, GEO_ID, SIZE_OF_INNER) nologging parallel
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_GEO_COST ADD CONSTRAINT REQ_PACKREC_GEO_COST_PK PRIMARY KEY (REQUEST_ID, DELIVERY_ID, PROD_ID, GEO_ID, SIZE_OF_INNER) USING INDEX REQ_PACKREC_GEO_COST_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
ALTER TABLE &m_di_trans..REQUEST DROP COLUMN ALLOW_MULTI_STYLE_PACK_REC;
 
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_SETTING ADD PROD_ID VARCHAR(32);
 
 
UPDATE &m_di_trans..REQ_PACKREC_SETTING SET PROD_ID = (select prod_id from &m_di_trans..PRODUCT_DM where std_hier_prod_lvl=1);
 
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_SETTING ADD ALLOW_MULTI_STYLE_PACK_REC INTEGER;
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_SETTING ADD ALLOW_PRIOR_DELIVERY_PACKS INTEGER;
 
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_SETTING MODIFY PROD_ID VARCHAR(32) NOT NULL;
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_SETTING DROP PRIMARY KEY;
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_SETTING ADD CONSTRAINT REQ_PACKREC_SETTING_PK PRIMARY KEY (REQUEST_ID, DELIVERY_ID, PROD_ID);
 
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_INNER ADD PROD_ID VARCHAR(32);
 
 
UPDATE &m_di_trans..REQ_PACKREC_INNER SET PROD_ID = (select prod_id from &m_di_trans..PRODUCT_DM where std_hier_prod_lvl=1);
 
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_INNER MODIFY PROD_ID VARCHAR(32) NOT NULL;
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_INNER DROP PRIMARY KEY;
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_INNER ADD CONSTRAINT REQ_PACKREC_INNER_PK PRIMARY KEY (REQUEST_ID, DELIVERY_ID, PROD_ID, SIZE_OF_INNER);
 
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_GEO_COST ADD PROD_ID VARCHAR(32);
 
 
UPDATE &m_di_trans..REQ_PACKREC_GEO_COST SET PROD_ID = (select prod_id from &m_di_trans..PRODUCT_DM where std_hier_prod_lvl=1);
 
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_GEO_COST MODIFY PROD_ID VARCHAR(32) NOT NULL;
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_GEO_COST DROP PRIMARY KEY;
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_GEO_COST ADD CONSTRAINT REQ_PACKREC_GEO_COST_PK PRIMARY KEY (REQUEST_ID, DELIVERY_ID, PROD_ID, GEO_ID, SIZE_OF_INNER);
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID746931;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID746931;
%put ERROR- Description                              : Pack Recommendation Settings to support more flexibility in pack recommendation;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 04APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID746931;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID746931",
"Pack Recommendation Settings to support more flexibility in pack recommendation",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID746931:;
 
 
* End of changes for CHANGE_ID:ID746931;
 
 
***********************************************************************************************;
*************************************  End Change ID746931 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID750328 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID750328;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID750328")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PRF_SIZESET))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_SIZESET;
%put NOTE: Change ID                             :ID750328;
%goto ID750328;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..PRF_CONFIG))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_CONFIG;
%put NOTE: Change ID                             :ID750328;
%goto ID750328;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID750328;
%goto ID750328;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID750328;
* Insert record into change management table for CHANGE_ID: ID750328;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID750328",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID750328;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE PRF_SIZESET ADD USER_MODIFIED_FLG INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRF_SIZESET_MBR ADD SALES_DISTRIBUTION_PCT NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRF_SIZESET_MBR ADD SALES_AUR NUMERIC(12,2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRF_SIZESET_MBR ADD UNITS_IMPUTED NUMERIC(12,2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=1 and SPEC_NM='sub_sizeset_flg'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 1, 'sub_sizeset_flg', '1', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
ALTER TABLE PRF_SIZESET ADD USER_MODIFIED_FLG INTEGER;
 
 
ALTER TABLE PRF_SIZESET_MBR ADD SALES_DISTRIBUTION_PCT NUMERIC(12,4);
 
 
ALTER TABLE PRF_SIZESET_MBR ADD SALES_AUR NUMERIC(12,2);
 
 
ALTER TABLE PRF_SIZESET_MBR ADD UNITS_IMPUTED NUMERIC(12,2);
 
 
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=1 and SPEC_NM='sub_sizeset_flg';
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 1, 'sub_sizeset_flg', '1', 'INTEGER');
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID750328;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID750328;
%put ERROR- Description                              : SIZE PROFILING 3.2 SCHEMA CHANGES;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 04APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID750328;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID750328",
"SIZE PROFILING 3.2 SCHEMA CHANGES",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID750328:;
 
 
* End of changes for CHANGE_ID:ID750328;
 
 
***********************************************************************************************;
*************************************  End Change ID750328 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID719792 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID719792;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID719792")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MDO_PLAN))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MDO_PLAN;
%put NOTE: Change ID                             :ID719792;
%goto ID719792;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..MPLN_GEO_PROD_RESULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MPLN_GEO_PROD_RESULT;
%put NOTE: Change ID                             :ID719792;
%goto ID719792;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID719792;
%goto ID719792;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52, M2TKMI43);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID719792;
* Insert record into change management table for CHANGE_ID: ID719792;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID719792",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID719792;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN ADD UNIFORM_TIMING_NUM_MARKDN INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN ADD UNIFORM_TIMING_PROD_LVL INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN ADD UNIFORM_TIMING_GEO_LVL INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT ADD UT_PROD_HIER_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT ADD UT_GEO_HIER_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO GEO_PROD_SETTING (GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,
SETTING_TYPE,SETTING_VAL,SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (25,1,1,1,50,0,1,0,2.0000,1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO GEO_PROD_SETTING (GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,
SETTING_TYPE,SETTING_VAL,SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (26,1,1,1,51,0,1,1.0000,99.0000,1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO GEO_PROD_SETTING (GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,
SETTING_TYPE,SETTING_VAL,SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (27,1,1,1,52,0,1,1.0000,99.0000,1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE MDO_PLAN ADD UNIFORM_TIMING_NUM_MARKDN INTEGER;
 
 
ALTER TABLE MDO_PLAN ADD UNIFORM_TIMING_PROD_LVL INTEGER;
 
 
ALTER TABLE MDO_PLAN ADD UNIFORM_TIMING_GEO_LVL INTEGER;
 
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD UT_PROD_HIER_SK INTEGER;
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD UT_GEO_HIER_SK INTEGER;
 
 
 
INSERT INTO GEO_PROD_SETTING (GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,
SETTING_TYPE,SETTING_VAL,SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (25,1,1,1,50,0,1,0,2.0000,1);
 
 
 
INSERT INTO GEO_PROD_SETTING (GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,
SETTING_TYPE,SETTING_VAL,SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (26,1,1,1,51,0,1,1.0000,99.0000,1);
 
 
 
INSERT INTO GEO_PROD_SETTING (GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,
SETTING_TYPE,SETTING_VAL,SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (27,1,1,1,52,0,1,1.0000,99.0000,1);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID719792;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID719792;
%put ERROR- Description                              : Schema and ETL enhancement for uniform timing (mdo_plan and stg_mdo_import_plan);
%put ERROR- Version                                  : D3MICM52, M2TKMI43;
%put ERROR- Date of Change                           : 30MAR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID719792;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID719792",
"Schema and ETL enhancement for uniform timing (mdo_plan and stg_mdo_import_plan)",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID719792:;
 
 
* End of changes for CHANGE_ID:ID719792;
 
 
***********************************************************************************************;
*************************************  End Change ID719792 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID747291 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID747291;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID747291")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID747291;
%goto ID747291;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID747291;
* Insert record into change management table for CHANGE_ID: ID747291;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID747291",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID747291;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM GEO_PROD_SETTING WHERE SETTING_TYPE = 11 AND USED_BY_APP = 1 AND GEO_HIER_SK = 1
AND PROD_HIER_SK = 1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 9
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO GEO_PROD_SETTING (GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,
SETTING_TYPE,SETTING_VAL,SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (9,1,1,1,11,16,1,2.0000,52.0000,1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM GEO_PROD_SETTING WHERE SETTING_TYPE = 11 AND USED_BY_APP = 1 AND GEO_HIER_SK = 1
AND PROD_HIER_SK = 1;
 
 
 
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 9 ;
 
 
 
INSERT INTO GEO_PROD_SETTING (GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,
SETTING_TYPE,SETTING_VAL,SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (9,1,1,1,11,16,1,2.0000,52.0000,1);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID747291;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID747291;
%put ERROR- Description                              : Max plan period is set to 52 for MDO;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 06APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID747291;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID747291",
"Max plan period is set to 52 for MDO",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID747291:;
 
 
* End of changes for CHANGE_ID:ID747291;
 
 
***********************************************************************************************;
*************************************  End Change ID747291 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change MOVE_WRKBNCH_MNGD_TABLES ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: MOVE_WRKBNCH_MNGD_TABLES;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("MOVE_WRKBNCH_MNGD_TABLES")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(DI_TRANS)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: DI_TRANS;
%put NOTE: Change ID                             :MOVE_WRKBNCH_MNGD_TABLES;
%goto MOVE_WRKBNCH_MNGD_TABLES;
 
%end;
%if not (%sysfunc(libref(DI_DATA)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: DI_DATA;
%put NOTE: Change ID                             :MOVE_WRKBNCH_MNGD_TABLES;
%goto MOVE_WRKBNCH_MNGD_TABLES;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : MOVE_WRKBNCH_MNGD_TABLES;
%goto MOVE_WRKBNCH_MNGD_TABLES;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : MOVE_WRKBNCH_MNGD_TABLES;
* Insert record into change management table for CHANGE_ID: MOVE_WRKBNCH_MNGD_TABLES;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"MOVE_WRKBNCH_MNGD_TABLES",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto MOVE_WRKBNCH_MNGD_TABLES;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
%let m_sql_statement = %str(
CREATE TABLE ATTR_SPEC
(
MODEL_GROUP_ID              INTEGER NOT NULL,
ATTR_SK                     INTEGER NOT NULL,
EFFECT_CLASS_NM             VARCHAR(40),
SELECTION_TYPE              INTEGER NOT NULL,
ATTR_USAGE                  INTEGER NOT NULL,
CREATED_DTTM                DATE,
CREATED_BY                  VARCHAR(20)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE BASE_FORECAST_OVERRIDE_GP
(
GEO_HIER_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
START_DATE_SK                      INTEGER NOT NULL,
END_DATE_SK                        INTEGER NOT NULL,
OVERRIDE_FACTOR                    NUMERIC(12,2),
PRIMARY KEY (GEO_HIER_SK,PROD_HIER_SK,START_DATE_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX BF_OGP_IX1 ON BASE_FORECAST_OVERRIDE_GP
(
GEO_HIER_SK,
PROD_HIER_SK
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE BASE_FORECAST_OVERRIDE_MG
(
MODEL_GROUP_ID                     INTEGER NOT NULL,
START_DATE_SK                      INTEGER NOT NULL,
END_DATE_SK                        INTEGER NOT NULL,
OVERRIDE_FACTOR                    NUMERIC(12,2),
PRIMARY KEY (MODEL_GROUP_ID,START_DATE_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX BF_OMG_IX1 ON BASE_FORECAST_OVERRIDE_MG
(
MODEL_GROUP_ID
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE CONFIG_AUDIT_TRAIL
(
AUDIT_TRAIL_SK                     INTEGER NOT NULL,
ACTION_TYPE                        VARCHAR(40),
OBJECT_TYPE                        VARCHAR(40),
OBJECT_NM                          VARCHAR(100),
NEW_VALUE                          VARCHAR(255),
OLD_VALUE                          VARCHAR(255),
GEO_HIER_SK                        INTEGER,
PROD_HIER_SK                       INTEGER,
USER_NM                            VARCHAR(40),
CREATED_DTTM                       DATE NOT NULL,
PRIMARY KEY (AUDIT_TRAIL_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX AUDIT_TRAIL_IX1 ON CONFIG_AUDIT_TRAIL
(
OBJECT_TYPE
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE CONFIG_GROUP
(
CONFIG_GROUP_ID             INTEGER NOT NULL,
CONFIG_GROUP_NM             VARCHAR(40),
NUM_OF_MODEL_GROUPS         INTEGER,
CONFIG_TEMPLATE_ID          INTEGER,
GEO_HIER_TYPE               INTEGER,
PROD_HIER_TYPE              INTEGER,
GEO_HIER_ASSOC_CD           INTEGER,
PROD_HIER_ASSOC_CD          INTEGER,
PRIMARY KEY (CONFIG_GROUP_ID)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE DATA_CONFIG
(
DATA_CONFIG_SK              INTEGER NOT NULL,
MODEL_GROUP_ID              INTEGER NOT NULL,
DATA_LVL_ID                 INTEGER,
GEO_HIER_SK                 INTEGER,
PROD_HIER_SK                INTEGER,
MODEL_COMP_NM               VARCHAR(5),
BY_GEO_LVL                  INTEGER,
BY_PROD_LVL                 INTEGER,
CREATED_DTTM                DATE,
CREATED_BY                  VARCHAR(20),
PRIMARY KEY (DATA_CONFIG_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE DATA_CONFIG_TEMPLATE
(
CONFIG_TEMPLATE_ID          INTEGER NOT NULL,
CONFIG_TEMPLATE_NM          VARCHAR(40),
CONFIG_TEMPLATE_DESC        VARCHAR(100),
INCLUDE_TS                  INTEGER,
TS_GEO_LVL                  INTEGER,
TS_PROD_LVL                 INTEGER,
TS_BY_GEO_LVL               INTEGER,
TS_BY_PROD_LVL              INTEGER,
INCLUDE_REG                 INTEGER,
REG_GEO_LVL                 INTEGER,
REG_PROD_LVL                INTEGER,
REG_BY_GEO_LVL              INTEGER,
REG_BY_PROD_LVL             INTEGER,
FCST_GEO_LVL                INTEGER,
FCST_PROD_LVL               INTEGER,
FCST_BY_GEO_LVL             INTEGER,
FCST_BY_PROD_LVL            INTEGER,
CREATED_BY                  VARCHAR(20),
CREATED_DTTM                DATE,
PRIMARY KEY (CONFIG_TEMPLATE_ID)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE GLOBAL_SETTING_DETAILS
(
SPEC_NM                     VARCHAR(32) NOT NULL,
APP                         VARCHAR(32) NOT NULL,
CONFIG_CD                   INTEGER NOT NULL,
DEFAULT_SPEC_VALUE          VARCHAR(100),
SPEC_DATATYPE               VARCHAR(40),
SPEC_DATATYPE_EXT           VARCHAR(40),
SPEC_VALUE_MIN              NUMERIC(12,4),
SPEC_VALUE_MAX              NUMERIC(12,4),
SPEC_VALUE_INCR             NUMERIC(12,4),
EDITABLE_FLG                INTEGER,
ENABLED_FLG                 INTEGER,
REQUIRED_FLG                INTEGER,
HIDDEN_FLG                  INTEGER,
MISSING_VAL_OK_FLG          INTEGER,
OVERRIDE_APP_LIST           VARCHAR(100),
REF_QUERY                   VARCHAR(500),
GENERATE_PREFIX_NM          VARCHAR(40),
GENERATE_SUFFIX_MAX         VARCHAR(40),
SPEC_VALUE_LIST_DELIMITER   VARCHAR(3),
DESC_KEY                    VARCHAR(100),
PRIMARY KEY (SPEC_NM,APP,CONFIG_CD)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE GLOBAL_SETTING_GROUP
(
GLOBAL_SETTING_GROUP_NM         VARCHAR(40) NOT NULL,
GLOBAL_SETTING_GROUP_DESC       VARCHAR(100),
GLOBAL_SETTING_GROUP_DESC_KEY   VARCHAR(100),
GLOBAL_SETTING_CATEGORY_FLG     INTEGER,
SETTING_GROUP_PERMISSION_ROLE   VARCHAR(100),
CONFIG_CD                       INTEGER,
PRIMARY KEY (GLOBAL_SETTING_GROUP_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE GLOBAL_SETTING_GROUP_MEMBER
(
SPEC_NM                     VARCHAR(32) NOT NULL,
APP                         VARCHAR(40) NOT NULL,
GLOBAL_SETTING_GROUP_NM     VARCHAR(40) NOT NULL,
PRIMARY KEY (SPEC_NM,APP,GLOBAL_SETTING_GROUP_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE GLOBAL_SETTING_VALUES
(
SPEC_NM                     VARCHAR(32) NOT NULL,
APP                         VARCHAR(40) NOT NULL,
SPEC_VALUE                  VARCHAR(100) NOT NULL,
SPEC_VALUE_DESC             VARCHAR(100),
SPEC_VALUE_DESC_KEY         VARCHAR(100),
PRIMARY KEY (SPEC_NM,APP,SPEC_VALUE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MA_SPEC_SEED
(
MODEL_GROUP_ID              INTEGER NOT NULL,
SPEC_NM                     VARCHAR(32) NOT NULL,
USER_NM                     VARCHAR(60) NOT NULL,
SPEC_VALUE                  VARCHAR(200),
PRIMARY KEY (MODEL_GROUP_ID,SPEC_NM,USER_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MODEL_GEO_PROD_STATUS_RULE
(
PROD_HIER_SK                INTEGER NOT NULL,
RULE_NM                     VARCHAR(32) NOT NULL,
RULE_VALUE                  VARCHAR(100),
SPEC_VALUE                  VARCHAR(200),
CREATED_DTTM                DATE,
CREATED_BY                  VARCHAR(20),
PRIMARY KEY (PROD_HIER_SK,RULE_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MODEL_GEO_PROD_STATUS_SPEC
(
SPEC_NM                     VARCHAR(32) NOT NULL,
SPEC_VALUE                  VARCHAR(100),
CREATED_DTTM                DATE,
CREATED_BY                  VARCHAR(20),
PRIMARY KEY (SPEC_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MODEL_GEO_PROD_STATUS_DETAILS
(
SPEC_NM                     VARCHAR(32) NOT NULL,
SPEC_RULE_FLG               INTEGER NOT NULL,
DEFAULT_SPEC_VALUE          VARCHAR(100),
SPEC_DATATYPE               VARCHAR(40),
SPEC_DATATYPE_EXT           VARCHAR(40),
SPEC_VALUE_MIN              NUMERIC(12,4),
SPEC_VALUE_MAX              NUMERIC(12,4),
SPEC_VALUE_INCR             NUMERIC(12,4),
REF_QUERY                   VARCHAR(500),
SPEC_VALUE_LIST_DELIMITER   VARCHAR(3),
DESCRIPTION                 VARCHAR(100),
DESC_KEY                    VARCHAR(100),
PRIMARY KEY (SPEC_NM,SPEC_RULE_FLG)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MODEL_GEO_PROD_STATUS_VALUES
(
SPEC_NM                     VARCHAR(32) NOT NULL,
SPEC_RULE_FLG               INTEGER NOT NULL,
SPEC_VALUE                  VARCHAR(100) NOT NULL,
SPEC_VALUE_DESC             VARCHAR(100),
SPEC_VALUE_DESC_KEY         VARCHAR(100),
PRIMARY KEY (SPEC_NM,SPEC_RULE_FLG,SPEC_VALUE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MODEL_GROUP
(
MODEL_GROUP_ID              INTEGER NOT NULL,
PROD_HIER_SK                INTEGER,
GEO_HIER_SK                 INTEGER,
NUM_GEO_PRODS               INTEGER,
SCHEDULED_FLG               INTEGER,
ENABLED_FLG                 INTEGER,
REFRESH_FREQ                INTEGER,
CONFIG_GROUP_ID             INTEGER,
SEASON                      VARCHAR(20),
TAG                         VARCHAR(40),
LAST_REFRESH_DTTM           DATE,
CONFIG_TEMPLATE_ID          INTEGER,
PRIMARY KEY (MODEL_GROUP_ID)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MODEL_SPEC
(
MODEL_GROUP_ID              INTEGER NOT NULL,
MODEL_COMP_NM               VARCHAR(5) NOT NULL,
SPEC_NM                     VARCHAR(32) NOT NULL,
SPEC_TYPE                   VARCHAR(5) NOT NULL,
SPEC_VALUE                  VARCHAR(100),
PRIORITY                    VARCHAR(3),
CREATED_DTTM                DATE,
CREATED_BY                  VARCHAR(20),
PRIMARY KEY (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MODEL_SPEC_DEFAULT
(
MODEL_COMP_NM               VARCHAR(5) NOT NULL,
SPEC_NM                     VARCHAR(32) NOT NULL,
SPEC_TYPE                   VARCHAR(5) NOT NULL,
DEFAULT_SPEC_VALUE          VARCHAR(100),
PRIORITY                    VARCHAR(3),
PRIMARY KEY (MODEL_COMP_NM,SPEC_NM,SPEC_TYPE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MODEL_SPEC_DETAILS
(
MODEL_COMP_NM               VARCHAR(5) NOT NULL,
SPEC_NM                     VARCHAR(32) NOT NULL,
SPEC_DATATYPE               VARCHAR(40),
SPEC_DATATYPE_EXT           VARCHAR(40),
SPEC_VALUE_MIN              NUMERIC(12,4),
SPEC_VALUE_MAX              NUMERIC(12,4),
SPEC_VALUE_INCR             NUMERIC(12,4),
HIDDEN_FLG                  INTEGER,
OVERRIDE_MODEL_COMP_NM_LIST VARCHAR(100),
REF_QUERY                   VARCHAR(500),
GENERATE_PREFIX_NM          VARCHAR(40),
GENERATE_SUFFIX_MAX         VARCHAR(40),
SPEC_VALUE_LIST_DELIMITER   VARCHAR(3),
SPEC_DESC                   VARCHAR(100),
DESC_KEY                    VARCHAR(100),
PRIMARY KEY (MODEL_COMP_NM,SPEC_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MODEL_SPEC_TEMPLATE
(
MODEL_SPEC_ID               INTEGER NOT NULL,
MODEL_COMP_NM               VARCHAR(5) NOT NULL,
SPEC_NM                     VARCHAR(32) NOT NULL,
SPEC_TYPE                   VARCHAR(5) NOT NULL,
SPEC_VALUE                  VARCHAR(100),
PRIORITY                    VARCHAR(3),
CREATED_DTTM                DATE,
CREATED_BY                  VARCHAR(20),
PRIMARY KEY (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MODEL_SPEC_VALUES
(
MODEL_COMP_NM               VARCHAR(5) NOT NULL,
SPEC_NM                     VARCHAR(32) NOT NULL,
SPEC_VALUE                  VARCHAR(100),
SPEC_VALUE_DESC             VARCHAR(100),
SPEC_VALUE_DESC_KEY         VARCHAR(100),
PRIMARY KEY (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MODEL_SPEC_WORKFLOW
(
TASK_NM                     VARCHAR(40) NOT NULL,
PARENT_TASK_NM              VARCHAR(40),
TASK_DESC                   VARCHAR(100),
TASK_DESC_KEY               VARCHAR(100),
TASK_LVL                    INTEGER,
SPEC_NM                     VARCHAR(32),
SPEC_TYPE                   VARCHAR(5),
MODEL_COMP_NM               VARCHAR(5),
DOW_FLG                     INTEGER,
HALO_FLG                    INTEGER,
PRIMARY KEY (TASK_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE SCORING_PARAM_CONFIG
(
EFFECT_TYPE                 VARCHAR(40) NOT NULL,
EFFECT_CATEGORY             VARCHAR(40) NOT NULL,
TSF_TYPE                    INTEGER NOT NULL,
EFFECT_EST                  NUMERIC(12,4),
EFFECT_EST_U                NUMERIC(12,4),
EFFECT_EST_L                NUMERIC(12,4),
COUNTER                     VARCHAR(40),
PRIMARY KEY (EFFECT_TYPE,EFFECT_CATEGORY,TSF_TYPE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE SCORING_PARAM_DEFAULT
(
GEO_HIER_SK                 INTEGER NOT NULL,
PROD_HIER_SK                INTEGER NOT NULL,
EFFECT_TYPE                 VARCHAR(40) NOT NULL,
EFFECT_CATEGORY             VARCHAR(40) NOT NULL,
TSF_TYPE                    INTEGER NOT NULL,
EFFECT_EST                  NUMERIC(12,4),
EFFECT_EST_U                NUMERIC(12,4),
EFFECT_EST_L                NUMERIC(12,4),
PRIMARY KEY (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,TSF_TYPE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
***********************************************************************************************;
 
 
data ATTR_SPEC;
 
 
attrib MODEL_GROUP_ID                      length=4                                            ;
 
 
attrib ATTR_SK                             length=4                                            ;
 
 
attrib EFFECT_CLASS_NM                     length=$40                                          ;
 
 
attrib SELECTION_TYPE                      length=4                                            ;
 
 
attrib ATTR_USAGE                          length=4                                            ;
 
 
attrib CREATED_DTTM                        length=8      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT  ;
 
 
attrib CREATED_BY                          length=$20                                          ;
 
 
stop; run;
 
 
 
 
***********************************************************************************************;
 
 
data BASE_FORECAST_OVERRIDE_GP;
 
 
attrib GEO_HIER_SK                         length=4                                            ;
 
 
attrib PROD_HIER_SK                        length=6                                            ;
 
 
attrib START_DATE_SK                       length=4                                            ;
 
 
attrib END_DATE_SK                         length=4                                            ;
 
 
attrib OVERRIDE_FACTOR                     length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table BASE_FORECAST_OVERRIDE_GP add CONSTRAINT PRIM_KEY PRIMARY KEY (GEO_HIER_SK, PROD_HIER_SK, START_DATE_SK);
 
 
alter table BASE_FORECAST_OVERRIDE_GP add NOT NULL (END_DATE_SK);
 
 
quit;
 
 
 
proc sql;
 
 
CREATE INDEX BF_OGP_IX1 ON BASE_FORECAST_OVERRIDE_GP(GEO_HIER_SK, PROD_HIER_SK);
 
 
quit;
 
 
***********************************************************************************************;
 
 
 
data BASE_FORECAST_OVERRIDE_MG;
 
 
attrib MODEL_GROUP_ID                      length=4                                            ;
 
 
attrib START_DATE_SK                       length=4                                            ;
 
 
attrib END_DATE_SK                         length=4                                            ;
 
 
attrib OVERRIDE_FACTOR                     length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table BASE_FORECAST_OVERRIDE_MG add CONSTRAINT PRIM_KEY PRIMARY KEY (MODEL_GROUP_ID, START_DATE_SK);
 
 
alter table BASE_FORECAST_OVERRIDE_MG add NOT NULL (END_DATE_SK);
 
 
quit;
 
 
 
proc sql;
 
 
CREATE INDEX MODEL_GROUP_ID ON BASE_FORECAST_OVERRIDE_MG(MODEL_GROUP_ID);
 
 
quit;
 
 
***********************************************************************************************;
 
 
 
data CONFIG_AUDIT_TRAIL;
 
 
attrib AUDIT_TRAIL_SK                      length=6                                            ;
 
 
attrib ACTION_TYPE                         length=$40                                          ;
 
 
attrib OBJECT_TYPE                         length=$40                                          ;
 
 
attrib OBJECT_NM                           length=$100                                         ;
 
 
attrib NEW_VALUE                           length=$255                                         ;
 
 
attrib OLD_VALUE                           length=$255                                         ;
 
 
attrib GEO_HIER_SK                         length=4                                            ;
 
 
attrib PROD_HIER_SK                        length=6                                            ;
 
 
attrib USER_NM                             length=$40                                          ;
 
 
attrib CREATED_DTTM                        length=8      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT  ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table CONFIG_AUDIT_TRAIL add CONSTRAINT PRIM_KEY PRIMARY KEY (AUDIT_TRAIL_SK);
 
 
alter table CONFIG_AUDIT_TRAIL add NOT NULL (CREATED_DTTM);
 
 
quit;
 
 
 
proc sql;
 
 
CREATE INDEX OBJECT_TYPE ON CONFIG_AUDIT_TRAIL(OBJECT_TYPE);
 
 
quit;
 
 
***********************************************************************************************;
 
 
 
 
data CONFIG_GROUP;
 
 
attrib CONFIG_GROUP_ID                     length=4                                            ;
 
 
attrib CONFIG_GROUP_NM                     length=$40                                          ;
 
 
attrib NUM_OF_MODEL_GROUPS                 length=4                                            ;
 
 
attrib CONFIG_TEMPLATE_ID                  length=4                                            ;
 
 
attrib GEO_HIER_TYPE                       length=4                                            ;
 
 
attrib PROD_HIER_TYPE                      length=4                                            ;
 
 
attrib GEO_HIER_ASSOC_CD                   length=4                                            ;
 
 
attrib PROD_HIER_ASSOC_CD                  length=4                                            ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table CONFIG_GROUP add CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIG_GROUP_ID);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data DATA_CONFIG;
 
 
attrib DATA_CONFIG_SK                      length=4                                            ;
 
 
attrib MODEL_GROUP_ID                      length=4                                            ;
 
 
attrib DATA_LVL_ID                         length=4                                            ;
 
 
attrib GEO_HIER_SK                         length=4                                            ;
 
 
attrib PROD_HIER_SK                        length=6                                            ;
 
 
attrib MODEL_COMP_NM                       length=$5                                           ;
 
 
attrib BY_GEO_LVL                          length=4                                            ;
 
 
attrib BY_PROD_LVL                         length=4                                            ;
 
 
attrib CREATED_DTTM                        length=8      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT  ;
 
 
attrib CREATED_BY                          length=$20                                          ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table DATA_CONFIG add CONSTRAINT PRIM_KEY PRIMARY KEY (DATA_CONFIG_SK);
 
 
alter table DATA_CONFIG add NOT NULL (MODEL_GROUP_ID);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data DATA_CONFIG_TEMPLATE;
 
 
attrib CONFIG_TEMPLATE_ID                  length=4                                            ;
 
 
attrib CONFIG_TEMPLATE_NM                  length=$40                                          ;
 
 
attrib CONFIG_TEMPLATE_DESC                length=$100                                         ;
 
 
attrib INCLUDE_TS                          length=4                                            ;
 
 
attrib TS_GEO_LVL                          length=4                                            ;
 
 
attrib TS_PROD_LVL                         length=4                                            ;
 
 
attrib TS_BY_GEO_LVL                       length=4                                            ;
 
 
attrib TS_BY_PROD_LVL                      length=4                                            ;
 
 
attrib INCLUDE_REG                         length=4                                            ;
 
 
attrib REG_GEO_LVL                         length=4                                            ;
 
 
attrib REG_PROD_LVL                        length=4                                            ;
 
 
attrib REG_BY_GEO_LVL                      length=4                                            ;
 
 
attrib REG_BY_PROD_LVL                     length=4                                            ;
 
 
attrib FCST_GEO_LVL                        length=4                                            ;
 
 
attrib FCST_PROD_LVL                       length=4                                            ;
 
 
attrib FCST_BY_GEO_LVL                     length=4                                            ;
 
 
attrib FCST_BY_PROD_LVL                    length=4                                            ;
 
 
attrib CREATED_DTTM                        length=8      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT  ;
 
 
attrib CREATED_BY                          length=$20                                          ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table DATA_CONFIG_TEMPLATE add CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIG_TEMPLATE_ID);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
 
data GLOBAL_SETTING_DETAILS;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib APP                                 length=$40                                          ;
 
 
attrib CONFIG_CD                           length=4                                            ;
 
 
attrib DEFAULT_SPEC_VALUE                  length=$100                                         ;
 
 
attrib SPEC_DATATYPE                       length=$40                                          ;
 
 
attrib SPEC_DATATYPE_EXT                   length=$40                                          ;
 
 
attrib SPEC_VALUE_MIN                      length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib SPEC_VALUE_MAX                      length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib SPEC_VALUE_INCR                     length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib EDITABLE_FLG                        length=4                                            ;
 
 
attrib ENABLED_FLG                         length=4                                            ;
 
 
attrib REQUIRED_FLG                        length=4                                            ;
 
 
attrib HIDDEN_FLG                          length=4                                            ;
 
 
attrib MISSING_VAL_OK_FLG                  length=4                                            ;
 
 
attrib OVERRIDE_APP_LIST                   length=$100                                         ;
 
 
attrib REF_QUERY                           length=$500                                         ;
 
 
attrib GENERATE_PREFIX_NM                  length=$40                                          ;
 
 
attrib GENERATE_SUFFIX_MAX                 length=$40                                          ;
 
 
attrib SPEC_VALUE_LIST_DELIMITER           length=$3                                           ;
 
 
attrib DESC_KEY                            length=$100                                         ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table GLOBAL_SETTING_DETAILS add CONSTRAINT PRIM_KEY PRIMARY KEY (SPEC_NM, APP, CONFIG_CD);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data GLOBAL_SETTING_GROUP;
 
 
attrib GLOBAL_SETTING_GROUP_NM             length=$40                                          ;
 
 
attrib GLOBAL_SETTING_GROUP_DESC           length=$100                                         ;
 
 
attrib GLOBAL_SETTING_GROUP_DESC_KEY       length=$100                                         ;
 
 
attrib GLOBAL_SETTING_CATEGORY_FLG         length=4                                            ;
 
 
attrib SETTING_GROUP_PERMISSION_ROLE       length=$100                                         ;
 
 
attrib CONFIG_CD                           length=4                                            ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table GLOBAL_SETTING_GROUP add CONSTRAINT PRIM_KEY PRIMARY KEY (GLOBAL_SETTING_GROUP_NM);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data GLOBAL_SETTING_GROUP_MEMBER;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib APP                                 length=$40                                          ;
 
 
attrib GLOBAL_SETTING_GROUP_NM             length=$40                                          ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table GLOBAL_SETTING_GROUP_MEMBER add CONSTRAINT PRIM_KEY PRIMARY KEY (SPEC_NM, APP, GLOBAL_SETTING_GROUP_NM);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data GLOBAL_SETTING_VALUES;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib APP                                 length=$40                                          ;
 
 
attrib SPEC_VALUE                          length=$100                                         ;
 
 
attrib SPEC_VALUE_DESC                     length=$100                                         ;
 
 
attrib SPEC_VALUE_DESC_KEY                 length=$100                                         ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table GLOBAL_SETTING_VALUES add CONSTRAINT PRIM_KEY PRIMARY KEY (SPEC_NM, APP, SPEC_VALUE);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data MA_SPEC_SEED;
 
 
attrib MODEL_GROUP_ID                      length=4                                            ;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib USER_NM                             length=$60                                          ;
 
 
attrib SPEC_VALUE                          length=$200                                         ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table MA_SPEC_SEED add CONSTRAINT PRIM_KEY PRIMARY KEY (MODEL_GROUP_ID, SPEC_NM, USER_NM);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data MODEL_GEO_PROD_STATUS_RULE;
 
 
attrib PROD_HIER_SK                        length=6                                            ;
 
 
attrib RULE_NM                             length=$32                                          ;
 
 
attrib RULE_VALUE                          length=$100                                         ;
 
 
attrib CREATED_DTTM                        length=8      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT  ;
 
 
attrib CREATED_BY                          length=$20                                          ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table MODEL_GEO_PROD_STATUS_RULE add CONSTRAINT PRIM_KEY PRIMARY KEY (PROD_HIER_SK, RULE_NM);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data MODEL_GEO_PROD_STATUS_SPEC;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib SPEC_VALUE                          length=$100                                         ;
 
 
attrib CREATED_DTTM                        length=8      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT  ;
 
 
attrib CREATED_BY                          length=$20                                          ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table MODEL_GEO_PROD_STATUS_SPEC add CONSTRAINT PRIM_KEY PRIMARY KEY (SPEC_NM);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data MODEL_GEO_PROD_STATUS_DETAILS;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib SPEC_RULE_FLG                       length=4                                            ;
 
 
attrib DEFAULT_SPEC_VALUE                  length=$100                                         ;
 
 
attrib SPEC_DATATYPE                       length=$40                                          ;
 
 
attrib SPEC_DATATYPE_EXT                   length=$40                                          ;
 
 
attrib SPEC_VALUE_MIN                      length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib SPEC_VALUE_MAX                      length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib SPEC_VALUE_INCR                     length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib REF_QUERY                           length=$500                                         ;
 
 
attrib SPEC_VALUE_LIST_DELIMITER           length=$3                                           ;
 
 
attrib DESCRIPTION                         length=$100                                         ;
 
 
attrib DESC_KEY                            length=$100                                         ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table MODEL_GEO_PROD_STATUS_DETAILS add CONSTRAINT PRIM_KEY PRIMARY KEY (SPEC_NM, SPEC_RULE_FLG);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
 
data MODEL_GEO_PROD_STATUS_VALUES;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib SPEC_RULE_FLG                       length=4                                            ;
 
 
attrib SPEC_VALUE                          length=$100                                         ;
 
 
attrib SPEC_VALUE_DESC                     length=$100                                         ;
 
 
attrib SPEC_VALUE_DESC_KEY                 length=$100                                         ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table MODEL_GEO_PROD_STATUS_VALUES add CONSTRAINT PRIM_KEY PRIMARY KEY (SPEC_NM, SPEC_RULE_FLG, SPEC_VALUE);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data MODEL_GROUP;
 
 
attrib MODEL_GROUP_ID                      length=4                                            ;
 
 
attrib PROD_HIER_SK                        length=6                                            ;
 
 
attrib GEO_HIER_SK                         length=4                                            ;
 
 
attrib NUM_GEO_PRODS                       length=6                                            ;
 
 
attrib SCHEDULED_FLG                       length=4                                            ;
 
 
attrib ENABLED_FLG                         length=4                                            ;
 
 
attrib REFRESH_FREQ                        length=6                                            ;
 
 
attrib CONFIG_GROUP_ID                     length=4                                            ;
 
 
attrib SEASON                              length=$20                                          ;
 
 
attrib TAG                                 length=$40                                          ;
 
 
attrib LAST_REFRESH_DTTM                   length=8      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT  ;
 
 
attrib CONFIG_TEMPLATE_ID                  length=4                                            ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table MODEL_GROUP add CONSTRAINT PRIM_KEY PRIMARY KEY (MODEL_GROUP_ID);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data MODEL_SPEC;
 
 
attrib MODEL_GROUP_ID                      length=4                                            ;
 
 
attrib MODEL_COMP_NM                       length=$5                                           ;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib SPEC_TYPE                           length=$5                                           ;
 
 
attrib SPEC_VALUE                          length=$100                                         ;
 
 
attrib PRIORITY                            length=$3                                           ;
 
 
attrib CREATED_DTTM                        length=8      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT  ;
 
 
attrib CREATED_BY                          length=$20                                          ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table MODEL_SPEC add CONSTRAINT PRIM_KEY PRIMARY KEY (MODEL_GROUP_ID, MODEL_COMP_NM, SPEC_NM, SPEC_TYPE);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data MODEL_SPEC_DEFAULT;
 
 
attrib MODEL_COMP_NM                       length=$5                                           ;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib SPEC_TYPE                           length=$5                                           ;
 
 
attrib DEFAULT_SPEC_VALUE                  length=$100                                         ;
 
 
attrib PRIORITY                            length=$3                                           ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table MODEL_SPEC_DEFAULT add CONSTRAINT PRIM_KEY PRIMARY KEY (MODEL_COMP_NM, SPEC_NM, SPEC_TYPE);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data MODEL_SPEC_DETAILS;
 
 
attrib MODEL_COMP_NM                       length=$5                                           ;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib SPEC_DATATYPE                       length=$40                                          ;
 
 
attrib SPEC_DATATYPE_EXT                   length=$40                                          ;
 
 
attrib SPEC_VALUE_MIN                      length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib SPEC_VALUE_MAX                      length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib SPEC_VALUE_INCR                     length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib HIDDEN_FLG                          length=4                                            ;
 
 
attrib OVERRIDE_MODEL_COMP_NM_LIST         length=$100                                         ;
 
 
attrib REF_QUERY                           length=$500                                         ;
 
 
attrib GENERATE_PREFIX_NM                  length=$40                                          ;
 
 
attrib GENERATE_SUFFIX_MAX                 length=$40                                          ;
 
 
attrib SPEC_VALUE_LIST_DELIMITER           length=$3                                           ;
 
 
attrib SPEC_DESC                           length=$100                                         ;
 
 
attrib DESC_KEY                            length=$100                                         ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table MODEL_SPEC_DETAILS add CONSTRAINT PRIM_KEY PRIMARY KEY (MODEL_COMP_NM, SPEC_NM);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data MODEL_SPEC_TEMPLATE;
 
 
attrib MODEL_SPEC_ID                       length=4                                            ;
 
 
attrib MODEL_COMP_NM                       length=$5                                           ;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib SPEC_TYPE                           length=$5                                           ;
 
 
attrib SPEC_VALUE                          length=$100                                         ;
 
 
attrib PRIORITY                            length=$3                                           ;
 
 
attrib CREATED_DTTM                        length=8      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT  ;
 
 
attrib CREATED_BY                          length=$20                                          ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table MODEL_SPEC_TEMPLATE add CONSTRAINT PRIM_KEY PRIMARY KEY (MODEL_SPEC_ID, MODEL_COMP_NM, SPEC_NM, SPEC_TYPE);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data MODEL_SPEC_VALUES;
 
 
attrib MODEL_COMP_NM                       length=$5                                           ;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib SPEC_VALUE                          length=$100                                         ;
 
 
attrib SPEC_VALUE_DESC                     length=$100                                         ;
 
 
attrib SPEC_VALUE_DESC_KEY                 length=$100                                         ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table MODEL_SPEC_VALUES add CONSTRAINT PRIM_KEY PRIMARY KEY (MODEL_COMP_NM, SPEC_NM, SPEC_VALUE);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data MODEL_SPEC_WORKFLOW;
 
 
attrib TASK_NM                             length=$40                                          ;
 
 
attrib PARENT_TASK_NM                      length=$40                                          ;
 
 
attrib TASK_DESC                           length=$100                                         ;
 
 
attrib TASK_DESC_KEY                       length=$100                                         ;
 
 
attrib TASK_LVL                            length=4                                            ;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib SPEC_TYPE                           length=$5                                           ;
 
 
attrib MODEL_COMP_NM                       length=$5                                           ;
 
 
attrib DOW_FLG                             length=4                                            ;
 
 
attrib HALO_FLG                            length=4                                            ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table MODEL_SPEC_WORKFLOW add CONSTRAINT PRIM_KEY PRIMARY KEY (TASK_NM);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data SCORING_PARAM_CONFIG;
 
 
attrib EFFECT_TYPE                         length=$40                                          ;
 
 
attrib EFFECT_CATEGORY                     length=$40                                          ;
 
 
attrib TSF_TYPE                            length=4                                            ;
 
 
attrib EFFECT_EST                          length=8      FORMAT=NLNUM12.4   INFORMAT=NLNUM12.4 ;
 
 
attrib EFFECT_EST_U                        length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib EFFECT_EST_L                        length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib COUNTER                             length=$40                                          ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table SCORING_PARAM_CONFIG add CONSTRAINT PRIM_KEY PRIMARY KEY (EFFECT_TYPE, EFFECT_CATEGORY, TSF_TYPE);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
data SCORING_PARAM_DEFAULT;
 
 
attrib GEO_HIER_SK                         length=4                                            ;
 
 
attrib PROD_HIER_SK                        length=6                                            ;
 
 
attrib EFFECT_TYPE                         length=$40                                          ;
 
 
attrib EFFECT_CATEGORY                     length=$40                                          ;
 
 
attrib TSF_TYPE                            length=4                                            ;
 
 
attrib EFFECT_EST                          length=8      FORMAT=NLNUM12.4   INFORMAT=NLNUM12.4 ;
 
 
attrib EFFECT_EST_U                        length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib EFFECT_EST_L                        length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table SCORING_PARAM_DEFAULT
add CONSTRAINT PRIM_KEY PRIMARY KEY (GEO_HIER_SK, PROD_HIER_SK, EFFECT_TYPE, EFFECT_CATEGORY, TSF_TYPE);
 
 
quit;
 
 
 
***********************************************************************************************;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: MOVE_WRKBNCH_MNGD_TABLES;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: MOVE_WRKBNCH_MNGD_TABLES;
%put ERROR- Description                              : Move workbench managed tables to Oracle;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 07APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: MOVE_WRKBNCH_MNGD_TABLES;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"MOVE_WRKBNCH_MNGD_TABLES",
"Move workbench managed tables to Oracle",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%MOVE_WRKBNCH_MNGD_TABLES:;
 
 
* End of changes for CHANGE_ID:MOVE_WRKBNCH_MNGD_TABLES;
 
 
***********************************************************************************************;
*************************************  End Change MOVE_WRKBNCH_MNGD_TABLES ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change GET_DATA_FROM_DI_DM ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: GET_DATA_FROM_DI_DM;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("GET_DATA_FROM_DI_DM")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(DI_TRANS)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: DI_TRANS;
%put NOTE: Change ID                             :GET_DATA_FROM_DI_DM;
%goto GET_DATA_FROM_DI_DM;
 
%end;
%if not (%sysfunc(libref(DI_DATA)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: DI_DATA;
%put NOTE: Change ID                             :GET_DATA_FROM_DI_DM;
%goto GET_DATA_FROM_DI_DM;
 
%end;
%if not (%sysfunc(exist(&m_di_data..MODEL_SPEC))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_data..MODEL_SPEC;
%put NOTE: Change ID                             :GET_DATA_FROM_DI_DM;
%goto GET_DATA_FROM_DI_DM;
 
%end;
%if not (%sysfunc(exist(&m_di_data..ATTR_SPEC))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_data..ATTR_SPEC;
%put NOTE: Change ID                             :GET_DATA_FROM_DI_DM;
%goto GET_DATA_FROM_DI_DM;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : GET_DATA_FROM_DI_DM;
%goto GET_DATA_FROM_DI_DM;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : GET_DATA_FROM_DI_DM;
* Insert record into change management table for CHANGE_ID: GET_DATA_FROM_DI_DM;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"GET_DATA_FROM_DI_DM",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto GET_DATA_FROM_DI_DM;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
* first change USAGE source column in ATTR_SPEC to ATTR_USAGE;
 
 
data work.ATTR_SPEC_OLD;
 
 
attrib ATTR_USAGE          length=4 ;
 
 
drop USAGE;
 
 
 
SET &m_di_data..ATTR_SPEC;
 
 
ATTR_USAGE=USAGE;
 
 
run;
 
 
 
 
 
proc append base = &m_di_trans..ATTR_SPEC data = work.ATTR_SPEC_OLD force; run;
 
 
proc append base = &m_di_trans..BASE_FORECAST_OVERRIDE_GP data = &m_di_data..BASE_FORECAST_OVERRIDE_GP force; run;
 
 
proc append base = &m_di_trans..BASE_FORECAST_OVERRIDE_MG data = &m_di_data..BASE_FORECAST_OVERRIDE_MG force; run;
 
 
proc append base = &m_di_trans..CONFIG_AUDIT_TRAIL data = &m_di_data..CONFIG_AUDIT_TRAIL force; run;
 
 
proc append base = &m_di_trans..CONFIG_GROUP data = &m_di_data..CONFIG_GROUP force; run;
 
 
proc append base = &m_di_trans..DATA_CONFIG data = &m_di_data..DATA_CONFIG force; run;
 
 
proc append base = &m_di_trans..DATA_CONFIG_TEMPLATE data = &m_di_data..DATA_CONFIG_TEMPLATE force; run;
 
 
proc append base = &m_di_trans..GLOBAL_SETTING_DETAILS data = &m_di_data..GLOBAL_SETTING_DETAILS force; run;
 
 
proc append base = &m_di_trans..GLOBAL_SETTING_GROUP data = &m_di_data..GLOBAL_SETTING_GROUP force; run;
 
 
proc append base = &m_di_trans..GLOBAL_SETTING_GROUP_MEMBER data = &m_di_data..GLOBAL_SETTING_GROUP_MEMBER force; run;
 
 
proc append base = &m_di_trans..GLOBAL_SETTING_VALUES data = &m_di_data..GLOBAL_SETTING_VALUES force; run;
 
 
proc append base = &m_di_trans..MA_SPEC_SEED data = &m_di_data..MA_SPEC force; run;
 
 
proc append base = &m_di_trans..MODEL_GEO_PROD_STATUS_RULE data = &m_di_data..MODEL_GEO_PROD_STATUS_RULE force; run;
 
 
proc append base = &m_di_trans..MODEL_GEO_PROD_STATUS_SPEC data = &m_di_data..MODEL_GEO_PROD_STATUS_SPEC force; run;
 
 
proc append base = &m_di_trans..MODEL_GEO_PROD_STATUS_DETAILS data = &m_di_data..MODEL_GEO_PROD_STATUS_DETAILS force; run;
 
 
proc append base = &m_di_trans..MODEL_GEO_PROD_STATUS_VALUES data = &m_di_data..MODEL_GEO_PROD_STATUS_VALUES force; run;
 
 
proc append base = &m_di_trans..MODEL_GROUP data = &m_di_data..MODEL_GROUP force; run;
 
 
proc append base = &m_di_trans..MODEL_SPEC data = &m_di_data..MODEL_SPEC force; run;
 
 
proc append base = &m_di_trans..MODEL_SPEC_DEFAULT data = &m_di_data..MODEL_SPEC_DEFAULT force; run;
 
 
proc append base = &m_di_trans..MODEL_SPEC_DETAILS data = &m_di_data..MODEL_SPEC_DETAILS force; run;
 
 
proc append base = &m_di_trans..MODEL_SPEC_TEMPLATE data = &m_di_data..MODEL_SPEC_TEMPLATE force; run;
 
 
proc append base = &m_di_trans..MODEL_SPEC_VALUES data = &m_di_data..MODEL_SPEC_VALUES force; run;
 
 
proc append base = &m_di_trans..MODEL_SPEC_WORKFLOW data = &m_di_data..MODEL_SPEC_WORKFLOW force; run;
 
 
proc append base = &m_di_trans..SCORING_PARAM_CONFIG data = &m_di_data..SCORING_PARAM_CONFIG force; run;
 
 
proc append base = &m_di_trans..SCORING_PARAM_DEFAULT data = &m_di_data..SCORING_PARAM_DEFAULT force; run;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
* first change USAGE source column in ATTR_SPEC to ATTR_USAGE;
 
 
data work.ATTR_SPEC_OLD;
 
 
attrib ATTR_USAGE          length=4 ;
 
 
drop USAGE;
 
 
 
SET &m_di_data..ATTR_SPEC;
 
 
ATTR_USAGE=USAGE;
 
 
run;
 
 
 
 
 
proc append base = &m_di_trans..ATTR_SPEC data = work.ATTR_SPEC_OLD force; run;
 
 
proc append base = &m_di_trans..BASE_FORECAST_OVERRIDE_GP data = &m_di_data..BASE_FORECAST_OVERRIDE_GP force; run;
 
 
proc append base = &m_di_trans..BASE_FORECAST_OVERRIDE_MG data = &m_di_data..BASE_FORECAST_OVERRIDE_MG force; run;
 
 
proc append base = &m_di_trans..CONFIG_AUDIT_TRAIL data = &m_di_data..CONFIG_AUDIT_TRAIL force; run;
 
 
proc append base = &m_di_trans..CONFIG_GROUP data = &m_di_data..CONFIG_GROUP force; run;
 
 
proc append base = &m_di_trans..DATA_CONFIG data = &m_di_data..DATA_CONFIG force; run;
 
 
proc append base = &m_di_trans..DATA_CONFIG_TEMPLATE data = &m_di_data..DATA_CONFIG_TEMPLATE force; run;
 
 
proc append base = &m_di_trans..GLOBAL_SETTING_DETAILS data = &m_di_data..GLOBAL_SETTING_DETAILS force; run;
 
 
proc append base = &m_di_trans..GLOBAL_SETTING_GROUP data = &m_di_data..GLOBAL_SETTING_GROUP force; run;
 
 
proc append base = &m_di_trans..GLOBAL_SETTING_GROUP_MEMBER data = &m_di_data..GLOBAL_SETTING_GROUP_MEMBER force; run;
 
 
proc append base = &m_di_trans..GLOBAL_SETTING_VALUES data = &m_di_data..GLOBAL_SETTING_VALUES force; run;
 
 
proc append base = &m_di_trans..MA_SPEC_SEED data = &m_di_data..MA_SPEC force; run;
 
 
proc append base = &m_di_trans..MODEL_GEO_PROD_STATUS_RULE data = &m_di_data..MODEL_GEO_PROD_STATUS_RULE force; run;
 
 
proc append base = &m_di_trans..MODEL_GEO_PROD_STATUS_SPEC data = &m_di_data..MODEL_GEO_PROD_STATUS_SPEC force; run;
 
 
proc append base = &m_di_trans..MODEL_GEO_PROD_STATUS_DETAILS data = &m_di_data..MODEL_GEO_PROD_STATUS_DETAILS force; run;
 
 
proc append base = &m_di_trans..MODEL_GEO_PROD_STATUS_VALUES data = &m_di_data..MODEL_GEO_PROD_STATUS_VALUES force; run;
 
 
proc append base = &m_di_trans..MODEL_GROUP data = &m_di_data..MODEL_GROUP force; run;
 
 
proc append base = &m_di_trans..MODEL_SPEC data = &m_di_data..MODEL_SPEC force; run;
 
 
proc append base = &m_di_trans..MODEL_SPEC_DEFAULT data = &m_di_data..MODEL_SPEC_DEFAULT force; run;
 
 
proc append base = &m_di_trans..MODEL_SPEC_DETAILS data = &m_di_data..MODEL_SPEC_DETAILS force; run;
 
 
proc append base = &m_di_trans..MODEL_SPEC_TEMPLATE data = &m_di_data..MODEL_SPEC_TEMPLATE force; run;
 
 
proc append base = &m_di_trans..MODEL_SPEC_VALUES data = &m_di_data..MODEL_SPEC_VALUES force; run;
 
 
proc append base = &m_di_trans..MODEL_SPEC_WORKFLOW data = &m_di_data..MODEL_SPEC_WORKFLOW force; run;
 
 
proc append base = &m_di_trans..SCORING_PARAM_CONFIG data = &m_di_data..SCORING_PARAM_CONFIG force; run;
 
 
proc append base = &m_di_trans..SCORING_PARAM_DEFAULT data = &m_di_data..SCORING_PARAM_DEFAULT force; run;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: GET_DATA_FROM_DI_DM;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: GET_DATA_FROM_DI_DM;
%put ERROR- Description                              : Get data for workbench managed tables from di_data to di_trans;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 07APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: GET_DATA_FROM_DI_DM;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"GET_DATA_FROM_DI_DM",
"Get data for workbench managed tables from di_data to di_trans",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%GET_DATA_FROM_DI_DM:;
 
 
* End of changes for CHANGE_ID:GET_DATA_FROM_DI_DM;
 
 
***********************************************************************************************;
*************************************  End Change GET_DATA_FROM_DI_DM ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change DROP_WRKBNCH_MNGD_TABLES ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: DROP_WRKBNCH_MNGD_TABLES;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("DROP_WRKBNCH_MNGD_TABLES")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_data.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_data.;
%put NOTE: Change ID                             :DROP_WRKBNCH_MNGD_TABLES;
%goto DROP_WRKBNCH_MNGD_TABLES;
 
%end;
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :DROP_WRKBNCH_MNGD_TABLES;
%goto DROP_WRKBNCH_MNGD_TABLES;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..attr_spec))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..attr_spec;
%put NOTE: Change ID                             :DROP_WRKBNCH_MNGD_TABLES;
%goto DROP_WRKBNCH_MNGD_TABLES;
 
%end;
%if not (%sysfunc(exist(&m_di_data..ATTR_SPEC))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_data..ATTR_SPEC;
%put NOTE: Change ID                             :DROP_WRKBNCH_MNGD_TABLES;
%goto DROP_WRKBNCH_MNGD_TABLES;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..SCORING_PARAM_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..SCORING_PARAM_DEFAULT;
%put NOTE: Change ID                             :DROP_WRKBNCH_MNGD_TABLES;
%goto DROP_WRKBNCH_MNGD_TABLES;
 
%end;
%if not (%sysfunc(exist(&m_di_data..SCORING_PARAM_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_data..SCORING_PARAM_DEFAULT;
%put NOTE: Change ID                             :DROP_WRKBNCH_MNGD_TABLES;
%goto DROP_WRKBNCH_MNGD_TABLES;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : DROP_WRKBNCH_MNGD_TABLES;
%goto DROP_WRKBNCH_MNGD_TABLES;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : DROP_WRKBNCH_MNGD_TABLES;
* Insert record into change management table for CHANGE_ID: DROP_WRKBNCH_MNGD_TABLES;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_WRKBNCH_MNGD_TABLES",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto DROP_WRKBNCH_MNGD_TABLES;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
DROP TABLE &m_di_data..ATTR_SPEC;
 
 
DROP TABLE &m_di_data..BASE_FORECAST_OVERRIDE_GP;
 
 
DROP TABLE &m_di_data..BASE_FORECAST_OVERRIDE_MG;
 
 
DROP TABLE &m_di_data..CONFIG_AUDIT_TRAIL;
 
 
DROP TABLE &m_di_data..CONFIG_GROUP;
 
 
DROP TABLE &m_di_data..DATA_CONFIG;
 
 
DROP TABLE &m_di_data..DATA_CONFIG_TEMPLATE;
 
 
DROP TABLE &m_di_data..GLOBAL_SETTING_DETAILS;
 
 
DROP TABLE &m_di_data..GLOBAL_SETTING_GROUP;
 
 
DROP TABLE &m_di_data..GLOBAL_SETTING_GROUP_MEMBER;
 
 
DROP TABLE &m_di_data..GLOBAL_SETTING_VALUES;
 
 
DROP TABLE &m_di_data..MA_SPEC_SEED;
 
 
DROP TABLE &m_di_data..MODEL_GEO_PROD_STATUS_RULE;
 
 
DROP TABLE &m_di_data..MODEL_GEO_PROD_STATUS_SPEC;
 
 
DROP TABLE &m_di_data..MODEL_GEO_PROD_STATUS_DETAILS;
 
 
DROP TABLE &m_di_data..MODEL_GEO_PROD_STATUS_VALUES;
 
 
DROP TABLE &m_di_data..MODEL_GROUP;
 
 
DROP TABLE &m_di_data..MODEL_SPEC;
 
 
DROP TABLE &m_di_data..MODEL_SPEC_DEFAULT;
 
 
DROP TABLE &m_di_data..MODEL_SPEC_DETAILS;
 
 
DROP TABLE &m_di_data..MODEL_SPEC_TEMPLATE;
 
 
DROP TABLE &m_di_data..MODEL_SPEC_VALUES;
 
 
DROP TABLE &m_di_data..MODEL_SPEC_WORKFLOW;
 
 
DROP TABLE &m_di_data..SCORING_PARAM_CONFIG;
 
 
DROP TABLE &m_di_data..SCORING_PARAM_DEFAULT;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
DROP TABLE &m_di_data..ATTR_SPEC;
 
 
DROP TABLE &m_di_data..BASE_FORECAST_OVERRIDE_GP;
 
 
DROP TABLE &m_di_data..BASE_FORECAST_OVERRIDE_MG;
 
 
DROP TABLE &m_di_data..CONFIG_AUDIT_TRAIL;
 
 
DROP TABLE &m_di_data..CONFIG_GROUP;
 
 
DROP TABLE &m_di_data..DATA_CONFIG;
 
 
DROP TABLE &m_di_data..DATA_CONFIG_TEMPLATE;
 
 
DROP TABLE &m_di_data..GLOBAL_SETTING_DETAILS;
 
 
DROP TABLE &m_di_data..GLOBAL_SETTING_GROUP;
 
 
DROP TABLE &m_di_data..GLOBAL_SETTING_GROUP_MEMBER;
 
 
DROP TABLE &m_di_data..GLOBAL_SETTING_VALUES;
 
 
DROP TABLE &m_di_data..MA_SPEC_SEED;
 
 
DROP TABLE &m_di_data..MODEL_GEO_PROD_STATUS_RULE;
 
 
DROP TABLE &m_di_data..MODEL_GEO_PROD_STATUS_SPEC;
 
 
DROP TABLE &m_di_data..MODEL_GEO_PROD_STATUS_DETAILS;
 
 
DROP TABLE &m_di_data..MODEL_GEO_PROD_STATUS_VALUES;
 
 
DROP TABLE &m_di_data..MODEL_GROUP;
 
 
DROP TABLE &m_di_data..MODEL_SPEC;
 
 
DROP TABLE &m_di_data..MODEL_SPEC_DEFAULT;
 
 
DROP TABLE &m_di_data..MODEL_SPEC_DETAILS;
 
 
DROP TABLE &m_di_data..MODEL_SPEC_TEMPLATE;
 
 
DROP TABLE &m_di_data..MODEL_SPEC_VALUES;
 
 
DROP TABLE &m_di_data..MODEL_SPEC_WORKFLOW;
 
 
DROP TABLE &m_di_data..SCORING_PARAM_CONFIG;
 
 
DROP TABLE &m_di_data..SCORING_PARAM_DEFAULT;
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: DROP_WRKBNCH_MNGD_TABLES;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: DROP_WRKBNCH_MNGD_TABLES;
%put ERROR- Description                              : Drop Workbench tables moved to RDBMS;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 11APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: DROP_WRKBNCH_MNGD_TABLES;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_WRKBNCH_MNGD_TABLES",
"Drop Workbench tables moved to RDBMS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%DROP_WRKBNCH_MNGD_TABLES:;
 
 
* End of changes for CHANGE_ID:DROP_WRKBNCH_MNGD_TABLES;
 
 
***********************************************************************************************;
*************************************  End Change DROP_WRKBNCH_MNGD_TABLES ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID752048 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID752048;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID752048")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID752048;
%goto ID752048;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID752048;
%goto ID752048;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID752048;
* Insert record into change management table for CHANGE_ID: ID752048;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID752048",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID752048;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FIXED_CAPPING_METHOD'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('FIXED_CAPPING_METHOD','REG','1','ORIGIN',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FIXED_CAPPING_METHOD';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('FIXED_CAPPING_METHOD','REG','1','ORIGIN',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID752048;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID752048;
%put ERROR- Description                              : Add FIXED_CAPPING_METHOD model spec;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 13APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID752048;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID752048",
"Add FIXED_CAPPING_METHOD model spec",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID752048:;
 
 
* End of changes for CHANGE_ID:ID752048;
 
 
***********************************************************************************************;
*************************************  End Change ID752048 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID749351 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID749351;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID749351")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID749351;
%goto ID749351;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID749351;
%goto ID749351;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID749351;
* Insert record into change management table for CHANGE_ID: ID749351;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID749351",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID749351;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'ATREG_COLD_START'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('ATREG_COLD_START','FCST','-1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'ATREG_MODULE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('ATREG_MODULE','ALL','-1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'BASELINE_OFFSET_TYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('BASELINE_OFFSET_TYPE','ALL','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'BFAVG_TSF'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('BFAVG_TSF','FCST','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'INT_LOWER_BOUND'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('INT_LOWER_BOUND','FCST','2','-100',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'MAX_PRICE_RATIO'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('MAX_PRICE_RATIO','ALL','1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('MAX_PRICE_RATIO','ALL','2','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'M_PRICE_CORR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('M_PRICE_CORR','REG','-1','0.8',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'MIN_STD_EST'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('MIN_STD_EST','REG','-1','0.00000001',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'MISSING_GP_FCST_VALUE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('MISSING_GP_FCST_VALUE','FCST','-1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_VALUES WHERE SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_VALUES
(SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC,SPEC_VALUE_DESC_KEY)
VALUES ('SALES_INTRO_FROM_GPSTATUS','FCST','1','Use sales introduction date','mspec.SALES_INTRO_FROM_GPSTATUS.truemeans.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_VALUES
(SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC,SPEC_VALUE_DESC_KEY)
VALUES ('SALES_INTRO_FROM_GPSTATUS','FCST','0','Do not use sales introduction date','mspec.SALES_INTRO_FROM_GPSTATUS.falsemeans.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'SA_SHIFT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('SA_SHIFT','ALL','-1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PF_LOWER_BOUND'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PF_LOWER_BOUND','ALL','1','0.0001',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PF_LOWER_BOUND','ALL','2','0.0001',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'ATREG_COLD_START';
 
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('ATREG_COLD_START','FCST','-1','0',NULL);
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'ATREG_MODULE';
 
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('ATREG_MODULE','ALL','-1','0',NULL);
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'BASELINE_OFFSET_TYPE';
 
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('BASELINE_OFFSET_TYPE','ALL','-1','1',NULL);
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'BFAVG_TSF';
 
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('BFAVG_TSF','FCST','-1','1',NULL);
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'INT_LOWER_BOUND';
 
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('INT_LOWER_BOUND','FCST','2','-100',NULL);
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'MAX_PRICE_RATIO';
 
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('MAX_PRICE_RATIO','ALL','1','1',NULL);
 
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('MAX_PRICE_RATIO','ALL','2','1',NULL);
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'M_PRICE_CORR';
 
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('M_PRICE_CORR','REG','-1','0.8',NULL);
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'MIN_STD_EST';
 
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('MIN_STD_EST','REG','-1','0.00000001',NULL);
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'MISSING_GP_FCST_VALUE';
 
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('MISSING_GP_FCST_VALUE','FCST','-1','0',NULL);
 
 
 
DELETE FROM MODEL_SPEC_VALUES WHERE SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS';
 
 
 
INSERT INTO MODEL_SPEC_VALUES
(SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC,SPEC_VALUE_DESC_KEY)
VALUES ('SALES_INTRO_FROM_GPSTATUS','FCST','1','Use sales introduction date','mspec.SALES_INTRO_FROM_GPSTATUS.truemeans.txt');
 
 
 
INSERT INTO MODEL_SPEC_VALUES
(SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC,SPEC_VALUE_DESC_KEY)
VALUES ('SALES_INTRO_FROM_GPSTATUS','FCST','0','Do not use sales introduction date','mspec.SALES_INTRO_FROM_GPSTATUS.falsemeans.txt');
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'SA_SHIFT';
 
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('SA_SHIFT','ALL','-1','0',NULL);
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PF_LOWER_BOUND';
 
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PF_LOWER_BOUND','ALL','1','0.0001',NULL);
 
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PF_LOWER_BOUND','ALL','2','0.0001',NULL);
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID749351;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID749351;
%put ERROR- Description                              : Fixes to model_spec_default for advanced specs;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 14APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID749351;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID749351",
"Fixes to model_spec_default for advanced specs",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID749351:;
 
 
* End of changes for CHANGE_ID:ID749351;
 
 
***********************************************************************************************;
*************************************  End Change ID749351 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID749351_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID749351_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID749351_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID749351_1;
%goto ID749351_1;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID749351_1;
%goto ID749351_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID749351_1;
* Insert record into change management table for CHANGE_ID: ID749351_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID749351_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID749351_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('SALES_INTRO_FROM_GPSTATUS','FCST','-1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS';
 
 
INSERT INTO MODEL_SPEC_DEFAULT
(SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('SALES_INTRO_FROM_GPSTATUS','FCST','-1','0',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID749351_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID749351_1;
%put ERROR- Description                              : Fixes to default for SALES_INTRO_FROM_GPSTATUS;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 14APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID749351_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID749351_1",
"Fixes to default for SALES_INTRO_FROM_GPSTATUS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID749351_1:;
 
 
* End of changes for CHANGE_ID:ID749351_1;
 
 
***********************************************************************************************;
*************************************  End Change ID749351_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change PRE_ID753541 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: PRE_ID753541;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("PRE_ID753541")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : PRE_ID753541;
%goto PRE_ID753541;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : PRE_ID753541;
* Insert record into change management table for CHANGE_ID: PRE_ID753541;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"PRE_ID753541",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto PRE_ID753541;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%di_util_delete_sequence(m_sequence_name=%str(SEQ_ALERT_COMP_THRSHLD_RULE_SK), m_schema_name=%str(&di_trans_schema))     ;
 
 
 
%di_util_delete_sequence(m_sequence_name=%str(SEQ_ALERT_COMP_RANGE_RULE_SK), m_schema_name=%str(&di_trans_schema));
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: PRE_ID753541;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: PRE_ID753541;
%put ERROR- Description                              : Drop Sequences to be created in change id ID753541;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 20APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: PRE_ID753541;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"PRE_ID753541",
"Drop Sequences to be created in change id ID753541",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%PRE_ID753541:;
 
 
* End of changes for CHANGE_ID:PRE_ID753541;
 
 
***********************************************************************************************;
*************************************  End Change PRE_ID753541 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID753541 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID753541;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID753541")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID753541;
%goto ID753541;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID753541;
* Insert record into change management table for CHANGE_ID: ID753541;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID753541",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID753541;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_ALERT_COMP_THRSHLD_RULE_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE ALERT_COMP_THRSHLD_RULE
(
ALERT_COMP_THRSHLD_RULE_SK INTEGER PRIMARY KEY,
PROD_HIER_SK                  INTEGER NOT NULL,
GEO_HIER_SK                   INTEGER NOT NULL,
GEO_HIER_ASSOC_CD             INTEGER NOT NULL,
THRESHOLD_VALUE_TYPE          INTEGER NOT NULL
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE ALERT_COMP_THRSHLD_RULE ADD CONSTRAINT ALERT_COMP_THRSHLD_RULE_IX1
UNIQUE (GEO_HIER_ASSOC_CD, PROD_HIER_SK, GEO_HIER_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_ALERT_COMP_RANGE_RULE_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE ALERT_COMP_THRSHLD_RANGE_RULE
(
ALERT_COMP_RANGE_RULE_SK   INTEGER PRIMARY KEY,
ALERT_COMP_THRSHLD_RULE_SK INTEGER ,
MIN_RANGE_VALUE               NUMERIC(12,2) NOT NULL,
MAX_RANGE_VALUE               NUMERIC(12,2) NOT NULL,
THRESHOLD_VALUE               NUMERIC(12,2) NOT NULL
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE ALERT_COMP_THRSHLD_RANGE_RULE ADD CONSTRAINT
ALERT_COMP_THRSHLD_RNG_RL_IX1 UNIQUE (ALERT_COMP_THRSHLD_RULE_SK,MIN_RANGE_VALUE, MAX_RANGE_VALUE)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
proc sql;
 
 
 
CREATE TABLE ALERT_COMP_THRSHLD_RULE
(
ALERT_COMP_THRSHLD_RULE_SK INTEGER PRIMARY KEY,
PROD_HIER_SK                  INTEGER NOT NULL,
GEO_HIER_SK                   INTEGER NOT NULL,
GEO_HIER_ASSOC_CD             INTEGER NOT NULL,
THRESHOLD_VALUE_TYPE          INTEGER NOT NULL
);
 
 
 
ALTER TABLE ALERT_COMP_THRSHLD_RULE ADD CONSTRAINT ALERT_COMP_THRSHLD_RULE_IX1
UNIQUE (GEO_HIER_ASSOC_CD, PROD_HIER_SK, GEO_HIER_SK);
 
 
 
 
CREATE TABLE ALERT_COMP_THRSHLD_RANGE_RULE
(
ALERT_COMP_RANGE_RULE_SK   INTEGER PRIMARY KEY,
ALERT_COMP_THRSHLD_RULE_SK INTEGER ,
MIN_RANGE_VALUE               NUMERIC(12,2) NOT NULL,
MAX_RANGE_VALUE               NUMERIC(12,2) NOT NULL,
THRESHOLD_VALUE               NUMERIC(12,2) NOT NULL
);
 
 
 
ALTER TABLE ALERT_COMP_THRSHLD_RANGE_RULE ADD CONSTRAINT ALERT_COMP_THRSHLD_RNG_RL_IX1
UNIQUE (ALERT_COMP_THRSHLD_RULE_SK, MIN_RANGE_VALUE, MAX_RANGE_VALUE);
 
 
 
 
quit;
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID753541;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID753541;
%put ERROR- Description                              : Adding tables for Competitor price change threshold;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 20APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID753541;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID753541",
"Adding tables for Competitor price change threshold",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID753541:;
 
 
* End of changes for CHANGE_ID:ID753541;
 
 
***********************************************************************************************;
*************************************  End Change ID753541 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID713182 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID713182;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID713182")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID713182;
%goto ID713182;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID713182;
%goto ID713182;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID713182;
* Insert record into change management table for CHANGE_ID: ID713182;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID713182",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID713182;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'HEDONIC_VOL_TSF'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('HEDONIC_VOL_TSF','ALL','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'HEDONIC_VOL_TSF';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('HEDONIC_VOL_TSF','ALL','-1','1',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID713182;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID713182;
%put ERROR- Description                              : Add HEDONIC_VOL_TSF model spec;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 25APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID713182;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID713182",
"Add HEDONIC_VOL_TSF model spec",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID713182:;
 
 
* End of changes for CHANGE_ID:ID713182;
 
 
***********************************************************************************************;
*************************************  End Change ID713182 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0750384 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0750384;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0750384")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :ID0750384;
%goto ID0750384;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0750384;
%goto ID0750384;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0750384;
* Insert record into change management table for CHANGE_ID: ID0750384;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0750384",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0750384;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
CREATE TABLE REQ_PACKREC_DELIVERY_TYPE (
REQUEST_ID               INTEGER NOT NULL,
DELIVERY_ID              INTEGER NOT NULL,
DELIVERY_TYPE_ID         INTEGER NOT NULL,
DELIVERY_TYPE_NM         VARCHAR(40)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE UNIQUE INDEX REQ_PACKREC_DEL_TYPE_PK on REQ_PACKREC_DELIVERY_TYPE (REQUEST_ID, DELIVERY_ID) nologging parallel
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_DELIVERY_TYPE ADD CONSTRAINT REQ_PACKREC_DEL_TYPE_PK PRIMARY KEY (REQUEST_ID, DELIVERY_ID) USING INDEX REQ_PACKREC_DEL_TYPE_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
CREATE TABLE &m_di_trans..REQ_PACKREC_DELIVERY_TYPE (
REQUEST_ID               INTEGER NOT NULL,
DELIVERY_ID              INTEGER NOT NULL,
DELIVERY_TYPE_ID         INTEGER NOT NULL,
DELIVERY_TYPE_NM         VARCHAR(40),
CONSTRAINT PRIM_KEY PRIMARY KEY (REQUEST_ID, DELIVERY_ID)
);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0750384;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0750384;
%put ERROR- Description                              : New Request table to support delivery types in pack recommendation;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 04APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0750384;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0750384",
"New Request table to support delivery types in pack recommendation",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0750384:;
 
 
* End of changes for CHANGE_ID:ID0750384;
 
 
***********************************************************************************************;
*************************************  End Change ID0750384 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID726328 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID726328;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID726328")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID726328;
%goto ID726328;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID726328;
%goto ID726328;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID726328;
* Insert record into change management table for CHANGE_ID: ID726328;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID726328",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID726328;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'EXCLUDE_NP_FROM_SHARE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('EXCLUDE_NP_FROM_SHARE','FCST','2','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'EXCLUDE_NP_FROM_SHARE';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('EXCLUDE_NP_FROM_SHARE','FCST','2','0',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID726328;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID726328;
%put ERROR- Description                              : Add new model spec EXCLUDE_NP_FROM_SHARE;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 03MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID726328;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID726328",
"Add new model spec EXCLUDE_NP_FROM_SHARE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID726328:;
 
 
* End of changes for CHANGE_ID:ID726328;
 
 
***********************************************************************************************;
*************************************  End Change ID726328 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change UNIFORM_TIMING_NOT_NULL ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: UNIFORM_TIMING_NOT_NULL;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("UNIFORM_TIMING_NOT_NULL")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : UNIFORM_TIMING_NOT_NULL;
%goto UNIFORM_TIMING_NOT_NULL;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2TKMI43);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : UNIFORM_TIMING_NOT_NULL;
* Insert record into change management table for CHANGE_ID: UNIFORM_TIMING_NOT_NULL;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"UNIFORM_TIMING_NOT_NULL",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto UNIFORM_TIMING_NOT_NULL;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE MDO_PLAN SET UNIFORM_TIMING_NUM_MARKDN = 0 WHERE UNIFORM_TIMING_NUM_MARKDN IS NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE MDO_PLAN SET UNIFORM_TIMING_PROD_LVL = DECISION_PROD_LVL WHERE UNIFORM_TIMING_PROD_LVL IS NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE MDO_PLAN SET UNIFORM_TIMING_GEO_LVL = DECISION_GEO_LVL WHERE UNIFORM_TIMING_GEO_LVL IS NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN
MODIFY
(
UNIFORM_TIMING_NUM_MARKDN INTEGER NOT NULL,
UNIFORM_TIMING_PROD_LVL INTEGER NOT NULL,
UNIFORM_TIMING_GEO_LVL INTEGER NOT NULL
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
Proc sql;
 
 
 
UPDATE MDO_PLAN SET UNIFORM_TIMING_NUM_MARKDN = 0 WHERE UNIFORM_TIMING_NUM_MARKDN IS NULL;
 
 
UPDATE MDO_PLAN SET UNIFORM_TIMING_PROD_LVL = DECISION_PROD_LVL WHERE UNIFORM_TIMING_PROD_LVL IS NULL;
 
 
UPDATE MDO_PLAN SET UNIFORM_TIMING_GEO_LVL = DECISION_GEO_LVL WHERE UNIFORM_TIMING_GEO_LVL IS NULL;
 
 
 
ALTER TABLE MDO_PLAN ADD NOT NULL (UNIFORM_TIMING_NUM_MARKDN);
 
 
ALTER TABLE MDO_PLAN ADD NOT NULL (UNIFORM_TIMING_PROD_LVL);
 
 
ALTER TABLE MDO_PLAN ADD NOT NULL (UNIFORM_TIMING_GEO_LVL);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: UNIFORM_TIMING_NOT_NULL;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: UNIFORM_TIMING_NOT_NULL;
%put ERROR- Description                              : Modify Uniform Timing Columns in MDO_PLAN to Not Null;
%put ERROR- Version                                  : D3MICM52,M2TKMI43;
%put ERROR- Date of Change                           : 26APR2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: UNIFORM_TIMING_NOT_NULL;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"UNIFORM_TIMING_NOT_NULL",
"Modify Uniform Timing Columns in MDO_PLAN to Not Null",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%UNIFORM_TIMING_NOT_NULL:;
 
 
* End of changes for CHANGE_ID:UNIFORM_TIMING_NOT_NULL;
 
 
***********************************************************************************************;
*************************************  End Change UNIFORM_TIMING_NOT_NULL ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID727189 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID727189;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID727189")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID727189;
%goto ID727189;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52, M2TKMI43);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID727189;
* Insert record into change management table for CHANGE_ID: ID727189;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID727189",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID727189;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT
ADD
(
DELAY_MARGIN_AMT NUMERIC(20,3),
DELAY_END_INV_AT_RISK_UNITS NUMERIC(12,2),
DELAY_MARKDN_LOSS_AMT NUMERIC(20,3),
DELAY_SALES_UNITS NUMERIC(12,2),
DELAY_END_INV_UNITS NUMERIC(12,2)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT
ADD
(
DELAY_MARGIN_AMT NUMERIC(20,3),
DELAY_END_INV_AT_RISK_UNITS NUMERIC(12,2),
DELAY_MARKDN_LOSS_AMT NUMERIC(20,3),
DELAY_SALES_UNITS NUMERIC(12,2),
DELAY_END_INV_UNITS NUMERIC(12,2)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
Proc sql;
 
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT
ADD
DELAY_MARGIN_AMT NUMERIC(20,3),
DELAY_END_INV_AT_RISK_UNITS NUMERIC(12,2),
DELAY_MARKDN_LOSS_AMT NUMERIC(20,3),
DELAY_SALES_UNITS NUMERIC(12,2),
DELAY_END_INV_UNITS NUMERIC(12,2)
;
 
 
 
ALTER TABLE MPLN_RESULT
ADD
DELAY_MARGIN_AMT NUMERIC(20,3),
DELAY_END_INV_AT_RISK_UNITS NUMERIC(12,2),
DELAY_MARKDN_LOSS_AMT NUMERIC(20,3),
DELAY_SALES_UNITS NUMERIC(12,2),
DELAY_END_INV_UNITS NUMERIC(12,2)
;
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID727189;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID727189;
%put ERROR- Description                              : Additional columns required to persist Delay Plan metrics;
%put ERROR- Version                                  : D3MICM52, M2TKMI43;
%put ERROR- Date of Change                           : 03MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID727189;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID727189",
"Additional columns required to persist Delay Plan metrics",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID727189:;
 
 
* End of changes for CHANGE_ID:ID727189;
 
 
***********************************************************************************************;
*************************************  End Change ID727189 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID755863 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID755863;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID755863")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID755863;
%goto ID755863;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52, M2TKMI43);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID755863;
* Insert record into change management table for CHANGE_ID: ID755863;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID755863",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID755863;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT
ADD
(
LOW_DEMAND_NUM_MEMBERS INTEGER
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT
ADD
(
LOW_DEMAND_NUM_MEMBERS INTEGER
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
Proc sql;
 
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT
ADD
LOW_DEMAND_NUM_MEMBERS INTEGER
;
 
 
 
ALTER TABLE MPLN_RESULT
ADD
LOW_DEMAND_NUM_MEMBERS INTEGER
;
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID755863;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID755863;
%put ERROR- Description                              : Add Count of Low Baseline demand prod/geo as a new Markdown metrics;
%put ERROR- Version                                  : D3MICM52, M2TKMI43;
%put ERROR- Date of Change                           : 03MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID755863;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID755863",
"Add Count of Low Baseline demand prod/geo as a new Markdown metrics",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID755863:;
 
 
* End of changes for CHANGE_ID:ID755863;
 
 
***********************************************************************************************;
*************************************  End Change ID755863 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID750624 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID750624;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID750624")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID750624;
%goto ID750624;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID750624;
%goto ID750624;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID750624;
* Insert record into change management table for CHANGE_ID: ID750624;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID750624",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID750624;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'FCST_DISAGG_METHOD'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('FCST_DISAGG_METHOD','FCST','1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('FCST_DISAGG_METHOD','FCST','2','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'FCST_DISAGG_METHOD';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('FCST_DISAGG_METHOD','FCST','1','1',NULL);
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('FCST_DISAGG_METHOD','FCST','2','1',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID750624;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID750624;
%put ERROR- Description                              : Add new model spec FCST_DISAGG_METHOD;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 04MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID750624;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID750624",
"Add new model spec FCST_DISAGG_METHOD",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID750624:;
 
 
* End of changes for CHANGE_ID:ID750624;
 
 
***********************************************************************************************;
*************************************  End Change ID750624 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID749317 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID749317;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID749317")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID749317;
%goto ID749317;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID749317;
* Insert record into change management table for CHANGE_ID: ID749317;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID749317",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID749317;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE ALERT_COST ADD INVC_COST_AMT_CHANGE NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE ALERT_COST ADD INVC_COST_PCT_CHANGE NUMERIC(12,2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
 
ALTER TABLE ALERT_COST ADD INVC_COST_AMT_CHANGE NUMERIC(20,3);
 
 
ALTER TABLE ALERT_COST ADD INVC_COST_PCT_CHANGE NUMERIC(12,2);
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID749317;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID749317;
%put ERROR- Description                              : Display current cost and cost change in new cost alerts;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 04MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID749317;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID749317",
"Display current cost and cost change in new cost alerts",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID749317:;
 
 
* End of changes for CHANGE_ID:ID749317;
 
 
***********************************************************************************************;
*************************************  End Change ID749317 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID750199 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID750199;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID750199")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID750199;
%goto ID750199;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID750199;
%goto ID750199;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID750199;
* Insert record into change management table for CHANGE_ID: ID750199;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID750199",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID750199;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PRICE_SP' AND MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PRICE_SP','TS','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PRICE_SS' AND MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PRICE_SS','TS','-1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PS_SP' AND MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PS_SP','TS','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PS_SS' AND MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PS_SS','TS','-1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'INV_ADJ_SP' AND MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('INV_ADJ_SP','TS','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'INV_ADJ_SS' AND MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('INV_ADJ_SS','TS','-1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PL_ADJ_SP' AND MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PL_ADJ_SP','TS','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PL_ADJ_SS' AND MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PL_ADJ_SS','TS','-1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'SEASON_SP' AND MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('SEASON_SP','TS','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'SEASON_SS' AND MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('SEASON_SS','TS','-1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PRICE_SP' AND MODEL_COMP_NM = 'TS';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PRICE_SP','TS','-1','1',NULL);
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PRICE_SS' AND MODEL_COMP_NM = 'TS';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PRICE_SS','TS','-1','0',NULL);
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PS_SP' AND MODEL_COMP_NM = 'TS';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PS_SP','TS','-1','1',NULL);
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PS_SS' AND MODEL_COMP_NM = 'TS';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PS_SS','TS','-1','0',NULL);
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'INV_ADJ_SP' AND MODEL_COMP_NM = 'TS';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('INV_ADJ_SP','TS','-1','1',NULL);
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'INV_ADJ_SS' AND MODEL_COMP_NM = 'TS';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('INV_ADJ_SS','TS','-1','0',NULL);
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PL_ADJ_SP' AND MODEL_COMP_NM = 'TS';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PL_ADJ_SP','TS','-1','1',NULL);
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'PL_ADJ_SS' AND MODEL_COMP_NM = 'TS';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('PL_ADJ_SS','TS','-1','0',NULL);
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'SEASON_SP' AND MODEL_COMP_NM = 'TS';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('SEASON_SP','TS','-1','1',NULL);
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'SEASON_SS' AND MODEL_COMP_NM = 'TS';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('SEASON_SS','TS','-1','0',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID750199;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID750199;
%put ERROR- Description                              : Add TS specs price_sp/ss,ps_sp/ss,inv_adj_sp/ss,pl_adj_sp/ss,season_sp/ss;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 05MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID750199;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID750199",
"Add TS specs price_sp/ss,ps_sp/ss,inv_adj_sp/ss,pl_adj_sp/ss,season_sp/ss",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID750199:;
 
 
* End of changes for CHANGE_ID:ID750199;
 
 
***********************************************************************************************;
*************************************  End Change ID750199 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID757899 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID757899;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID757899")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PRF_SIZESET_MBR))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_SIZESET_MBR;
%put NOTE: Change ID                             :ID757899;
%goto ID757899;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID757899;
%goto ID757899;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID757899;
* Insert record into change management table for CHANGE_ID: ID757899;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID757899",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID757899;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE PRF_SIZESET_MBR ADD POST_IMPUTATION_SALES_UNITS NUMERIC(12,2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PRF_PROD_SIZE_EXCLUDE
(
PROFILING_PROJECT_SK          INTEGER NOT NULL,
PROD_HIER_SK                  INTEGER NOT NULL,
STD_SIZE_CD                   INTEGER NOT NULL,
PRIMARY KEY (PROFILING_PROJECT_SK, PROD_HIER_SK, STD_SIZE_CD)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
CREATE TABLE PRF_PROD_SIZE_EXCLUDE
(
PROFILING_PROJECT_SK          INTEGER NOT NULL,
PROD_HIER_SK                  INTEGER NOT NULL,
STD_SIZE_CD                   INTEGER NOT NULL,
CONSTRAINT PRIM_KEY PRIMARY KEY (PROFILING_PROJECT_SK, PROD_HIER_SK, STD_SIZE_CD)
)
;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE PRF_SIZESET_MBR ADD POST_IMPUTATION_SALES_UNITS NUMERIC(12,2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PRF_PROD_SIZE_EXCLUDE
(
PROFILING_PROJECT_SK          INTEGER NOT NULL,
PROD_HIER_SK                  INTEGER NOT NULL,
STD_SIZE_CD                   INTEGER NOT NULL,
PRIMARY KEY (PROFILING_PROJECT_SK, PROD_HIER_SK, STD_SIZE_CD)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID757899;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID757899;
%put ERROR- Description                              : SIZE PROFILING 3.2 SCHEMA CHANGES PART II;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 05MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID757899;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID757899",
"SIZE PROFILING 3.2 SCHEMA CHANGES PART II",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID757899:;
 
 
* End of changes for CHANGE_ID:ID757899;
 
 
***********************************************************************************************;
*************************************  End Change ID757899 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID757899_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID757899_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID757899_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PRF_SIZESET_MBR))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_SIZESET_MBR;
%put NOTE: Change ID                             :ID757899_2;
%goto ID757899_2;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID757899_2;
%goto ID757899_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID757899_2;
* Insert record into change management table for CHANGE_ID: ID757899_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID757899_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID757899_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
ALTER TABLE PRF_SIZESET_MBR ADD POST_IMPUTATION_SALES_UNITS NUMERIC(12,2);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID757899_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID757899_2;
%put ERROR- Description                              : SIZE PROFILING 3.2 SCHEMA CHANGES PART II;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 15SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID757899_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID757899_2",
"SIZE PROFILING 3.2 SCHEMA CHANGES PART II",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID757899_2:;
 
 
* End of changes for CHANGE_ID:ID757899_2;
 
 
***********************************************************************************************;
*************************************  End Change ID757899_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID757500 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID757500;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID757500")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID757500;
%goto ID757500;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2TKMI43);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID757500;
* Insert record into change management table for CHANGE_ID: ID757500;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID757500",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID757500;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE GEO_PROD_MTS
ADD
(
SEASON_START_INV_UNITS NUMERIC(12,2),
SEASON_START_INV_VAL_AT_RET NUMERIC(20,3),
SEASON_TO_DT_REVENUE_AMT NUMERIC(20,3)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_MTS
ADD
(
SEASON_START_INV_UNITS NUMERIC(12,2),
SEASON_START_INV_VAL_AT_RET NUMERIC(20,3),
SEASON_TO_DT_REVENUE_AMT NUMERIC(20,3)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
ALTER TABLE GEO_PROD_MTS ADD SEASON_START_INV_UNITS NUMERIC(12,2);
 
 
ALTER TABLE GEO_PROD_MTS ADD SEASON_START_INV_VAL_AT_RET NUMERIC(20,3);
 
 
ALTER TABLE GEO_PROD_MTS ADD SEASON_TO_DT_REVENUE_AMT NUMERIC(20,3);
 
 
 
ALTER TABLE MPLN_GEO_PROD_MTS ADD SEASON_START_INV_UNITS NUMERIC(12,2);
 
 
ALTER TABLE MPLN_GEO_PROD_MTS ADD SEASON_START_INV_VAL_AT_RET NUMERIC(20,3);
 
 
ALTER TABLE MPLN_GEO_PROD_MTS ADD SEASON_TO_DT_REVENUE_AMT NUMERIC(20,3);
 
 
 
quit;
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID757500;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID757500;
%put ERROR- Description                              : Add columns to geo_prod_mts and mpln_geo_prod_mts;
%put ERROR- Version                                  : D3MICM52,M2TKMI43;
%put ERROR- Date of Change                           : 06MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID757500;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID757500",
"Add columns to geo_prod_mts and mpln_geo_prod_mts",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID757500:;
 
 
* End of changes for CHANGE_ID:ID757500;
 
 
***********************************************************************************************;
*************************************  End Change ID757500 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID757540 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID757540;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID757540")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID757540;
%goto ID757540;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2TKMI43);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID757540;
* Insert record into change management table for CHANGE_ID: ID757540;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID757540",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID757540;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE BUDGET
(
BUDGET_NM VARCHAR(100),
BUDGET_TYPE INTEGER NOT NULL,
GEO_HIER_SK INTEGER NOT NULL,
PROD_HIER_SK INTEGER NOT NULL,
START_DT DATE NOT NULL,
END_DT DATE NOT NULL,
TOTAL_BUDGET_AMT NUMERIC(20,3) NOT NULL,
USED_BUDGET_AMT NUMERIC(20,3) NOT NULL,
REVISED_BUDGET_AMT NUMERIC(20,3),
PRIMARY KEY (GEO_HIER_SK, PROD_HIER_SK, START_DT, BUDGET_TYPE)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
CREATE TABLE BUDGET
(
BUDGET_NM VARCHAR(100),
BUDGET_TYPE INTEGER NOT NULL,
GEO_HIER_SK INTEGER NOT NULL,
PROD_HIER_SK INTEGER NOT NULL,
START_DT DATE NOT NULL,
END_DT DATE NOT NULL,
TOTAL_BUDGET_AMT NUMERIC(20,3) NOT NULL,
USED_BUDGET_AMT NUMERIC(20,3) NOT NULL,
REVISED_BUDGET_AMT NUMERIC(20,3),
CONSTRAINT PRIM_KEY PRIMARY KEY (GEO_HIER_SK, PROD_HIER_SK, START_DT, BUDGET_TYPE)
);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID757540;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID757540;
%put ERROR- Description                              : Add budget table to transacted schema;
%put ERROR- Version                                  : D3MICM52,M2TKMI43;
%put ERROR- Date of Change                           : 06MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID757540;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID757540",
"Add budget table to transacted schema",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID757540:;
 
 
* End of changes for CHANGE_ID:ID757540;
 
 
***********************************************************************************************;
*************************************  End Change ID757540 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID758390 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID758390;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID758390")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID758390;
%goto ID758390;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2TKMI43);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID758390;
* Insert record into change management table for CHANGE_ID: ID758390;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID758390",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID758390;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT
ADD INV_AT_RISK_NUM_MEMBERS INTEGER
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT
ADD INV_AT_RISK_NUM_MEMBERS INTEGER
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE MPLN_RESULT
ADD INV_AT_RISK_NUM_MEMBERS INTEGER
;
 
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT
ADD INV_AT_RISK_NUM_MEMBERS INTEGER
;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID758390;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID758390;
%put ERROR- Description                              : Add inventory at risk number of members;
%put ERROR- Version                                  : D3MICM52,M2TKMI43;
%put ERROR- Date of Change                           : 09MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID758390;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID758390",
"Add inventory at risk number of members",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID758390:;
 
 
* End of changes for CHANGE_ID:ID758390;
 
 
***********************************************************************************************;
*************************************  End Change ID758390 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID759165 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID759165;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID759165")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID759165;
%goto ID759165;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID759165;
* Insert record into change management table for CHANGE_ID: ID759165;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID759165",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID759165;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS
ADD WEIGHTED_MAPE_FIT NUMERIC(12,2)
ADD MEDIAN_PE_FIT NUMERIC(12,2)
ADD WEIGHTED_MEAN_PE_FIT NUMERIC(12,2)
ADD HOLIDAY_ID INTEGER
ADD HOLIDAY_NM VARCHAR(40)
ADD MAX_HD_RMSE_FIT NUMERIC(12,2)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE
ADD WEIGHTED_MAPE_FIT NUMERIC(12,2)
ADD MEDIAN_PE_FIT NUMERIC(12,2)
ADD WEIGHTED_MEAN_PE_FIT NUMERIC(12,2)
ADD HOLIDAY_ID INTEGER
ADD HOLIDAY_NM VARCHAR(40)
ADD MAX_HD_RMSE_FIT NUMERIC(12,2)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE FA_SCENARIO_STATUS
ADD WEIGHTED_MAPE_FIT NUMERIC(12,2)
ADD MEDIAN_PE_FIT NUMERIC(12,2)
ADD WEIGHTED_MEAN_PE_FIT NUMERIC(12,2)
ADD HOLIDAY_ID INTEGER
ADD HOLIDAY_NM VARCHAR(40)
ADD MAX_HD_RMSE_FIT NUMERIC(12,2)
;
 
 
 
ALTER TABLE FA_SCORE
ADD WEIGHTED_MAPE_FIT NUMERIC(12,2)
ADD MEDIAN_PE_FIT NUMERIC(12,2)
ADD WEIGHTED_MEAN_PE_FIT NUMERIC(12,2)
ADD HOLIDAY_ID INTEGER
ADD HOLIDAY_NM VARCHAR(40)
ADD MAX_HD_RMSE_FIT NUMERIC(12,2)
;
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID759165;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID759165;
%put ERROR- Description                              : Enhancements to MA and FA;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 11MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID759165;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID759165",
"Enhancements to MA and FA",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID759165:;
 
 
* End of changes for CHANGE_ID:ID759165;
 
 
***********************************************************************************************;
*************************************  End Change ID759165 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0755732 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0755732;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0755732")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0755732;
%goto ID0755732;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0755732;
* Insert record into change management table for CHANGE_ID: ID0755732;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0755732",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0755732;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
UPDATE PROFILE_SCORE_SETTING SET CLASSIFIED_STORE_PENALTY = 1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
UPDATE PROFILE_SCORE_SETTING SET CLASSIFIED_STORE_PENALTY = 1;
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0755732;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0755732;
%put ERROR- Description                              : Default value of CLASSIFIED_STORE_PENALTY in PROFILE_SCORE_SETTING should be 1;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 05MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0755732;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0755732",
"Default value of CLASSIFIED_STORE_PENALTY in PROFILE_SCORE_SETTING should be 1",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0755732:;
 
 
* End of changes for CHANGE_ID:ID0755732;
 
 
***********************************************************************************************;
*************************************  End Change ID0755732 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID759742 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID759742;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID759742")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID759742;
%goto ID759742;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID759742;
* Insert record into change management table for CHANGE_ID: ID759742;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID759742",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID759742;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update ALERT_COST set
INVC_COST_AMT_CHANGE = INVC_COST - PREV_INVC_COST,
INVC_COST_PCT_CHANGE = (INVC_COST - PREV_INVC_COST) / PREV_INVC_COST
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update ALERT_COST set
INVC_COST_AMT_CHANGE = INVC_COST - PREV_INVC_COST,
INVC_COST_PCT_CHANGE = (INVC_COST - PREV_INVC_COST) / PREV_INVC_COST ;
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID759742;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID759742;
%put ERROR- Description                              : ROMR74410 Display current cost and cost change in new cost alerts;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 13MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID759742;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID759742",
"ROMR74410 Display current cost and cost change in new cost alerts",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID759742:;
 
 
* End of changes for CHANGE_ID:ID759742;
 
 
***********************************************************************************************;
*************************************  End Change ID759742 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID758581 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID758581;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID758581")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID758581;
%goto ID758581;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID758581;
* Insert record into change management table for CHANGE_ID: ID758581;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID758581",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID758581;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PRF_JOB ADD JOB_TYPE INTEGER DEFAULT 1 NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRF_JOB RENAME COLUMN PROFILING_PROJECT_SK TO CONTEXT_SK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRF_JOB MODIFY CONTEXT_SK INTEGER  NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
DROP TABLE PRF_RSLT_SG_ATTR
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
data &m_di_trans..PRF_JOB;
 
 
set &m_di_trans..PRF_JOB;
 
 
ATTRIB JOB_TYPE LENGTH=4;
 
 
 
JOB_TYPE=1;
 
 
RUN;
 
 
 
proc sql;
 
 
ALTER TABLE PRF_JOB  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PRF_JOB_SK);
 
 
quit;
 
 
 
 
proc datasets library=&m_di_trans.  nolist nodetails nowarn ;
 
 
MODIFY PRF_JOB;
 
 
RENAME  PROFILING_PROJECT_SK=CONTEXT_SK;
 
 
IC DELETE _NM0002_;
 
 
 
QUIT;
 
 
 
proc sql;
 
 
DROP TABLE PRF_RSLT_SG_ATTR;
 
 
quit;
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID758581;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID758581;
%put ERROR- Description                              : SIZE PROFILING 3.2 SCHEMA CHANGES PART III;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 13MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID758581;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID758581",
"SIZE PROFILING 3.2 SCHEMA CHANGES PART III",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID758581:;
 
 
* End of changes for CHANGE_ID:ID758581;
 
 
***********************************************************************************************;
*************************************  End Change ID758581 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID722108 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID722108;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID722108")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID722108;
%goto ID722108;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID722108;
* Insert record into change management table for CHANGE_ID: ID722108;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID722108",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID722108;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE CONFIG_GROUP SET GEO_HIER_ASSOC_CD = 0 WHERE GEO_HIER_TYPE = 2
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE CONFIG_GROUP SET PROD_HIER_ASSOC_CD = 0 WHERE PROD_HIER_TYPE = 2
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
UPDATE CONFIG_GROUP SET GEO_HIER_ASSOC_CD = 0 WHERE GEO_HIER_TYPE = 2;
 
 
UPDATE CONFIG_GROUP SET PROD_HIER_ASSOC_CD = 0 WHERE PROD_HIER_TYPE = 2;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID722108;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID722108;
%put ERROR- Description                              : Remove global setting GEO_HIER_TYPE and PROD_HIER_TYPE;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 15MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID722108;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID722108",
"Remove global setting GEO_HIER_TYPE and PROD_HIER_TYPE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID722108:;
 
 
* End of changes for CHANGE_ID:ID722108;
 
 
***********************************************************************************************;
*************************************  End Change ID722108 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID722108_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID722108_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID722108_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID722108_1;
%goto ID722108_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID722108_1;
* Insert record into change management table for CHANGE_ID: ID722108_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID722108_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID722108_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE CONFIG_GROUP DROP COLUMN GEO_HIER_TYPE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE CONFIG_GROUP DROP COLUMN PROD_HIER_TYPE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE CONFIG_GROUP DROP COLUMN GEO_HIER_TYPE;
 
 
ALTER TABLE CONFIG_GROUP DROP COLUMN PROD_HIER_TYPE;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID722108_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID722108_1;
%put ERROR- Description                              : Drop GEO_HIER_TYPE and PROD_HIER_TYPE columns from CONFIG_GROUP table;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 16MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID722108_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID722108_1",
"Drop GEO_HIER_TYPE and PROD_HIER_TYPE columns from CONFIG_GROUP table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID722108_1:;
 
 
* End of changes for CHANGE_ID:ID722108_1;
 
 
***********************************************************************************************;
*************************************  End Change ID722108_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID760165 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID760165;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID760165")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID760165;
%goto ID760165;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID760165;
%goto ID760165;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID760165;
* Insert record into change management table for CHANGE_ID: ID760165;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID760165",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID760165;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'MAX_FIT_APE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('MAX_FIT_APE','MA','-1','1000',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('MAX_FIT_APE','FA','-1','1000',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM FA_SPEC WHERE SPEC_NM = 'MAX_FIT_APE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO FA_SPEC (MODEL_GROUP_ID,SPEC_NM,SPEC_VALUE)
VALUES (-1,'MAX_FIT_APE','1000')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'MAX_FIT_APE';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('MAX_FIT_APE','MA','-1','1000',NULL);
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('MAX_FIT_APE','FA','-1','1000',NULL);
 
 
 
DELETE FROM FA_SPEC WHERE SPEC_NM = 'MAX_FIT_APE';
 
 
INSERT INTO FA_SPEC (MODEL_GROUP_ID,SPEC_NM,SPEC_VALUE)
VALUES (-1,'MAX_FIT_APE','1000');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID760165;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID760165;
%put ERROR- Description                              : Add MAX_FIT_APE as an FA spec and MA spec;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 16MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID760165;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID760165",
"Add MAX_FIT_APE as an FA spec and MA spec",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID760165:;
 
 
* End of changes for CHANGE_ID:ID760165;
 
 
***********************************************************************************************;
*************************************  End Change ID760165 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0760288 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0760288;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0760288")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :ID0760288;
%goto ID0760288;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0760288;
%goto ID0760288;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0760288;
* Insert record into change management table for CHANGE_ID: ID0760288;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0760288",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0760288;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
CREATE TABLE REQ_INVENTORY (
REQUEST_ID               INTEGER NOT NULL,
PROD_ID                  VARCHAR(32) NOT NULL,
GEO_ID                   varchar(32) NOT NULL,
RECEIPT_DT               DATE NOT NULL,
UNITS                    INTEGER NOT NULL
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE UNIQUE INDEX REQ_INVENTORY_PK on REQ_INVENTORY (REQUEST_ID, PROD_ID, GEO_ID, RECEIPT_DT) nologging parallel
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_INVENTORY ADD CONSTRAINT REQ_INVENTORY_PK PRIMARY KEY (REQUEST_ID, PROD_ID, GEO_ID, RECEIPT_DT) USING INDEX REQ_INVENTORY_PK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
PROC SQL;
 
 
CREATE TABLE REQ_INVENTORY (
REQUEST_ID               INTEGER NOT NULL,
PROD_ID                  VARCHAR(32) NOT NULL,
GEO_ID                   varchar(32) NOT NULL,
RECEIPT_DT               DATE NOT NULL,
UNITS                    INTEGER NOT NULL
);
 
 
CREATE UNIQUE INDEX REQ_INVENTORY_PK on REQ_INVENTORY (REQUEST_ID, PROD_ID, GEO_ID, RECEIPT_DT) ;
 
 
ALTER TABLE REQ_INVENTORY ADD CONSTRAINT PRIM_KEY PRIMARY KEY (REQUEST_ID, PROD_ID, GEO_ID, RECEIPT_DT) ;
 
 
 
QUIT;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0760288;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0760288;
%put ERROR- Description                              : New table REQ_INVENTORY needed for packopt;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 18MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0760288;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0760288",
"New table REQ_INVENTORY needed for packopt",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0760288:;
 
 
* End of changes for CHANGE_ID:ID0760288;
 
 
***********************************************************************************************;
*************************************  End Change ID0760288 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID760260 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID760260;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID760260")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :ID760260;
%goto ID760260;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID760260;
%goto ID760260;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID760260;
* Insert record into change management table for CHANGE_ID: ID760260;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID760260",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID760260;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20025, 2, 1, 1, 1, 25, 1, 3.0, 0.0, 0.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20026, 2, 1, 1, 1, 26, 1, 3.0, 0.0, 0.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20027, 2, 1, 1, 1, 27, 1, -1.0, 0.0, 0.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20028, 2, 1, 1, 1, 28, 1, -1.0, 0.0, 0.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20029, 2, 1, 1, 1, 29, 1, 0.0, 0.00, 0.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20030, 2, 1, 1, 1, 30, 1, 0.0, 0.00, 0.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20031, 2, 1, 1, 1, 31, 1, 0.0, 0.00, 1.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20032, 2, 1, 1, 1, 32, 1, 0.0, 0.00, 10.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20025, 2, 1, 1, 1, 25, 1, 3.0, 0.0, 0.0);
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20026, 2, 1, 1, 1, 26, 1, 3.0, 0.0, 0.0);
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20027, 2, 1, 1, 1, 27, 1, -1.0, 0.0, 0.0);
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20028, 2, 1, 1, 1, 28, 1, -1.0, 0.0, 0.0);
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20029, 2, 1, 1, 1, 29, 1, 0.0, 0.00, 0.0);
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20030, 2, 1, 1, 1, 30, 1, 0.0, 0.00, 0.0);
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20031, 2, 1, 1, 1, 31, 1, 0.0, 0.00, 1.0);
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)   values ( 20032, 2, 1, 1, 1, 32, 1, 0.0, 0.00, 10.0);
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID760260;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID760260;
%put ERROR- Description                              : DEFAULT OPTIMIZATION SETTINGS;
%put ERROR- Version                                  : D3MICM52,M2MI42;
%put ERROR- Date of Change                           : 19MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID760260;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID760260",
"DEFAULT OPTIMIZATION SETTINGS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID760260:;
 
 
* End of changes for CHANGE_ID:ID760260;
 
 
***********************************************************************************************;
*************************************  End Change ID760260 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID761056 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID761056;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID761056")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :ID761056;
%goto ID761056;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID761056;
%goto ID761056;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID761056;
* Insert record into change management table for CHANGE_ID: ID761056;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID761056",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID761056;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
CREATE TABLE CAT_CUSTOM_ATTR_LIST_VALUE (
CAT_CUSTOM_ATTR_SK INTEGER NOT NULL,
ATTR_VALUE VARCHAR2(40) NOT NULL
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE CATEGORY_PLAN ADD EVAL_OPT_RESULT_DTTM TIMESTAMP NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE CALENDAR ADD EVAL_OPT_RESULT_DTTM TIMESTAMP NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE CAT_CUSTOM_ATTR ADD HIDDEN_FLG INTEGER NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE CAT_CUSTOM_ATTR ADD EDIT_FLG INTEGER NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
CREATE TABLE CAT_CUSTOM_ATTR_LIST_VALUE (
CAT_CUSTOM_ATTR_SK INTEGER NOT NULL,
ATTR_VALUE VARCHAR(40) NOT NULL
);
 
 
 
ALTER TABLE CATEGORY_PLAN ADD EVAL_OPT_RESULT_DTTM DATE;
 
 
ALTER TABLE CALENDAR ADD EVAL_OPT_RESULT_DTTM DATE;
 
 
ALTER TABLE CAT_CUSTOM_ATTR ADD HIDDEN_FLG INTEGER ;
 
 
ALTER TABLE CAT_CUSTOM_ATTR ADD EDIT_FLG INTEGER ;
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID761056;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID761056;
%put ERROR- Description                              : Custom Attribute Extensions;
%put ERROR- Version                                  : D3MICM52,M2MI42;
%put ERROR- Date of Change                           : 19MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID761056;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID761056",
"Custom Attribute Extensions",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID761056:;
 
 
* End of changes for CHANGE_ID:ID761056;
 
 
***********************************************************************************************;
*************************************  End Change ID761056 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID733774 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID733774;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID733774")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID733774;
%goto ID733774;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID733774;
* Insert record into change management table for CHANGE_ID: ID733774;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID733774",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID733774;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE NUM_GEO_PROD
(
PROD_HIER_SK                  INTEGER NOT NULL,
PROD_HIER_ASSOC_CD            INTEGER NOT NULL,
GEO_HIER_SK                   INTEGER NOT NULL,
GEO_HIER_ASSOC_CD             INTEGER NOT NULL,
USER_NM                       VARCHAR(40) NOT NULL,
PRIMARY KEY (PROD_HIER_SK, PROD_HIER_ASSOC_CD, GEO_HIER_SK, GEO_HIER_ASSOC_CD, USER_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE COVERAGE_INPUT
(
PROD_HIER_SK                  INTEGER NOT NULL,
PROD_HIER_ASSOC_CD            INTEGER NOT NULL,
GEO_HIER_SK                   INTEGER NOT NULL,
GEO_HIER_ASSOC_CD             INTEGER NOT NULL,
USER_NM                       VARCHAR(40) NOT NULL,
PRIMARY KEY(PROD_HIER_SK, PROD_HIER_ASSOC_CD, GEO_HIER_SK, GEO_HIER_ASSOC_CD, USER_NM)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE COVERAGE_OUTPUT
(
PROD_HIER_SK                  INTEGER NOT NULL,
PROD_HIER_ASSOC_CD            INTEGER NOT NULL,
GEO_HIER_SK                   INTEGER NOT NULL,
GEO_HIER_ASSOC_CD             INTEGER NOT NULL,
USER_NM                       VARCHAR(40) NOT NULL,
PRIMARY KEY(PROD_HIER_SK, PROD_HIER_ASSOC_CD, GEO_HIER_SK, GEO_HIER_ASSOC_CD, USER_NM)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
CREATE TABLE NUM_GEO_PROD
(
PROD_HIER_SK                  INTEGER NOT NULL,
PROD_HIER_ASSOC_CD            INTEGER NOT NULL,
GEO_HIER_SK                   INTEGER NOT NULL,
GEO_HIER_ASSOC_CD             INTEGER NOT NULL,
USER_NM                       VARCHAR(40) NOT NULL
);
 
 
ALTER TABLE NUM_GEO_PROD ADD CONSTRAINT PRIM_KEY PRIMARY KEY (PROD_HIER_SK, PROD_HIER_ASSOC_CD, GEO_HIER_SK, GEO_HIER_ASSOC_CD, USER_NM) ;
 
 
 
CREATE TABLE COVERAGE_INPUT
(
PROD_HIER_SK                  INTEGER NOT NULL,
PROD_HIER_ASSOC_CD            INTEGER NOT NULL,
GEO_HIER_SK                   INTEGER NOT NULL,
GEO_HIER_ASSOC_CD             INTEGER NOT NULL,
USER_NM                       VARCHAR(40) NOT NULL
);
 
 
ALTER TABLE COVERAGE_INPUT ADD CONSTRAINT PRIM_KEY PRIMARY KEY (PROD_HIER_SK, PROD_HIER_ASSOC_CD, GEO_HIER_SK, GEO_HIER_ASSOC_CD, USER_NM) ;
 
 
 
CREATE TABLE COVERAGE_OUTPUT
(
PROD_HIER_SK                  INTEGER NOT NULL,
PROD_HIER_ASSOC_CD            INTEGER NOT NULL,
GEO_HIER_SK                   INTEGER NOT NULL,
GEO_HIER_ASSOC_CD             INTEGER NOT NULL,
USER_NM                       VARCHAR(40) NOT NULL
);
 
 
ALTER TABLE COVERAGE_OUTPUT ADD CONSTRAINT PRIM_KEY PRIMARY KEY (PROD_HIER_SK, PROD_HIER_ASSOC_CD, GEO_HIER_SK, GEO_HIER_ASSOC_CD, USER_NM) ;
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID733774;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID733774;
%put ERROR- Description                              : New tables NUM_GEO_PROD, COVERAGE_INPUT, COVERAGE_OUTPUT;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 23MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID733774;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID733774",
"New tables NUM_GEO_PROD, COVERAGE_INPUT, COVERAGE_OUTPUT",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID733774:;
 
 
* End of changes for CHANGE_ID:ID733774;
 
 
***********************************************************************************************;
*************************************  End Change ID733774 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID761590 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID761590;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID761590")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID761590;
%goto ID761590;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID761590;
* Insert record into change management table for CHANGE_ID: ID761590;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID761590",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID761590;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE CATEGORY_PLAN ADD ACTION_RESULT_DTTM TIMESTAMP NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE CATEGORY_PLAN ADD ACTION_CONTEXT_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE CATEGORY_PLAN ADD ACTION_NM VARCHAR(40) NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE CATEGORY_PLAN ADD ACTION_PROCESS_CD INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE CALENDAR ADD ACTION_RESULT_DTTM TIMESTAMP NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE CALENDAR ADD ACTION_CONTEXT_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE CALENDAR ADD ACTION_NM VARCHAR(40) NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE CALENDAR ADD ACTION_PROCESS_CD INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPP_PLAN ADD ACTION_RESULT_DTTM TIMESTAMP NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPP_PLAN ADD ACTION_CONTEXT_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPP_PLAN ADD ACTION_NM VARCHAR(40) NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPP_PLAN ADD ACTION_PROCESS_CD INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
ALTER TABLE CATEGORY_PLAN ADD ACTION_RESULT_DTTM DATE ;
 
 
ALTER TABLE CATEGORY_PLAN ADD ACTION_CONTEXT_SK INTEGER;
 
 
ALTER TABLE CATEGORY_PLAN ADD ACTION_NM VARCHAR(40) ;
 
 
ALTER TABLE CATEGORY_PLAN ADD ACTION_PROCESS_CD INTEGER;
 
 
 
ALTER TABLE CALENDAR ADD ACTION_RESULT_DTTM DATE ;
 
 
ALTER TABLE CALENDAR ADD ACTION_CONTEXT_SK INTEGER;
 
 
ALTER TABLE CALENDAR ADD ACTION_NM VARCHAR(40) ;
 
 
ALTER TABLE CALENDAR ADD ACTION_PROCESS_CD INTEGER;
 
 
 
ALTER TABLE RPP_PLAN ADD ACTION_RESULT_DTTM DATE ;
 
 
ALTER TABLE RPP_PLAN ADD ACTION_CONTEXT_SK INTEGER;
 
 
ALTER TABLE RPP_PLAN ADD ACTION_NM VARCHAR(40) ;
 
 
ALTER TABLE RPP_PLAN ADD ACTION_PROCESS_CD INTEGER;
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID761590;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID761590;
%put ERROR- Description                              : Added action support;
%put ERROR- Version                                  : D3MICM52,M2MI42;
%put ERROR- Date of Change                           : 23MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID761590;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID761590",
"Added action support",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID761590:;
 
 
* End of changes for CHANGE_ID:ID761590;
 
 
***********************************************************************************************;
*************************************  End Change ID761590 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID757832_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID757832_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID757832_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID757832_2;
%goto ID757832_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2TKMI43);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID757832_2;
* Insert record into change management table for CHANGE_ID: ID757832_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID757832_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID757832_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT ADD NUM_MEMBERS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT ADD NUM_MEMBERS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE MPLN_RESULT ADD NUM_MEMBERS INTEGER;
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD NUM_MEMBERS INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID757832_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID757832_2;
%put ERROR- Description                              : Move column num_members from table mpln_geo_prod_agg to mpln_result and mpln_geo_prod_result;
%put ERROR- Version                                  : D3MICM52,M2TKMI43;
%put ERROR- Date of Change                           : 25MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID757832_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID757832_2",
"Move column num_members from table mpln_geo_prod_agg to mpln_result and mpln_geo_prod_result",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID757832_2:;
 
 
* End of changes for CHANGE_ID:ID757832_2;
 
 
***********************************************************************************************;
*************************************  End Change ID757832_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change PKO_BULK_PACK_SIZE ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: PKO_BULK_PACK_SIZE;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("PKO_BULK_PACK_SIZE")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : PKO_BULK_PACK_SIZE;
%goto PKO_BULK_PACK_SIZE;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : PKO_BULK_PACK_SIZE;
* Insert record into change management table for CHANGE_ID: PKO_BULK_PACK_SIZE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"PKO_BULK_PACK_SIZE",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto PKO_BULK_PACK_SIZE;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%if not (%sysfunc(exist(&m_di_trans..PKO_BULK_PACK_SIZE))) %then
%do;
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PKO_BULK_PACK_SIZE
(
BULK_PACK_SIZE_SK                  INTEGER NOT NULL,
BUY_SK                             INTEGER,
DELIVERY_SK                        INTEGER,
BULKSIZE                           INTEGER NOT NULL,
INNER_PACK_HANDLE_COST             NUMERIC(20,3),
OUTER_PACK_HANDLE_COST             NUMERIC(20,3),
OPENING_COST                       NUMERIC(20,3),
PRIMARY KEY (BULK_PACK_SIZE_SK)
)
);
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1)
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_BULK_PACK_SIZE_SK START WITH 100000;
 
 
);
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%if not (%sysfunc(exist(&m_di_trans..PKO_BULK_PACK_SIZE))) %then
%do;
 
 
 
proc sql;
 
 
CREATE TABLE PKO_BULK_PACK_SIZE
(
BULK_PACK_SIZE_SK                  INTEGER NOT NULL,
BUY_SK                             INTEGER,
DELIVERY_SK                        INTEGER,
BULKSIZE                           INTEGER NOT NULL,
INNER_PACK_HANDLE_COST             NUMERIC(20,3),
OUTER_PACK_HANDLE_COST             NUMERIC(20,3),
OPENING_COST                       NUMERIC(20,3)
)
;
 
 
 
ALTER TABLE PKO_BULK_PACK_SIZE add CONSTRAINT PRIM_KEY PRIMARY KEY (BULK_PACK_SIZE_SK);
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: PKO_BULK_PACK_SIZE;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: PKO_BULK_PACK_SIZE;
%put ERROR- Description                              : Add Table PKO_BULK_PACK_SIZE;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 06NOV2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: PKO_BULK_PACK_SIZE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"PKO_BULK_PACK_SIZE",
"Add Table PKO_BULK_PACK_SIZE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%PKO_BULK_PACK_SIZE:;
 
 
* End of changes for CHANGE_ID:PKO_BULK_PACK_SIZE;
 
 
***********************************************************************************************;
*************************************  End Change PKO_BULK_PACK_SIZE ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ADD_PROCESS_NM ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ADD_PROCESS_NM;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ADD_PROCESS_NM")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ADD_PROCESS_NM;
%goto ADD_PROCESS_NM;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,F1MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ADD_PROCESS_NM;
* Insert record into change management table for CHANGE_ID: ADD_PROCESS_NM;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ADD_PROCESS_NM",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ADD_PROCESS_NM;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%if (%di_util_varexist(dsname=&m_di_trans..REQ_CONTEXT, varname=PROCESS_NM)=0) %then
%do;
 
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_CONTEXT ADD PROCESS_NM VARCHAR(40)
);
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
%if (%di_util_varexist(dsname=&m_di_trans..REQ_CONTEXT, varname=PROCESS_NM)=0) %then
%do;
 
 
proc sql;
 
 
ALTER TABLE REQ_CONTEXT ADD PROCESS_NM VARCHAR(40);
 
 
quit;
 
 
%end;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ADD_PROCESS_NM;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ADD_PROCESS_NM;
%put ERROR- Description                              : Update schema changes for pack;
%put ERROR- Version                                  : D3MICM52,F1MI42;
%put ERROR- Date of Change                           : 26MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ADD_PROCESS_NM;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ADD_PROCESS_NM",
"Update schema changes for pack",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ADD_PROCESS_NM:;
 
 
* End of changes for CHANGE_ID:ADD_PROCESS_NM;
 
 
***********************************************************************************************;
*************************************  End Change ADD_PROCESS_NM ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID762905 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID762905;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID762905")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID762905;
%goto ID762905;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID762905;
* Insert record into change management table for CHANGE_ID: ID762905;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID762905",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID762905;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN DROP COLUMN STYLECOLORS_IN_BUYS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN DROP COLUMN STYLECOLORS_WITH_NEED
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN DROP COLUMN STORES_IN_DELIVERIES
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN DROP COLUMN STORES_WITH_NEED
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PKO_PACK_PRODUCT_SETTING
(
PACK_PRODUCT_SETTING_SK            INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
BUY_SK                             INTEGER,
DELIVERY_SK                        INTEGER,
NUM_PACK_REC_MAX                   INTEGER,
SIZE_OF_OUTER_MAX                  INTEGER,
BREAK_PACKS                        INTEGER,
REC_MULTICOLOR                     INTEGER,
OPEN_COST_PER_INNER                NUMERIC(20,3),
OUTER_HANDLE_DSCT_RATE             NUMERIC(12,4),
PRIMARY KEY (PACK_PRODUCT_SETTING_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_PACK_PRODUCT_SETTING_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD REC_MULTICOLOR INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PACKREC_INNER ADD PACK_PRODUCT_SETTING_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BULK_PACK_SIZE ADD PACK_PRODUCT_SETTING_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_LIMIT_PACK ADD PACK_PRODUCT_SETTING_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PKO_DELIVERY_PRODUCT
(
DELIVERY_PRODUCT_SK                INTEGER NOT NULL,
DELIVERY_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
PRIMARY KEY (DELIVERY_PRODUCT_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_DELIVERY_PRODUCT_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PKO_DELIVERY_STYLECOLOR
(
DELIVERY_STYLECOLOR_SK             INTEGER NOT NULL,
DELIVERY_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
PROD_ID                            VARCHAR(32) NOT NULL,
PRIMARY KEY (DELIVERY_STYLECOLOR_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_DELIVERY_STYLECOLOR_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN DROP COLUMN STYLECOLORS_IN_BUYS;
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN DROP COLUMN STYLECOLORS_WITH_NEED;
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN DROP COLUMN STORES_IN_DELIVERIES;
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN DROP COLUMN STORES_WITH_NEED;
 
 
 
CREATE TABLE PKO_PACK_PRODUCT_SETTING
(
PACK_PRODUCT_SETTING_SK            INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
BUY_SK                             INTEGER,
DELIVERY_SK                        INTEGER,
NUM_PACK_REC_MAX                   INTEGER,
SIZE_OF_OUTER_MAX                  INTEGER,
BREAK_PACKS                        INTEGER,
REC_MULTICOLOR                     INTEGER,
OPEN_COST_PER_INNER                NUMERIC(20,3),
OUTER_HANDLE_DSCT_RATE             NUMERIC(12,4)
) ;
 
 
 
ALTER TABLE PKO_PACK_PRODUCT_SETTING add CONSTRAINT PRIM_KEY PRIMARY KEY (PACK_PRODUCT_SETTING_SK);
 
 
 
ALTER TABLE PKO_DELIVERY ADD REC_MULTICOLOR INTEGER ;
 
 
 
ALTER TABLE PKO_PACKREC_INNER ADD PACK_PRODUCT_SETTING_SK INTEGER ;
 
 
ALTER TABLE PKO_BULK_PACK_SIZE ADD PACK_PRODUCT_SETTING_SK INTEGER ;
 
 
ALTER TABLE PKO_LIMIT_PACK ADD PACK_PRODUCT_SETTING_SK INTEGER ;
 
 
 
CREATE TABLE PKO_DELIVERY_PRODUCT
(
DELIVERY_PRODUCT_SK                INTEGER NOT NULL,
DELIVERY_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL
);
 
 
 
ALTER TABLE PKO_DELIVERY_PRODUCT add CONSTRAINT PRIM_KEY PRIMARY KEY (DELIVERY_PRODUCT_SK);
 
 
 
 
CREATE TABLE PKO_DELIVERY_STYLECOLOR
(
DELIVERY_STYLECOLOR_SK             INTEGER NOT NULL,
DELIVERY_SK                        INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
PROD_ID                            VARCHAR(32) NOT NULL
);
 
 
 
ALTER TABLE PKO_DELIVERY_STYLECOLOR add CONSTRAINT PRIM_KEY PRIMARY KEY (DELIVERY_STYLECOLOR_SK);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID762905;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID762905;
%put ERROR- Description                              : Update schema changes for pack;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 26MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID762905;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID762905",
"Update schema changes for pack",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID762905:;
 
 
* End of changes for CHANGE_ID:ID762905;
 
 
***********************************************************************************************;
*************************************  End Change ID762905 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID762925 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID762925;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID762925")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID762925;
%goto ID762925;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID762925;
%goto ID762925;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID762925;
* Insert record into change management table for CHANGE_ID: ID762925;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID762925",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID762925;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE MODEL_COMP_NM = 'FA' AND SPEC_NM = 'MAPE_WEIGHT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE MODEL_COMP_NM = 'FA' AND SPEC_NM = 'MAPE_WEIGHT';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID762925;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID762925;
%put ERROR- Description                              : Remove MAPE_WEIGHT as FA spec;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 26MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID762925;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID762925",
"Remove MAPE_WEIGHT as FA spec",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID762925:;
 
 
* End of changes for CHANGE_ID:ID762925;
 
 
***********************************************************************************************;
*************************************  End Change ID762925 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID761781 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID761781;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID761781")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PROFILING_PROJECT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PROFILING_PROJECT;
%put NOTE: Change ID                             :ID761781;
%goto ID761781;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID761781;
%goto ID761781;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID761781;
* Insert record into change management table for CHANGE_ID: ID761781;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID761781",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID761781;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE PROFILING_PROJECT ADD OUT_OF_DATE_FLG INTEGER DEFAULT 0 NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
data &m_di_trans..PROFILING_PROJECT;
 
 
set &m_di_trans..PROFILING_PROJECT;
 
 
ATTRIB OUT_OF_DATE_FLG LENGTH=4;
 
 
 
OUT_OF_DATE_FLG=0;
 
 
RUN;
 
 
 
proc sql;
 
 
ALTER TABLE PROFILING_PROJECT  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PROFILING_PROJECT_SK);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID761781;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID761781;
%put ERROR- Description                              : Add out_of_date_flg to PROFILING_PROJECT table;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 26MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID761781;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID761781",
"Add out_of_date_flg to PROFILING_PROJECT table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID761781:;
 
 
* End of changes for CHANGE_ID:ID761781;
 
 
***********************************************************************************************;
*************************************  End Change ID761781 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID762209 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID762209;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID762209")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID762209;
%goto ID762209;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID762209;
* Insert record into change management table for CHANGE_ID: ID762209;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID762209",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID762209;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE ALERT_COST ADD RPO_PLAN_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE ALERT_COST ADD RPO_PLAN_MEMBER_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE ALERT_COMP ADD RPO_PLAN_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE ALERT_COMP ADD RPO_PLAN_MEMBER_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN ADD PROCESS_RUN_DTTM DATE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN ADD PROCESS_OPTION INTEGER DEFAULT 1 NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN ADD RPO_PLAN_TYPE INTEGER DEFAULT 1 NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
ALTER TABLE ALERT_COST ADD RPO_PLAN_SK INTEGER;
 
 
ALTER TABLE ALERT_COST ADD RPO_PLAN_MEMBER_SK INTEGER;
 
 
 
ALTER TABLE ALERT_COMP ADD RPO_PLAN_SK INTEGER;
 
 
ALTER TABLE ALERT_COMP ADD RPO_PLAN_MEMBER_SK INTEGER;
 
 
 
 
ALTER TABLE RPO_PLAN ADD PROCESS_RUN_DTTM DATE;
 
 
quit;
 
 
 
data &m_di_trans..RPO_PLAN;
 
 
set &m_di_trans..RPO_PLAN;
 
 
ATTRIB PROCESS_OPTION LENGTH=4;
 
 
ATTRIB RPO_PLAN_TYPE LENGTH=4;
 
 
 
PROCESS_OPTION=1;
 
 
RPO_PLAN_TYPE=1;
 
 
RUN;
 
 
 
proc sql;
 
 
alter table &m_di_trans..RPO_PLAN add NOT NULL (PROCESS_OPTION);
 
 
alter table &m_di_trans..RPO_PLAN add NOT NULL (RPO_PLAN_TYPE);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID762209;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID762209;
%put ERROR- Description                              : Recommending prices for products with alerts;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 23MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID762209;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID762209",
"Recommending prices for products with alerts",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID762209:;
 
 
* End of changes for CHANGE_ID:ID762209;
 
 
***********************************************************************************************;
*************************************  End Change ID762209 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID733892 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID733892;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID733892")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :ID733892;
%goto ID733892;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID733892;
%goto ID733892;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID733892;
* Insert record into change management table for CHANGE_ID: ID733892;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID733892",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID733892;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE FA_SCORING_RULE (
FA_SCORING_RULE_SK       INTEGER NOT NULL,
WEIGHT                   NUMERIC(12,4),
MEASURE                  VARCHAR(40)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORING_RULE ADD CONSTRAINT FA_SCORING_RULE_PK PRIMARY KEY (FA_SCORING_RULE_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FA_SCORING_RANGE_RULE (
FA_SCORING_RANGE_RULE_SK   INTEGER NOT NULL,
FA_SCORING_RULE_SK       INTEGER NOT NULL,
RANGE_START_VALUE        NUMERIC(12,4),
RANGE_END_VALUE          NUMERIC(12,4),
VALUE                    NUMERIC(12,4)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORING_RANGE_RULE ADD CONSTRAINT FA_SCORING_RANGE_RULE_PK PRIMARY KEY (FA_SCORING_RANGE_RULE_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
CREATE TABLE FA_SCORING_RULE (
FA_SCORING_RULE_SK       INTEGER NOT NULL,
WEIGHT                   NUMERIC(12,4),
MEASURE                  VARCHAR(40)
);
 
 
ALTER TABLE FA_SCORING_RULE ADD CONSTRAINT FA_SCORING_RULE_PK PRIMARY KEY (FA_SCORING_RULE_SK);
 
 
 
CREATE TABLE FA_SCORING_RANGE_RULE (
FA_SCORING_RANGE_RULE_SK   INTEGER NOT NULL,
FA_SCORING_RULE_SK       INTEGER NOT NULL,
RANGE_START_VALUE        NUMERIC(12,4),
RANGE_END_VALUE          NUMERIC(12,4),
VALUE                    NUMERIC(12,4)
);
 
 
ALTER TABLE FA_SCORING_RANGE_RULE ADD CONSTRAINT FA_SCORING_RANGE_RULE_PK PRIMARY KEY (FA_SCORING_RANGE_RULE_SK);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID733892;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID733892;
%put ERROR- Description                              : New tables FA_SCORING_RULE and FA_SCORING_RANGE_RULE for FA;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 02JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID733892;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID733892",
"New tables FA_SCORING_RULE and FA_SCORING_RANGE_RULE for FA",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID733892:;
 
 
* End of changes for CHANGE_ID:ID733892;
 
 
***********************************************************************************************;
*************************************  End Change ID733892 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID739353 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID739353;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID739353")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID739353;
%goto ID739353;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID739353;
%goto ID739353;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID739353;
* Insert record into change management table for CHANGE_ID: ID739353;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID739353",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID739353;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'DOW_PROFILE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DOW_PROFILE','DOW','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'DAILY_FCST_METHOD'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DAILY_FCST_METHOD','DOW','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'DOW_PROFILE';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DOW_PROFILE','DOW','-1','1',NULL);
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'DAILY_FCST_METHOD';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DAILY_FCST_METHOD','DOW','-1','1',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID739353;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID739353;
%put ERROR- Description                              : Add DOW specs DOW_PROFILE and DAILY_FCST_METHOD;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 05JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID739353;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID739353",
"Add DOW specs DOW_PROFILE and DAILY_FCST_METHOD",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID739353:;
 
 
* End of changes for CHANGE_ID:ID739353;
 
 
***********************************************************************************************;
*************************************  End Change ID739353 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID765135 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID765135;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID765135")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID765135;
%goto ID765135;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID765135;
%goto ID765135;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID765135;
* Insert record into change management table for CHANGE_ID: ID765135;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID765135",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID765135;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE MODEL_SPEC_DEFAULT SET DEFAULT_SPEC_VALUE = '' WHERE SPEC_NM = 'HOLDOUT_DETAILS_TABLES'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
UPDATE MODEL_SPEC_DEFAULT SET DEFAULT_SPEC_VALUE = '' WHERE SPEC_NM = 'HOLDOUT_DETAILS_TABLES';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID765135;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID765135;
%put ERROR- Description                              : Change default value for FA spec HOLDOUT_DETAILS_TABLES;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 06JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID765135;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID765135",
"Change default value for FA spec HOLDOUT_DETAILS_TABLES",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID765135:;
 
 
* End of changes for CHANGE_ID:ID765135;
 
 
***********************************************************************************************;
*************************************  End Change ID765135 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID762768 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID762768;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID762768")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID762768;
%goto ID762768;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID762768;
* Insert record into change management table for CHANGE_ID: ID762768;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID762768",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID762768;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM FA_SCENARIO_STATUS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
DELETE FROM FA_SCORE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS MODIFY MEDIAN_PE NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS MODIFY ELASTICITY_TAIL NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS MODIFY PCT_ELASTICITY_DEFAULTED NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS MODIFY MEDIAN_PE_FIT NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS MODIFY MAX_HD_RMSE_FIT NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS MODIFY SCORE NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS DROP COLUMN WEIGHTED_MAPE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS DROP COLUMN WEIGHTED_MEAN_PE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS DROP COLUMN WEIGHTED_MAPE_FIT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS DROP COLUMN WEIGHTED_MEAN_PE_FIT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCENARIO_STATUS ADD
(
INV_WEIGHTED_MAPE NUMERIC(12,4),
INV_WEIGHTED_MEAN_PE NUMERIC(12,4),
SALES_WEIGHTED_MAPE NUMERIC(12,4),
SALES_WEIGHTED_MEAN_PE NUMERIC(12,4),
REVENUE_WEIGHTED_MAPE NUMERIC(12,4),
REVENUE_WEIGHTED_MEAN_PE NUMERIC(12,4),
INV_WEIGHTED_MAPE_FIT NUMERIC(12,4),
INV_WEIGHTED_MEAN_PE_FIT NUMERIC(12,4),
SALES_WEIGHTED_MAPE_FIT NUMERIC(12,4),
SALES_WEIGHTED_MEAN_PE_FIT NUMERIC(12,4),
REVENUE_WEIGHTED_MAPE_FIT NUMERIC(12,4),
REVENUE_WEIGHTED_MEAN_PE_FIT NUMERIC(12,4)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE MODIFY MEDIAN_PE NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE MODIFY ELASTICITY_TAIL NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE MODIFY PCT_ELASTICITY_DEFAULTED NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE MODIFY MEDIAN_PE_FIT NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE MODIFY MAX_HD_RMSE_FIT NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE MODIFY SCORE NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE DROP COLUMN WEIGHTED_MAPE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE DROP COLUMN WEIGHTED_MEAN_PE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE DROP COLUMN WEIGHTED_MAPE_FIT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE DROP COLUMN WEIGHTED_MEAN_PE_FIT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORE ADD
(
INV_WEIGHTED_MAPE NUMERIC(12,4),
INV_WEIGHTED_MEAN_PE NUMERIC(12,4),
SALES_WEIGHTED_MAPE NUMERIC(12,4),
SALES_WEIGHTED_MEAN_PE NUMERIC(12,4),
REVENUE_WEIGHTED_MAPE NUMERIC(12,4),
REVENUE_WEIGHTED_MEAN_PE NUMERIC(12,4),
INV_WEIGHTED_MAPE_FIT NUMERIC(12,4),
INV_WEIGHTED_MEAN_PE_FIT NUMERIC(12,4),
SALES_WEIGHTED_MAPE_FIT NUMERIC(12,4),
SALES_WEIGHTED_MEAN_PE_FIT NUMERIC(12,4),
REVENUE_WEIGHTED_MAPE_FIT NUMERIC(12,4),
REVENUE_WEIGHTED_MEAN_PE_FIT NUMERIC(12,4)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
DELETE FROM FA_SCENARIO_STATUS;
 
 
DELETE FROM FA_SCORE;
 
 
 
ALTER TABLE FA_SCENARIO_STATUS MODIFY MEDIAN_PE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS MODIFY ELASTICITY_TAIL NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS MODIFY PCT_ELASTICITY_DEFAULTED NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS MODIFY MEDIAN_PE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS MODIFY MAX_HD_RMSE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS MODIFY SCORE NUMERIC(12,4);
 
 
 
ALTER TABLE FA_SCENARIO_STATUS DROP COLUMN WEIGHTED_MAPE;
 
 
ALTER TABLE FA_SCENARIO_STATUS DROP COLUMN WEIGHTED_MEAN_PE;
 
 
ALTER TABLE FA_SCENARIO_STATUS DROP COLUMN WEIGHTED_MAPE_FIT;
 
 
ALTER TABLE FA_SCENARIO_STATUS DROP COLUMN WEIGHTED_MEAN_PE_FIT;
 
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD INV_WEIGHTED_MAPE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD INV_WEIGHTED_MEAN_PE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD SALES_WEIGHTED_MAPE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD SALES_WEIGHTED_MEAN_PE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD REVENUE_WEIGHTED_MAPE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD REVENUE_WEIGHTED_MEAN_PE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD INV_WEIGHTED_MAPE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD INV_WEIGHTED_MEAN_PE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD SALES_WEIGHTED_MAPE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD SALES_WEIGHTED_MEAN_PE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD REVENUE_WEIGHTED_MAPE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCENARIO_STATUS ADD REVENUE_WEIGHTED_MEAN_PE_FIT NUMERIC(12,4);
 
 
 
ALTER TABLE FA_SCORE MODIFY MEDIAN_PE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE MODIFY ELASTICITY_TAIL NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE MODIFY PCT_ELASTICITY_DEFAULTED NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE MODIFY MEDIAN_PE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE MODIFY MAX_HD_RMSE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE MODIFY SCORE NUMERIC(12,4);
 
 
 
ALTER TABLE FA_SCORE DROP COLUMN WEIGHTED_MAPE;
 
 
ALTER TABLE FA_SCORE DROP COLUMN WEIGHTED_MEAN_PE;
 
 
ALTER TABLE FA_SCORE DROP COLUMN WEIGHTED_MAPE_FIT;
 
 
ALTER TABLE FA_SCORE DROP COLUMN WEIGHTED_MEAN_PE_FIT;
 
 
 
ALTER TABLE FA_SCORE ADD INV_WEIGHTED_MAPE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE ADD INV_WEIGHTED_MEAN_PE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE ADD SALES_WEIGHTED_MAPE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE ADD SALES_WEIGHTED_MEAN_PE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE ADD REVENUE_WEIGHTED_MAPE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE ADD REVENUE_WEIGHTED_MEAN_PE NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE ADD INV_WEIGHTED_MAPE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE ADD INV_WEIGHTED_MEAN_PE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE ADD SALES_WEIGHTED_MAPE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE ADD SALES_WEIGHTED_MEAN_PE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE ADD REVENUE_WEIGHTED_MAPE_FIT NUMERIC(12,4);
 
 
ALTER TABLE FA_SCORE ADD REVENUE_WEIGHTED_MEAN_PE_FIT NUMERIC(12,4);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID762768;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID762768;
%put ERROR- Description                              : Output weighted measurements in scenario_status table for all three candidate weights;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 06JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID762768;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID762768",
"Output weighted measurements in scenario_status table for all three candidate weights",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID762768:;
 
 
* End of changes for CHANGE_ID:ID762768;
 
 
***********************************************************************************************;
*************************************  End Change ID762768 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID733774_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID733774_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID733774_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID733774_1;
%goto ID733774_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID733774_1;
* Insert record into change management table for CHANGE_ID: ID733774_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID733774_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID733774_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE NUM_GEO_PROD ADD NUM_GEO_PRODS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE NUM_GEO_PROD ADD NUM_GEO_PRODS INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID733774_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID733774_1;
%put ERROR- Description                              : Fix table NUM_GEO_PROD;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 23MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID733774_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID733774_1",
"Fix table NUM_GEO_PROD",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID733774_1:;
 
 
* End of changes for CHANGE_ID:ID733774_1;
 
 
***********************************************************************************************;
*************************************  End Change ID733774_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID765897 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID765897;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID765897")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID765897;
%goto ID765897;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID765897;
* Insert record into change management table for CHANGE_ID: ID765897;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID765897",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID765897;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update VEHICLE_CATEGORY set VEHICLE_CATEGORY_NM='Miles', VEHICLE_CATEGORY_DESC='Buy N1 of P1 [ and N2 of P2 ] and get M Miles' where VEHICLE_CATEGORY_SK = 51
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update VEHICLE_CATEGORY set VEHICLE_CATEGORY_NM='MilesHigh', VEHICLE_CATEGORY_DESC='Buy N1 of P1 [ and N2 of P2 ] and get M Miles' where VEHICLE_CATEGORY_SK = 52
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into VEHICLE_CATEGORY (VEHICLE_CATEGORY_SK, VEHICLE_CATEGORY_NM, VEHICLE_CATEGORY_DESC, VEHICLE_CATEGORY_TYPE, ACTIVE_FLG, PRICE_FLG)
values (53, 'Points', 'Buy N1 of P1 [ and N2 of P2 ] and get P Points', 'PRICE', 1, 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into VEHICLE_CATEGORY (VEHICLE_CATEGORY_SK, VEHICLE_CATEGORY_NM, VEHICLE_CATEGORY_DESC, VEHICLE_CATEGORY_TYPE, ACTIVE_FLG, PRICE_FLG)
values (54, 'PointsHigh', 'Buy N1 of P1 [ and N2 of P2 ] and get P Points', 'PRICE', 1, 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
update VEHICLE set VEHICLE_CATEGORY_SK = 53 where VEHICLE_SK in (select VEHICLE_SK
from VEHICLE, CUSTOM_ATTR
where VEHICLE_CATEGORY_SK=51
and VEHICLE_SK=OBJECT_SK
and CAT_CUSTOM_ATTR_SK=-110
and ATTR_VALUE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
update VEHICLE set VEHICLE_CATEGORY_SK = 54 where VEHICLE_SK in (select VEHICLE_SK
from VEHICLE, CUSTOM_ATTR
where VEHICLE_CATEGORY_SK=52
and VEHICLE_SK=OBJECT_SK
and CAT_CUSTOM_ATTR_SK=-117
and ATTR_VALUE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from CAT_CUSTOM_ATTR where CAT_CUSTOM_ATTR_SK in (-110, -117)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from CUSTOM_ATTR where CAT_CUSTOM_ATTR_SK in (-110, -117)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
update CUSTOM_ATTR
set CAT_CUSTOM_ATTR_SK = CAT_CUSTOM_ATTR_SK - 21
where CAT_CUSTOM_ATTR_SK <= -104 and CAT_CUSTOM_ATTR_SK >= -109
and OBJECT_SK in (select VEHICLE_SK from VEHICLE where VEHICLE_CATEGORY_SK = 53)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
update CUSTOM_ATTR
set CAT_CUSTOM_ATTR_SK = CAT_CUSTOM_ATTR_SK - 20
where CAT_CUSTOM_ATTR_SK <= -111 and CAT_CUSTOM_ATTR_SK >= -116
and OBJECT_SK in (select VEHICLE_SK from VEHICLE where VEHICLE_CATEGORY_SK = 54)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-125, 53, 7,'BuyCount1',          '', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-126, 53, 7,'BuyAmount1',         '', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-127, 53, 7,'BuyCount2',          '', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-128, 53, 7,'BuyAmount2',         '', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-129, 53, 7,'GetCount',           '', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-130, 53, 7,'GetValue',           '', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-131, 54, 7,'BuyCount1',          '', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-132, 54, 7,'BuyAmount1',         '', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-133, 54, 7,'BuyCount2',          '', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-134, 54, 7,'BuyAmount2',         '', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-135, 54, 7,'GetCount',           '', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-136, 54, 7,'GetValue',           '', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
update VEHICLE_CATEGORY set VEHICLE_CATEGORY_NM='Miles', VEHICLE_CATEGORY_DESC='Buy N1 of P1 [ and N2 of P2 ] and get M Miles' where VEHICLE_CATEGORY_SK = 51;
 
 
update VEHICLE_CATEGORY set VEHICLE_CATEGORY_NM='MilesHigh', VEHICLE_CATEGORY_DESC='Buy N1 of P1 [ and N2 of P2 ] and get M Miles' where VEHICLE_CATEGORY_SK = 52;
 
 
insert into VEHICLE_CATEGORY (VEHICLE_CATEGORY_SK, VEHICLE_CATEGORY_NM, VEHICLE_CATEGORY_DESC, VEHICLE_CATEGORY_TYPE, ACTIVE_FLG, PRICE_FLG)
values (53, 'Points', 'Buy N1 of P1 [ and N2 of P2 ] and get P Points', 'PRICE', 1, 1);
 
 
insert into VEHICLE_CATEGORY (VEHICLE_CATEGORY_SK, VEHICLE_CATEGORY_NM, VEHICLE_CATEGORY_DESC, VEHICLE_CATEGORY_TYPE, ACTIVE_FLG, PRICE_FLG)
values (54, 'PointsHigh', 'Buy N1 of P1 [ and N2 of P2 ] and get P Points', 'PRICE', 1, 1);
 
 
 
create table WORK.VEHICLE2 as select * from VEHICLE;
 
 
 
update VEHICLE set VEHICLE_CATEGORY_SK = 53 where VEHICLE_SK in (select VEHICLE_SK
from WORK.VEHICLE2, CUSTOM_ATTR
where VEHICLE_CATEGORY_SK=51
and VEHICLE_SK=OBJECT_SK
and CAT_CUSTOM_ATTR_SK=-110
and ATTR_VALUE = '2');
 
 
 
update VEHICLE set VEHICLE_CATEGORY_SK = 54 where VEHICLE_SK in (select VEHICLE_SK
from WORK.VEHICLE2, CUSTOM_ATTR
where VEHICLE_CATEGORY_SK=52
and VEHICLE_SK=OBJECT_SK
and CAT_CUSTOM_ATTR_SK=-117
and ATTR_VALUE = '2');
 
 
 
delete from CAT_CUSTOM_ATTR where CAT_CUSTOM_ATTR_SK in (-110, -117);
 
 
delete from CUSTOM_ATTR where CAT_CUSTOM_ATTR_SK in (-110, -117);
 
 
 
update CUSTOM_ATTR
set CAT_CUSTOM_ATTR_SK = CAT_CUSTOM_ATTR_SK - 21
where CAT_CUSTOM_ATTR_SK <= -104 and CAT_CUSTOM_ATTR_SK >= -109
and OBJECT_SK in (select VEHICLE_SK from VEHICLE where VEHICLE_CATEGORY_SK = 53);
 
 
 
update CUSTOM_ATTR
set CAT_CUSTOM_ATTR_SK = CAT_CUSTOM_ATTR_SK - 20
where CAT_CUSTOM_ATTR_SK <= -111 and CAT_CUSTOM_ATTR_SK >= -116
and OBJECT_SK in (select VEHICLE_SK from VEHICLE where VEHICLE_CATEGORY_SK = 54);
 
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-125, 53, 7,'BuyCount1',          '', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-126, 53, 7,'BuyAmount1',         '', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-127, 53, 7,'BuyCount2',          '', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-128, 53, 7,'BuyAmount2',         '', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-129, 53, 7,'GetCount',           '', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-130, 53, 7,'GetValue',           '', 2);
 
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-131, 54, 7,'BuyCount1',          '', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-132, 54, 7,'BuyAmount1',         '', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-133, 54, 7,'BuyCount2',          '', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-134, 54, 7,'BuyAmount2',         '', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-135, 54, 7,'GetCount',           '', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-136, 54, 7,'GetValue',           '', 2);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID765897;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID765897;
%put ERROR- Description                              : Separate MilesPoints into two price types;
%put ERROR- Version                                  : D3MICM52,M2MI42;
%put ERROR- Date of Change                           : 08JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID765897;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID765897",
"Separate MilesPoints into two price types",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID765897:;
 
 
* End of changes for CHANGE_ID:ID765897;
 
 
***********************************************************************************************;
*************************************  End Change ID765897 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID761590_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID761590_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID761590_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID761590_2;
%goto ID761590_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52, M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID761590_2;
* Insert record into change management table for CHANGE_ID: ID761590_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID761590_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID761590_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE TABLE RPP_PLAN_COST_FACT
(
PLAN_SK INTEGER NOT NULL,
PROD_HIER_SK INTEGER NOT NULL,
GEO_HIER_SK INTEGER NOT NULL,
COST NUMERIC(12,2) NOT NULL
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE INDEX RPP_PLAN_COST_FACT_IX1 ON RPP_PLAN_COST_FACT
(
PLAN_SK
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
CREATE TABLE RPP_PLAN_COST_FACT
(
PLAN_SK INTEGER NOT NULL,
PROD_HIER_SK INTEGER NOT NULL,
GEO_HIER_SK INTEGER NOT NULL,
COST NUMERIC(12,2) NOT NULL
)
;
 
 
 
create index PLAN_SK on RPP_PLAN_COST_FACT(PLAN_SK);
 
 
 
quit;
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID761590_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID761590_2;
%put ERROR- Description                              : Add table for promotion specific cost fact;
%put ERROR- Version                                  : D3MICM52, M2MI42;
%put ERROR- Date of Change                           : 08JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID761590_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID761590_2",
"Add table for promotion specific cost fact",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID761590_2:;
 
 
* End of changes for CHANGE_ID:ID761590_2;
 
 
***********************************************************************************************;
*************************************  End Change ID761590_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0661257 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0661257;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0661257")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0661257;
%goto ID0661257;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0661257;
* Insert record into change management table for CHANGE_ID: ID0661257;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0661257",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0661257;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE REQUEST ADD ADJUST_ORDER_QTY_MIN_FLG INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE REQUEST ADD ADJUST_ORDER_QTY_MAX_FLG INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
ALTER TABLE REQUEST ADD ADJUST_ORDER_QTY_MIN_FLG INTEGER;
 
 
ALTER TABLE REQUEST ADD ADJUST_ORDER_QTY_MAX_FLG INTEGER;
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0661257;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0661257;
%put ERROR- Description                              : NF: Adjust store_order_min and max for stored inventory;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 10JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0661257;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0661257",
"NF: Adjust store_order_min and max for stored inventory",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0661257:;
 
 
* End of changes for CHANGE_ID:ID0661257;
 
 
***********************************************************************************************;
*************************************  End Change ID0661257 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID767638 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID767638;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID767638")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID767638;
%goto ID767638;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID767638;
%goto ID767638;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID767638;
* Insert record into change management table for CHANGE_ID: ID767638;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID767638",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID767638;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'DOW_PROFILE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DOW_PROFILE','FCST','1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DOW_PROFILE','FCST','2','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'DAILY_FCST_METHOD'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DAILY_FCST_METHOD','FCST','1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DAILY_FCST_METHOD','FCST','2','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'DOW_PROFILE';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DOW_PROFILE','FCST','1','1',NULL);
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DOW_PROFILE','FCST','2','1',NULL);
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'DAILY_FCST_METHOD';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DAILY_FCST_METHOD','FCST','1','1',NULL);
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DAILY_FCST_METHOD','FCST','2','1',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID767638;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID767638;
%put ERROR- Description                              : Change model specs DOW_PROFILE and DAILY_FCST_METHOD component from DOW to FCST;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 15JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID767638;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID767638",
"Change model specs DOW_PROFILE and DAILY_FCST_METHOD component from DOW to FCST",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID767638:;
 
 
* End of changes for CHANGE_ID:ID767638;
 
 
***********************************************************************************************;
*************************************  End Change ID767638 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID768125 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID768125;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID768125")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID768125;
%goto ID768125;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID768125;
* Insert record into change management table for CHANGE_ID: ID768125;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID768125",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID768125;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE DATA_CONFIG_TEMPLATE DROP COLUMN INCLUDE_TS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE DATA_CONFIG_TEMPLATE DROP COLUMN INCLUDE_REG
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE DATA_CONFIG_TEMPLATE RENAME COLUMN FCST_GEO_LVL TO DOW_GEO_LVL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE DATA_CONFIG_TEMPLATE RENAME COLUMN FCST_PROD_LVL TO DOW_PROD_LVL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE DATA_CONFIG_TEMPLATE RENAME COLUMN FCST_BY_GEO_LVL TO DOW_BY_GEO_LVL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE DATA_CONFIG_TEMPLATE RENAME COLUMN FCST_BY_PROD_LVL TO DOW_BY_PROD_LVL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
ALTER TABLE DATA_CONFIG_TEMPLATE DROP COLUMN INCLUDE_TS;
 
 
ALTER TABLE DATA_CONFIG_TEMPLATE DROP COLUMN INCLUDE_REG;
 
 
quit;
 
 
 
proc datasets library=&m_di_trans nolist;
 
 
modify DATA_CONFIG_TEMPLATE ;
 
 
rename FCST_GEO_LVL = DOW_GEO_LVL;
 
 
rename FCST_PROD_LVL = DOW_PROD_LVL;
 
 
rename FCST_BY_GEO_LVL = DOW_BY_GEO_LVL;
 
 
rename FCST_BY_PROD_LVL = DOW_BY_PROD_LVL;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE DATA_CONFIG_TEMPLATE DROP COLUMN INCLUDE_TS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE DATA_CONFIG_TEMPLATE DROP COLUMN INCLUDE_REG
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE DATA_CONFIG_TEMPLATE RENAME COLUMN FCST_GEO_LVL TO DOW_GEO_LVL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE DATA_CONFIG_TEMPLATE RENAME COLUMN FCST_PROD_LVL TO DOW_PROD_LVL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE DATA_CONFIG_TEMPLATE RENAME COLUMN FCST_BY_GEO_LVL TO DOW_BY_GEO_LVL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE DATA_CONFIG_TEMPLATE RENAME COLUMN FCST_BY_PROD_LVL TO DOW_BY_PROD_LVL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
REORG TABLE DATA_CONFIG_TEMPLATE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID768125;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID768125;
%put ERROR- Description                              : Modify DATA_CONFIG_TEMPLATE table to support DOW component;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 16JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID768125;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID768125",
"Modify DATA_CONFIG_TEMPLATE table to support DOW component",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID768125:;
 
 
* End of changes for CHANGE_ID:ID768125;
 
 
***********************************************************************************************;
*************************************  End Change ID768125 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID767774 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID767774;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID767774")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MA_SCENARIO_STATUS))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MA_SCENARIO_STATUS;
%put NOTE: Change ID                             :ID767774;
%goto ID767774;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID767774;
%goto ID767774;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID767774;
* Insert record into change management table for CHANGE_ID: ID767774;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID767774",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID767774;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DROP TABLE MA_SCENARIO_STATUS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DROP TABLE MA_SCENARIO_STATUS;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID767774;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID767774;
%put ERROR- Description                              : Drop table MA_SCENARIO_STATUS from schema;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 15JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID767774;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID767774",
"Drop table MA_SCENARIO_STATUS from schema",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID767774:;
 
 
* End of changes for CHANGE_ID:ID767774;
 
 
***********************************************************************************************;
*************************************  End Change ID767774 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID767635 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID767635;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID767635")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID767635;
%goto ID767635;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID767635;
%goto ID767635;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID767635;
* Insert record into change management table for CHANGE_ID: ID767635;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID767635",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID767635;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'DOW_EVENT_PROD_AGG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DOW_EVENT_PROD_AGG','DOW','-1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM MODEL_SPEC_DEFAULT WHERE SPEC_NM = 'DOW_EVENT_PROD_AGG';
 
 
INSERT INTO MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES ('DOW_EVENT_PROD_AGG','DOW','-1','0',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID767635;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID767635;
%put ERROR- Description                              : Add DOW spec DOW_EVENT_PROD_AGG;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 15JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID767635;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID767635",
"Add DOW spec DOW_EVENT_PROD_AGG",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID767635:;
 
 
* End of changes for CHANGE_ID:ID767635;
 
 
***********************************************************************************************;
*************************************  End Change ID767635 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID768006 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID768006;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID768006")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID768006;
%goto ID768006;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID768006;
* Insert record into change management table for CHANGE_ID: ID768006;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID768006",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID768006;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN ADD ALLOW_MARKDN_DURING_PROMO_CD INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO GEO_PROD_SETTING (GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (28,1,1,1,53,1,1,1,2,1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE MDO_PLAN ADD ALLOW_MARKDN_DURING_PROMO_CD INTEGER;
 
 
 
INSERT INTO GEO_PROD_SETTING (GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (28,1,1,1,53,1,1,1,2,1);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID768006;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID768006;
%put ERROR- Description                              : Add plan setting and pricing rule for allow markdown during promo;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 16JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID768006;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID768006",
"Add plan setting and pricing rule for allow markdown during promo",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID768006:;
 
 
* End of changes for CHANGE_ID:ID768006;
 
 
***********************************************************************************************;
*************************************  End Change ID768006 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID768547 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID768547;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID768547")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID768547;
%goto ID768547;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID768547;
* Insert record into change management table for CHANGE_ID: ID768547;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID768547",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID768547;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD USE_SHARED_PACK_CONFIGS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD USE_SHARED_PACK_CONFIGS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_BUY ADD USE_SHARED_PACK_CONFIGS INTEGER ;
 
 
ALTER TABLE PKO_DELIVERY ADD USE_SHARED_PACK_CONFIGS INTEGER ;
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID768547;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID768547;
%put ERROR- Description                              : Support Style-level Configurations in client;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 21JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID768547;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID768547",
"Support Style-level Configurations in client",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID768547:;
 
 
* End of changes for CHANGE_ID:ID768547;
 
 
***********************************************************************************************;
*************************************  End Change ID768547 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID763412 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID763412;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID763412")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID763412;
%goto ID763412;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID763412;
* Insert record into change management table for CHANGE_ID: ID763412;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID763412",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID763412;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE PKOPT_PLANNED_QTY (
PLANNED_QTY_SK INTEGER NOT NULL,
IMPORT_ID INTEGER NOT NULL,
PROD_ID VARCHAR(32) NOT NULL,
PROD_HIER_SK INTEGER,
GEO_ID VARCHAR(32) NOT NULL,
GEO_HIER_SK INTEGER,
QTY INTEGER NOT NULL,
PRIMARY KEY (PLANNED_QTY_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_PLANNED_QTY_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX PKOPT_PLANNED_QTY_IX1 ON PKOPT_PLANNED_QTY
(
IMPORT_ID
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX PKOPT_PLANNED_QTY_IX2 ON PKOPT_PLANNED_QTY
(
PROD_ID
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PKO_EXTERNAL_NEED_SUMMARY
(
PKO_EXTERNAL_NEED_SUM_SK           INTEGER NOT NULL,
PKO_NEED_LOCATION_GROUP_SK         INTEGER NOT NULL,
NEED_DT                            DATE,
NEED                               INTEGER NOT NULL,
DELIVERY_SEQUENCE_ID               INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
IMPORT_ID                          INTEGER NOT NULL,
PRIMARY KEY (PKO_EXTERNAL_NEED_SUM_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_PKO_EXTERNAL_NEED_SUM_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
CREATE TABLE PKOPT_PLANNED_QTY (
PLANNED_QTY_SK INTEGER NOT NULL,
IMPORT_ID INTEGER NOT NULL,
PROD_ID VARCHAR(32) NOT NULL,
PROD_HIER_SK INTEGER,
GEO_ID VARCHAR(32) NOT NULL,
GEO_HIER_SK INTEGER,
QTY INTEGER NOT NULL
) ;
 
 
 
ALTER TABLE PKOPT_PLANNED_QTY ADD CONSTRAINT PKOPT_PLANNED_QTY PRIMARY KEY (PLANNED_QTY_SK);
 
 
 
CREATE INDEX IMPORT_ID ON PKOPT_PLANNED_QTY
(
IMPORT_ID
) ;
 
 
 
CREATE INDEX PROD_ID ON PKOPT_PLANNED_QTY
(
PROD_ID
) ;
 
 
 
CREATE TABLE PKO_EXTERNAL_NEED_SUMMARY
(
PKO_EXTERNAL_NEED_SUM_SK           INTEGER NOT NULL,
PKO_NEED_LOCATION_GROUP_SK         INTEGER NOT NULL,
NEED_DT                            DATE,
NEED                               INTEGER NOT NULL,
DELIVERY_SEQUENCE_ID               INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
IMPORT_ID                          INTEGER NOT NULL
) ;
 
 
 
ALTER TABLE PKO_EXTERNAL_NEED_SUMMARY ADD CONSTRAINT PKO_EXTERNAL_NEED_SUMMARY PRIMARY KEY (PKO_EXTERNAL_NEED_SUM_SK);
 
 
 
quit;
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID763412;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID763412;
%put ERROR- Description                              : Store level plan imports;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 21JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID763412;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID763412",
"Store level plan imports",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID763412:;
 
 
* End of changes for CHANGE_ID:ID763412;
 
 
***********************************************************************************************;
*************************************  End Change ID763412 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0767188 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0767188;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0767188")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :ID0767188;
%goto ID0767188;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..REQ_PACKREC_SETTING))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..REQ_PACKREC_SETTING;
%put NOTE: Change ID                             :ID0767188;
%goto ID0767188;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0767188;
%goto ID0767188;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0767188;
* Insert record into change management table for CHANGE_ID: ID0767188;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0767188",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0767188;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_SETTING ADD USE_SHARED_PACK_CONFIGS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
ALTER TABLE REQ_PACKREC_SETTING ADD USE_SHARED_PACK_CONFIGS INTEGER;
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0767188;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0767188;
%put ERROR- Description                              : NF: Packopt Schema change for shared pack configs by style;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 21JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0767188;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0767188",
"NF: Packopt Schema change for shared pack configs by style",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0767188:;
 
 
* End of changes for CHANGE_ID:ID0767188;
 
 
***********************************************************************************************;
*************************************  End Change ID0767188 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID763412_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID763412_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID763412_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID763412_1;
%goto ID763412_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID763412_1;
* Insert record into change management table for CHANGE_ID: ID763412_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID763412_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID763412_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKOPT_PLANNED_QTY DROP COLUMN PROD_HIER_SK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKOPT_PLANNED_QTY DROP COLUMN GEO_HIER_SK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKOPT_PLANNED_QTY DROP COLUMN PROD_HIER_SK ;
 
 
ALTER TABLE PKOPT_PLANNED_QTY DROP COLUMN GEO_HIER_SK ;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID763412_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID763412_1;
%put ERROR- Description                              : Store level plan imports;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 22JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID763412_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID763412_1",
"Store level plan imports",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID763412_1:;
 
 
* End of changes for CHANGE_ID:ID763412_1;
 
 
***********************************************************************************************;
*************************************  End Change ID763412_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID769264 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID769264;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID769264")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID769264;
%goto ID769264;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID769264;
* Insert record into change management table for CHANGE_ID: ID769264;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID769264",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID769264;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD SKU_MIN INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_STORE_NEED ADD SKU_MIN INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_DELIVERY ADD SKU_MIN INTEGER ;
 
 
ALTER TABLE PKO_STORE_NEED ADD SKU_MIN INTEGER ;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID769264;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID769264;
%put ERROR- Description                              : SKU x Store Minimums in Client;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 22JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID769264;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID769264",
"SKU x Store Minimums in Client",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID769264:;
 
 
* End of changes for CHANGE_ID:ID769264;
 
 
***********************************************************************************************;
*************************************  End Change ID769264 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID733774_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID733774_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID733774_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID733774_2;
%goto ID733774_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID733774_2;
* Insert record into change management table for CHANGE_ID: ID733774_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID733774_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID733774_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DROP TABLE COVERAGE_INPUT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
DROP TABLE COVERAGE_OUTPUT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE TABLE COVERAGE_OUTPUT
(
PROD_HIER_SK                  INTEGER NOT NULL,
PROD_HIER_ASSOC_CD            INTEGER NOT NULL,
GEO_HIER_SK                   INTEGER NOT NULL,
GEO_HIER_ASSOC_CD             INTEGER NOT NULL,
PRIMARY KEY(PROD_HIER_SK, PROD_HIER_ASSOC_CD, GEO_HIER_SK, GEO_HIER_ASSOC_CD)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
DROP TABLE COVERAGE_INPUT;
 
 
CREATE TABLE COVERAGE_OUTPUT
(
PROD_HIER_SK                  INTEGER NOT NULL,
PROD_HIER_ASSOC_CD            INTEGER NOT NULL,
GEO_HIER_SK                   INTEGER NOT NULL,
GEO_HIER_ASSOC_CD             INTEGER NOT NULL
);
 
 
ALTER TABLE COVERAGE_OUTPUT ADD CONSTRAINT PRIM_KEY PRIMARY KEY (PROD_HIER_SK, PROD_HIER_ASSOC_CD, GEO_HIER_SK, GEO_HIER_ASSOC_CD) ;
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID733774_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID733774_2;
%put ERROR- Description                              : Remove COVERAGE_INPUT table and COVERAGE_OUTPUT user_nm column.;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 23MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID733774_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID733774_2",
"Remove COVERAGE_INPUT table and COVERAGE_OUTPUT user_nm column.",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID733774_2:;
 
 
* End of changes for CHANGE_ID:ID733774_2;
 
 
***********************************************************************************************;
*************************************  End Change ID733774_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID763412_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID763412_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID763412_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID763412_2;
%goto ID763412_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID763412_2;
* Insert record into change management table for CHANGE_ID: ID763412_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID763412_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID763412_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_IMPORTED_NEED ADD TOTAL INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_IMPORTED_NEED ADD TOTAL INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID763412_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID763412_2;
%put ERROR- Description                              : Store level plan imports;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 27JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID763412_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID763412_2",
"Store level plan imports",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID763412_2:;
 
 
* End of changes for CHANGE_ID:ID763412_2;
 
 
***********************************************************************************************;
*************************************  End Change ID763412_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID769228 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID769228;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID769228")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID769228;
%goto ID769228;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID769228;
* Insert record into change management table for CHANGE_ID: ID769228;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID769228",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID769228;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE PKO_NEED_LOCGRP_PRODUCT
(
PKO_NEED_LOCGRP_PRODUCT_SK         INTEGER NOT NULL,
PKO_NEED_LOCATION_GROUP_SK         INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
PRIMARY KEY (PKO_NEED_LOCGRP_PRODUCT_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_PKO_NEED_LOCGRP_PRODUCT_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
CREATE TABLE PKO_NEED_LOCGRP_PRODUCT
(
PKO_NEED_LOCGRP_PRODUCT_SK         INTEGER NOT NULL,
PKO_NEED_LOCATION_GROUP_SK         INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL
)
;
 
 
ALTER TABLE PKO_NEED_LOCGRP_PRODUCT ADD CONSTRAINT PKO_NEED_LOCGRP_PRODUCT PRIMARY KEY (PKO_NEED_LOCGRP_PRODUCT_SK);
 
 
quit;
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID769228;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID769228;
%put ERROR- Description                              : Remove products from a delivery;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 28JUN2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID769228;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID769228",
"Remove products from a delivery",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID769228:;
 
 
* End of changes for CHANGE_ID:ID769228;
 
 
***********************************************************************************************;
*************************************  End Change ID769228 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID761590_3 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID761590_3;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID761590_3")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID761590_3;
%goto ID761590_3;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID761590_3;
* Insert record into change management table for CHANGE_ID: ID761590_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID761590_3",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID761590_3;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE RPP_PLAN_COST_FACT ADD COST_TYPE INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
 
ALTER TABLE RPP_PLAN_COST_FACT ADD COST_TYPE INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID761590_3;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID761590_3;
%put ERROR- Description                              : Add cost type column to promotion specific cost fact;
%put ERROR- Version                                  : D3MICM52,M2MI42;
%put ERROR- Date of Change                           : 01JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID761590_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID761590_3",
"Add cost type column to promotion specific cost fact",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID761590_3:;
 
 
* End of changes for CHANGE_ID:ID761590_3;
 
 
***********************************************************************************************;
*************************************  End Change ID761590_3 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID764696 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID764696;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID764696")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID764696;
%goto ID764696;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID764696;
* Insert record into change management table for CHANGE_ID: ID764696;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID764696",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID764696;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE TABLE_PARTITION_META ADD ETL_STG2DM INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE TABLE_PARTITION_META ADD SORT_ORDER varchar(255)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ALLOWED_PRICE_CHG_DATE',1,0,0,null,'PROD_HIER_SK GEO_HIER_ASSOC_CD GEO_HIER_SK ALLOWED_DATE PRICE_TYPE PRIORITY')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_GEO_DM',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_GEO_HIER_ASSOC_DM',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_GEO_LVL',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_GEO_SCOPE',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_HIERARCHY_HISTORY',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_INPUT_GEO_LVL',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_INPUT_PROD_LVL',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_MAP',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_PROD_DM',0,1,0,0,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_PROD_HIER_ASSOC_DM',0,1,0,0,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_PROD_LVL',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_PROD_SCOPE',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_REG',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_SPEC',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_SPEC_PREV',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTRIBUTE',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTRIBUTE_HISTORY',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BASE_FORECAST',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BASE_FORECAST_AVG',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BASE_FORECAST_OVERRIDE_GP',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BASE_FORECAST_OVERRIDE_GP_LOW',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BASE_FORECAST_OVERRIDE_MG',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BAYESIAN_MODEL',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BUDGET',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CLR_DC_INV_REPORT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CLR_EFF_REPORT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CLR_INV_AGING_REPORT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CLR_ITEM_SEL_REPORT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CLR_MD_PROJECTION_REPORT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CLR_MD_PROJECTION_REPORT_WEEKLY',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COMP_PRICE_FACT',0,0,0,null,'GEO_HIER_SK PROD_HIER_SK COMPETITOR_SK PRICE_TYPE START_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COMP_PRICE_FACT_CURRENT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COMP_PRICE_VALIDITY_RULE',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COMPETITOR',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CONFIG_AUDIT_TRAIL',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CONFIG_GROUP',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COST_FACT_CURRENT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK COST_TYPE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COST_FACT_FUTURE',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK COST_TYPE VALID_FROM_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COST_FACT_HISTORY',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK COST_TYPE VALID_FROM_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DATA_CONFIG',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DATA_CONFIG_TEMPLATE',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DATA_LVL',1,0,0,null,'GEO_LVL PROD_LVL DATE_LVL PROD_HIER_ASSOC_CD GEO_HIER_ASSOC_CD')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DATE_DM',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DATE_HIER_ASSOC_DM',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DATE_LVL',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DEMAND_DISAGG_FACTOR',0,0,0,null,'PROD_HIER_SK GEO_HIER_SK START_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DEMAND_DISAGG_FACTOR_DEFAULT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DISAGG_FACTOR',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DOW_SALES_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK DAY_OF_WEEK')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DOW_EVENT_SALES_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK DAY_OF_WEEK')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('EXCEPTION_TYPE',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('FIELD_LOOKUP_VALUES',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('FUTURE_RECEIPT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK RECEIPT_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_DATE',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_ACCUM_MEASURE',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_EXCEPTION',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_OWNED_INV',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_PERFORMANCE',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_PURGE_LIST',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_STATUS',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK VALID_FROM_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_VAT',0,1,0,0,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_STORE',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEOGRAPHY_ATTR_LOOKUP',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEOGRAPHY_ATTRIBUTES',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEOGRAPHY_DM',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEOGRAPHY_HIER_ASSOC_DM',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEOGRAPHY_LVL',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GLOBAL_SETTING',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GLOBAL_SETTING_DETAILS',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GLOBAL_SETTING_GROUP',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GLOBAL_SETTING_GROUP_MEMBER',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GLOBAL_SETTING_PREV',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GLOBAL_SETTING_VALUES',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HALO_FACTOR',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HALO_GEO_PROD',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HALO_PARAM',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HALO_PRODUCTS',0,0,0,null,'CAUSE_PROD_HIER_SK EFFECT_PROD_HIER_SK')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HALO_VAR',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HEDONIC_PRICE',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HEDONIC_SCORE',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HIERARCHY_ASSOC_DM',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HIERARCHY_HISTORY',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('INVENTORY_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('JOB',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('JOB_INSTANCE',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('JOB_INSTANCE_PARAM',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('JOB_STATUS',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MKDN_APPR_REPORT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_DATA_AGG',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_DATA_CALIB_PS',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_DATA_LOW',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_EXCEPTION',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_FIT_STAT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_HIER_ASSOC_DM',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD_STATUS',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD_STATUS_DETAILS',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD_STATUS_INC',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD_STATUS_RULE',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD_STATUS_SPEC',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD_STATUS_VALUES',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GROUP',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GROUP_FACTOR',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GROUP_STATS',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_PARAM_EST',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_PROD_HIER_ASSOC_DM',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC_DEFAULT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC_DETAILS',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC_PREV',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC_TEMPLATE',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC_VALUES',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC_WORKFLOW',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MOVING_HEDONIC_SCORE',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MPLN_GEO_PROD_ACCUM_MTS',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MPLN_PERIOD_ACTUAL_MTS',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MPLN_PERIOD_EST_MTS',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MPLN_PERIOD_EST_MTS_HIST',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MPLN_STORE_EST_MTS',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_DM',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_FUTURE_RECEIPT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_GROUP',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_GROUP_GEO_SETTINGS',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_HIER_DM',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_INVENTORY_FACT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_LVL',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_PACK_GROUP',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_PROD',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_TYPE',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PERIOD_IN_LIFECYCLE',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_GEO_PROD_STATUS',0,0,0,1,'PROD_HIER_SK GEO_HIER_SK VALID_FROM_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_GEO_PROD_STATUS_META',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_PROD_PRTN_MBR',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_PROJ_PROD',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_SALES_DATA_SUMMARY',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_SALES_FACT',0,0,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_SALES_FACT_META',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_SSD_AGG',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_SSD_SRC',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_SSD_SSET',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_STOCKOUT_FACT',0,0,0,1,'PROD_HIER_SK GEO_HIER_SK START_DT END_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_STOCKOUT_FACT_META',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_STR_CLSF',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_STR_CLSF_A',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRICE_CHANGE_PRIORITY',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRICE_FACT_CURRENT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRICE_FACT_FUTURE',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK VALID_FROM_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRICE_FACT_HISTORY',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK VALID_FROM_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRICE_PROMO_ELASTICITY',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROD_DATA_CONFIG',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROD_GEO_HIER_ASSOC',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROD_GEO_RELATION',0,1,0,0,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROD_LIFECYCLE_CURVE',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROD_SIZE_PTCP',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROD_SIZESET',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_ATTR_LOOKUP',0,1,0,0,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_ATTRIBUTES',0,1,0,0,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_CROSS_EFFECT_SPEC',0,1,0,0,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_DM',0,1,0,0,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_HIER_ASSOC_DM',0,1,0,0,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_LVL',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_RELATION',0,1,0,0,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROMO_FACTOR',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROMO_FACTOR_DECOM',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROMO_SALES_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK START_DT END_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROMOTION_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK VEHICLE_SK CONDITION_TYPE RANGE_START_DISC_PCT RANGE_END_DISC_PCT START_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROMOTION_FACT_FUTURE',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK VEHICLE_SK CONDITION_TYPE RANGE_START_DISC_PCT RANGE_END_DISC_PCT START_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PSYCHOLOGICAL_POINTS',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REFERENCE_VALUES',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REG_COST_CHG_REPORT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REG_COST_HIST_REPORT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REG_GM_CHG_REPORT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REG_PRC_CHG_REPORT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REG_SKU_COST_CHG_REPORT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REG_SKU_RETAIL_CHG_REPORT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REPORT_BY_EVENT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REPORT_CATEGORY_X_IMPACT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REPORT_DATA_LVL',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REPORT_DEMAND_DECOM_DATE_SK',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REPORT_MEASURES_BY_PS',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REPORT_MEASURES_DATE_SK',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RETURN_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RETURN_RATE_AVG',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_CAL_AGG',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_CAT_AGG',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_PGSPOT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_PROMOEFF',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_PROMOPLAN',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_PROMOSUMM',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_VENDOR_FUND',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_VG_SUMMARY',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SALES_AVG',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SALES_AVG_LOW',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SALES_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SALES_MIX_DAY_OF_WEEK',1,0,0,null,'GEO_HIER_SK PROD_HIER_SK DAY_OF_WEEK')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SCORE_DATA',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SCORING_PARAM',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SCORING_PARAM_UNCAPPED',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SCORING_PARAM_AVG',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SCORING_PARAM_CONFIG',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SCORING_PARAM_DEFAULT',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SIZESET',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SIZESET_MBR',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('STORE_CATEGORY',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('STORE_CATEGORY_MBR',0,0,0,null,'GEO_HIER_SK STORE_CATEGORY_ID')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('STORE_EXCLUDED',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('STR_GRP_MBR',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('TARGET_METRICS',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('TREND_SEASONALITY',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('UNACC_DISCOUNT',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('VEHICLE_SUPPORT_MAP',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('VEHICLE_SUPPORT_MAP_PREV',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('VENDOR',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE TABLE_PARTITION_META ADD ETL_STG2DM INTEGER ;
 
 
ALTER TABLE TABLE_PARTITION_META ADD SORT_ORDER varchar(255);
 
 
 
delete from TABLE_PARTITION_META;
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ALLOWED_PRICE_CHG_DATE',1,0,0,null,'PROD_HIER_SK GEO_HIER_ASSOC_CD GEO_HIER_SK ALLOWED_DATE PRICE_TYPE PRIORITY');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_GEO_DM',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_GEO_HIER_ASSOC_DM',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_GEO_LVL',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_GEO_SCOPE',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_HIERARCHY_HISTORY',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_INPUT_GEO_LVL',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_INPUT_PROD_LVL',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_MAP',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_PROD_DM',0,1,0,0,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_PROD_HIER_ASSOC_DM',0,1,0,0,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_PROD_LVL',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_PROD_SCOPE',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_REG',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_SPEC',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTR_SPEC_PREV',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTRIBUTE',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('ATTRIBUTE_HISTORY',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BASE_FORECAST',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BASE_FORECAST_AVG',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BASE_FORECAST_OVERRIDE_GP',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BASE_FORECAST_OVERRIDE_GP_LOW',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BASE_FORECAST_OVERRIDE_MG',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BAYESIAN_MODEL',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('BUDGET',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CLR_DC_INV_REPORT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CLR_EFF_REPORT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CLR_INV_AGING_REPORT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CLR_ITEM_SEL_REPORT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CLR_MD_PROJECTION_REPORT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CLR_MD_PROJECTION_REPORT_WEEKLY',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COMP_PRICE_FACT',0,0,0,null,'GEO_HIER_SK PROD_HIER_SK COMPETITOR_SK PRICE_TYPE START_DT');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COMP_PRICE_FACT_CURRENT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COMP_PRICE_VALIDITY_RULE',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COMPETITOR',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CONFIG_AUDIT_TRAIL',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('CONFIG_GROUP',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COST_FACT_CURRENT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK COST_TYPE');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COST_FACT_FUTURE',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK COST_TYPE VALID_FROM_DT');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('COST_FACT_HISTORY',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK COST_TYPE VALID_FROM_DT');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DATA_CONFIG',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DATA_CONFIG_TEMPLATE',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DATA_LVL',1,0,0,null,'GEO_LVL PROD_LVL DATE_LVL PROD_HIER_ASSOC_CD GEO_HIER_ASSOC_CD');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DATE_DM',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DATE_HIER_ASSOC_DM',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DATE_LVL',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DEMAND_DISAGG_FACTOR',0,0,0,null,'PROD_HIER_SK GEO_HIER_SK START_DT');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DEMAND_DISAGG_FACTOR_DEFAULT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DISAGG_FACTOR',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DOW_SALES_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK DAY_OF_WEEK');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('DOW_EVENT_SALES_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK DAY_OF_WEEK');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('EXCEPTION_TYPE',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('FIELD_LOOKUP_VALUES',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('FUTURE_RECEIPT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK RECEIPT_DT');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_DATE',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_ACCUM_MEASURE',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_EXCEPTION',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_OWNED_INV',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_PERFORMANCE',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_PURGE_LIST',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_STATUS',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK VALID_FROM_DT');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_PROD_VAT',0,1,0,0,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEO_STORE',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEOGRAPHY_ATTR_LOOKUP',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEOGRAPHY_ATTRIBUTES',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEOGRAPHY_DM',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEOGRAPHY_HIER_ASSOC_DM',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GEOGRAPHY_LVL',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GLOBAL_SETTING',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GLOBAL_SETTING_DETAILS',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GLOBAL_SETTING_GROUP',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GLOBAL_SETTING_GROUP_MEMBER',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GLOBAL_SETTING_PREV',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('GLOBAL_SETTING_VALUES',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HALO_FACTOR',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HALO_GEO_PROD',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HALO_PARAM',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HALO_PRODUCTS',0,0,0,null,'CAUSE_PROD_HIER_SK EFFECT_PROD_HIER_SK');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HALO_VAR',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HEDONIC_PRICE',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HEDONIC_SCORE',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HIERARCHY_ASSOC_DM',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('HIERARCHY_HISTORY',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('INVENTORY_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('JOB',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('JOB_INSTANCE',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('JOB_INSTANCE_PARAM',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('JOB_STATUS',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MKDN_APPR_REPORT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_DATA_AGG',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_DATA_CALIB_PS',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_DATA_LOW',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_EXCEPTION',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_FIT_STAT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_HIER_ASSOC_DM',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD_STATUS',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD_STATUS_DETAILS',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD_STATUS_INC',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD_STATUS_RULE',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD_STATUS_SPEC',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GEO_PROD_STATUS_VALUES',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GROUP',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GROUP_FACTOR',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_GROUP_STATS',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_PARAM_EST',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_PROD_HIER_ASSOC_DM',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC_DEFAULT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC_DETAILS',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC_PREV',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC_TEMPLATE',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC_VALUES',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MODEL_SPEC_WORKFLOW',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MOVING_HEDONIC_SCORE',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MPLN_GEO_PROD_ACCUM_MTS',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MPLN_PERIOD_ACTUAL_MTS',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MPLN_PERIOD_EST_MTS',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MPLN_PERIOD_EST_MTS_HIST',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('MPLN_STORE_EST_MTS',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_DM',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_FUTURE_RECEIPT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_GROUP',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_GROUP_GEO_SETTINGS',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_HIER_DM',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_INVENTORY_FACT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_LVL',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_PACK_GROUP',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_PROD',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PACK_TYPE',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PERIOD_IN_LIFECYCLE',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_GEO_PROD_STATUS',0,0,0,1,'PROD_HIER_SK GEO_HIER_SK VALID_FROM_DT');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_GEO_PROD_STATUS_META',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_PROD_PRTN_MBR',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_PROJ_PROD',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_SALES_DATA_SUMMARY',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_SALES_FACT',0,0,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_SALES_FACT_META',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_SSD_AGG',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_SSD_SRC',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_SSD_SSET',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_STOCKOUT_FACT',0,0,0,1,'PROD_HIER_SK GEO_HIER_SK START_DT END_DT');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_STOCKOUT_FACT_META',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_STR_CLSF',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRF_STR_CLSF_A',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRICE_CHANGE_PRIORITY',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRICE_FACT_CURRENT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRICE_FACT_FUTURE',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK VALID_FROM_DT');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRICE_FACT_HISTORY',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK VALID_FROM_DT');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRICE_PROMO_ELASTICITY',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROD_DATA_CONFIG',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROD_GEO_HIER_ASSOC',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROD_GEO_RELATION',0,1,0,0,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROD_LIFECYCLE_CURVE',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROD_SIZE_PTCP',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROD_SIZESET',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_ATTR_LOOKUP',0,1,0,0,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_ATTRIBUTES',0,1,0,0,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_CROSS_EFFECT_SPEC',0,1,0,0,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_DM',0,1,0,0,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_HIER_ASSOC_DM',0,1,0,0,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_LVL',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PRODUCT_RELATION',0,1,0,0,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROMO_FACTOR',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROMO_FACTOR_DECOM',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROMO_SALES_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK START_DT END_DT');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROMOTION_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK VEHICLE_SK CONDITION_TYPE RANGE_START_DISC_PCT RANGE_END_DISC_PCT START_DT');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PROMOTION_FACT_FUTURE',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK VEHICLE_SK CONDITION_TYPE RANGE_START_DISC_PCT RANGE_END_DISC_PCT START_DT');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('PSYCHOLOGICAL_POINTS',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REFERENCE_VALUES',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REG_COST_CHG_REPORT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REG_COST_HIST_REPORT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REG_GM_CHG_REPORT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REG_PRC_CHG_REPORT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REG_SKU_COST_CHG_REPORT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REG_SKU_RETAIL_CHG_REPORT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REPORT_BY_EVENT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REPORT_CATEGORY_X_IMPACT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REPORT_DATA_LVL',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REPORT_DEMAND_DECOM_DATE_SK',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REPORT_MEASURES_BY_PS',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('REPORT_MEASURES_DATE_SK',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RETURN_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RETURN_RATE_AVG',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_CAL_AGG',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_CAT_AGG',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_PGSPOT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_PROMOEFF',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_PROMOPLAN',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_PROMOSUMM',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_VENDOR_FUND',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('RPP_VG_SUMMARY',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SALES_AVG',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SALES_AVG_LOW',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SALES_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SALES_MIX_DAY_OF_WEEK',1,0,0,null,'GEO_HIER_SK PROD_HIER_SK DAY_OF_WEEK');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SCORE_DATA',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SCORING_PARAM',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SCORING_PARAM_UNCAPPED',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SCORING_PARAM_AVG',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SCORING_PARAM_CONFIG',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SCORING_PARAM_DEFAULT',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SIZESET',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('SIZESET_MBR',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('STORE_CATEGORY',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('STORE_CATEGORY_MBR',0,0,0,null,'GEO_HIER_SK STORE_CATEGORY_ID');
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('STORE_EXCLUDED',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('STR_GRP_MBR',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('TARGET_METRICS',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('TREND_SEASONALITY',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('UNACC_DISCOUNT',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('VEHICLE_SUPPORT_MAP',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('VEHICLE_SUPPORT_MAP_PREV',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER) VALUES ('VENDOR',1,0,0,null,null);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID764696;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID764696;
%put ERROR- Description                              : Adding new columns etl_stg2dm & sort_order to table_partition_meta.;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 04JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID764696;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID764696",
"Adding new columns etl_stg2dm & sort_order to table_partition_meta.",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID764696:;
 
 
* End of changes for CHANGE_ID:ID764696;
 
 
***********************************************************************************************;
*************************************  End Change ID764696 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID763266 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID763266;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID763266")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID763266;
%goto ID763266;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID763266;
* Insert record into change management table for CHANGE_ID: ID763266;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID763266",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID763266;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD ALLOW_PRIOR_DELIVERY_PACKS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD ALLOW_PRIOR_DELIVERY_PACKS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PACK_PRODUCT_SETTING ADD ALLOW_PRIOR_DELIVERY_PACKS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_BUY ADD ALLOW_PRIOR_DELIVERY_PACKS INTEGER ;
 
 
ALTER TABLE PKO_DELIVERY ADD ALLOW_PRIOR_DELIVERY_PACKS INTEGER ;
 
 
ALTER TABLE PKO_PACK_PRODUCT_SETTING ADD ALLOW_PRIOR_DELIVERY_PACKS INTEGER ;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID763266;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID763266;
%put ERROR- Description                              : Specify Carry-over Packs;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 06JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID763266;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID763266",
"Specify Carry-over Packs",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID763266:;
 
 
* End of changes for CHANGE_ID:ID763266;
 
 
***********************************************************************************************;
*************************************  End Change ID763266 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID749317_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID749317_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID749317_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID749317_2;
%goto ID749317_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID749317_2;
* Insert record into change management table for CHANGE_ID: ID749317_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID749317_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID749317_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN ADD APPLY_FUTURE_PROMOTIONS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE RPO_PLAN ADD APPLY_FUTURE_PROMOTIONS INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID749317_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID749317_2;
%put ERROR- Description                              : The system shall allow a user to optimize regular prices by accounting for future promotions.;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 04MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID749317_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID749317_2",
"The system shall allow a user to optimize regular prices by accounting for future promotions.",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID749317_2:;
 
 
* End of changes for CHANGE_ID:ID749317_2;
 
 
***********************************************************************************************;
*************************************  End Change ID749317_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0773201 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0773201;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0773201")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :ID0773201;
%goto ID0773201;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0773201;
%goto ID0773201;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0773201;
* Insert record into change management table for CHANGE_ID: ID0773201;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0773201",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0773201;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
create table REQ_SKU_STORE_MIN (
REQUEST_ID      INTEGER NOT NULL,
DELIVERY_ID     INTEGER NOT NULL,
PROD_ID         VARCHAR(32) NOT NULL,
GEO_ID          VARCHAR(32) NOT NULL,
ORDER_MIN       INTEGER NOT NULL,
PRIMARY KEY (REQUEST_ID, DELIVERY_ID, PROD_ID, GEO_ID)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
data &m_di_trans..REQ_SKU_STORE_MIN;
 
 
attrib REQUEST_ID   length=4;
 
 
attrib DELIVERY_ID  length=4;
 
 
attrib PROD_ID      length=$32;
 
 
attrib GEO_ID       length=$32;
 
 
attrib ORDER_MIN    length=8;
 
 
stop;
 
 
run;
 
 
proc sql;
 
 
alter table &m_di_trans..REQ_SKU_STORE_MIN add
constraint prim_key PRIMARY KEY (REQUEST_ID, DELIVERY_ID, PROD_ID, GEO_ID);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0773201;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0773201;
%put ERROR- Description                              : Add Packopt Request Table REQ_SKU_STORE_MIN;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 07JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0773201;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0773201",
"Add Packopt Request Table REQ_SKU_STORE_MIN",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0773201:;
 
 
* End of changes for CHANGE_ID:ID0773201;
 
 
***********************************************************************************************;
*************************************  End Change ID0773201 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID763270 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID763270;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID763270")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID763270;
%goto ID763270;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID763270;
* Insert record into change management table for CHANGE_ID: ID763270;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID763270",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID763270;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE PKO_DELIVERY_TYPE (
DELIVERY_TYPE_SK INTEGER NOT NULL,
PURCHASE_ORDER_PLAN_SK INTEGER,
DELIVERY_TYPE_ID INTEGER NOT NULL,
DELIVERY_TYPE_NM VARCHAR(40),
PRIMARY KEY (DELIVERY_TYPE_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(100, 'Floor Set', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(101, 'Flow One', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(102, 'Promotion Buy', 3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(103, 'Flow Two', 4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(104, 'Flow Three', 5)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(105, 'Sell Off', 6)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(106, 'Transition', 7)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_DELIVERY_TYPE_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD DELIVERY_TYPE_ID INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
CREATE TABLE PKO_DELIVERY_TYPE (
DELIVERY_TYPE_SK INTEGER NOT NULL,
PURCHASE_ORDER_PLAN_SK INTEGER,
DELIVERY_TYPE_ID INTEGER NOT NULL,
DELIVERY_TYPE_NM VARCHAR(40)
) ;
 
 
ALTER TABLE PKO_DELIVERY_TYPE ADD CONSTRAINT PRIM_KEY PRIMARY KEY (DELIVERY_TYPE_SK) ;
 
 
 
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(100, 'Floor Set', 1);
 
 
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(101, 'Flow One', 2);
 
 
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(102, 'Promotion Buy', 3);
 
 
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(103, 'Flow Two', 4);
 
 
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(104, 'Flow Three', 5);
 
 
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(105, 'Sell Off', 6);
 
 
INSERT INTO PKO_DELIVERY_TYPE (DELIVERY_TYPE_SK, DELIVERY_TYPE_NM, DELIVERY_TYPE_ID) VALUES(106, 'Transition', 7);
 
 
 
ALTER TABLE PKO_DELIVERY ADD DELIVERY_TYPE_ID INTEGER;
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID763270;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID763270;
%put ERROR- Description                              : Determine Packs Across Deliveries;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 07JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID763270;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID763270",
"Determine Packs Across Deliveries",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID763270:;
 
 
* End of changes for CHANGE_ID:ID763270;
 
 
***********************************************************************************************;
*************************************  End Change ID763270 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change DROP_NOT_NULL_CLUSTER_ID ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: DROP_NOT_NULL_CLUSTER_ID;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("DROP_NOT_NULL_CLUSTER_ID")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : DROP_NOT_NULL_CLUSTER_ID;
%goto DROP_NOT_NULL_CLUSTER_ID;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : DROP_NOT_NULL_CLUSTER_ID;
* Insert record into change management table for CHANGE_ID: DROP_NOT_NULL_CLUSTER_ID;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_NOT_NULL_CLUSTER_ID",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto DROP_NOT_NULL_CLUSTER_ID;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PROD_GEO_PROFILE MODIFY (CLUSTER_ID NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%di_util_drop_constraint(m_lib=di_trans, m_table=REQ_PROD_GEO_PROFILE, m_column=%str(CLUSTER_ID), m_constraint=%str(not null));
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: DROP_NOT_NULL_CLUSTER_ID;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: DROP_NOT_NULL_CLUSTER_ID;
%put ERROR- Description                              : Drop NOT NULL Constraint on CLUSTER_ID;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 14JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: DROP_NOT_NULL_CLUSTER_ID;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_NOT_NULL_CLUSTER_ID",
"Drop NOT NULL Constraint on CLUSTER_ID",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%DROP_NOT_NULL_CLUSTER_ID:;
 
 
* End of changes for CHANGE_ID:DROP_NOT_NULL_CLUSTER_ID;
 
 
***********************************************************************************************;
*************************************  End Change DROP_NOT_NULL_CLUSTER_ID ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID774840 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID774840;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID774840")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID774840;
%goto ID774840;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID774840;
%goto ID774840;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID774840;
* Insert record into change management table for CHANGE_ID: ID774840;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID774840",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID774840;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE MODEL_SPEC_DEFAULT SET DEFAULT_SPEC_VALUE = '0' WHERE SPEC_NM = 'PS_1'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
UPDATE MODEL_SPEC_DEFAULT SET DEFAULT_SPEC_VALUE = '0' WHERE SPEC_NM = 'PS_1';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID774840;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID774840;
%put ERROR- Description                              : Update default value for PS_xx specs;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 17JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID774840;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID774840",
"Update default value for PS_xx specs",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID774840:;
 
 
* End of changes for CHANGE_ID:ID774840;
 
 
***********************************************************************************************;
*************************************  End Change ID774840 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change RENAME_PRIMARY_KEY_02 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: RENAME_PRIMARY_KEY_02;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("RENAME_PRIMARY_KEY_02")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : RENAME_PRIMARY_KEY_02;
%goto RENAME_PRIMARY_KEY_02;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : RENAME_PRIMARY_KEY_02;
* Insert record into change management table for CHANGE_ID: RENAME_PRIMARY_KEY_02;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"RENAME_PRIMARY_KEY_02",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto RENAME_PRIMARY_KEY_02;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
%di_util_rename_pk(m_table_name=%str(RPO_PLAN_RESULT),              m_pk_name=%str(RPO_PLAN_RESULT_PK));
 
 
%di_util_rename_pk(m_table_name=%str(RPO_PLAN_MEMBER_RESULT),       m_pk_name=%str(RPO_PLAN_MEMBER_RESULT_PK));
 
 
%di_util_rename_pk(m_table_name=%str(RPO_PLAN_MEMBER_RESULT_KPI),   m_pk_name=%str(RPO_PLAN_MEMBER_RESULT_KPI_PK));
 
 
%di_util_rename_pk(m_table_name=%str(RPO_PLAN_MEMBER_AGG),          m_pk_name=%str(RPO_PLAN_MEMBER_AGG_PK));
 
 
%di_util_rename_pk(m_table_name=%str(RPO_GEO_PROD_AGG),             m_pk_name=%str(RPO_GEO_PROD_AGG_PK));
 
 
%di_util_rename_pk(m_table_name=%str(COMP_PRICE_RULE_RESULT),       m_pk_name=%str(COMP_PRICE_RULE_RESULT_PK));
 
 
%di_util_rename_pk(m_table_name=%str(MARGIN_RULE_RESULT),           m_pk_name=%str(MARGIN_RULE_RESULT_PK));
 
 
%di_util_rename_pk(m_table_name=%str(MIN_MAX_RULE_RESULT),          m_pk_name=%str(MIN_MAX_RULE_RESULT_PK));
 
 
%di_util_rename_pk(m_table_name=%str(PRICING_RELN_RULE_RESULT),     m_pk_name=%str(PRICING_RELN_RULE_RESULT_PK));
 
 
%di_util_rename_pk(m_table_name=%str(GRID_RULE_RESULT),             m_pk_name=%str(GRID_RULE_RESULT_PK));
 
 
%di_util_rename_pk(m_table_name=%str(SAME_PRICE_SET_RELN),          m_pk_name=%str(SAME_PRICE_SET_RELN_PK));
 
 
%di_util_rename_pk(m_table_name=%str(SAME_PRICE_SET),               m_pk_name=%str(SAME_PRICE_SET_PK));
 
 
%di_util_rename_pk(m_table_name=%str(PROCESS_MESSAGE_DETAIL),       m_pk_name=%str(PROCESS_MESSAGE_DETAIL_PK));
 
 
%di_util_rename_pk(m_table_name=%str(RPP_PLAN_PROD_ASGMNT),         m_pk_name=%str(RPP_PLAN_PROD_ASGMNT_PK));
 
 
%di_util_rename_pk(m_table_name=%str(CUSTOM_ATTR),                  m_pk_name=%str(CUSTOM_ATTR_PK));
 
 
%di_util_rename_pk(m_table_name=%str(RPP_PLAN_METRIC),              m_pk_name=%str(RPP_PLAN_METRIC_PK));
 
 
%di_util_rename_pk(m_table_name=%str(RPP_PLAN_PROD_METRICS),        m_pk_name=%str(RPP_PLAN_PROD_METRICS_PK));
 
 
%di_util_rename_pk(m_table_name=%str(RPP_NOTIFICATION),             m_pk_name=%str(RPP_NOTIFICATION_PK));
 
 
%di_util_rename_pk(m_table_name=%str(PROCESS_MESSAGE_DETAIL),       m_pk_name=%str(PROCESS_MESSAGE_DETAIL_PK));
 
 
%di_util_rename_pk(m_table_name=%str(AGGREGATION_METRICS),          m_pk_name=%str(AGGREGATION_METRICS_PK));
 
 
%di_util_rename_pk(m_table_name=%str(RPP_PLAN_OPT_SETTING),         m_pk_name=%str(RPP_PLAN_OPT_SETTING_PK));
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
*  Do not rename primary keys since performance is very slow and renaming is of no use. ;
 
proc sql;
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: RENAME_PRIMARY_KEY_02;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: RENAME_PRIMARY_KEY_02;
%put ERROR- Description                              : Rename primary keys;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 14JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: RENAME_PRIMARY_KEY_02;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"RENAME_PRIMARY_KEY_02",
"Rename primary keys",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%RENAME_PRIMARY_KEY_02:;
 
 
* End of changes for CHANGE_ID:RENAME_PRIMARY_KEY_02;
 
 
***********************************************************************************************;
*************************************  End Change RENAME_PRIMARY_KEY_02 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change PRF_COPY_SIZESET_CHG ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: PRF_COPY_SIZESET_CHG;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("PRF_COPY_SIZESET_CHG")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : PRF_COPY_SIZESET_CHG;
%goto PRF_COPY_SIZESET_CHG;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : PRF_COPY_SIZESET_CHG;
* Insert record into change management table for CHANGE_ID: PRF_COPY_SIZESET_CHG;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"PRF_COPY_SIZESET_CHG",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto PRF_COPY_SIZESET_CHG;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PRF_SIZESET DROP COLUMN USER_MODIFIED_FLG
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRF_SIZESET ADD COPIED_FLG INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRF_PLAN ADD COPIED_FLG INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PRF_SIZESET DROP COLUMN USER_MODIFIED_FLG;
 
 
ALTER TABLE PRF_SIZESET ADD COPIED_FLG INTEGER;
 
 
ALTER TABLE PRF_PLAN ADD COPIED_FLG INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: PRF_COPY_SIZESET_CHG;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: PRF_COPY_SIZESET_CHG;
%put ERROR- Description                              : Size Profiling 32 Schema changes part 4;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 14JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: PRF_COPY_SIZESET_CHG;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"PRF_COPY_SIZESET_CHG",
"Size Profiling 32 Schema changes part 4",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%PRF_COPY_SIZESET_CHG:;
 
 
* End of changes for CHANGE_ID:PRF_COPY_SIZESET_CHG;
 
 
***********************************************************************************************;
*************************************  End Change PRF_COPY_SIZESET_CHG ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID776254 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID776254;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID776254")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID776254;
%goto ID776254;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID776254;
* Insert record into change management table for CHANGE_ID: ID776254;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID776254",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID776254;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (40, 'CustomPrice1', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (41, 'CustomPrice2', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (42, 'CustomPrice3', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (43, 'CustomPrice4', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (44, 'CustomPrice5', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (45, 'CustomPrice6', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (46, 'CustomPrice7', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (47, 'CustomPrice8', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (48, 'CustomPrice9', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (49, 'CustomPrice10', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-140, 40, 7,'Value',     '0', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-141, 40, 7,'ValueType', '1', 3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-142, 41, 7,'Value',     '0', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-143, 41, 7,'ValueType', '1', 3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-144, 42, 7,'Value',     '0', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-145, 42, 7,'ValueType', '1', 3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-146, 43, 7,'Value',     '0', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-147, 43, 7,'ValueType', '1', 3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-148, 44, 7,'Value',     '0', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-149, 44, 7,'ValueType', '1', 3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-150, 45, 7,'Value',     '0', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-151, 45, 7,'ValueType', '1', 3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-152, 46, 7,'Value',     '0', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-153, 46, 7,'ValueType', '1', 3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-154, 47, 7,'Value',     '0', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-155, 47, 7,'ValueType', '1', 3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-156, 48, 7,'Value',     '0', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-157, 48, 7,'ValueType', '1', 3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-158, 49, 7,'Value',     '0', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-159, 49, 7,'ValueType', '1', 3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (40, 'CustomPrice1', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (41, 'CustomPrice2', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (42, 'CustomPrice3', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (43, 'CustomPrice4', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (44, 'CustomPrice5', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (45, 'CustomPrice6', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (46, 'CustomPrice7', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (47, 'CustomPrice8', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (48, 'CustomPrice9', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (49, 'CustomPrice10', 'Custom Price', 0, 2, 'PRICE');
 
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-140, 40, 7,'Value',     '0', 1);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-141, 40, 7,'ValueType', '1', 3);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-142, 41, 7,'Value',     '0', 1);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-143, 41, 7,'ValueType', '1', 3);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-144, 42, 7,'Value',     '0', 1);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-145, 42, 7,'ValueType', '1', 3);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-146, 43, 7,'Value',     '0', 1);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-147, 43, 7,'ValueType', '1', 3);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-148, 44, 7,'Value',     '0', 1);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-149, 44, 7,'ValueType', '1', 3);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-150, 45, 7,'Value',     '0', 1);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-151, 45, 7,'ValueType', '1', 3);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-152, 46, 7,'Value',     '0', 1);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-153, 46, 7,'ValueType', '1', 3);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-154, 47, 7,'Value',     '0', 1);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-155, 47, 7,'ValueType', '1', 3);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-156, 48, 7,'Value',     '0', 1);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-157, 48, 7,'ValueType', '1', 3);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-158, 49, 7,'Value',     '0', 1);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-159, 49, 7,'ValueType', '1', 3);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID776254;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID776254;
%put ERROR- Description                              : Custom Price Type support;
%put ERROR- Version                                  : D3MICM52,M2MI42;
%put ERROR- Date of Change                           : 11JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID776254;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID776254",
"Custom Price Type support",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID776254:;
 
 
* End of changes for CHANGE_ID:ID776254;
 
 
***********************************************************************************************;
*************************************  End Change ID776254 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID776757 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID776757;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID776757")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID776757;
%goto ID776757;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID776757;
* Insert record into change management table for CHANGE_ID: ID776757;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID776757",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID776757;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORING_RANGE_RULE RENAME COLUMN VALUE TO RULE_VALUE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc datasets library=&m_di_trans nolist;
 
 
modify FA_SCORING_RANGE_RULE ;
 
 
rename VALUE=RULE_VALUE;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORING_RANGE_RULE DROP COLUMN VALUE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORING_RANGE_RULE ADD  COLUMN RULE_VALUE NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
REORG TABLE FA_SCORING_RANGE_RULE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID776757;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID776757;
%put ERROR- Description                              : Rename column value to rule_value in FA_SCORING_RANGE_RULE;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 21JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID776757;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID776757",
"Rename column value to rule_value in FA_SCORING_RANGE_RULE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID776757:;
 
 
* End of changes for CHANGE_ID:ID776757;
 
 
***********************************************************************************************;
*************************************  End Change ID776757 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID776757_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID776757_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID776757_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID776757_1;
%goto ID776757_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID776757_1;
* Insert record into change management table for CHANGE_ID: ID776757_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID776757_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID776757_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORING_RANGE_RULE RENAME COLUMN RULE_VALUE TO RANGE_VALUE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc datasets library=&m_di_trans nolist;
 
 
modify FA_SCORING_RANGE_RULE ;
 
 
rename RULE_VALUE=RANGE_VALUE;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORING_RANGE_RULE DROP COLUMN RULE_VALUE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE FA_SCORING_RANGE_RULE ADD  COLUMN RANGE_VALUE NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
REORG TABLE FA_SCORING_RANGE_RULE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID776757_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID776757_1;
%put ERROR- Description                              : Rename column rule_value to range_value in FA_SCORING_RANGE_RULE;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 21JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID776757_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID776757_1",
"Rename column rule_value to range_value in FA_SCORING_RANGE_RULE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID776757_1:;
 
 
* End of changes for CHANGE_ID:ID776757_1;
 
 
***********************************************************************************************;
*************************************  End Change ID776757_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID753658 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID753658;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID753658")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID753658;
%goto ID753658;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID753658;
* Insert record into change management table for CHANGE_ID: ID753658;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID753658",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID753658;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PROCESS_STATUS ADD PROCESS_WEIGHT INTEGER DEFAULT 0
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
alter table &m_di_trans..PROCESS_STATUS add PROCESS_WEIGHT num 4;
 
 
update &m_di_trans..PROCESS_STATUS set PROCESS_WEIGHT=0;
 
 
quit;
 
 
 
proc sql;
 
 
alter table &m_di_trans..PROCESS_STATUS add NOT NULL (PROCESS_WEIGHT);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID753658;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID753658;
%put ERROR- Description                              : Data Mapping Algorithm That Takes The Number Of Active Plan Members Into Account...;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 04MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID753658;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID753658",
"Data Mapping Algorithm That Takes The Number Of Active Plan Members Into Account...",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID753658:;
 
 
* End of changes for CHANGE_ID:ID753658;
 
 
***********************************************************************************************;
*************************************  End Change ID753658 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID777046 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID777046;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID777046")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID777046;
%goto ID777046;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID777046;
* Insert record into change management table for CHANGE_ID: ID777046;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID777046",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID777046;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PACK_TOTAL ADD NUM_STORES INTEGER DEFAULT 0 NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
alter table &m_di_trans..PKO_PACK_TOTAL ADD NUM_STORES INTEGER ;
 
 
update &m_di_trans..PKO_PACK_TOTAL set NUM_STORES=0;
 
 
quit;
 
 
 
proc sql;
 
 
alter table &m_di_trans..PKO_PACK_TOTAL add NOT NULL (NUM_STORES);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID777046;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID777046;
%put ERROR- Description                              : Show store totals in pack totals view;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 21JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID777046;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID777046",
"Show store totals in pack totals view",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID777046:;
 
 
* End of changes for CHANGE_ID:ID777046;
 
 
***********************************************************************************************;
*************************************  End Change ID777046 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID776254_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID776254_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID776254_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID776254_2;
%goto ID776254_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID776254_2;
* Insert record into change management table for CHANGE_ID: ID776254_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID776254_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID776254_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from vehicle_category where vehicle_category_sk >= 40 and vehicle_category_sk <=49
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (40, 'Custom1', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (41, 'Custom2', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (42, 'Custom3', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (43, 'Custom4', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (44, 'Custom5', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (45, 'Custom6', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (46, 'Custom7', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (47, 'Custom8', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (48, 'Custom9', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (49, 'Custom0', 'Custom Price', 0, 2, 'PRICE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from CAT_CUSTOM_ATTR where CAT_CUSTOM_ATTR_SK <= -140 and CAT_CUSTOM_ATTR_SK >= -159
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-140, 40, 7,'Value',         '0', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-141, 40, 7,'ValueType',     '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-142, 40, 7,'PriceConflict', '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-143, 41, 7,'Value',         '0', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-144, 41, 7,'ValueType',     '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-145, 41, 7,'PriceConflict', '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-146, 42, 7,'Value',         '0', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-147, 42, 7,'ValueType',     '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-148, 42, 7,'PriceConflict', '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-149, 43, 7,'Value',         '0', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-150, 43, 7,'ValueType',     '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-151, 43, 7,'PriceConflict', '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-152, 44, 7,'Value',         '0', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-153, 44, 7,'ValueType',     '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-154, 44, 7,'PriceConflict', '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-155, 45, 7,'Value',         '0', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-156, 45, 7,'ValueType',     '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-157, 45, 7,'PriceConflict', '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-158, 46, 7,'Value',         '0', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-159, 46, 7,'ValueType',     '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-160, 46, 7,'PriceConflict', '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-161, 47, 7,'Value',         '0', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-162, 47, 7,'ValueType',     '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-163, 47, 7,'PriceConflict', '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-164, 48, 7,'Value',         '0', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-165, 48, 7,'ValueType',     '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-166, 48, 7,'PriceConflict', '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-167, 49, 7,'Value',         '0', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-168, 49, 7,'ValueType',     '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-169, 49, 7,'PriceConflict', '1', 2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from vehicle_category where vehicle_category_sk >= 40 and vehicle_category_sk <=49;
 
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (40, 'Custom1', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (41, 'Custom2', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (42, 'Custom3', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (43, 'Custom4', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (44, 'Custom5', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (45, 'Custom6', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (46, 'Custom7', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (47, 'Custom8', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (48, 'Custom9', 'Custom Price', 0, 2, 'PRICE');
 
 
INSERT INTO vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG, PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (49, 'Custom0', 'Custom Price', 0, 2, 'PRICE');
 
 
 
delete from CAT_CUSTOM_ATTR where CAT_CUSTOM_ATTR_SK <= -140 and CAT_CUSTOM_ATTR_SK >= -159;
 
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-140, 40, 7,'Value',         '0', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-141, 40, 7,'ValueType',     '1', 2);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-142, 40, 7,'PriceConflict', '1', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-143, 41, 7,'Value',         '0', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-144, 41, 7,'ValueType',     '1', 2);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-145, 41, 7,'PriceConflict', '1', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-146, 42, 7,'Value',         '0', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-147, 42, 7,'ValueType',     '1', 2);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-148, 42, 7,'PriceConflict', '1', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-149, 43, 7,'Value',         '0', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-150, 43, 7,'ValueType',     '1', 2);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-151, 43, 7,'PriceConflict', '1', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-152, 44, 7,'Value',         '0', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-153, 44, 7,'ValueType',     '1', 2);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-154, 44, 7,'PriceConflict', '1', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-155, 45, 7,'Value',         '0', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-156, 45, 7,'ValueType',     '1', 2);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-157, 45, 7,'PriceConflict', '1', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-158, 46, 7,'Value',         '0', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-159, 46, 7,'ValueType',     '1', 2);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-160, 46, 7,'PriceConflict', '1', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-161, 47, 7,'Value',         '0', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-162, 47, 7,'ValueType',     '1', 2);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-163, 47, 7,'PriceConflict', '1', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-164, 48, 7,'Value',         '0', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-165, 48, 7,'ValueType',     '1', 2);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-166, 48, 7,'PriceConflict', '1', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-167, 49, 7,'Value',         '0', 2);
 
 
insert into CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-168, 49, 7,'ValueType',     '1', 2);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE) VALUES  (-169, 49, 7,'PriceConflict', '1', 2);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID776254_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID776254_2;
%put ERROR- Description                              : Custom Price Type support;
%put ERROR- Version                                  : D3MICM52,M2MI42;
%put ERROR- Date of Change                           : 22JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID776254_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID776254_2",
"Custom Price Type support",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID776254_2:;
 
 
* End of changes for CHANGE_ID:ID776254_2;
 
 
***********************************************************************************************;
*************************************  End Change ID776254_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID773092 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID773092;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID773092")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID773092;
%goto ID773092;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID773092;
* Insert record into change management table for CHANGE_ID: ID773092;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID773092",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID773092;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE RPP_PLAN set OBJECTIVE_SK = SCOPE_SK where OBJECTIVE_SK is NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
UPDATE RPP_PLAN set OBJECTIVE_SK = SCOPE_SK where OBJECTIVE_SK is NULL;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID773092;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID773092;
%put ERROR- Description                              : Update Objective_SK to scope_SK in RPP_PLAN where objective_SK is null;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 21JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID773092;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID773092",
"Update Objective_SK to scope_SK in RPP_PLAN where objective_SK is null",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID773092:;
 
 
* End of changes for CHANGE_ID:ID773092;
 
 
***********************************************************************************************;
*************************************  End Change ID773092 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID772003 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID772003;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID772003")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID772003;
%goto ID772003;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID772003;
* Insert record into change management table for CHANGE_ID: ID772003;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID772003",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID772003;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
alter table RPP_VENDOR_DEAL add STATE_CD INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
alter table RPP_VENDOR_DEAL add STATE_CD INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID772003;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID772003;
%put ERROR- Description                              : Vendor deals on regional plans;
%put ERROR- Version                                  : D3MICM52,M2MI42;
%put ERROR- Date of Change                           : 26JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID772003;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID772003",
"Vendor deals on regional plans",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID772003:;
 
 
* End of changes for CHANGE_ID:ID772003;
 
 
***********************************************************************************************;
*************************************  End Change ID772003 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID778001 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID778001;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID778001")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID778001;
%goto ID778001;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID778001;
* Insert record into change management table for CHANGE_ID: ID778001;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID778001",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID778001;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE RPP_PLAN ADD FCST_UNITS_ADJUST_TYPE INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE RPP_PLAN ADD FCST_UNITS_ADJUST_TYPE INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID778001;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID778001;
%put ERROR- Description                              : SUPPORT FOR FORECAST OVERRIDE EXTENSIONS;
%put ERROR- Version                                  : D3MICM52,M2MI42;
%put ERROR- Date of Change                           : 28JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID778001;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID778001",
"SUPPORT FOR FORECAST OVERRIDE EXTENSIONS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID778001:;
 
 
* End of changes for CHANGE_ID:ID778001;
 
 
***********************************************************************************************;
*************************************  End Change ID778001 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID778944 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID778944;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID778944")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID778944;
%goto ID778944;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID778944;
%goto ID778944;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID778944;
* Insert record into change management table for CHANGE_ID: ID778944;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID778944",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID778944;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'LCP_CURVE_TYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'LCP_CURVE_TYPE';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID778944;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID778944;
%put ERROR- Description                              : Drop model spec LCP_CURVE_TYPE;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 28JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID778944;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID778944",
"Drop model spec LCP_CURVE_TYPE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID778944:;
 
 
* End of changes for CHANGE_ID:ID778944;
 
 
***********************************************************************************************;
*************************************  End Change ID778944 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID778947 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID778947;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID778947")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID778947;
%goto ID778947;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID778947;
%goto ID778947;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID778947;
* Insert record into change management table for CHANGE_ID: ID778947;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID778947",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID778947;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'LCP_FACTOR_UPPER_BOUND'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('LCP_FACTOR_UPPER_BOUND','ALL','1','100',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('LCP_FACTOR_UPPER_BOUND','ALL','2','100',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'LCP_FACTOR_UPPER_BOUND';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('LCP_FACTOR_UPPER_BOUND','ALL','1','100',NULL);
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('LCP_FACTOR_UPPER_BOUND','ALL','2','100',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID778947;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID778947;
%put ERROR- Description                              : Add model spec LCP_FACTOR_UPPER_BOUND;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 28JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID778947;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID778947",
"Add model spec LCP_FACTOR_UPPER_BOUND",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID778947:;
 
 
* End of changes for CHANGE_ID:ID778947;
 
 
***********************************************************************************************;
*************************************  End Change ID778947 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID779284 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID779284;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID779284")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID779284;
%goto ID779284;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID779284;
* Insert record into change management table for CHANGE_ID: ID779284;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID779284",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID779284;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
alter table MDO_PLAN modify PRICE_VALUE_LIST VARCHAR(1000)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
alter table MDO_PLAN modify PRICE_VALUE_LIST VARCHAR(1000);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID779284;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID779284;
%put ERROR- Description                              : Increase PRICE_VALUE_LIST in MDO_PLAN to hold enough values for price ranges;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 28JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID779284;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID779284",
"Increase PRICE_VALUE_LIST in MDO_PLAN to hold enough values for price ranges",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID779284:;
 
 
* End of changes for CHANGE_ID:ID779284;
 
 
***********************************************************************************************;
*************************************  End Change ID779284 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID779284_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID779284_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID779284_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID779284_1;
%goto ID779284_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID779284_1;
* Insert record into change management table for CHANGE_ID: ID779284_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID779284_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID779284_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
alter table PRICE_GRID add PRICE_VALUE_SUMMARY_LIST VARCHAR(1000)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
alter table PRICE_GRID add PRICE_VALUE_SUMMARY_LIST VARCHAR(1000);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID779284_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID779284_1;
%put ERROR- Description                              : Add PRICE_VALUE_RANGE_LIST to PRICE_GRID which will be summary of price range;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 29JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID779284_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID779284_1",
"Add PRICE_VALUE_RANGE_LIST to PRICE_GRID which will be summary of price range",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID779284_1:;
 
 
* End of changes for CHANGE_ID:ID779284_1;
 
 
***********************************************************************************************;
*************************************  End Change ID779284_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID779284MIG ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID779284MIG;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID779284MIG")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID779284MIG;
%goto ID779284MIG;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID779284MIG;
* Insert record into change management table for CHANGE_ID: ID779284MIG;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID779284MIG",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID779284MIG;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
create table work.price_grid_summary as
select pr.price_grid_sk,
pr.price_range_start_val,
pr.price_range_end_val,
pr.price_disc_value_list
from &m_di_trans..price_grid pg,
&m_di_trans..price_grid_range pr
where pg.used_by_app = 1
and pr.price_grid_sk = pg.price_grid_sk
and pg.price_value_type in (1,2)
order by pr.price_grid_sk;
 
 
quit;
 
 
 
data work.price_grid_summary;
 
 
set work.price_grid_summary;
 
 
by price_grid_sk;
 
 
attrib price_value_summary_list length=$1000;
 
 
retain price_value_summary_list '';
 
 
 
if first.price_grid_sk then price_value_summary_list = '';
 
 
 
if not missing(price_disc_value_list);
 
 
 
if first.price_grid_sk and last.price_grid_sk then do;
 
 
price_value_summary_list = price_disc_value_list;
 
 
end;
 
 
else do;
 
 
if first.price_grid_sk or (not last.price_grid_sk) then
price_value_summary_list = cats(price_value_summary_list,price_disc_value_list,':',left(put(price_range_end_val,22.2)),'|');
 
 
if last.price_grid_sk then
price_value_summary_list = cats(price_value_summary_list,price_disc_value_list);
 
 
end;
 
 
if last.price_grid_sk then output;
 
 
drop price_range_start_val price_range_end_val price_disc_value_list;
 
 
run;
 
 
 
%di_dm_trans_update(
upload_lib=work,
upload_table=price_grid_summary,
update_table=price_grid,
sql= %str(update &m_di_trans..price_grid pg set price_value_summary_list = (SELECT price_value_summary_list
FROM work.price_grid_summary ps WHERE pg.price_grid_sk = ps.price_grid_sk))
);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
create table work.price_grid_summary as
select pr.price_grid_sk,
pr.price_range_start_val,
pr.price_range_end_val,
pr.price_disc_value_list
from &m_di_trans..price_grid pg,
&m_di_trans..price_grid_range pr
where pg.used_by_app = 1
and pr.price_grid_sk = pg.price_grid_sk
and pg.price_value_type in (1,2)
order by pr.price_grid_sk;
 
 
quit;
 
 
 
data work.price_grid_summary;
 
 
set work.price_grid_summary;
 
 
by price_grid_sk;
 
 
attrib price_value_summary_list length=$1000;
 
 
retain price_value_summary_list '';
 
 
 
if first.price_grid_sk then price_value_summary_list = '';
 
 
 
if not missing(price_disc_value_list);
 
 
 
if first.price_grid_sk and last.price_grid_sk then do;
 
 
price_value_summary_list = price_disc_value_list;
 
 
end;
 
 
else do;
 
 
if first.price_grid_sk or (not last.price_grid_sk) then
price_value_summary_list = cats(price_value_summary_list,price_disc_value_list,':',left(put(price_range_end_val,22.2)),'|');
 
 
if last.price_grid_sk then
price_value_summary_list = cats(price_value_summary_list,price_disc_value_list);
 
 
end;
 
 
if last.price_grid_sk then output;
 
 
drop price_range_start_val price_range_end_val price_disc_value_list;
 
 
run;
 
 
 
%di_dm_trans_update(
upload_lib=work,
upload_table=price_grid_summary,
update_table=price_grid,
sql= %str(update &m_di_trans..price_grid pg set price_value_summary_list = (SELECT price_value_summary_list
FROM work.price_grid_summary ps WHERE pg.price_grid_sk = ps.price_grid_sk))
);
 
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID779284MIG;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID779284MIG;
%put ERROR- Description                              : Add PRICE_VALUE_RANGE_LIST to PRICE_GRID which will be summary of price range;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 29JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID779284MIG;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID779284MIG",
"Add PRICE_VALUE_RANGE_LIST to PRICE_GRID which will be summary of price range",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID779284MIG:;
 
 
* End of changes for CHANGE_ID:ID779284MIG;
 
 
***********************************************************************************************;
*************************************  End Change ID779284MIG ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID742165 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID742165;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID742165")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID742165;
%goto ID742165;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID742165;
* Insert record into change management table for CHANGE_ID: ID742165;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID742165",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID742165;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE TABLE ATTRIBUTE
(
ATTR_SK   INTEGER NOT NULL,
ATTR_NM   VARCHAR(40) NOT NULL,
ATTR_TYPE INTEGER
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
ALTER TABLE ATTRIBUTE ADD CONSTRAINT ATTRIBUTE_PK PRIMARY KEY (ATTR_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
CREATE TABLE ATTRIBUTE
(
ATTR_SK   INTEGER NOT NULL,
ATTR_NM   VARCHAR(40) NOT NULL,
ATTR_TYPE INTEGER
)    ;
 
 
 
 
ALTER TABLE ATTRIBUTE ADD CONSTRAINT PRIM_KEY PRIMARY KEY (ATTR_SK) ;
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID742165;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID742165;
%put ERROR- Description                              : Add replicate table ATTRIBUTE into transact schema for Product Search;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 01AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID742165;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID742165",
"Add replicate table ATTRIBUTE into transact schema for Product Search",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID742165:;
 
 
* End of changes for CHANGE_ID:ID742165;
 
 
***********************************************************************************************;
*************************************  End Change ID742165 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID742165_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID742165_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID742165_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_data.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_data.;
%put NOTE: Change ID                             :ID742165_2;
%goto ID742165_2;
 
%end;
%if not (%sysfunc(exist(&m_di_data..ATTRIBUTE))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_data..ATTRIBUTE;
%put NOTE: Change ID                             :ID742165_2;
%goto ID742165_2;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID742165_2;
%goto ID742165_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID742165_2;
* Insert record into change management table for CHANGE_ID: ID742165_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID742165_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID742165_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
proc sql noprint;
 
 
select count(*)
into :_cnt_ATTRIBUTE
from &m_di_trans..ATTRIBUTE
;
 
 
quit;
 
 
 
%if &_cnt_ATTRIBUTE = 0 %then
%do;
 
 
 
 
%di_dm_trans_append
(
di_trans=&m_di_trans.,
trans_table=ATTRIBUTE,
append_table=&m_di_data..ATTRIBUTE,
bulkload=1
);
 
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
proc sql noprint;
 
 
select count(*)
into :_cnt_ATTRIBUTE
from &m_di_trans..ATTRIBUTE
;
 
 
quit;
 
 
 
%if &_cnt_ATTRIBUTE = 0 %then
%do;
 
 
 
 
%di_dm_trans_append
(
di_trans=&m_di_trans.,
trans_table=ATTRIBUTE,
append_table=&m_di_data..ATTRIBUTE,
bulkload=1
);
 
 
 
 
%end;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID742165_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID742165_2;
%put ERROR- Description                              : Get data for ATTRIBUTE table;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 01AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID742165_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID742165_2",
"Get data for ATTRIBUTE table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID742165_2:;
 
 
* End of changes for CHANGE_ID:ID742165_2;
 
 
***********************************************************************************************;
*************************************  End Change ID742165_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change CPY_PROD_GEO_ATTRS ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: CPY_PROD_GEO_ATTRS;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("CPY_PROD_GEO_ATTRS")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_data.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_data.;
%put NOTE: Change ID                             :CPY_PROD_GEO_ATTRS;
%goto CPY_PROD_GEO_ATTRS;
 
%end;
%if not (%sysfunc(exist(&m_di_data..PRODUCT_ATTRIBUTES))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_data..PRODUCT_ATTRIBUTES;
%put NOTE: Change ID                             :CPY_PROD_GEO_ATTRS;
%goto CPY_PROD_GEO_ATTRS;
 
%end;
%if not (%sysfunc(exist(&m_di_data..GEOGRAPHY_ATTRIBUTES))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_data..GEOGRAPHY_ATTRIBUTES;
%put NOTE: Change ID                             :CPY_PROD_GEO_ATTRS;
%goto CPY_PROD_GEO_ATTRS;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : CPY_PROD_GEO_ATTRS;
%goto CPY_PROD_GEO_ATTRS;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : CPY_PROD_GEO_ATTRS;
* Insert record into change management table for CHANGE_ID: CPY_PROD_GEO_ATTRS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"CPY_PROD_GEO_ATTRS",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto CPY_PROD_GEO_ATTRS;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql noprint;
 
 
select count(*)
into :_cnt_prod_ATTRIBUTE
from &m_di_trans..PRODUCT_ATTRIBUTES
;
 
 
quit;
 
 
 
%if &_cnt_prod_ATTRIBUTE = 0 %then
%do;
 
 
 
 
%di_dm_trans_append
(
di_trans=&m_di_trans.,
trans_table=product_attributes,
append_table=&m_di_data..product_attributes,
bulkload=1
);
 
 
 
 
%end;
 
 
 
proc sql noprint;
 
 
select count(*)
into :_cnt_geo_ATTRIBUTE
from &m_di_trans..GEOGRAPHY_ATTRIBUTES
;
 
 
quit;
 
 
 
%if &_cnt_geo_ATTRIBUTE = 0 %then
%do;
 
 
 
 
%di_dm_trans_append
(
di_trans=&m_di_trans.,
trans_table=GEOGRAPHY_ATTRIBUTES,
append_table=&m_di_data..GEOGRAPHY_ATTRIBUTES,
bulkload=1
);
 
 
 
 
%end;
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
select count(*)
into :_cnt_prod_ATTRIBUTE
from &m_di_trans..PRODUCT_ATTRIBUTES
;
 
 
quit;
 
 
 
%if &_cnt_prod_ATTRIBUTE = 0 %then
%do;
 
 
 
 
%di_dm_trans_append
(
di_trans=&m_di_trans.,
trans_table=product_attributes,
append_table=&m_di_data..product_attributes,
bulkload=1
);
 
 
 
 
%end;
 
 
 
proc sql noprint;
 
 
select count(*)
into :_cnt_geo_ATTRIBUTE
from &m_di_trans..GEOGRAPHY_ATTRIBUTES
;
 
 
quit;
 
 
 
%if &_cnt_geo_ATTRIBUTE = 0 %then
%do;
 
 
 
 
%di_dm_trans_append
(
di_trans=&m_di_trans.,
trans_table=GEOGRAPHY_ATTRIBUTES,
append_table=&m_di_data..GEOGRAPHY_ATTRIBUTES,
bulkload=1
);
 
 
 
 
%end;
 
 
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: CPY_PROD_GEO_ATTRS;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: CPY_PROD_GEO_ATTRS;
%put ERROR- Description                              : Get data for PRODUCT_ATTRIBUTES and GEOGRAPHY_ATTRIBUTES;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 01AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: CPY_PROD_GEO_ATTRS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"CPY_PROD_GEO_ATTRS",
"Get data for PRODUCT_ATTRIBUTES and GEOGRAPHY_ATTRIBUTES",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%CPY_PROD_GEO_ATTRS:;
 
 
* End of changes for CHANGE_ID:CPY_PROD_GEO_ATTRS;
 
 
***********************************************************************************************;
*************************************  End Change CPY_PROD_GEO_ATTRS ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID780082 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID780082;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID780082")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID780082;
%goto ID780082;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID780082;
%goto ID780082;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID780082;
* Insert record into change management table for CHANGE_ID: ID780082;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID780082",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID780082;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DAILY_FCST_METHOD'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DAILY_FCST_METHOD';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID780082;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID780082;
%put ERROR- Description                              : Remove model spec DAILY_FCST_METHOD;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 02AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID780082;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID780082",
"Remove model spec DAILY_FCST_METHOD",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID780082:;
 
 
* End of changes for CHANGE_ID:ID780082;
 
 
***********************************************************************************************;
*************************************  End Change ID780082 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID780102 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID780102;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID780102")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID780102;
%goto ID780102;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID780102;
* Insert record into change management table for CHANGE_ID: ID780102;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID780102",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID780102;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
alter table FCST_EXPORT_INPUT add DAILY_MODEL INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table FCST_EXPORT_INPUT add DAILY_OUTPUT INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
alter table FCST_EXPORT_INPUT add DAILY_MODEL INTEGER ;
 
 
alter table FCST_EXPORT_INPUT add DAILY_OUTPUT INTEGER ;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID780102;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID780102;
%put ERROR- Description                              : Add DAILY_MODEL and DAILY_OUTPUT columns to FCST_EXPORT_INPUT table;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 03AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID780102;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID780102",
"Add DAILY_MODEL and DAILY_OUTPUT columns to FCST_EXPORT_INPUT table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID780102:;
 
 
* End of changes for CHANGE_ID:ID780102;
 
 
***********************************************************************************************;
*************************************  End Change ID780102 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID760260_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID760260_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID760260_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :ID760260_2;
%goto ID760260_2;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID760260_2;
%goto ID760260_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID760260_2;
* Insert record into change management table for CHANGE_ID: ID760260_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID760260_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID760260_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update  GEO_PROD_SETTING set SETTING_CEIL = 1.0 where GEO_PROD_SETTING_SK = 20032
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update  GEO_PROD_SETTING set SETTING_CEIL = 1.0 where GEO_PROD_SETTING_SK = 20032;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID760260_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID760260_2;
%put ERROR- Description                              : DEFAULT OPTIMIZATION SETTINGS...correcting default value;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 02AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID760260_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID760260_2",
"DEFAULT OPTIMIZATION SETTINGS...correcting default value",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID760260_2:;
 
 
* End of changes for CHANGE_ID:ID760260_2;
 
 
***********************************************************************************************;
*************************************  End Change ID760260_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID781186 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID781186;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID781186")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID781186;
%goto ID781186;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID781186;
* Insert record into change management table for CHANGE_ID: ID781186;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID781186",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID781186;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'RUN_MDO_ANALYSIS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from FA_SPEC where SPEC_NM = 'RUN_MDO_ANALYSIS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'RUN_MDO_ANALYSIS';
 
 
delete from FA_SPEC where SPEC_NM = 'RUN_MDO_ANALYSIS';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID781186;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID781186;
%put ERROR- Description                              : Remove FA spec Remove FA spec RUN_MDO_ANALYSIS;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 05AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID781186;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID781186",
"Remove FA spec Remove FA spec RUN_MDO_ANALYSIS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID781186:;
 
 
* End of changes for CHANGE_ID:ID781186;
 
 
***********************************************************************************************;
*************************************  End Change ID781186 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID778001_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID778001_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID778001_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID778001_2;
%goto ID778001_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID778001_2;
* Insert record into change management table for CHANGE_ID: ID778001_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID778001_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID778001_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE RPP_PLAN_PROD_ASGMNT ADD FCST_UNITS_ADJUST_TYPE INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPP_PLAN_PROD_ASGMNT ADD FCST_UNITS_ADJUST NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE RPP_PLAN_PROD_ASGMNT ADD FCST_UNITS_ADJUST_TYPE INTEGER;
 
 
ALTER TABLE RPP_PLAN_PROD_ASGMNT ADD FCST_UNITS_ADJUST NUMERIC(20,3);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID778001_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID778001_2;
%put ERROR- Description                              : SUPPORT FOR FORECAST OVERRIDE EXTENSIONS;
%put ERROR- Version                                  : D3MICM52,M2MI42;
%put ERROR- Date of Change                           : 28JUL2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID778001_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID778001_2",
"SUPPORT FOR FORECAST OVERRIDE EXTENSIONS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID778001_2:;
 
 
* End of changes for CHANGE_ID:ID778001_2;
 
 
***********************************************************************************************;
*************************************  End Change ID778001_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ADD_GEO_PROD_RPP_TABLE ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ADD_GEO_PROD_RPP_TABLE;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ADD_GEO_PROD_RPP_TABLE")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :ADD_GEO_PROD_RPP_TABLE;
%goto ADD_GEO_PROD_RPP_TABLE;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ADD_GEO_PROD_RPP_TABLE;
%goto ADD_GEO_PROD_RPP_TABLE;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ADD_GEO_PROD_RPP_TABLE;
* Insert record into change management table for CHANGE_ID: ADD_GEO_PROD_RPP_TABLE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ADD_GEO_PROD_RPP_TABLE",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ADD_GEO_PROD_RPP_TABLE;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
create table GEO_PROD_RPP (
PROD_HIER_SK                INTEGER NOT NULL,
GEO_HIER_SK                 INTEGER NOT NULL,
PLAN_SK                     INTEGER NOT NULL,
REGULAR_PRICE               NUMERIC(20,3),
COST                        NUMERIC(20,3),
MIN_VENDOR_DEAL_COST        NUMERIC(20,3),
MAX_VENDOR_DEAL_COST        NUMERIC(20,3),
MIN_PROMOTION_PRICE         NUMERIC(20,3),
MAX_PROMOTION_PRICE         NUMERIC(20,3),
BASE_SALES_UNITS            NUMERIC(20,3),
BASE_SALES_AMT              NUMERIC(20,3),
BASE_COST_AMT               NUMERIC(20,3),
FCST_SALES_UNITS            NUMERIC(20,3),
FCST_SALES_AMT              NUMERIC(20,3),
FCST_COST_AMT               NUMERIC(20,3),
ACTUAL_SALES_UNITS          NUMERIC(20,3),
ACTUAL_SALES_AMT            NUMERIC(20,3),
ACTUAL_COST_AMT             NUMERIC(20,3)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE GEO_PROD_RPP ADD CONSTRAINT GEO_PROD_RPP_PK PRIMARY KEY (PROD_HIER_SK,GEO_HIER_SK,PLAN_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
create table GEO_PROD_RPP (
PROD_HIER_SK                INTEGER NOT NULL,
GEO_HIER_SK                 INTEGER NOT NULL,
PLAN_SK                     INTEGER NOT NULL,
REGULAR_PRICE               NUMERIC(20,3),
COST                        NUMERIC(20,3),
MIN_VENDOR_DEAL_COST        NUMERIC(20,3),
MAX_VENDOR_DEAL_COST        NUMERIC(20,3),
MIN_PROMOTION_PRICE         NUMERIC(20,3),
MAX_PROMOTION_PRICE         NUMERIC(20,3),
BASE_SALES_UNITS            NUMERIC(20,3),
BASE_SALES_AMT              NUMERIC(20,3),
BASE_COST_AMT               NUMERIC(20,3),
FCST_SALES_UNITS            NUMERIC(20,3),
FCST_SALES_AMT              NUMERIC(20,3),
FCST_COST_AMT               NUMERIC(20,3),
ACTUAL_SALES_UNITS          NUMERIC(20,3),
ACTUAL_SALES_AMT            NUMERIC(20,3),
ACTUAL_COST_AMT             NUMERIC(20,3)
);
 
 
 
ALTER TABLE GEO_PROD_RPP ADD CONSTRAINT GEO_PROD_RPP_PK PRIMARY KEY (PROD_HIER_SK,GEO_HIER_SK,PLAN_SK) ;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ADD_GEO_PROD_RPP_TABLE;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ADD_GEO_PROD_RPP_TABLE;
%put ERROR- Description                              : New export tables/fields for Promotion Optimization to support report data mart;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 04AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ADD_GEO_PROD_RPP_TABLE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ADD_GEO_PROD_RPP_TABLE",
"New export tables/fields for Promotion Optimization to support report data mart",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ADD_GEO_PROD_RPP_TABLE:;
 
 
* End of changes for CHANGE_ID:ADD_GEO_PROD_RPP_TABLE;
 
 
***********************************************************************************************;
*************************************  End Change ADD_GEO_PROD_RPP_TABLE ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID781517 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID781517;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID781517")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID781517;
%goto ID781517;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID781517;
%goto ID781517;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID781517;
* Insert record into change management table for CHANGE_ID: ID781517;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID781517",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID781517;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'COMPUTE_BASELINE_OFFSET'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('COMPUTE_BASELINE_OFFSET','ALL','1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('COMPUTE_BASELINE_OFFSET','ALL','2','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'COMPUTE_BASELINE_OFFSET';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('COMPUTE_BASELINE_OFFSET','ALL','1','0',NULL);
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('COMPUTE_BASELINE_OFFSET','ALL','2','0',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID781517;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID781517;
%put ERROR- Description                              : Add model spec COMPUTE_BASELINE_OFFSET;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 08AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID781517;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID781517",
"Add model spec COMPUTE_BASELINE_OFFSET",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID781517:;
 
 
* End of changes for CHANGE_ID:ID781517;
 
 
***********************************************************************************************;
*************************************  End Change ID781517 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID781306 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID781306;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID781306")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID781306;
%goto ID781306;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID781306;
%goto ID781306;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID781306;
* Insert record into change management table for CHANGE_ID: ID781306;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID781306",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID781306;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DEREG_TOLERANCE_FACTOR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('DEREG_TOLERANCE_FACTOR','ALL','-1','3',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DEREG_TOLERANCE_FACTOR_MINOBS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('DEREG_TOLERANCE_FACTOR_MINOBS','ALL','-1','12',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DEREG_MIN_FACTOR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('DEREG_MIN_FACTOR','ALL','-1','0.001',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DEREG_TOLERANCE_FACTOR';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('DEREG_TOLERANCE_FACTOR','ALL','-1','3',NULL);
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DEREG_TOLERANCE_FACTOR_MINOBS';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('DEREG_TOLERANCE_FACTOR_MINOBS','ALL','-1','12',NULL);
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DEREG_MIN_FACTOR';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('DEREG_MIN_FACTOR','ALL','-1','0.001',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID781306;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID781306;
%put ERROR- Description                              : Add model specs DEREG_TOLERANCE_FACTOR, DEREG_TOLERANCE_FACTOR_MINOBS and DEREG_MIN_FACTOR;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 08AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID781306;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID781306",
"Add model specs DEREG_TOLERANCE_FACTOR, DEREG_TOLERANCE_FACTOR_MINOBS and DEREG_MIN_FACTOR",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID781306:;
 
 
* End of changes for CHANGE_ID:ID781306;
 
 
***********************************************************************************************;
*************************************  End Change ID781306 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID781663 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID781663;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID781663")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID781663;
%goto ID781663;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID781663;
%goto ID781663;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID781663;
* Insert record into change management table for CHANGE_ID: ID781663;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID781663",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID781663;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASELINE_CF_PR1'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('BASELINE_CF_PR1','ALL','1','1.00',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('BASELINE_CF_PR1','ALL','2','1.00',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'USE_BASELINE_CF'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('USE_BASELINE_CF','ALL','1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('USE_BASELINE_CF','ALL','2','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASELINE_CF_PR1';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('BASELINE_CF_PR1','ALL','1','1.00',NULL);
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('BASELINE_CF_PR1','ALL','2','1.00',NULL);
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'USE_BASELINE_CF';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('USE_BASELINE_CF','ALL','1','1',NULL);
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('USE_BASELINE_CF','ALL','2','1',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID781663;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID781663;
%put ERROR- Description                              : Add model specs BASELINE_CF_PR1 and USE_BASELINE_CF;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 08AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID781663;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID781663",
"Add model specs BASELINE_CF_PR1 and USE_BASELINE_CF",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID781663:;
 
 
* End of changes for CHANGE_ID:ID781663;
 
 
***********************************************************************************************;
*************************************  End Change ID781663 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID781594 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID781594;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID781594")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID781594;
%goto ID781594;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID781594;
%goto ID781594;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID781594;
* Insert record into change management table for CHANGE_ID: ID781594;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID781594",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID781594;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MIN_HIST_INV'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('MIN_HIST_INV','ALL','-1','3',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MIN_HIST_INV';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('MIN_HIST_INV','ALL','-1','3',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID781594;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID781594;
%put ERROR- Description                              : Add model spec MIN_HIST_INV;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 08AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID781594;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID781594",
"Add model spec MIN_HIST_INV",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID781594:;
 
 
* End of changes for CHANGE_ID:ID781594;
 
 
***********************************************************************************************;
*************************************  End Change ID781594 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change RENAME_COL_COPIED_FLG ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: RENAME_COL_COPIED_FLG;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("RENAME_COL_COPIED_FLG")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PRF_SIZESET))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_SIZESET;
%put NOTE: Change ID                             :RENAME_COL_COPIED_FLG;
%goto RENAME_COL_COPIED_FLG;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : RENAME_COL_COPIED_FLG;
%goto RENAME_COL_COPIED_FLG;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : RENAME_COL_COPIED_FLG;
* Insert record into change management table for CHANGE_ID: RENAME_COL_COPIED_FLG;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"RENAME_COL_COPIED_FLG",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto RENAME_COL_COPIED_FLG;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE PRF_SIZESET RENAME COLUMN COPIED_FLG TO CUSTOM_FLG
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRF_PLAN RENAME COLUMN COPIED_FLG TO CUSTOM_FLG
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc datasets lib=&m_di_trans. nolist;
 
 
 
modify  PRF_SIZESET;
 
 
rename copied_flg=custom_flg;
 
 
quit;
 
 
run;
 
 
proc datasets lib=&m_di_trans. nolist;
 
 
 
modify  PRF_PLAN;
 
 
rename copied_flg=custom_flg;
 
 
quit;
 
 
run;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: RENAME_COL_COPIED_FLG;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: RENAME_COL_COPIED_FLG;
%put ERROR- Description                              : Rename COPIED_FLG;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 09AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: RENAME_COL_COPIED_FLG;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"RENAME_COL_COPIED_FLG",
"Rename COPIED_FLG",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%RENAME_COL_COPIED_FLG:;
 
 
* End of changes for CHANGE_ID:RENAME_COL_COPIED_FLG;
 
 
***********************************************************************************************;
*************************************  End Change RENAME_COL_COPIED_FLG ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID782326 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID782326;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID782326")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID782326;
%goto ID782326;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID782326;
* Insert record into change management table for CHANGE_ID: ID782326;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID782326",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID782326;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MAX_FIT_APE' and MODEL_COMP_NM = 'MA'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('MAX_FIT_APE','MA','-1','1000',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MAPE_GEO_LVL' and MODEL_COMP_NM = 'MA'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('MAPE_GEO_LVL','MA','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MAPE_PROD_LVL' and MODEL_COMP_NM = 'MA'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('MAPE_PROD_LVL','MA','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'LAST_INSAMPLE_WEEK' and MODEL_COMP_NM = 'MA'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('LAST_INSAMPLE_WEEK','MA','-1','',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MAX_FIT_APE' and MODEL_COMP_NM = 'MA' ;
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('MAX_FIT_APE','MA','-1','1000',NULL);
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MAPE_GEO_LVL' and MODEL_COMP_NM = 'MA' ;
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('MAPE_GEO_LVL','MA','-1','1',NULL);
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MAPE_PROD_LVL' and MODEL_COMP_NM = 'MA' ;
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('MAPE_PROD_LVL','MA','-1','1',NULL);
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'LAST_INSAMPLE_WEEK' and MODEL_COMP_NM = 'MA' ;
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('LAST_INSAMPLE_WEEK','MA','-1','',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID782326;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID782326;
%put ERROR- Description                              : Fix MA_SPEC_SEED missing specs and re-check MODEL_SPEC_DEFAULT;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 10AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID782326;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID782326",
"Fix MA_SPEC_SEED missing specs and re-check MODEL_SPEC_DEFAULT",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID782326:;
 
 
* End of changes for CHANGE_ID:ID782326;
 
 
***********************************************************************************************;
*************************************  End Change ID782326 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID782915 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID782915;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID782915")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID782915;
%goto ID782915;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID782915;
* Insert record into change management table for CHANGE_ID: ID782915;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID782915",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID782915;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from FA_SCORING_RULE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (1,0.0,'ELASTICITY_TAIL')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (2,0.0,'INV_WEIGHTED_MAPE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (3,0.0,'INV_WEIGHTED_MAPE_FIT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (4,0.0,'INV_WEIGHTED_MEAN_PE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (5,0.0,'INV_WEIGHTED_MEAN_PE_FIT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (6,0.0,'MAX_HD_RMSE_FIT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (7,0.0,'MEDIAN_PE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (8,0.0,'MEDIAN_PE_FIT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (9,0.0,'PCT_ELASTICITY_DEFAULTED')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (10,0.0,'REVENUE_WEIGHTED_MAPE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (11,0.0,'REVENUE_WEIGHTED_MAPE_FIT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (12,0.0,'REVENUE_WEIGHTED_MEAN_PE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (13,0.0,'REVENUE_WEIGHTED_MEAN_PE_FIT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (14,0.0,'SALES_WEIGHTED_MAPE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (15,0.0,'SALES_WEIGHTED_MAPE_FIT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (16,0.0,'SALES_WEIGHTED_MEAN_PE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (17,0.0,'SALES_WEIGHTED_MEAN_PE_FIT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from FA_SCORING_RANGE_RULE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (1,1,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (2,2,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (3,3,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (4,4,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (5,5,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (6,6,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (7,7,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (8,8,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (9,9,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (10,10,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (11,11,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (12,12,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (13,13,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (14,14,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (15,15,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (16,16,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (17,17,-99999999.99,99999999.99,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from FA_SCORING_RULE;
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (1,0.0,'ELASTICITY_TAIL');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (2,0.0,'INV_WEIGHTED_MAPE');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (3,0.0,'INV_WEIGHTED_MAPE_FIT');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (4,0.0,'INV_WEIGHTED_MEAN_PE');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (5,0.0,'INV_WEIGHTED_MEAN_PE_FIT');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (6,0.0,'MAX_HD_RMSE_FIT');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (7,0.0,'MEDIAN_PE');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (8,0.0,'MEDIAN_PE_FIT');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (9,0.0,'PCT_ELASTICITY_DEFAULTED');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (10,0.0,'REVENUE_WEIGHTED_MAPE');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (11,0.0,'REVENUE_WEIGHTED_MAPE_FIT');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (12,0.0,'REVENUE_WEIGHTED_MEAN_PE');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (13,0.0,'REVENUE_WEIGHTED_MEAN_PE_FIT');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (14,0.0,'SALES_WEIGHTED_MAPE');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (15,0.0,'SALES_WEIGHTED_MAPE_FIT');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (16,0.0,'SALES_WEIGHTED_MEAN_PE');
 
 
insert into FA_SCORING_RULE (FA_SCORING_RULE_SK,WEIGHT,MEASURE)
values (17,0.0,'SALES_WEIGHTED_MEAN_PE_FIT');
 
 
 
delete from FA_SCORING_RANGE_RULE;
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (1,1,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (2,2,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (3,3,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (4,4,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (5,5,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (6,6,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (7,7,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (8,8,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (9,9,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (10,10,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (11,11,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (12,12,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (13,13,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (14,14,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (15,15,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (16,16,-99999999.99,99999999.99,0);
 
 
insert into FA_SCORING_RANGE_RULE (FA_SCORING_RANGE_RULE_SK,FA_SCORING_RULE_SK,RANGE_START_VALUE,RANGE_END_VALUE,RANGE_VALUE)
values (17,17,-99999999.99,99999999.99,0);
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID782915;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID782915;
%put ERROR- Description                              : Seed FA_SCORING_RULE and FA_SCORING_RANGE_RULE tables;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 12AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID782915;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID782915",
"Seed FA_SCORING_RULE and FA_SCORING_RANGE_RULE tables",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID782915:;
 
 
* End of changes for CHANGE_ID:ID782915;
 
 
***********************************************************************************************;
*************************************  End Change ID782915 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change DROP_INV_FLG ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: DROP_INV_FLG;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("DROP_INV_FLG")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : DROP_INV_FLG;
%goto DROP_INV_FLG;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : DROP_INV_FLG;
* Insert record into change management table for CHANGE_ID: DROP_INV_FLG;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_INV_FLG",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto DROP_INV_FLG;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE RPP_PLAN_PROD_ASGMNT DROP COLUMN INVENTORY_FLG
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
 
ALTER TABLE RPP_PLAN_PROD_ASGMNT DROP COLUMN INVENTORY_FLG;
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: DROP_INV_FLG;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: DROP_INV_FLG;
%put ERROR- Description                              : Drop INVENTORY_FLG column from RPP_PLAN_PROD_ASGMNT;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 15AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: DROP_INV_FLG;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_INV_FLG",
"Drop INVENTORY_FLG column from RPP_PLAN_PROD_ASGMNT",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%DROP_INV_FLG:;
 
 
* End of changes for CHANGE_ID:DROP_INV_FLG;
 
 
***********************************************************************************************;
*************************************  End Change DROP_INV_FLG ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ADD_INV_FLG ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ADD_INV_FLG;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ADD_INV_FLG")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ADD_INV_FLG;
%goto ADD_INV_FLG;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ADD_INV_FLG;
* Insert record into change management table for CHANGE_ID: ADD_INV_FLG;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ADD_INV_FLG",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ADD_INV_FLG;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE RPP_PLAN_PROD_ASGMNT ADD INVENTORY_FLG INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE RPP_PLAN_PROD_ASGMNT ADD INVENTORY_FLG INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ADD_INV_FLG;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ADD_INV_FLG;
%put ERROR- Description                              : Add INVENTORY_FLG column for RPP_PLAN_PROD_ASGMNT;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 17AUG2010;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ADD_INV_FLG;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ADD_INV_FLG",
"Add INVENTORY_FLG column for RPP_PLAN_PROD_ASGMNT",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ADD_INV_FLG:;
 
 
* End of changes for CHANGE_ID:ADD_INV_FLG;
 
 
***********************************************************************************************;
*************************************  End Change ADD_INV_FLG ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID783636 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID783636;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID783636")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID783636;
%goto ID783636;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID783636;
* Insert record into change management table for CHANGE_ID: ID783636;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID783636",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID783636;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'HALO_GEO_LVL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('HALO_GEO_LVL','ALL','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'HALO_GEO_LVL';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('HALO_GEO_LVL','ALL','-1','1',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID783636;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID783636;
%put ERROR- Description                              : Fix MA_SPEC_SEED missing specs and re-check MODEL_SPEC_DEFAULT;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 10AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID783636;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID783636",
"Fix MA_SPEC_SEED missing specs and re-check MODEL_SPEC_DEFAULT",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID783636:;
 
 
* End of changes for CHANGE_ID:ID783636;
 
 
***********************************************************************************************;
*************************************  End Change ID783636 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID785355 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID785355;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID785355")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID785355;
%goto ID785355;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID785355;
* Insert record into change management table for CHANGE_ID: ID785355;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID785355",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID785355;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_IDM_FCST_LVL' and MODEL_COMP_NM = 'FCST'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_IDM_DISAGG_LVL' and MODEL_COMP_NM = 'FCST'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_IDM_MODEL' and MODEL_COMP_NM = 'FCST'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_IDM_FCST_LVL' and MODEL_COMP_NM = 'FCST';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_IDM_DISAGG_LVL' and MODEL_COMP_NM = 'FCST';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_IDM_MODEL' and MODEL_COMP_NM = 'FCST';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID785355;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID785355;
%put ERROR- Description                              : Remove model specs FCST_IDM_FCST_LVL, FCST_IDM_DISAGG_LVL, FCST_IDM_MODEL;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 19AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID785355;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID785355",
"Remove model specs FCST_IDM_FCST_LVL, FCST_IDM_DISAGG_LVL, FCST_IDM_MODEL",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID785355:;
 
 
* End of changes for CHANGE_ID:ID785355;
 
 
***********************************************************************************************;
*************************************  End Change ID785355 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID785283 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID785283;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID785283")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID785283;
%goto ID785283;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID785283;
* Insert record into change management table for CHANGE_ID: ID785283;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID785283",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID785283;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where SPEC_NM = 'FCST_MINOBS' and MODEL_COMP_NM = 'FCST'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where SPEC_NM = 'FCST_MINOBS_TREND' and MODEL_COMP_NM = 'FCST'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where SPEC_NM = 'FCST_MINOBS' and MODEL_COMP_NM = 'FCST';
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where SPEC_NM = 'FCST_MINOBS_TREND' and MODEL_COMP_NM = 'FCST';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID785283;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID785283;
%put ERROR- Description                              : Change spec type to -1 for model specs FCST_MINOBS and FCST_MINOBS_TREND;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 19AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID785283;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID785283",
"Change spec type to -1 for model specs FCST_MINOBS and FCST_MINOBS_TREND",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID785283:;
 
 
* End of changes for CHANGE_ID:ID785283;
 
 
***********************************************************************************************;
*************************************  End Change ID785283 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID767635_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID767635_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID767635_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID767635_1;
%goto ID767635_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID767635_1;
* Insert record into change management table for CHANGE_ID: ID767635_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID767635_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID767635_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_NM = 'DOW_EVENT_GEO_AGG' where SPEC_NM = 'DOW_EVENT_PROD_AGG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_NM = 'DOW_EVENT_GEO_AGG' where SPEC_NM = 'DOW_EVENT_PROD_AGG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC_DEFAULT set SPEC_NM = 'DOW_EVENT_GEO_AGG' where SPEC_NM = 'DOW_EVENT_PROD_AGG';
 
 
update MODEL_SPEC set SPEC_NM = 'DOW_EVENT_GEO_AGG' where SPEC_NM = 'DOW_EVENT_PROD_AGG';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID767635_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID767635_1;
%put ERROR- Description                              : Change DOW spec DOW_EVENT_PROD_AGG to DOW_EVENT_GEO_AGG;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 21AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID767635_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID767635_1",
"Change DOW spec DOW_EVENT_PROD_AGG to DOW_EVENT_GEO_AGG",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID767635_1:;
 
 
* End of changes for CHANGE_ID:ID767635_1;
 
 
***********************************************************************************************;
*************************************  End Change ID767635_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID785810 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID785810;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID785810")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID785810;
%goto ID785810;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID785810;
* Insert record into change management table for CHANGE_ID: ID785810;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID785810",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID785810;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FIXED_CAPPING_METHOD' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('REG','FIXED_CAPPING_METHOD','2','ORIGIN',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FIXED_CAPPING_METHOD' and SPEC_TYPE = '2';
 
 
insert into MODEL_SPEC_DEFAULT (MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('REG','FIXED_CAPPING_METHOD','2','ORIGIN',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID785810;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID785810;
%put ERROR- Description                              : Add FIXED_CAPPING_METHOD model spec for SHARE model;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 22AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID785810;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID785810",
"Add FIXED_CAPPING_METHOD model spec for SHARE model",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID785810:;
 
 
* End of changes for CHANGE_ID:ID785810;
 
 
***********************************************************************************************;
*************************************  End Change ID785810 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID786113 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID786113;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID786113")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID786113;
%goto ID786113;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID786113;
* Insert record into change management table for CHANGE_ID: ID786113;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID786113",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID786113;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '0.3' where SPEC_NM = 'DOW_MIN_SPLIT_PCT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '0.3' where SPEC_NM = 'DOW_MIN_SPLIT_PCT';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID786113;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID786113;
%put ERROR- Description                              : Change DOW spec DOW_EVENT_PROD_AGG to DOW_EVENT_GEO_AGG;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 22AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID786113;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID786113",
"Change DOW spec DOW_EVENT_PROD_AGG to DOW_EVENT_GEO_AGG",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID786113:;
 
 
* End of changes for CHANGE_ID:ID786113;
 
 
***********************************************************************************************;
*************************************  End Change ID786113 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change MOVE_HALO_PRODS_TO_RDBMS ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: MOVE_HALO_PRODS_TO_RDBMS;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("MOVE_HALO_PRODS_TO_RDBMS")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : MOVE_HALO_PRODS_TO_RDBMS;
%goto MOVE_HALO_PRODS_TO_RDBMS;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : MOVE_HALO_PRODS_TO_RDBMS;
* Insert record into change management table for CHANGE_ID: MOVE_HALO_PRODS_TO_RDBMS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"MOVE_HALO_PRODS_TO_RDBMS",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto MOVE_HALO_PRODS_TO_RDBMS;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE HALO_PRODUCTS (
CAUSE_PROD_HIER_SK INTEGER NOT NULL,
EFFECT_PROD_HIER_SK INTEGER NOT NULL
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE HALO_PRODUCTS add CONSTRAINT HALO_PRODUCTS_PK
PRIMARY KEY (CAUSE_PROD_HIER_SK, EFFECT_PROD_HIER_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
CREATE TABLE HALO_PRODUCTS (
CAUSE_PROD_HIER_SK INTEGER NOT NULL,
EFFECT_PROD_HIER_SK INTEGER NOT NULL
) ;
 
 
 
ALTER TABLE HALO_PRODUCTS add CONSTRAINT HALO_PRODUCTS_PK
PRIMARY KEY (CAUSE_PROD_HIER_SK, EFFECT_PROD_HIER_SK);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: MOVE_HALO_PRODS_TO_RDBMS;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: MOVE_HALO_PRODS_TO_RDBMS;
%put ERROR- Description                              : Move HALO_PRODUCTS Table from SAS to RDBMS;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 22AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: MOVE_HALO_PRODS_TO_RDBMS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"MOVE_HALO_PRODS_TO_RDBMS",
"Move HALO_PRODUCTS Table from SAS to RDBMS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%MOVE_HALO_PRODS_TO_RDBMS:;
 
 
* End of changes for CHANGE_ID:MOVE_HALO_PRODS_TO_RDBMS;
 
 
***********************************************************************************************;
*************************************  End Change MOVE_HALO_PRODS_TO_RDBMS ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change XFR_DATA_FOR_HALO_PRODS ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: XFR_DATA_FOR_HALO_PRODS;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("XFR_DATA_FOR_HALO_PRODS")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(DI_TRANS)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: DI_TRANS;
%put NOTE: Change ID                             :XFR_DATA_FOR_HALO_PRODS;
%goto XFR_DATA_FOR_HALO_PRODS;
 
%end;
%if not (%sysfunc(libref(DI_DATA)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: DI_DATA;
%put NOTE: Change ID                             :XFR_DATA_FOR_HALO_PRODS;
%goto XFR_DATA_FOR_HALO_PRODS;
 
%end;
%if not (%sysfunc(exist(&m_di_data..HALO_PRODUCTS))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_data..HALO_PRODUCTS;
%put NOTE: Change ID                             :XFR_DATA_FOR_HALO_PRODS;
%goto XFR_DATA_FOR_HALO_PRODS;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..HALO_PRODUCTS))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..HALO_PRODUCTS;
%put NOTE: Change ID                             :XFR_DATA_FOR_HALO_PRODS;
%goto XFR_DATA_FOR_HALO_PRODS;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : XFR_DATA_FOR_HALO_PRODS;
%goto XFR_DATA_FOR_HALO_PRODS;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : XFR_DATA_FOR_HALO_PRODS;
* Insert record into change management table for CHANGE_ID: XFR_DATA_FOR_HALO_PRODS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"XFR_DATA_FOR_HALO_PRODS",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto XFR_DATA_FOR_HALO_PRODS;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc append base = &m_di_trans..HALO_PRODUCTS data = &m_di_data..HALO_PRODUCTS force; run;
 
 
 
proc sql;
 
 
DROP TABLE &m_di_data..HALO_PRODUCTS;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc append base = &m_di_trans..HALO_PRODUCTS data = &m_di_data..HALO_PRODUCTS force; run;
 
 
 
proc sql;
 
 
DROP TABLE &m_di_data..HALO_PRODUCTS;
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: XFR_DATA_FOR_HALO_PRODS;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: XFR_DATA_FOR_HALO_PRODS;
%put ERROR- Description                              : Get data for HALO_PRODUCTS table from di_data to di_trans;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 22AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: XFR_DATA_FOR_HALO_PRODS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"XFR_DATA_FOR_HALO_PRODS",
"Get data for HALO_PRODUCTS table from di_data to di_trans",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%XFR_DATA_FOR_HALO_PRODS:;
 
 
* End of changes for CHANGE_ID:XFR_DATA_FOR_HALO_PRODS;
 
 
***********************************************************************************************;
*************************************  End Change XFR_DATA_FOR_HALO_PRODS ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID787294 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID787294;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID787294")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID787294;
%goto ID787294;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID787294;
* Insert record into change management table for CHANGE_ID: ID787294;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID787294",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID787294;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update DATA_CONFIG set MODEL_COMP_NM = 'DOW' where MODEL_COMP_NM = 'FCST'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update DATA_CONFIG set MODEL_COMP_NM = 'DOW' where MODEL_COMP_NM = 'FCST';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID787294;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID787294;
%put ERROR- Description                              : Correct DATA_CONFIG table to have DOW component name in place of FCST;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 25AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID787294;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID787294",
"Correct DATA_CONFIG table to have DOW component name in place of FCST",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID787294:;
 
 
* End of changes for CHANGE_ID:ID787294;
 
 
***********************************************************************************************;
*************************************  End Change ID787294 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID787735 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID787735;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID787735")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID787735;
%goto ID787735;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2TKMI43);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID787735;
* Insert record into change management table for CHANGE_ID: ID787735;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID787735",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID787735;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT  ADD FW_INV_AT_OWNED_PRICE NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT           ADD FW_INV_AT_OWNED_PRICE NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_FAW_MTS ADD FAW_OWNED_PRICE NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT  ADD FW_INV_AT_OWNED_PRICE NUMERIC(20,3);
 
 
ALTER TABLE MPLN_RESULT           ADD FW_INV_AT_OWNED_PRICE NUMERIC(20,3);
 
 
ALTER TABLE MPLN_GEO_PROD_FAW_MTS ADD FAW_OWNED_PRICE NUMERIC(20,3);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID787735;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID787735;
%put ERROR- Description                              : Add columns for Financial Inventory Value (owned value);
%put ERROR- Version                                  : D3MICM52,M2TKMI43;
%put ERROR- Date of Change                           : 29AUG2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID787735;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID787735",
"Add columns for Financial Inventory Value (owned value)",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID787735:;
 
 
* End of changes for CHANGE_ID:ID787735;
 
 
***********************************************************************************************;
*************************************  End Change ID787735 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID760263 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID760263;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID760263")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID760263;
%goto ID760263;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID760263;
* Insert record into change management table for CHANGE_ID: ID760263;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID760263",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID760263;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM PURGE_QUERY
WHERE table_nm in ('IDX_MODEL_DATA','IDX_PROMO_FACTOR','IDX_PROMO_FACTOR_DECOM',
'IDX_SCORING_PARAM','IDX_SCORING_PARAM_AVG','IDX_MODEL_DATA_CALIB','Inventory_Sparse_Refresh',
'Inventory_Sparse','ATTR_SPEC','CONFIG_AUDIT_TRAIL','DATA_CONFIG','DATA_CONFIG_TEMPLATE',
'MODEL_GROUP','MODEL_SPEC','MODEL_SPEC_TEMPLATE','MODEL_GEO_PROD_STATUS_RULE',
'MODEL_GEO_PROD_STATUS_SPEC','PROD_DATA_CONFIG')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM PURGE_QUERY
WHERE table_nm in ('IDX_MODEL_DATA','IDX_PROMO_FACTOR','IDX_PROMO_FACTOR_DECOM',
'IDX_SCORING_PARAM','IDX_SCORING_PARAM_AVG','IDX_MODEL_DATA_CALIB','Inventory_Sparse_Refresh',
'Inventory_Sparse','ATTR_SPEC','CONFIG_AUDIT_TRAIL','DATA_CONFIG','DATA_CONFIG_TEMPLATE',
'MODEL_GROUP','MODEL_SPEC','MODEL_SPEC_TEMPLATE','MODEL_GEO_PROD_STATUS_RULE',
'MODEL_GEO_PROD_STATUS_SPEC','PROD_DATA_CONFIG');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID760263;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID760263;
%put ERROR- Description                              : Remove obsolete entries from Purge_query;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 01SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID760263;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID760263",
"Remove obsolete entries from Purge_query",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID760263:;
 
 
* End of changes for CHANGE_ID:ID760263;
 
 
***********************************************************************************************;
*************************************  End Change ID760263 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID789244 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID789244;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID789244")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID789244;
%goto ID789244;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID789244;
* Insert record into change management table for CHANGE_ID: ID789244;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID789244",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID789244;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MODEL_SPEC_DETAILS DROP COLUMN SPEC_DESC
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MODEL_SPEC_VALUES DROP COLUMN SPEC_VALUE_DESC
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MODEL_GEO_PROD_STATUS_DETAILS DROP COLUMN DESCRIPTION
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MODEL_GEO_PROD_STATUS_VALUES DROP COLUMN SPEC_VALUE_DESC
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE GLOBAL_SETTING_VALUES DROP COLUMN SPEC_VALUE_DESC
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
ALTER TABLE MODEL_SPEC_DETAILS DROP COLUMN SPEC_DESC;
 
 
ALTER TABLE MODEL_SPEC_VALUES DROP COLUMN SPEC_VALUE_DESC;
 
 
ALTER TABLE MODEL_GEO_PROD_STATUS_DETAILS DROP COLUMN DESCRIPTION;
 
 
ALTER TABLE MODEL_GEO_PROD_STATUS_VALUES DROP COLUMN SPEC_VALUE_DESC;
 
 
ALTER TABLE GLOBAL_SETTING_VALUES DROP COLUMN SPEC_VALUE_DESC;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MODEL_SPEC_DETAILS DROP COLUMN SPEC_DESC
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MODEL_SPEC_VALUES DROP COLUMN SPEC_VALUE_DESC
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MODEL_GEO_PROD_STATUS_DETAILS DROP COLUMN DESCRIPTION
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MODEL_GEO_PROD_STATUS_VALUES DROP COLUMN SPEC_VALUE_DESC
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE GLOBAL_SETTING_VALUES DROP COLUMN SPEC_VALUE_DESC
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID789244;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID789244;
%put ERROR- Description                              : Drop description columns from global setting and model spec config tables;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 01SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID789244;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID789244",
"Drop description columns from global setting and model spec config tables",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID789244:;
 
 
* End of changes for CHANGE_ID:ID789244;
 
 
***********************************************************************************************;
*************************************  End Change ID789244 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ADD_GEO_PROD_SETTINGS ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ADD_GEO_PROD_SETTINGS;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ADD_GEO_PROD_SETTINGS")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ADD_GEO_PROD_SETTINGS;
%goto ADD_GEO_PROD_SETTINGS;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ADD_GEO_PROD_SETTINGS;
* Insert record into change management table for CHANGE_ID: ADD_GEO_PROD_SETTINGS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ADD_GEO_PROD_SETTINGS",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ADD_GEO_PROD_SETTINGS;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20005
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20005, 2, 1, 1, 1,  5, 1,  100.0, 0.0000, 100.0000)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20006
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20006, 2, 1, 1, 1,  6, 1,  100.0, 0.0000, 100.0000)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20019
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20019, 2, 1, 1, 1, 19, 1, 100.0, 0.00,  100.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20020
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20020, 2, 1, 1, 1, 20, 1, 100.0, 0.00,  100.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20021
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20021, 2, 1, 1, 1, 21, 1, 100.0, 0.00,  100.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20022
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20022, 2, 1, 1, 1, 22, 1, 100.0, 0.00,  100.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20023
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20023, 2, 1, 1, 1, 23, 1, 100.0, 0.00,  100.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20024
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20024, 2, 1, 1, 1, 24, 1, 100.0, 0.00,  100.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
 
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20005;
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20005, 2, 1, 1, 1,  5, 1,  100.0, 0.0000, 100.0000);
 
 
 
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20006;
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20006, 2, 1, 1, 1,  6, 1,  100.0, 0.0000, 100.0000);
 
 
 
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20019;
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20019, 2, 1, 1, 1, 19, 1, 100.0, 0.00,  100.0);
 
 
 
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20020;
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20020, 2, 1, 1, 1, 20, 1, 100.0, 0.00,  100.0);
 
 
 
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20021;
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20021, 2, 1, 1, 1, 21, 1, 100.0, 0.00,  100.0);
 
 
 
 
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20022;
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20022, 2, 1, 1, 1, 22, 1, 100.0, 0.00,  100.0);
 
 
 
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20023;
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20023, 2, 1, 1, 1, 23, 1, 100.0, 0.00,  100.0);
 
 
 
DELETE FROM geo_prod_setting WHERE GEO_PROD_SETTING_SK=20024;
 
 
insert into geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,SETTING_CEIL)
values ( 20024, 2, 1, 1, 1, 24, 1, 100.0, 0.00,  100.0);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ADD_GEO_PROD_SETTINGS;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ADD_GEO_PROD_SETTINGS;
%put ERROR- Description                              : Additiona seed values for GEO_PROD_SETTINGS table;
%put ERROR- Version                                  : M1MI42;
%put ERROR- Date of Change                           : 01SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ADD_GEO_PROD_SETTINGS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ADD_GEO_PROD_SETTINGS",
"Additiona seed values for GEO_PROD_SETTINGS table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ADD_GEO_PROD_SETTINGS:;
 
 
* End of changes for CHANGE_ID:ADD_GEO_PROD_SETTINGS;
 
 
***********************************************************************************************;
*************************************  End Change ADD_GEO_PROD_SETTINGS ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID790541 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID790541;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID790541")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID790541;
%goto ID790541;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID790541;
* Insert record into change management table for CHANGE_ID: ID790541;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID790541",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID790541;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
proc sql;
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='GEO_PROD_BENEFITS';
 
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('GEO_PROD_BENEFITS', 'SAS', 1, 30, '%di_purge_geo_prod_benefits(libref=DI_DM);', 742,1,'RPO');
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='GEO_PROD_BENEFITS_PS';
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('GEO_PROD_BENEFITS_PS', 'SAS', 1, 30, '%di_purge_geo_prod_benefits_ps(libref=DI_DM);', 742,1,'RPO');
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
proc sql;
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='GEO_PROD_BENEFITS';
 
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('GEO_PROD_BENEFITS', 'SAS', 1, 30, '%di_purge_geo_prod_benefits(libref=DI_DM);', 742,1,'RPO');
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='GEO_PROD_BENEFITS_PS';
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('GEO_PROD_BENEFITS_PS', 'SAS', 1, 30, '%di_purge_geo_prod_benefits_ps(libref=DI_DM);', 742,1,'RPO');
 
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID790541;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID790541;
%put ERROR- Description                              : Add purge macros for new tables viz. GEO_PROD_BENEFITS and GEO_PROD_BENEFITS_PS;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 07SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID790541;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID790541",
"Add purge macros for new tables viz. GEO_PROD_BENEFITS and GEO_PROD_BENEFITS_PS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID790541:;
 
 
* End of changes for CHANGE_ID:ID790541;
 
 
***********************************************************************************************;
*************************************  End Change ID790541 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID791890 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID791890;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID791890")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID791890;
%goto ID791890;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID791890;
* Insert record into change management table for CHANGE_ID: ID791890;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID791890",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID791890;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'ATREG_COLD_START'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'ATREG_COLD_START'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'ATREG_MODULE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'ATREG_MODULE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASE_FORECAST_OVERRIDE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'BASE_FORECAST_OVERRIDE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DESEASON_SOURCE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'DESEASON_SOURCE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DETREND_SOURCE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'DETREND_SOURCE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DMREG_SELECT_TYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'DMREG_SELECT_TYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'EST_MODE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'EST_MODE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'EXCLUDE_NP_FROM_SHARE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'EXCLUDE_NP_FROM_SHARE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_DAILY_TO_WEEKLY'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'FCST_DAILY_TO_WEEKLY'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_INTERMITTENT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'FCST_INTERMITTENT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_OUTTYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'FCST_OUTTYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_TS_CS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'FCST_TS_CS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MAX_PRICE_RATIO'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'MAX_PRICE_RATIO'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MISC_ADJ'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'MISC_ADJ'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'RRP'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'RRP'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'VARIABLE_SELECT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'VARIABLE_SELECT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'ATREG_COLD_START';
 
 
delete from MODEL_SPEC where SPEC_NM = 'ATREG_COLD_START';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'ATREG_MODULE';
 
 
delete from MODEL_SPEC where SPEC_NM = 'ATREG_MODULE';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASE_FORECAST_OVERRIDE';
 
 
delete from MODEL_SPEC where SPEC_NM = 'BASE_FORECAST_OVERRIDE';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DESEASON_SOURCE';
 
 
delete from MODEL_SPEC where SPEC_NM = 'DESEASON_SOURCE';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DETREND_SOURCE';
 
 
delete from MODEL_SPEC where SPEC_NM = 'DETREND_SOURCE';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DMREG_SELECT_TYPE';
 
 
delete from MODEL_SPEC where SPEC_NM = 'DMREG_SELECT_TYPE';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'EST_MODE';
 
 
delete from MODEL_SPEC where SPEC_NM = 'EST_MODE';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'EXCLUDE_NP_FROM_SHARE';
 
 
delete from MODEL_SPEC where SPEC_NM = 'EXCLUDE_NP_FROM_SHARE';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_DAILY_TO_WEEKLY';
 
 
delete from MODEL_SPEC where SPEC_NM = 'FCST_DAILY_TO_WEEKLY';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_INTERMITTENT';
 
 
delete from MODEL_SPEC where SPEC_NM = 'FCST_INTERMITTENT';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_OUTTYPE';
 
 
delete from MODEL_SPEC where SPEC_NM = 'FCST_OUTTYPE';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_TS_CS';
 
 
delete from MODEL_SPEC where SPEC_NM = 'FCST_TS_CS';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MAX_PRICE_RATIO';
 
 
delete from MODEL_SPEC where SPEC_NM = 'MAX_PRICE_RATIO';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MISC_ADJ';
 
 
delete from MODEL_SPEC where SPEC_NM = 'MISC_ADJ';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'RRP';
 
 
delete from MODEL_SPEC where SPEC_NM = 'RRP';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'VARIABLE_SELECT';
 
 
delete from MODEL_SPEC where SPEC_NM = 'VARIABLE_SELECT';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID791890;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID791890;
%put ERROR- Description                              : Remove several model specs and remove component specialization from others;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 09SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID791890;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID791890",
"Remove several model specs and remove component specialization from others",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID791890:;
 
 
* End of changes for CHANGE_ID:ID791890;
 
 
***********************************************************************************************;
*************************************  End Change ID791890 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID792047 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID792047;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID792047")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID792047;
%goto ID792047;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID792047;
* Insert record into change management table for CHANGE_ID: ID792047;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID792047",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID792047;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '1' where SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '1' where SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID792047;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID792047;
%put ERROR- Description                              : Change default value for model spec SALES_INTRO_FROM_GPSTATUS to 1;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 12SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID792047;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID792047",
"Change default value for model spec SALES_INTRO_FROM_GPSTATUS to 1",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID792047:;
 
 
* End of changes for CHANGE_ID:ID792047;
 
 
***********************************************************************************************;
*************************************  End Change ID792047 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID792049 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID792049;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID792049")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID792049;
%goto ID792049;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID792049;
* Insert record into change management table for CHANGE_ID: ID792049;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID792049",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID792049;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = 'WEEK' where SPEC_NM = 'SEASON_FREQ'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = 'WEEK' where SPEC_NM = 'SEASON_FREQ';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID792049;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID792049;
%put ERROR- Description                              : Change default value for model spec SEASON_FREQ to WEEK;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 12SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID792049;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID792049",
"Change default value for model spec SEASON_FREQ to WEEK",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID792049:;
 
 
* End of changes for CHANGE_ID:ID792049;
 
 
***********************************************************************************************;
*************************************  End Change ID792049 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID792051 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID792051;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID792051")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID792051;
%goto ID792051;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID792051;
* Insert record into change management table for CHANGE_ID: ID792051;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID792051",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID792051;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set MODEL_COMP_NM = 'ALL' where SPEC_NM = 'TS_COMP_UPPER_BOUND'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set MODEL_COMP_NM = 'ALL' where SPEC_NM = 'TS_COMP_LOWER_BOUND'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC_DEFAULT set MODEL_COMP_NM = 'ALL' where SPEC_NM = 'TS_COMP_UPPER_BOUND';
 
 
update MODEL_SPEC_DEFAULT set MODEL_COMP_NM = 'ALL' where SPEC_NM = 'TS_COMP_LOWER_BOUND';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID792051;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID792051;
%put ERROR- Description                              : Change TS_COMP_LOWER_BOUND & TS_COMP_UPPER_BOUND model specs component to ALL;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 12SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID792051;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID792051",
"Change TS_COMP_LOWER_BOUND & TS_COMP_UPPER_BOUND model specs component to ALL",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID792051:;
 
 
* End of changes for CHANGE_ID:ID792051;
 
 
***********************************************************************************************;
*************************************  End Change ID792051 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID792884 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID792884;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID792884")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PRF_SIZESET))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_SIZESET;
%put NOTE: Change ID                             :ID792884;
%goto ID792884;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..PRF_SIZESET_MBR))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_SIZESET_MBR;
%put NOTE: Change ID                             :ID792884;
%goto ID792884;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..PRF_PLAN))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_PLAN;
%put NOTE: Change ID                             :ID792884;
%goto ID792884;
 
%end;
%if not (%sysfunc(exist())) %then
%do;
%put NOTE: Skip this change since this table does not exist: ;
%put NOTE: Change ID                             :ID792884;
%goto ID792884;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID792884;
%goto ID792884;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID792884;
* Insert record into change management table for CHANGE_ID: ID792884;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID792884",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID792884;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
UPDATE PRF_SIZESET SET CUSTOM_FLG = 0 WHERE CUSTOM_FLG IS NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PRF_PLAN SET CUSTOM_FLG = 0 WHERE CUSTOM_FLG IS NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PRF_SIZESET_MBR SET SALES_DISTRIBUTION_PCT = 0 WHERE SALES_DISTRIBUTION_PCT IS NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PRF_SIZESET_MBR SET SALES_AUR = 0 WHERE SALES_AUR IS NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PRF_SIZESET_MBR SET UNITS_IMPUTED = 0 WHERE UNITS_IMPUTED IS NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PRF_SIZESET_MBR SET POST_IMPUTATION_SALES_UNITS = 0 WHERE POST_IMPUTATION_SALES_UNITS IS NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
UPDATE PRF_SIZESET SET CUSTOM_FLG = 0 WHERE CUSTOM_FLG IS NULL;
 
 
UPDATE PRF_PLAN SET CUSTOM_FLG = 0 WHERE CUSTOM_FLG IS NULL;
 
 
UPDATE PRF_SIZESET_MBR SET SALES_DISTRIBUTION_PCT = 0 WHERE SALES_DISTRIBUTION_PCT IS NULL;
 
 
UPDATE PRF_SIZESET_MBR SET SALES_AUR = 0 WHERE SALES_AUR IS NULL;
 
 
UPDATE PRF_SIZESET_MBR SET UNITS_IMPUTED = 0 WHERE UNITS_IMPUTED IS NULL;
 
 
UPDATE PRF_SIZESET_MBR SET POST_IMPUTATION_SALES_UNITS = 0 WHERE POST_IMPUTATION_SALES_UNITS IS NULL;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID792884;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID792884;
%put ERROR- Description                              : Provide default values for 3.2 columns;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 15SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID792884;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID792884",
"Provide default values for 3.2 columns",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID792884:;
 
 
* End of changes for CHANGE_ID:ID792884;
 
 
***********************************************************************************************;
*************************************  End Change ID792884 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID794818 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID794818;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID794818")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID794818;
%goto ID794818;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID794818;
* Insert record into change management table for CHANGE_ID: ID794818;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID794818",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID794818;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_VALUE = 'SIMPLE' where SPEC_NM = 'FCST_DISAGG_BESTN_LIST' and SPEC_VALUE = 'IDM'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = 'SIMPLE' where SPEC_NM = 'FCST_DISAGG_BESTN_LIST' and DEFAULT_SPEC_VALUE = 'IDM'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_VALUE = 'SIMPLE' where SPEC_NM = 'INT_BESTN_LIST' and SPEC_VALUE = 'IDM'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = 'SIMPLE' where SPEC_NM = 'INT_BESTN_LIST' and DEFAULT_SPEC_VALUE = 'IDM'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC set SPEC_VALUE = 'SIMPLE' where SPEC_NM = 'FCST_DISAGG_BESTN_LIST' and SPEC_VALUE = 'IDM';
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = 'SIMPLE' where SPEC_NM = 'FCST_DISAGG_BESTN_LIST' and DEFAULT_SPEC_VALUE = 'IDM';
 
 
update MODEL_SPEC set SPEC_VALUE = 'SIMPLE' where SPEC_NM = 'INT_BESTN_LIST' and SPEC_VALUE = 'IDM';
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = 'SIMPLE' where SPEC_NM = 'INT_BESTN_LIST' and DEFAULT_SPEC_VALUE = 'IDM';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID794818;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID794818;
%put ERROR- Description                              : Remove IDM as a model spec value;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 23SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID794818;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID794818",
"Remove IDM as a model spec value",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID794818:;
 
 
* End of changes for CHANGE_ID:ID794818;
 
 
***********************************************************************************************;
*************************************  End Change ID794818 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID793322 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID793322;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID793322")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID793322;
%goto ID793322;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID793322;
* Insert record into change management table for CHANGE_ID: ID793322;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID793322",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID793322;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '10.0' where SPEC_NM = 'TS_SEASON_VAR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '20.0' where SPEC_NM = 'TS_SEASON_MAX'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '10.0' where SPEC_NM = 'TS_SEASON_VAR';
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '20.0' where SPEC_NM = 'TS_SEASON_MAX';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID793322;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID793322;
%put ERROR- Description                              : Change type and default value for model specs TS_SEASON_VAR and TS_SEASON_MAX;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 15SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID793322;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID793322",
"Change type and default value for model specs TS_SEASON_VAR and TS_SEASON_MAX",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID793322:;
 
 
* End of changes for CHANGE_ID:ID793322;
 
 
***********************************************************************************************;
*************************************  End Change ID793322 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID794546 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID794546;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID794546")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID794546;
%goto ID794546;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID794546;
* Insert record into change management table for CHANGE_ID: ID794546;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID794546",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID794546;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD USE_GROSS_NEEDS_FLG INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_BUY ADD USE_GROSS_NEEDS_FLG INTEGER ;
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID794546;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID794546;
%put ERROR- Description                              : Allow user to specify needs as net;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 22SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID794546;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID794546",
"Allow user to specify needs as net",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID794546:;
 
 
* End of changes for CHANGE_ID:ID794546;
 
 
***********************************************************************************************;
*************************************  End Change ID794546 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID791033 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID791033;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID791033")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID791033;
%goto ID791033;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID791033;
* Insert record into change management table for CHANGE_ID: ID791033;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID791033",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID791033;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('GEO_PROD_BENEFITS',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('GEO_PROD_BENEFITS_PS',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('GEO_PROD_BENEFITS',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('GEO_PROD_BENEFITS_PS',0,0,0,null,null);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID791033;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID791033;
%put ERROR- Description                              : Adding new entries for Geo Prod Benefits to table_partition_meta.;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 22SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID791033;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID791033",
"Adding new entries for Geo Prod Benefits to table_partition_meta.",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID791033:;
 
 
* End of changes for CHANGE_ID:ID791033;
 
 
***********************************************************************************************;
*************************************  End Change ID791033 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change DROP_MA_SPEC_TABLE ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: DROP_MA_SPEC_TABLE;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("DROP_MA_SPEC_TABLE")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_data.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_data.;
%put NOTE: Change ID                             :DROP_MA_SPEC_TABLE;
%goto DROP_MA_SPEC_TABLE;
 
%end;
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :DROP_MA_SPEC_TABLE;
%goto DROP_MA_SPEC_TABLE;
 
%end;
%if not (%sysfunc(exist(&m_di_data..ma_spec))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_data..ma_spec;
%put NOTE: Change ID                             :DROP_MA_SPEC_TABLE;
%goto DROP_MA_SPEC_TABLE;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : DROP_MA_SPEC_TABLE;
%goto DROP_MA_SPEC_TABLE;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : DROP_MA_SPEC_TABLE;
* Insert record into change management table for CHANGE_ID: DROP_MA_SPEC_TABLE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_MA_SPEC_TABLE",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto DROP_MA_SPEC_TABLE;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
DROP TABLE &m_di_data..MA_SPEC;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
DROP TABLE &m_di_data..MA_SPEC;
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: DROP_MA_SPEC_TABLE;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: DROP_MA_SPEC_TABLE;
%put ERROR- Description                              : Drop MA_SPEC moved to RDBMS;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 23SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: DROP_MA_SPEC_TABLE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_MA_SPEC_TABLE",
"Drop MA_SPEC moved to RDBMS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%DROP_MA_SPEC_TABLE:;
 
 
* End of changes for CHANGE_ID:DROP_MA_SPEC_TABLE;
 
 
***********************************************************************************************;
*************************************  End Change DROP_MA_SPEC_TABLE ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change TABLE_PART_META_01 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: TABLE_PART_META_01;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("TABLE_PART_META_01")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : TABLE_PART_META_01;
%goto TABLE_PART_META_01;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : TABLE_PART_META_01;
* Insert record into change management table for CHANGE_ID: TABLE_PART_META_01;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"TABLE_PART_META_01",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto TABLE_PART_META_01;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('DATA_MODEL_CHANGE_MANAGEMENT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('DATA_MODEL_VERSION_MANAGEMENT',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('PRICING_RULES_COLUMN_META',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('PRICING_RULES_RULE_META',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('PURGE_RESULT_TABLE',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('REPORT_DECOMP',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('REPORT_DECOMP_PS',0,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('DOW_ADJ_FACTOR',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('DOW_PROD_GEO_GROUP_ATTR',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('DOW_PROFILE',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('MODEL_GEO_PROD_STATUS_META',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('PRICE_POINT_CORRECTION',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'VARIABLE_SELECT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'ATTR_SPEC'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'BASE_FORECAST_OVERRIDE_GP'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'BASE_FORECAST_OVERRIDE_MG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'BUDGET'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'CONFIG_AUDIT_TRAIL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'CONFIG_GROUP'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'DATA_CONFIG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'DATA_CONFIG_TEMPLATE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'GLOBAL_SETTING_DETAILS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'GLOBAL_SETTING_GROUP'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'GLOBAL_SETTING_GROUP_MEMBER'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'GLOBAL_SETTING_VALUES'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'HALO_PRODUCTS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_GEO_PROD_STATUS_DETAILS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_GEO_PROD_STATUS_RULE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_GEO_PROD_STATUS_SPEC'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_GEO_PROD_STATUS_VALUES'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_GROUP'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_SPEC'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_SPEC_DEFAULT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_SPEC_DETAILS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_SPEC_TEMPLATE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_SPEC_VALUES'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_SPEC_WORKFLOW'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'MPLN_GEO_PROD_ACCUM_MTS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'PRF_SSD_SRC'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'PROD_DATA_CONFIG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'RPP_CAL_AGG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'RPP_CAT_AGG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'SCORING_PARAM_CONFIG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'SCORING_PARAM_DEFAULT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('DATA_MODEL_CHANGE_MANAGEMENT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('DATA_MODEL_VERSION_MANAGEMENT',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('PRICING_RULES_COLUMN_META',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('PRICING_RULES_RULE_META',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('PURGE_RESULT_TABLE',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('REPORT_DECOMP',0,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('REPORT_DECOMP_PS',0,0,0,null,null);
 
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('DOW_ADJ_FACTOR',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('DOW_PROD_GEO_GROUP_ATTR',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('DOW_PROFILE',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('MODEL_GEO_PROD_STATUS_META',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('PRICE_POINT_CORRECTION',1,0,0,null,null);
 
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'VARIABLE_SELECT';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'ATTR_SPEC';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'BASE_FORECAST_OVERRIDE_GP';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'BASE_FORECAST_OVERRIDE_MG';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'BUDGET';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'CONFIG_AUDIT_TRAIL';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'CONFIG_GROUP';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'DATA_CONFIG';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'DATA_CONFIG_TEMPLATE';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'GLOBAL_SETTING_DETAILS';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'GLOBAL_SETTING_GROUP';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'GLOBAL_SETTING_GROUP_MEMBER';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'GLOBAL_SETTING_VALUES';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'HALO_PRODUCTS';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_GEO_PROD_STATUS_DETAILS';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_GEO_PROD_STATUS_RULE';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_GEO_PROD_STATUS_SPEC';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_GEO_PROD_STATUS_VALUES';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_GROUP';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_SPEC';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_SPEC_DEFAULT';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_SPEC_DETAILS';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_SPEC_TEMPLATE';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_SPEC_VALUES';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'MODEL_SPEC_WORKFLOW';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'MPLN_GEO_PROD_ACCUM_MTS';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'PRF_SSD_SRC';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'PROD_DATA_CONFIG';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'RPP_CAL_AGG';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'RPP_CAT_AGG';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'SCORING_PARAM_CONFIG';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'SCORING_PARAM_DEFAULT';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: TABLE_PART_META_01;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: TABLE_PART_META_01;
%put ERROR- Description                              : Synchronize table_partition_meta for 5.2;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 27SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: TABLE_PART_META_01;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"TABLE_PART_META_01",
"Synchronize table_partition_meta for 5.2",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%TABLE_PART_META_01:;
 
 
* End of changes for CHANGE_ID:TABLE_PART_META_01;
 
 
***********************************************************************************************;
*************************************  End Change TABLE_PART_META_01 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change REMOVE_GEO_STORE ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: REMOVE_GEO_STORE;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("REMOVE_GEO_STORE")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : REMOVE_GEO_STORE;
%goto REMOVE_GEO_STORE;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : REMOVE_GEO_STORE;
* Insert record into change management table for CHANGE_ID: REMOVE_GEO_STORE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"REMOVE_GEO_STORE",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto REMOVE_GEO_STORE;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_STORE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_PROD_BENEFITS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_PROD_BENEFITS_PS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'SALES_AVG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('GEO_PROD_BENEFITS',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('GEO_PROD_BENEFITS_PS',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('SALES_AVG',1,0,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_STORE';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_PROD_BENEFITS';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_PROD_BENEFITS_PS';
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'SALES_AVG';
 
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('GEO_PROD_BENEFITS',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('GEO_PROD_BENEFITS_PS',1,0,0,null,null);
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
VALUES ('SALES_AVG',1,0,0,null,null);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: REMOVE_GEO_STORE;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: REMOVE_GEO_STORE;
%put ERROR- Description                              : Remove GEO_STORE from table_partition_meta for 5.2;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 06JUN2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: REMOVE_GEO_STORE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"REMOVE_GEO_STORE",
"Remove GEO_STORE from table_partition_meta for 5.2",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%REMOVE_GEO_STORE:;
 
 
* End of changes for CHANGE_ID:REMOVE_GEO_STORE;
 
 
***********************************************************************************************;
*************************************  End Change REMOVE_GEO_STORE ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change TABLE_PART_META_SORT ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: TABLE_PART_META_SORT;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("TABLE_PART_META_SORT")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%put NOTE: This change will be applied on every run : TABLE_PART_META_SORT;
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sort data=&m_di_trans..TABLE_PARTITION_META OUT=work.TABLE_PARTITION_META;
 
 
by table_nm;
 
 
run;
 
 
 
proc sql;
 
 
delete * from &m_di_trans..TABLE_PARTITION_META ;
 
 
insert into &m_di_trans..TABLE_PARTITION_META
select * from work.TABLE_PARTITION_META;
 
 
drop table work.TABLE_PARTITION_META;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sort data=&m_di_trans..TABLE_PARTITION_META OUT=work.TABLE_PARTITION_META;
 
 
by table_nm;
 
 
run;
 
 
 
proc sql;
 
 
delete * from &m_di_trans..TABLE_PARTITION_META ;
 
 
insert into &m_di_trans..TABLE_PARTITION_META
select * from work.TABLE_PARTITION_META;
 
 
drop table work.TABLE_PARTITION_META;
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: TABLE_PART_META_SORT;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: TABLE_PART_META_SORT;
%put ERROR- Description                              : Sort table_partition_meta;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 27SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: TABLE_PART_META_SORT;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"TABLE_PART_META_SORT",
"Sort table_partition_meta",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%TABLE_PART_META_SORT:;
 
 
* End of changes for CHANGE_ID:TABLE_PART_META_SORT;
 
 
***********************************************************************************************;
*************************************  End Change TABLE_PART_META_SORT ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change COMMONLST_FILE ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: COMMONLST_FILE;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("COMMONLST_FILE")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(DI_TRANS)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: DI_TRANS;
%put NOTE: Change ID                             :COMMONLST_FILE;
%goto COMMONLST_FILE;
 
%end;
%if not (%sysfunc(exist(DI_TRANS.TABLE_PARTITION_META))) %then
%do;
%put NOTE: Skip this change since this table does not exist: DI_TRANS.TABLE_PARTITION_META;
%put NOTE: Change ID                             :COMMONLST_FILE;
%goto COMMONLST_FILE;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : COMMONLST_FILE;
%goto COMMONLST_FILE;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : COMMONLST_FILE;
* Insert record into change management table for CHANGE_ID: COMMONLST_FILE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"COMMONLST_FILE",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto COMMONLST_FILE;
 
%end;
 
 
 
 
%put NOTE: Skipping this change since this change should never be applied.;
%put NOTE- Change ID                             :COMMONLST_FILE;
%goto COMMONLST_FILE;
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let DI_MISC_PATH=%di_util_misc_path();
 
 
 
%if %sysfunc(exist(DI_TRANS.TABLE_PARTITION_META))
%then %do;
 
 
filename comm "&DI_MISC_PATH/dbmsc/common-files.lst";
 
 
data _null_;
 
 
file comm lrecl=32000;;
 
 
set di_trans.table_partition_meta (where=(full_copy_flg=1));
 
 
table_nm=lowcase(table_nm);
 
 
 
indfile=trim(table_nm) || ".sas7bdat" ;
 
 
put comm @1 indfile;
 
 
 
if (lowcase(table_nm) not in ("attr_spec","model_data_agg","psychological_points","model_exception","price_point_correction",
"iso_currency","prod_cross_relation") ) then do;
 
 
indfile=trim(table_nm) || ".sas7bndx" ;
 
 
put comm @1 indfile;
 
 
end;
 
 
run;
 
 
filename comm clear;
 
 
 
 
%end;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%let DI_MISC_PATH=%di_util_misc_path();
 
 
 
%if %sysfunc(exist(DI_TRANS.TABLE_PARTITION_META))
%then %do;
 
 
filename comm "&DI_MISC_PATH/dbmsc/common-files.lst";
 
 
data _null_;
 
 
file comm lrecl=32000;;
 
 
set di_trans.table_partition_meta (where=(full_copy_flg=1));
 
 
table_nm=lowcase(table_nm);
 
 
 
indfile=trim(table_nm) || ".sas7bdat" ;
 
 
put comm @1 indfile;
 
 
 
if (lowcase(table_nm) not in ("attr_spec","model_data_agg","psychological_points","model_exception","price_point_correction",
"iso_currency","prod_cross_relation") ) then do;
 
 
indfile=trim(table_nm) || ".sas7bndx" ;
 
 
put comm @1 indfile;
 
 
end;
 
 
run;
 
 
filename comm clear;
 
 
 
 
%end;
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: COMMONLST_FILE;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: COMMONLST_FILE;
%put ERROR- Description                              : Refresh Table Partition Meta;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 05JUN2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: COMMONLST_FILE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"COMMONLST_FILE",
"Refresh Table Partition Meta",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%COMMONLST_FILE:;
 
 
* End of changes for CHANGE_ID:COMMONLST_FILE;
 
 
***********************************************************************************************;
*************************************  End Change COMMONLST_FILE ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change DROP_PACK_OPT_PROD_SETTING ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: DROP_PACK_OPT_PROD_SETTING;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("DROP_PACK_OPT_PROD_SETTING")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PACK_OPT_PROD_SETTING))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PACK_OPT_PROD_SETTING;
%put NOTE: Change ID                             :DROP_PACK_OPT_PROD_SETTING;
%goto DROP_PACK_OPT_PROD_SETTING;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : DROP_PACK_OPT_PROD_SETTING;
%goto DROP_PACK_OPT_PROD_SETTING;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : DROP_PACK_OPT_PROD_SETTING;
* Insert record into change management table for CHANGE_ID: DROP_PACK_OPT_PROD_SETTING;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_PACK_OPT_PROD_SETTING",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto DROP_PACK_OPT_PROD_SETTING;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DROP TABLE PACK_OPT_PROD_SETTING
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DROP TABLE PACK_OPT_PROD_SETTING;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: DROP_PACK_OPT_PROD_SETTING;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: DROP_PACK_OPT_PROD_SETTING;
%put ERROR- Description                              : Drop table PACK_OPT_PROD_SETTING from schema;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 28SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: DROP_PACK_OPT_PROD_SETTING;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_PACK_OPT_PROD_SETTING",
"Drop table PACK_OPT_PROD_SETTING from schema",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%DROP_PACK_OPT_PROD_SETTING:;
 
 
* End of changes for CHANGE_ID:DROP_PACK_OPT_PROD_SETTING;
 
 
***********************************************************************************************;
*************************************  End Change DROP_PACK_OPT_PROD_SETTING ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change DROP_PACK_OPT_PROD_DC_SETTING ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: DROP_PACK_OPT_PROD_DC_SETTING;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("DROP_PACK_OPT_PROD_DC_SETTING")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PACK_OPT_PROD_DC_SETTING))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PACK_OPT_PROD_DC_SETTING;
%put NOTE: Change ID                             :DROP_PACK_OPT_PROD_DC_SETTING;
%goto DROP_PACK_OPT_PROD_DC_SETTING;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : DROP_PACK_OPT_PROD_DC_SETTING;
%goto DROP_PACK_OPT_PROD_DC_SETTING;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : DROP_PACK_OPT_PROD_DC_SETTING;
* Insert record into change management table for CHANGE_ID: DROP_PACK_OPT_PROD_DC_SETTING;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_PACK_OPT_PROD_DC_SETTING",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto DROP_PACK_OPT_PROD_DC_SETTING;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DROP TABLE PACK_OPT_PROD_DC_SETTING
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DROP TABLE PACK_OPT_PROD_DC_SETTING;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: DROP_PACK_OPT_PROD_DC_SETTING;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: DROP_PACK_OPT_PROD_DC_SETTING;
%put ERROR- Description                              : Drop table PACK_OPT_PROD_DC_SETTING from schema;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 28SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: DROP_PACK_OPT_PROD_DC_SETTING;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_PACK_OPT_PROD_DC_SETTING",
"Drop table PACK_OPT_PROD_DC_SETTING from schema",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%DROP_PACK_OPT_PROD_DC_SETTING:;
 
 
* End of changes for CHANGE_ID:DROP_PACK_OPT_PROD_DC_SETTING;
 
 
***********************************************************************************************;
*************************************  End Change DROP_PACK_OPT_PROD_DC_SETTING ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID733917 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID733917;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID733917")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID733917;
%goto ID733917;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID733917;
* Insert record into change management table for CHANGE_ID: ID733917;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID733917",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID733917;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%di_util_drop_constraint(m_lib=DI_TRANS, m_table=RPO_PLAN_MEMBER_RESULT_KPI,m_column=BASE_SALES_UNITS,m_constraint=not null, m_engine=ORACLE);
 
 
%di_util_drop_constraint(m_lib=DI_TRANS, m_table=RPO_PLAN_MEMBER_RESULT_KPI,m_column=BASE_REVENUE_AMT,m_constraint=not null, m_engine=ORACLE);
 
 
%di_util_drop_constraint(m_lib=DI_TRANS, m_table=RPO_PLAN_MEMBER_RESULT_KPI,m_column=BASE_MARGIN_AMT,m_constraint=not null, m_engine=ORACLE);
 
 
%di_util_drop_constraint(m_lib=DI_TRANS, m_table=RPO_PLAN_MEMBER_RESULT_KPI,m_column=BASE_MARGIN_PCT,m_constraint=not null, m_engine=ORACLE);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%di_util_drop_constraint(m_lib=di_trans, m_table=RPO_PLAN_MEMBER_RESULT_KPI, m_column=%str(BASE_SALES_UNITS), m_constraint=%str(not null));
 
 
%di_util_drop_constraint(m_lib=di_trans, m_table=RPO_PLAN_MEMBER_RESULT_KPI, m_column=%str(BASE_REVENUE_AMT), m_constraint=%str(not null));
 
 
%di_util_drop_constraint(m_lib=di_trans, m_table=RPO_PLAN_MEMBER_RESULT_KPI, m_column=%str(BASE_MARGIN_AMT), m_constraint=%str(not null));
 
 
%di_util_drop_constraint(m_lib=di_trans, m_table=RPO_PLAN_MEMBER_RESULT_KPI, m_column=%str(BASE_MARGIN_PCT), m_constraint=%str(not null));
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID733917;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID733917;
%put ERROR- Description                              : Drop NOT NULL Constraints for KPIs in RPO_PLAN_MEMBER_RESULT_KPI;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 28SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID733917;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID733917",
"Drop NOT NULL Constraints for KPIs in RPO_PLAN_MEMBER_RESULT_KPI",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID733917:;
 
 
* End of changes for CHANGE_ID:ID733917;
 
 
***********************************************************************************************;
*************************************  End Change ID733917 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID795430 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID795430;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID795430")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID795430;
%goto ID795430;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID795430;
* Insert record into change management table for CHANGE_ID: ID795430;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID795430",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID795430;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update model_spec set spec_value = '20.0' where spec_nm = 'TS_SEASON_MAX' and model_group_id = -1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update model_spec_default set default_spec_value = '20.0' where spec_nm = 'TS_SEASON_MAX'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update model_spec set spec_value = '10.0' where spec_nm = 'TS_SEASON_VAR' and model_group_id = -1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update model_spec_default set default_spec_value = '10.0' where spec_nm = 'TS_SEASON_VAR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update model_spec set spec_value = '20.0' where spec_nm = 'TS_SEASON_MAX' and model_group_id = -1;
 
 
update model_spec_default set default_spec_value = '20.0' where spec_nm = 'TS_SEASON_MAX';
 
 
update model_spec set spec_value = '10.0' where spec_nm = 'TS_SEASON_VAR' and model_group_id = -1;
 
 
update model_spec_default set default_spec_value = '10.0' where spec_nm = 'TS_SEASON_VAR';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID795430;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID795430;
%put ERROR- Description                              : TS_SEASON_VAR and TS_SEASON_MAX migration - step 1;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 28SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID795430;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID795430",
"TS_SEASON_VAR and TS_SEASON_MAX migration - step 1",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID795430:;
 
 
* End of changes for CHANGE_ID:ID795430;
 
 
***********************************************************************************************;
*************************************  End Change ID795430 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID795430_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID795430_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID795430_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID795430_1;
%goto ID795430_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID795430_1;
* Insert record into change management table for CHANGE_ID: ID795430_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID795430_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID795430_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update model_spec set spec_value = exp(to_number(spec_value))
where spec_nm = 'TS_SEASON_MAX' and model_group_id != -1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
update &m_di_trans..model_spec set spec_value = put(exp(input(spec_value,BEST10.)),BEST10.)
where spec_nm = 'TS_SEASON_MAX' and model_group_id <> -1;
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID795430_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID795430_1;
%put ERROR- Description                              : TS_SEASON_VAR and TS_SEASON_MAX migration - step 2;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 28SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID795430_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID795430_1",
"TS_SEASON_VAR and TS_SEASON_MAX migration - step 2",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID795430_1:;
 
 
* End of changes for CHANGE_ID:ID795430_1;
 
 
***********************************************************************************************;
*************************************  End Change ID795430_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID797643 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID797643;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID797643")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID797643;
%goto ID797643;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID797643;
* Insert record into change management table for CHANGE_ID: ID797643;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID797643",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID797643;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FA_SCORE_FUNC'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from FA_SPEC where SPEC_NM = 'FA_SCORE_FUNC'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FA_SCORE_FUNC';
 
 
delete from FA_SPEC where SPEC_NM = 'FA_SCORE_FUNC';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID797643;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID797643;
%put ERROR- Description                              : Remove FA_SCORE_FUNC FA spec;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 29SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID797643;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID797643",
"Remove FA_SCORE_FUNC FA spec",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID797643:;
 
 
* End of changes for CHANGE_ID:ID797643;
 
 
***********************************************************************************************;
*************************************  End Change ID797643 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID797052 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID797052;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID797052")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID797052;
%goto ID797052;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID797052;
%goto ID797052;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID797052;
* Insert record into change management table for CHANGE_ID: ID797052;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID797052",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID797052;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MAX_PRICE_RATIO'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('MAX_PRICE_RATIO','ALL','1','1.0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('MAX_PRICE_RATIO','ALL','2','1.0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MAX_PRICE_RATIO';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('MAX_PRICE_RATIO','ALL','1','1.0',NULL);
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('MAX_PRICE_RATIO','ALL','2','1.0',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID797052;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID797052;
%put ERROR- Description                              : Surface model spec MAX_PRICE_RATIO for user editing;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 30SEP2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID797052;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID797052",
"Surface model spec MAX_PRICE_RATIO for user editing",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID797052:;
 
 
* End of changes for CHANGE_ID:ID797052;
 
 
***********************************************************************************************;
*************************************  End Change ID797052 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID761590_4 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID761590_4;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID761590_4")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID761590_4;
%goto ID761590_4;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID761590_4;
* Insert record into change management table for CHANGE_ID: ID761590_4;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID761590_4",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID761590_4;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE RPP_METRICS
(
OBJECT_CAT_SK   INTEGER NOT NULL,
OBJECT_CAT_TYPE INTEGER NOT NULL,
PROD_HIER_SK    INTEGER NOT NULL,
GEO_HIER_SK     INTEGER NOT NULL,
START_DT        DATE NOT NULL,
END_DT          DATE NOT NULL,
KPI             INTEGER NOT NULL,
KPI_TYPE        INTEGER NOT NULL,
KPI_VALUE       NUMERIC(20,3) NOT NULL
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPP_METRICS add CONSTRAINT RPP_METRICS_PK
PRIMARY KEY (OBJECT_CAT_SK,OBJECT_CAT_TYPE,PROD_HIER_SK,GEO_HIER_SK,START_DT)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
CREATE TABLE RPP_METRICS
(
OBJECT_CAT_SK   INTEGER NOT NULL,
OBJECT_CAT_TYPE INTEGER NOT NULL,
PROD_HIER_SK    INTEGER NOT NULL,
GEO_HIER_SK     INTEGER NOT NULL,
START_DT        DATE NOT NULL,
END_DT          DATE NOT NULL,
KPI             INTEGER NOT NULL,
KPI_TYPE        INTEGER NOT NULL,
KPI_VALUE       NUMERIC(20,3) NOT NULL
)
;
 
 
 
ALTER TABLE RPP_METRICS add CONSTRAINT RPP_METRICS_PK
PRIMARY KEY (OBJECT_CAT_SK,OBJECT_CAT_TYPE,PROD_HIER_SK,GEO_HIER_SK,START_DT);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID761590_4;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID761590_4;
%put ERROR- Description                              : Table for storing custom metrics for calendar and category plans;
%put ERROR- Version                                  : D3MICM52,M2MI42;
%put ERROR- Date of Change                           : 05OCT2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID761590_4;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID761590_4",
"Table for storing custom metrics for calendar and category plans",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID761590_4:;
 
 
* End of changes for CHANGE_ID:ID761590_4;
 
 
***********************************************************************************************;
*************************************  End Change ID761590_4 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID799648 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID799648;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID799648")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID799648;
%goto ID799648;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID799648;
%goto ID799648;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID799648;
* Insert record into change management table for CHANGE_ID: ID799648;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID799648",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID799648;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'LIMIT_PRICE_RATIO_UPPER'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'LIMIT_PRICE_RATIO_UPPER';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID799648;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID799648;
%put ERROR- Description                              : Remove LIMIT_PRICE_RATIO_UPPER model spec;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 07OCT2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID799648;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID799648",
"Remove LIMIT_PRICE_RATIO_UPPER model spec",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID799648:;
 
 
* End of changes for CHANGE_ID:ID799648;
 
 
***********************************************************************************************;
*************************************  End Change ID799648 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID800510 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID800510;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID800510")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID800510;
%goto ID800510;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID800510;
%goto ID800510;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID800510;
* Insert record into change management table for CHANGE_ID: ID800510;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID800510",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID800510;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '0.01' where SPEC_NM = 'BASELINE_CF_PR1'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '0.01' where SPEC_NM = 'BASELINE_CF_PR1';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID800510;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID800510;
%put ERROR- Description                              : Change default value for model spec BASELINE_CF_PR1 to 0.01;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 11OCT2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID800510;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID800510",
"Change default value for model spec BASELINE_CF_PR1 to 0.01",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID800510:;
 
 
* End of changes for CHANGE_ID:ID800510;
 
 
***********************************************************************************************;
*************************************  End Change ID800510 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID801832 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID801832;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID801832")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID801832;
%goto ID801832;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID801832;
* Insert record into change management table for CHANGE_ID: ID801832;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID801832",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID801832;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
INSERT INTO REQUEST_DELETE (TABLE_NM, DELETE_ORDER) VALUES ('REQ_INVENTORY', 38)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO REQUEST_DELETE (TABLE_NM, DELETE_ORDER) VALUES ('REQ_PACKREC_DELIVERY_TYPE', 39)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO REQUEST_DELETE (TABLE_NM, DELETE_ORDER) VALUES ('REQ_SKU_STORE_MIN', 40)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
INSERT INTO REQUEST_DELETE (TABLE_NM, DELETE_ORDER) VALUES ('REQ_INVENTORY', 38) ;
 
 
INSERT INTO REQUEST_DELETE (TABLE_NM, DELETE_ORDER) VALUES ('REQ_PACKREC_DELIVERY_TYPE', 39) ;
 
 
INSERT INTO REQUEST_DELETE (TABLE_NM, DELETE_ORDER) VALUES ('REQ_SKU_STORE_MIN', 40) ;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID801832;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID801832;
%put ERROR- Description                              : REQUEST_DELETE table needs to be updated to include new REQ_ and RES_ tables;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 17OCT2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID801832;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID801832",
"REQUEST_DELETE table needs to be updated to include new REQ_ and RES_ tables",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID801832:;
 
 
* End of changes for CHANGE_ID:ID801832;
 
 
***********************************************************************************************;
*************************************  End Change ID801832 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID645754 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID645754;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID645754")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID645754;
%goto ID645754;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID645754;
* Insert record into change management table for CHANGE_ID: ID645754;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID645754",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID645754;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE RPP_SPOT_USAGE RENAME COLUMN COUNT TO SPOT_COUNT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc datasets library=&m_di_trans nolist;
 
 
modify RPP_SPOT_USAGE ;
 
 
rename COUNT=SPOT_COUNT;
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID645754;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID645754;
%put ERROR- Description                              : INCORRECTLY USING A DB2 RESERVED WORD AS A COLUMN NAME IN RPP_SPOT_USAGE;
%put ERROR- Version                                  : D3MICM52,M2MI42;
%put ERROR- Date of Change                           : 18OCT2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID645754;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID645754",
"INCORRECTLY USING A DB2 RESERVED WORD AS A COLUMN NAME IN RPP_SPOT_USAGE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID645754:;
 
 
* End of changes for CHANGE_ID:ID645754;
 
 
***********************************************************************************************;
*************************************  End Change ID645754 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID802430 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID802430;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID802430")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID802430;
%goto ID802430;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID802430;
* Insert record into change management table for CHANGE_ID: ID802430;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID802430",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID802430;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 29
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GEO_PROD_SETTING(
GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,
SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (29,1,1,1,54,0,1,0,9999,1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 30
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GEO_PROD_SETTING(
GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,
SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES(30,1,1,1,55,0,1,0,9999,1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 29 ;
 
 
INSERT INTO GEO_PROD_SETTING(
GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,
SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (29,1,1,1,54,0,1,0,9999,1);
 
 
 
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 30 ;
 
 
INSERT INTO GEO_PROD_SETTING(
GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,
SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES(30,1,1,1,55,0,1,0,9999,1);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID802430;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID802430;
%put ERROR- Description                              : GEO_PROD_SETTING rows for MDO forced markdown and low demand discount price point rules;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 18OCT2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID802430;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID802430",
"GEO_PROD_SETTING rows for MDO forced markdown and low demand discount price point rules",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID802430:;
 
 
* End of changes for CHANGE_ID:ID802430;
 
 
***********************************************************************************************;
*************************************  End Change ID802430 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0806946 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0806946;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0806946")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0806946;
%goto ID0806946;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0806946;
* Insert record into change management table for CHANGE_ID: ID0806946;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0806946",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0806946;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='DEMAND_DISAGG_FACTOR';
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency , purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('DEMAND_DISAGG_FACTOR',          'SAS',1, 9999,'%szpk_purge_demand_disagg_factors();',                                     1095,0,'SZPK');
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='PKO_PURCHASE_ORDER_PLAN';
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency , purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('PKO_PURCHASE_ORDER_PLAN',          'SAS',1, 9999,'%szpk_purge_po_plans();',                                     1095,0,'SZPF');
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='DEMAND_DISAGG_FACTOR';
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency , purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('DEMAND_DISAGG_FACTOR',          'SAS',1, 9999,'%szpk_purge_demand_disagg_factors();',                                     1095,0,'SZPK');
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='PKO_PURCHASE_ORDER_PLAN';
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency , purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('PKO_PURCHASE_ORDER_PLAN',          'SAS',1, 9999,'%szpk_purge_po_plans();',                                     1095,0,'SZPF');
 
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0806946;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0806946;
%put ERROR- Description                              : Add two purge jobs to purge_query table for Pack Optimization;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 08NOV2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0806946;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0806946",
"Add two purge jobs to purge_query table for Pack Optimization",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0806946:;
 
 
* End of changes for CHANGE_ID:ID0806946;
 
 
***********************************************************************************************;
*************************************  End Change ID0806946 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID808451 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID808451;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID808451")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID808451;
%goto ID808451;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52, M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID808451;
* Insert record into change management table for CHANGE_ID: ID808451;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID808451",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID808451;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='GEO_PROD_VAT';
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency , purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('GEO_PROD_VAT','SAS',1,91,'%di_purge_geo_prod_vat(libref=DI_DM);',1103,0,'ALL');
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='GEO_PROD_VAT';
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency , purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('GEO_PROD_VAT','SAS',1,91,'%di_purge_geo_prod_vat(libref=DI_DM);',1103,0,'ALL');
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID808451;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID808451;
%put ERROR- Description                              : Add purge job for GEO_PROD_VAT;
%put ERROR- Version                                  : D3MICM52, M2MI42;
%put ERROR- Date of Change                           : 09NOV2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID808451;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID808451",
"Add purge job for GEO_PROD_VAT",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID808451:;
 
 
* End of changes for CHANGE_ID:ID808451;
 
 
***********************************************************************************************;
*************************************  End Change ID808451 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID809391 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID809391;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID809391")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID809391;
%goto ID809391;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID809391;
* Insert record into change management table for CHANGE_ID: ID809391;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID809391",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID809391;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE ATTR_PROD_HIER_KEYS
(
PARTITION_SK   INTEGER NOT NULL,
START_SK       INTEGER NOT NULL,
END_SK         INTEGER NOT NULL,
STATUS         INTEGER NOT NULL,
DTTM           DATE
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE ATTR_PROD_HIER_KEYS add CONSTRAINT PARTITION_SK PRIMARY KEY (PARTITION_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
PROC SQL;
 
 
CREATE TABLE ATTR_PROD_HIER_KEYS
(
PARTITION_SK   INTEGER NOT NULL,
START_SK       INTEGER NOT NULL,
END_SK         INTEGER NOT NULL,
STATUS         INTEGER NOT NULL,
DTTM           DATE
)
;
 
 
 
ALTER TABLE ATTR_PROD_HIER_KEYS add CONSTRAINT PRIM_KEY PRIMARY KEY (PARTITION_SK);
 
 
QUIT;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID809391;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID809391;
%put ERROR- Description                              : Attribute hierarchy keys;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 10NOV2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID809391;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID809391",
"Attribute hierarchy keys",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID809391:;
 
 
* End of changes for CHANGE_ID:ID809391;
 
 
***********************************************************************************************;
*************************************  End Change ID809391 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change TABLE_META_01 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: TABLE_META_01;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("TABLE_META_01")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : TABLE_META_01;
%goto TABLE_META_01;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : TABLE_META_01;
* Insert record into change management table for CHANGE_ID: TABLE_META_01;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"TABLE_META_01",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto TABLE_META_01;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
create table TABLE_META
(
TABLE_NAME       VARCHAR(30),
LIBNAMES         VARCHAR(30),
TABLESPACE       VARCHAR(30),
LOGGING          VARCHAR(10),
PARTITION_CD     INTEGER,
COMPONENT_CD     INTEGER,
APP_MDO          INTEGER,
APP_RPO          INTEGER,
APP_RPP          INTEGER,
APP_SZPF         INTEGER,
APP_SZPK         INTEGER,
APP_FCST         INTEGER
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE TABLE_META add CONSTRAINT TABLE_NAME PRIMARY KEY (TABLE_NAME)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
PROC SQL;
 
 
create table TABLE_META
(
TABLE_NAME       VARCHAR(30),
LIBNAMES         VARCHAR(30),
TABLESPACE       VARCHAR(30),
LOGGING          VARCHAR(10),
PARTITION_CD     INTEGER,
COMPONENT_CD     INTEGER,
APP_MDO          INTEGER,
APP_RPO          INTEGER,
APP_RPP          INTEGER,
APP_SZPF         INTEGER,
APP_SZPK         INTEGER,
APP_FCST         INTEGER
);
 
 
ALTER TABLE TABLE_META add CONSTRAINT PRIM_KEY PRIMARY KEY (TABLE_NAME);
 
 
QUIT;
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: TABLE_META_01;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: TABLE_META_01;
%put ERROR- Description                              : Metadata about each table;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 10NOV2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: TABLE_META_01;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"TABLE_META_01",
"Metadata about each table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%TABLE_META_01:;
 
 
* End of changes for CHANGE_ID:TABLE_META_01;
 
 
***********************************************************************************************;
*************************************  End Change TABLE_META_01 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change SEED_TABLE_META ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: SEED_TABLE_META;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("SEED_TABLE_META")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%put NOTE: This change will be applied on every run : SEED_TABLE_META;
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%seed_table_meta(m_seed=TRUE);
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
%seed_table_meta(m_seed=TRUE);
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: SEED_TABLE_META;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: SEED_TABLE_META;
%put ERROR- Description                              : Seed values for di_dm2.table_meta table;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 21NOV2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: SEED_TABLE_META;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"SEED_TABLE_META",
"Seed values for di_dm2.table_meta table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%SEED_TABLE_META:;
 
 
* End of changes for CHANGE_ID:SEED_TABLE_META;
 
 
***********************************************************************************************;
*************************************  End Change SEED_TABLE_META ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID807460 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID807460;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID807460")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID807460;
%goto ID807460;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID807460;
%goto ID807460;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID807460;
* Insert record into change management table for CHANGE_ID: ID807460;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID807460",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID807460;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'TRAINING_P'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('TRAINING_P','ALL','-1','1.0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'VALIDATION_P'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('VALIDATION_P','ALL','-1','0.0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'TRAINING_P';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('TRAINING_P','ALL','-1','1.0',NULL);
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'VALIDATION_P';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('VALIDATION_P','ALL','-1','0.0',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID807460;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID807460;
%put ERROR- Description                              : Support model specs TRAINING_P and VALIDATION_P;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 14NOV2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID807460;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID807460",
"Support model specs TRAINING_P and VALIDATION_P",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID807460:;
 
 
* End of changes for CHANGE_ID:ID807460;
 
 
***********************************************************************************************;
*************************************  End Change ID807460 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID810776 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID810776;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID810776")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID810776;
%goto ID810776;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID810776;
* Insert record into change management table for CHANGE_ID: ID810776;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID810776",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID810776;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT ADD NUM_MARKDN_PRODS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT ADD NUM_MARKDN_GEOS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT ADD NUM_MARKDN_PRODS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT ADD NUM_MARKDN_GEOS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE MPLN_RESULT ADD NUM_MARKDN_PRODS INTEGER;
 
 
ALTER TABLE MPLN_RESULT ADD NUM_MARKDN_GEOS INTEGER;
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD NUM_MARKDN_PRODS INTEGER;
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD NUM_MARKDN_GEOS INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID810776;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID810776;
%put ERROR- Description                              : Add columns for affected product and location counts;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 16NOV2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID810776;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID810776",
"Add columns for affected product and location counts",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID810776:;
 
 
* End of changes for CHANGE_ID:ID810776;
 
 
***********************************************************************************************;
*************************************  End Change ID810776 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID811896 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID811896;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID811896")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID811896;
%goto ID811896;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID811896;
%goto ID811896;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID811896;
* Insert record into change management table for CHANGE_ID: ID811896;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID811896",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID811896;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'BASELINE_OFFSET_VALUE' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASELINE_OFFSET_VALUE' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC where SPEC_NM = 'BASELINE_OFFSET_VALUE' and SPEC_TYPE = '2';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASELINE_OFFSET_VALUE' and SPEC_TYPE = '2';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID811896;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID811896;
%put ERROR- Description                              : Remove model spec BASELINE_OFFSET_VALUE from share model;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 23NOV2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID811896;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID811896",
"Remove model spec BASELINE_OFFSET_VALUE from share model",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID811896:;
 
 
* End of changes for CHANGE_ID:ID811896;
 
 
***********************************************************************************************;
*************************************  End Change ID811896 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID809394 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID809394;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID809394")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..TABLE_PARTITION_META))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..TABLE_PARTITION_META;
%put NOTE: Change ID                             :ID809394;
%goto ID809394;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID809394;
%goto ID809394;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID809394;
* Insert record into change management table for CHANGE_ID: ID809394;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID809394",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID809394;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update TABLE_PARTITION_META
set partition_flg = 0
where table_nm in ('ATTR_PROD_DM','ATTR_PROD_HIER_ASSOC_DM')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update TABLE_PARTITION_META
set partition_flg = 0
where table_nm in ('ATTR_PROD_DM','ATTR_PROD_HIER_ASSOC_DM');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID809394;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID809394;
%put ERROR- Description                              : Remove ATTR_PROD_DM and ATTR_PROD_HIER_ASSOC_DM from partition process;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 28NOV2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID809394;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID809394",
"Remove ATTR_PROD_DM and ATTR_PROD_HIER_ASSOC_DM from partition process",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID809394:;
 
 
* End of changes for CHANGE_ID:ID809394;
 
 
***********************************************************************************************;
*************************************  End Change ID809394 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0804309 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0804309;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0804309")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0804309;
%goto ID0804309;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0804309;
* Insert record into change management table for CHANGE_ID: ID0804309;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0804309",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0804309;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='PROFILE';
 
 
INSERT INTO &m_di_trans..PURGE_QUERY (table_nm, database_nm, purge_order, purge_frequency, purge_query_txt, num_days_preserved, partition_flg, app_nm)
VALUES ('PROFILE', 'RDBMS', 1, 9999, '%szpf_purge_published_profiles();', 1095, 0, 'SZPF');
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='PROFILE';
 
 
INSERT INTO &m_di_trans..PURGE_QUERY (table_nm, database_nm, purge_order, purge_frequency, purge_query_txt, num_days_preserved, partition_flg, app_nm)
VALUES ('PROFILE', 'RDBMS', 1, 9999, '%szpf_purge_published_profiles();', 1095, 0, 'SZPF');
 
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0804309;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0804309;
%put ERROR- Description                              : Add purge job for published profiles;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 02DEC2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0804309;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0804309",
"Add purge job for published profiles",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0804309:;
 
 
* End of changes for CHANGE_ID:ID0804309;
 
 
***********************************************************************************************;
*************************************  End Change ID0804309 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID812606 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID812606;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID812606")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID812606;
%goto ID812606;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52, M1MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID812606;
* Insert record into change management table for CHANGE_ID: ID812606;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID812606",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID812606;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
options user = work;
 
 
 
%di_etl_repair_data(partition = 1);
 
 
 
options user = &m_di_trans;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
options user = work;
 
 
 
%di_etl_repair_data(partition = 1);
 
 
 
options user = &m_di_trans;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID812606;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID812606;
%put ERROR- Description                              : Sorting and indexing the partition tables migrated from 4.3;
%put ERROR- Version                                  : D3MICM52, M1MI42;
%put ERROR- Date of Change                           : 05DEC2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID812606;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID812606",
"Sorting and indexing the partition tables migrated from 4.3",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID812606:;
 
 
* End of changes for CHANGE_ID:ID812606;
 
 
***********************************************************************************************;
*************************************  End Change ID812606 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID741526 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID741526;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID741526")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID741526;
%goto ID741526;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID741526;
* Insert record into change management table for CHANGE_ID: ID741526;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID741526",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID741526;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY where table_nm = 'GEO_PROD_OWNED_INV';
 
 
INSERT INTO &m_di_trans..purge_query (table_nm ,database_nm ,purge_order ,purge_frequency , purge_query_txt,
num_days_preserved ,partition_flg ,app_nm)
VALUES ('GEO_PROD_OWNED_INV', 'SAS',15, 28,'%di_purge_geo_prod_owned_inv(libref=DI_DM);', 0,1,'CPO');
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY where table_nm = 'GEO_PROD_OWNED_INV';
 
 
INSERT INTO &m_di_trans..purge_query (table_nm ,database_nm ,purge_order ,purge_frequency , purge_query_txt,
num_days_preserved ,partition_flg ,app_nm)
VALUES ('GEO_PROD_OWNED_INV', 'SAS',15, 28,'%di_purge_geo_prod_owned_inv(libref=DI_DM);', 0,1,'CPO');
 
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID741526;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID741526;
%put ERROR- Description                              : Purge deleted records from Geo_prod_owned_inv partitions;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 08DEC2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID741526;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID741526",
"Purge deleted records from Geo_prod_owned_inv partitions",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID741526:;
 
 
* End of changes for CHANGE_ID:ID741526;
 
 
***********************************************************************************************;
*************************************  End Change ID741526 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID808700 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID808700;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID808700")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID808700;
%goto ID808700;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID808700;
* Insert record into change management table for CHANGE_ID: ID808700;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID808700",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID808700;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TAG VARCHAR(40)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD TAG VARCHAR(40)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD TAG VARCHAR(40)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TAG VARCHAR(40);
 
 
ALTER TABLE PKO_BUY ADD TAG VARCHAR(40);
 
 
ALTER TABLE PKO_DELIVERY ADD TAG VARCHAR(40);
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID808700;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID808700;
%put ERROR- Description                              : Add tags to purchase order plans;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 15DEC2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID808700;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID808700",
"Add tags to purchase order plans",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID808700:;
 
 
* End of changes for CHANGE_ID:ID808700;
 
 
***********************************************************************************************;
*************************************  End Change ID808700 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID819669 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID819669;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID819669")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID819669;
%goto ID819669;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID819669;
* Insert record into change management table for CHANGE_ID: ID819669;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID819669",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID819669;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PRICE_GRID MODIFY PRICE_VALUE_SUMMARY_LIST VARCHAR2(4000)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRICE_GRID MODIFY PRICE_ENDING_SUMMARY_LIST VARCHAR2(4000)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN MODIFY PRICE_VALUE_LIST VARCHAR2(4000)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN MODIFY PRICE_ENDING_LIST VARCHAR2(4000)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
ALTER TABLE PRICE_GRID MODIFY PRICE_VALUE_SUMMARY_LIST VARCHAR(4000);
 
 
ALTER TABLE PRICE_GRID MODIFY PRICE_ENDING_SUMMARY_LIST VARCHAR(4000);
 
 
ALTER TABLE MDO_PLAN MODIFY PRICE_VALUE_LIST VARCHAR(4000);
 
 
ALTER TABLE MDO_PLAN MODIFY PRICE_ENDING_LIST VARCHAR(4000);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID819669;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID819669;
%put ERROR- Description                              : Increase column lengths for price grid and price ending strings;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 16DEC2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID819669;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID819669",
"Increase column lengths for price grid and price ending strings",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID819669:;
 
 
* End of changes for CHANGE_ID:ID819669;
 
 
***********************************************************************************************;
*************************************  End Change ID819669 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0819818 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0819818;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0819818")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0819818;
%goto ID0819818;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0819818;
* Insert record into change management table for CHANGE_ID: ID0819818;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0819818",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0819818;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='PROFILE';
 
 
INSERT INTO &m_di_trans..PURGE_QUERY (table_nm, database_nm, purge_order, purge_frequency, purge_query_txt, num_days_preserved, partition_flg, app_nm)
VALUES ('PROFILE', 'RDBMS', 1, 9999, '%szpf_purge_published_profiles();', 1095, 0, 'ALL');
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM &m_di_trans..PURGE_QUERY WHERE TABLE_NM='PROFILE';
 
 
INSERT INTO &m_di_trans..PURGE_QUERY (table_nm, database_nm, purge_order, purge_frequency, purge_query_txt, num_days_preserved, partition_flg, app_nm)
VALUES ('PROFILE', 'RDBMS', 1, 9999, '%szpf_purge_published_profiles();', 1095, 0, 'ALL');
 
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0819818;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0819818;
%put ERROR- Description                              : PROFILE publish job should have ALL as APP_NM in Purge_Query table;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 16DEC2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0819818;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0819818",
"PROFILE publish job should have ALL as APP_NM in Purge_Query table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0819818:;
 
 
* End of changes for CHANGE_ID:ID0819818;
 
 
***********************************************************************************************;
*************************************  End Change ID0819818 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0818694 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0818694;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0818694")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0818694;
%goto ID0818694;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0818694;
* Insert record into change management table for CHANGE_ID: ID0818694;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0818694",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0818694;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
 
UPDATE GEO_PROD_SETTING SET SETTING_VAL=1 where SETTING_TYPE in (51,52) and SETTING_VAL=0;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
UPDATE GEO_PROD_SETTING SET SETTING_VAL=1 where SETTING_TYPE in (51,52) and SETTING_VAL=0;
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0818694;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0818694;
%put ERROR- Description                              : Correct seed values for uniform timing rules in GEO_PROD_SETTING SETTING_VAL;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 22DEC2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0818694;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0818694",
"Correct seed values for uniform timing rules in GEO_PROD_SETTING SETTING_VAL",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0818694:;
 
 
* End of changes for CHANGE_ID:ID0818694;
 
 
***********************************************************************************************;
*************************************  End Change ID0818694 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0719381 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0719381;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0719381")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0719381;
%goto ID0719381;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0719381;
* Insert record into change management table for CHANGE_ID: ID0719381;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0719381",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0719381;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'PROMOTION_FACT_FUTURE';
 
 
quit;
 
 
 
proc sql;
 
 
delete from PURGE_QUERY where TABLE_NM='PROMOTION_FACT_FUTURE';
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'PROMOTION_FACT_FUTURE';
 
 
quit;
 
 
 
proc sql;
 
 
delete from PURGE_QUERY where TABLE_NM='PROMOTION_FACT_FUTURE';
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0719381;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0719381;
%put ERROR- Description                              : Removing entries for PROMOTION_FACT_FUTURE;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 26DEC2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0719381;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0719381",
"Removing entries for PROMOTION_FACT_FUTURE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0719381:;
 
 
* End of changes for CHANGE_ID:ID0719381;
 
 
***********************************************************************************************;
*************************************  End Change ID0719381 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0817138 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0817138;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0817138")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0817138;
%goto ID0817138;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52, M2MI42);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0817138;
* Insert record into change management table for CHANGE_ID: ID0817138;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0817138",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0817138;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE RPP_PLAN_PROD_ASGMNT PPA
SET FCST_UNITS_ADJUST_TYPE = (SELECT FCST_UNITS_ADJUST_TYPE FROM RPP_PLAN P WHERE P.PLAN_SK = PPA.PLAN_SK)
WHERE FCST_UNITS_ADJUST IS NULL OR FCST_UNITS_ADJUST = 0
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE RPP_PLAN_PROD_ASGMNT PPA
SET FCST_UNITS_ADJUST = (SELECT FCST_UNITS_ADJUST FROM RPP_PLAN P WHERE P.PLAN_SK = PPA.PLAN_SK)
WHERE FCST_UNITS_ADJUST IS NULL OR FCST_UNITS_ADJUST = 0
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
UPDATE RPP_PLAN_PROD_ASGMNT PPA
SET FCST_UNITS_ADJUST_TYPE = (SELECT FCST_UNITS_ADJUST_TYPE FROM RPP_PLAN P WHERE P.PLAN_SK = PPA.PLAN_SK)
WHERE FCST_UNITS_ADJUST IS NULL OR FCST_UNITS_ADJUST = 0 ;
 
 
 
UPDATE RPP_PLAN_PROD_ASGMNT PPA
SET FCST_UNITS_ADJUST = (SELECT FCST_UNITS_ADJUST FROM RPP_PLAN P WHERE P.PLAN_SK = PPA.PLAN_SK)
WHERE FCST_UNITS_ADJUST IS NULL OR FCST_UNITS_ADJUST = 0 ;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0817138;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0817138;
%put ERROR- Description                              : Need to add alter to move promo forecast override to product level;
%put ERROR- Version                                  : D3MICM52, M2MI42;
%put ERROR- Date of Change                           : 06JAN2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0817138;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0817138",
"Need to add alter to move promo forecast override to product level",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0817138:;
 
 
* End of changes for CHANGE_ID:ID0817138;
 
 
***********************************************************************************************;
*************************************  End Change ID0817138 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0826002 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0826002;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0826002")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0826002;
%goto ID0826002;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52,F2TKMI43);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0826002;
* Insert record into change management table for CHANGE_ID: ID0826002;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0826002",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0826002;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE INDEX MPLN_GPR_UT_IX ON MPLN_GEO_PROD_RESULT
(
MDO_PLAN_SK,
AGG_CD,
UT_PROD_HIER_SK,
UT_GEO_HIER_SK
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
CREATE INDEX MPLN_GPR_UT_IX ON MPLN_GEO_PROD_RESULT
(
MDO_PLAN_SK,
AGG_CD,
UT_PROD_HIER_SK,
UT_GEO_HIER_SK
);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0826002;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0826002;
%put ERROR- Description                              : Add index on table mpln_geo_prod_result;
%put ERROR- Version                                  : D3MICM52,F2TKMI43;
%put ERROR- Date of Change                           : 17JAN2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0826002;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0826002",
"Add index on table mpln_geo_prod_result",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0826002:;
 
 
* End of changes for CHANGE_ID:ID0826002;
 
 
***********************************************************************************************;
*************************************  End Change ID0826002 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0828974 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0828974;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0828974")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..VEHICLE_CATEGORY))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..VEHICLE_CATEGORY;
%put NOTE: Change ID                             :ID0828974;
%goto ID0828974;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0828974;
%goto ID0828974;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0828974;
* Insert record into change management table for CHANGE_ID: ID0828974;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0828974",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0828974;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let _cnt_psy_points=0;
 
 
 
proc sql noprint;
 
 
select count(*)
into :_cnt_psy_points
from &m_di_trans..vehicle_category
where vehicle_category_sk=199
;
 
 
quit;
 
 
 
%if &_cnt_psy_points = 0 %then
%do;
 
 
 
proc sql noprint;
 
 
 
INSERT INTO &m_di_trans..vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG,
PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (199, 'PSYCHOLOGICAL_POINTS', 'Psychological points only (Do not use for promotions!)', 0, 0, 'PSY_POINTS');
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%let _cnt_psy_points=0;
 
 
 
proc sql noprint;
 
 
select count(*)
into :_cnt_psy_points
from &m_di_trans..vehicle_category
where vehicle_category_sk=199
;
 
 
quit;
 
 
 
%if &_cnt_psy_points = 0 %then
%do;
 
 
 
proc sql noprint;
 
 
 
INSERT INTO &m_di_trans..vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG,
PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (199, 'PSYCHOLOGICAL_POINTS', 'Psychological points only (Do not use for promotions!)', 0, 0, 'PSY_POINTS');
 
 
 
%end;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0828974;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0828974;
%put ERROR- Description                              : Vehicle category seed for psychological points;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 02FEB2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0828974;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0828974",
"Vehicle category seed for psychological points",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0828974:;
 
 
* End of changes for CHANGE_ID:ID0828974;
 
 
***********************************************************************************************;
*************************************  End Change ID0828974 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID831464 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID831464;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID831464")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID831464;
%goto ID831464;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID831464;
%goto ID831464;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID831464;
* Insert record into change management table for CHANGE_ID: ID831464;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID831464",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID831464;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = 'NONE' where SPEC_NM = 'FCST_ZEROMISS' and SPEC_TYPE = '1'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_ZEROMISS' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('FCST_ZEROMISS','FCST','2','NONE',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = 'NONE' where SPEC_NM = 'FCST_ZEROMISS' and SPEC_TYPE = '1';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'FCST_ZEROMISS' and SPEC_TYPE = '2';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('FCST_ZEROMISS','FCST','2','NONE',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID831464;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID831464;
%put ERROR- Description                              : Change default value for FCST_ZEROMISS to NONE;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 06FEB2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID831464;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID831464",
"Change default value for FCST_ZEROMISS to NONE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID831464:;
 
 
* End of changes for CHANGE_ID:ID831464;
 
 
***********************************************************************************************;
*************************************  End Change ID831464 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID833633 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID833633;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID833633")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID833633;
%goto ID833633;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID833633;
%goto ID833633;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID833633;
* Insert record into change management table for CHANGE_ID: ID833633;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID833633",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID833633;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'MISC_ADJ_STATUS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MISC_ADJ_STATUS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC where SPEC_NM = 'MISC_ADJ_STATUS';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MISC_ADJ_STATUS';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID833633;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID833633;
%put ERROR- Description                              : Remove model spec MISC_ADJ_STATUS;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 06FEB2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID833633;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID833633",
"Remove model spec MISC_ADJ_STATUS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID833633:;
 
 
* End of changes for CHANGE_ID:ID833633;
 
 
***********************************************************************************************;
*************************************  End Change ID833633 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID833236 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID833236;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID833236")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID833236;
%goto ID833236;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID833236;
%goto ID833236;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID833236;
* Insert record into change management table for CHANGE_ID: ID833236;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID833236",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID833236;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY in
('ARP','M_ARP','RRP','CARP','CRRP')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from SCORING_PARAM_CONFIG where EFFECT_CATEGORY in
('ARP','M_ARP','RRP','CARP','CRRP')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY in
('ARP','M_ARP','RRP','CARP','CRRP');
 
 
delete from SCORING_PARAM_CONFIG where EFFECT_CATEGORY in
('ARP','M_ARP','RRP','CARP','CRRP');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID833236;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID833236;
%put ERROR- Description                              : Remove ARP, M_ARP, RRP, CARP and CRRP scoring parameter defaults;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 13FEB2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID833236;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID833236",
"Remove ARP, M_ARP, RRP, CARP and CRRP scoring parameter defaults",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID833236:;
 
 
* End of changes for CHANGE_ID:ID833236;
 
 
***********************************************************************************************;
*************************************  End Change ID833236 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID832370 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID832370;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID832370")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID832370;
%goto ID832370;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID832370;
* Insert record into change management table for CHANGE_ID: ID832370;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID832370",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID832370;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
 
DELETE from &m_di_trans..purge_query
where table_nm in ('CLEAN_ATTR_HIER_PROD','CLEAN_ATTR_HIER_GEO');
 
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('CLEAN_ATTR_HIER_PROD', 'SAS', 1, 9999,'%di_purge_dangling_nodes_attr(hier_type=1);',0,1,'ALL');
 
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('CLEAN_ATTR_HIER_GEO', 'SAS', 1, 9999,'%di_purge_dangling_nodes_attr(hier_type=2);',0,1,'ALL');
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
DELETE from &m_di_trans..purge_query
where table_nm in ('CLEAN_ATTR_HIER_PROD','CLEAN_ATTR_HIER_GEO');
 
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('CLEAN_ATTR_HIER_PROD', 'SAS', 1, 9999,'%di_purge_dangling_nodes_attr(hier_type=1);',0,1,'ALL');
 
 
 
INSERT INTO &m_di_trans..purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('CLEAN_ATTR_HIER_GEO', 'SAS', 1, 9999,'%di_purge_dangling_nodes_attr(hier_type=2);',0,1,'ALL');
 
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID832370;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID832370;
%put ERROR- Description                              : Add purge job to remove dangling nodes from Analytical hierarchies;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 14FEB2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID832370;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID832370",
"Add purge job to remove dangling nodes from Analytical hierarchies",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID832370:;
 
 
* End of changes for CHANGE_ID:ID832370;
 
 
***********************************************************************************************;
*************************************  End Change ID832370 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID833232 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID833232;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID833232")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID833232;
%goto ID833232;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC;
%put NOTE: Change ID                             :ID833232;
%goto ID833232;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID833232;
%goto ID833232;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID833232;
* Insert record into change management table for CHANGE_ID: ID833232;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID833232",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID833232;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASELINE_CF_PR1' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASELINE_OFFSET_NBINS' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASELINE_OFFSET_PCTILE' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'COMPUTE_BASELINE_OFFSET' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASELINE_OFFSET_TYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'TS_BASELINE_OFFSET' and SPEC_TYPE = '-1'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'USE_BASELINE_CF' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'BASELINE_CF_PR1' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'BASELINE_OFFSET_NBINS' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'BASELINE_OFFSET_PCTILE' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'COMPUTE_BASELINE_OFFSET' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'BASELINE_OFFSET_TYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'TS_BASELINE_OFFSET' and SPEC_TYPE = '-1'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'USE_BASELINE_CF' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASELINE_CF_PR1' and SPEC_TYPE = '2';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASELINE_OFFSET_NBINS' and SPEC_TYPE = '2';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASELINE_OFFSET_PCTILE' and SPEC_TYPE = '2';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'COMPUTE_BASELINE_OFFSET' and SPEC_TYPE = '2';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BASELINE_OFFSET_TYPE';
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'TS_BASELINE_OFFSET' and SPEC_TYPE = '-1';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'USE_BASELINE_CF' and SPEC_TYPE = '2';
 
 
 
delete from MODEL_SPEC where SPEC_NM = 'BASELINE_CF_PR1' and SPEC_TYPE = '2';
 
 
delete from MODEL_SPEC where SPEC_NM = 'BASELINE_OFFSET_NBINS' and SPEC_TYPE = '2';
 
 
delete from MODEL_SPEC where SPEC_NM = 'BASELINE_OFFSET_PCTILE' and SPEC_TYPE = '2';
 
 
delete from MODEL_SPEC where SPEC_NM = 'COMPUTE_BASELINE_OFFSET' and SPEC_TYPE = '2';
 
 
delete from MODEL_SPEC where SPEC_NM = 'BASELINE_OFFSET_TYPE';
 
 
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'TS_BASELINE_OFFSET' and SPEC_TYPE = '-1';
 
 
delete from MODEL_SPEC where SPEC_NM = 'USE_BASELINE_CF' and SPEC_TYPE = '2';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID833232;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID833232;
%put ERROR- Description                              : Change 6 baseline offset model specs to DIRECT model only; delete BASELINE_OFFSET_TYPE;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 14FEB2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID833232;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID833232",
"Change 6 baseline offset model specs to DIRECT model only; delete BASELINE_OFFSET_TYPE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID833232:;
 
 
* End of changes for CHANGE_ID:ID833232;
 
 
***********************************************************************************************;
*************************************  End Change ID833232 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID834613 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID834613;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID834613")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID834613;
%goto ID834613;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID834613;
* Insert record into change management table for CHANGE_ID: ID834613;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID834613",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID834613;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE INDEX PKO_DELIVERY_IDX1 ON PKO_DELIVERY (BUY_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX PKO_STORE_NEED_IDX1 ON PKO_STORE_NEED (DELIVERY_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
CREATE INDEX BUY_SK ON PKO_DELIVERY (BUY_SK);
 
 
 
CREATE INDEX DELIVERY_SK ON PKO_STORE_NEED (DELIVERY_SK);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID834613;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID834613;
%put ERROR- Description                              : navigating purchase order plan objects is slow with a lot of plans;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 16FEB2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID834613;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID834613",
"navigating purchase order plan objects is slow with a lot of plans",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID834613:;
 
 
* End of changes for CHANGE_ID:ID834613;
 
 
***********************************************************************************************;
*************************************  End Change ID834613 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID834906 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID834906;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID834906")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID834906;
%goto ID834906;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC;
%put NOTE: Change ID                             :ID834906;
%goto ID834906;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID834906;
%goto ID834906;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID834906;
* Insert record into change management table for CHANGE_ID: ID834906;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID834906",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID834906;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'EFF_REF_PRICE_RATIO_MIN'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('EFF_REF_PRICE_RATIO_MIN','ALL','-1','0.0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'EFF_REF_PRICE_RATIO_MIN'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'ALL','EFF_REF_PRICE_RATIO_MIN','-1','0.0',NULL,NULL,'SEED')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'EFF_REF_PRICE_RATIO_MAX'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('EFF_REF_PRICE_RATIO_MAX','ALL','-1','1000000.0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'EFF_REF_PRICE_RATIO_MAX'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'ALL','EFF_REF_PRICE_RATIO_MAX','-1','1000000.0',NULL,NULL,'SEED')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'EFF_REF_PRICE_RATIO_MIN';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('EFF_REF_PRICE_RATIO_MIN','ALL','-1','0.0',NULL);
 
 
delete from MODEL_SPEC where SPEC_NM = 'EFF_REF_PRICE_RATIO_MIN';
 
 
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'ALL','EFF_REF_PRICE_RATIO_MIN','-1','0.0',NULL,NULL,'SEED');
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'EFF_REF_PRICE_RATIO_MAX';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('EFF_REF_PRICE_RATIO_MAX','ALL','-1','1000000.0',NULL);
 
 
delete from MODEL_SPEC where SPEC_NM = 'EFF_REF_PRICE_RATIO_MAX';
 
 
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'ALL','EFF_REF_PRICE_RATIO_MAX','-1','1000000.0',NULL,NULL,'SEED');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID834906;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID834906;
%put ERROR- Description                              : Add model specs EFF_REF_PRICE_RATIO_MIN and EFF_REF_PRICE_RATIO_MAX;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 17FEB2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID834906;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID834906",
"Add model specs EFF_REF_PRICE_RATIO_MIN and EFF_REF_PRICE_RATIO_MAX",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID834906:;
 
 
* End of changes for CHANGE_ID:ID834906;
 
 
***********************************************************************************************;
*************************************  End Change ID834906 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID836365B ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID836365B;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID836365B")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID836365B;
%goto ID836365B;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID836365B;
* Insert record into change management table for CHANGE_ID: ID836365B;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID836365B",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID836365B;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
 
%if (%di_util_varexist(dsname=&m_di_trans..ALERT_COST, varname=CREATED_DTTM)=0) %then
%do;
 
 
 
%let m_sql_statement = %str(
ALTER TABLE ALERT_COST RENAME COLUMN CREATED_DT TO CREATED_DTTM
);
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
 
 
%if (%di_util_varexist(dsname=&m_di_trans..ALERT_COMP, varname=CREATED_DTTM)=0) %then
%do;
 
 
 
%let m_sql_statement = %str(
ALTER TABLE ALERT_COMP RENAME COLUMN CREATED_DT TO CREATED_DTTM
);
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
 
%if (%di_util_varexist(dsname=&m_di_trans..ALERT_NEW_PROD, varname=CREATED_DTTM)=0) %then
%do;
 
 
 
%let m_sql_statement = %str(
ALTER TABLE ALERT_NEW_PROD RENAME COLUMN CREATED_DT TO CREATED_DTTM
);
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
%if (%di_util_varexist(dsname=&m_di_trans..ALERT_COST, varname=CREATED_DTTM)=0) %then
%do;
 
 
proc datasets library=&m_di_trans nolist;
 
 
modify ALERT_COST ;
 
 
rename CREATED_DT=CREATED_DTTM;
 
 
format created_dttm NLDATM21.;
 
 
informat created_dttm NLDATM21.;
 
 
 
modify ALERT_COMP ;
 
 
rename CREATED_DT=CREATED_DTTM;
 
 
format created_dttm NLDATM21.;
 
 
informat created_dttm NLDATM21.;
 
 
 
modify ALERT_NEW_PROD ;
 
 
rename CREATED_DT=CREATED_DTTM;
 
 
format created_dttm NLDATM21.;
 
 
informat created_dttm NLDATM21.;
 
 
quit;
 
 
 
proc sql;
 
 
update ALERT_COST     set CREATED_DTTM=created_dttm*24*60*60+(00*60*60+00*60+00);
 
 
update ALERT_COMP     set CREATED_DTTM=created_dttm*24*60*60+(00*60*60+00*60+00);
 
 
update ALERT_NEW_PROD set CREATED_DTTM=created_dttm*24*60*60+(00*60*60+00*60+00);
 
 
 
quit;
 
 
%end;
 
 
%else
%do;
 
 
/* CREATED_DT already changed to CREATED_DTTM.  Apply this formula */
proc sql;
 
 
update ALERT_COST     set CREATED_DTTM=created_dttm*24*60*60+(00*60*60+00*60+00);
 
 
update ALERT_COMP     set CREATED_DTTM=created_dttm*24*60*60+(00*60*60+00*60+00);
 
 
update ALERT_NEW_PROD set CREATED_DTTM=created_dttm*24*60*60+(00*60*60+00*60+00);
 
 
 
quit;
 
 
%end;
 
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID836365B;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID836365B;
%put ERROR- Description                              : rename column created_dt to created_dttm for rpo alert tables;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 22FEB2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID836365B;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID836365B",
"rename column created_dt to created_dttm for rpo alert tables",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID836365B:;
 
 
* End of changes for CHANGE_ID:ID836365B;
 
 
***********************************************************************************************;
*************************************  End Change ID836365B ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID837815 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID837815;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID837815")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PURGE_QUERY))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PURGE_QUERY;
%put NOTE: Change ID                             :ID837815;
%goto ID837815;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID837815;
%goto ID837815;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID837815;
* Insert record into change management table for CHANGE_ID: ID837815;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID837815",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID837815;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE PURGE_QUERY SET NUM_DAYS_PRESERVED = 60 WHERE table_nm='FUTURE_RECEIPT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PURGE_QUERY SET PURGE_FREQUENCY = 60 WHERE table_nm='FUTURE_RECEIPT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
UPDATE PURGE_QUERY SET NUM_DAYS_PRESERVED = 60 WHERE table_nm='FUTURE_RECEIPT';
 
 
UPDATE PURGE_QUERY SET PURGE_FREQUENCY = 60 WHERE table_nm='FUTURE_RECEIPT';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID837815;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID837815;
%put ERROR- Description                              : Purge process needs to purge future_receipt history;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 28FEB2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID837815;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID837815",
"Purge process needs to purge future_receipt history",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID837815:;
 
 
* End of changes for CHANGE_ID:ID837815;
 
 
***********************************************************************************************;
*************************************  End Change ID837815 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID800148 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID800148;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID800148")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PRF_CONFIG))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_CONFIG;
%put NOTE: Change ID                             :ID800148;
%goto ID800148;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID800148;
%goto ID800148;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID800148;
* Insert record into change management table for CHANGE_ID: ID800148;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID800148",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID800148;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=2 and SPEC_NM='im_fringe_set_imputation'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_fringe_set_imputation', '0', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=2 and SPEC_NM='im_fringe_size_lastpercent'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_fringe_size_lastpercent', '0.2', 'NUMERIC')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=2 and SPEC_NM='im_fringe_size_ratio'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_fringe_size_ratio', '0.1', 'NUMERIC')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=2 and SPEC_NM='im_fringe_moving_window'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_fringe_moving_window', '3', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=2 and SPEC_NM='im_fringe_sko_rate'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_fringe_sko_rate', '0.4', 'NUMERIC')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=2 and SPEC_NM='im_fringe_set_imputation';
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_fringe_set_imputation', '0', 'INTEGER');
 
 
 
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=2 and SPEC_NM='im_fringe_size_lastpercent';
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_fringe_size_lastpercent', '0.2', 'NUMERIC');
 
 
 
 
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=2 and SPEC_NM='im_fringe_size_ratio';
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_fringe_size_ratio', '0.1', 'NUMERIC');
 
 
 
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=2 and SPEC_NM='im_fringe_moving_window';
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_fringe_moving_window', '3', 'INTEGER');
 
 
 
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=2 and SPEC_NM='im_fringe_sko_rate';
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_fringe_sko_rate', '0.4', 'NUMERIC');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID800148;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID800148;
%put ERROR- Description                              : IMPUTATION ENHANCEMENT FOR FRINGE SIZES;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 02MAR2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID800148;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID800148",
"IMPUTATION ENHANCEMENT FOR FRINGE SIZES",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID800148:;
 
 
* End of changes for CHANGE_ID:ID800148;
 
 
***********************************************************************************************;
*************************************  End Change ID800148 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID838719 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID838719;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID838719")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID838719;
%goto ID838719;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID838719;
* Insert record into change management table for CHANGE_ID: ID838719;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID838719",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID838719;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD HAS_NEED INTEGER DEFAULT 0 NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_NEED NUMERIC(20,3) DEFAULT 0.0 NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE GLOBAL TEMPORARY TABLE TMP_PLAN_UPDT1 ON COMMIT PRESERVE ROWS AS
SELECT COUNT(*) AS NEED_COUNT, B.PURCHASE_ORDER_PLAN_SK FROM PKO_PURCHASE_ORDER_PLAN P, PKO_BUY B, PKO_DELIVERY D, PKO_STORE_NEED N
WHERE B.PURCHASE_ORDER_PLAN_SK IN (SELECT PURCHASE_ORDER_PLAN_SK FROM PKO_PURCHASE_ORDER_PLAN)
AND D.BUY_SK=B.BUY_SK
AND N.DELIVERY_SK=D.DELIVERY_SK
AND P.PURCHASE_ORDER_PLAN_SK=B.PURCHASE_ORDER_PLAN_SK
GROUP BY B.PURCHASE_ORDER_PLAN_SK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN SET HAS_NEED = 1
WHERE PURCHASE_ORDER_PLAN_SK IN (SELECT PURCHASE_ORDER_PLAN_SK FROM TMP_PLAN_UPDT1 WHERE NEED_COUNT > 0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
COMMIT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
TRUNCATE TABLE TMP_PLAN_UPDT1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DROP TABLE TMP_PLAN_UPDT1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE GLOBAL TEMPORARY TABLE TMP_PLAN_UPDT2 ON COMMIT PRESERVE ROWS AS
SELECT PURCHASE_ORDER_PLAN_SK, SUM(STORE_NEED) AS SUM_NEED FROM PKO_STORE_NEED SN, PKO_DELIVERY D, PKO_BUY B
WHERE PURCHASE_ORDER_PLAN_SK IN(SELECT PURCHASE_ORDER_PLAN_SK FROM PKO_PURCHASE_ORDER_PLAN)
AND SN.DELIVERY_SK=D.DELIVERY_SK AND B.BUY_SK=D.BUY_SK GROUP BY PURCHASE_ORDER_PLAN_SK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN P SET P.TOTAL_NEED = ( SELECT SUM_NEED FROM TMP_PLAN_UPDT2 PT
WHERE PT.SUM_NEED IS NOT NULL AND PT.PURCHASE_ORDER_PLAN_SK = P.PURCHASE_ORDER_PLAN_SK)
WHERE EXISTS ( SELECT NULL FROM TMP_PLAN_UPDT2 PT WHERE PT.SUM_NEED IS NOT NULL
AND PT.PURCHASE_ORDER_PLAN_SK = P.PURCHASE_ORDER_PLAN_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
COMMIT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
TRUNCATE TABLE TMP_PLAN_UPDT2
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DROP TABLE TMP_PLAN_UPDT2
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID838719;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID838719;
%put ERROR- Description                              : Loading plans for larger number of plans is slow due to metric calculations;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 01MAR2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID838719;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID838719",
"Loading plans for larger number of plans is slow due to metric calculations",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID838719:;
 
 
* End of changes for CHANGE_ID:ID838719;
 
 
***********************************************************************************************;
*************************************  End Change ID838719 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID838719B ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID838719B;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID838719B")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID838719B;
%goto ID838719B;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID838719B;
* Insert record into change management table for CHANGE_ID: ID838719B;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID838719B",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID838719B;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
proc sql noprint;
 
 
ALTER TABLE &m_di_trans..PKO_PURCHASE_ORDER_PLAN ADD HAS_NEED INTEGER ;
 
 
ALTER TABLE &m_di_trans..PKO_PURCHASE_ORDER_PLAN ADD NOT NULL (HAS_NEED);
 
 
UPDATE &m_di_trans..PKO_PURCHASE_ORDER_PLAN set HAS_NEED=0;
 
 
 
ALTER TABLE &m_di_trans..PKO_PURCHASE_ORDER_PLAN ADD TOTAL_NEED NUMERIC(20,3) ;
 
 
ALTER TABLE &m_di_trans..PKO_PURCHASE_ORDER_PLAN ADD NOT NULL (TOTAL_NEED);
 
 
UPDATE &m_di_trans..PKO_PURCHASE_ORDER_PLAN set TOTAL_NEED=0.0;
 
 
 
quit;
 
 
 
 
PROC SQL noprint;
 
 
 
CREATE TABLE WORK.TMP_PLAN_UPDT1 AS
SELECT COUNT(*) AS NEED_COUNT, B.PURCHASE_ORDER_PLAN_SK
FROM &m_di_trans..PKO_PURCHASE_ORDER_PLAN P,
&m_di_trans..PKO_BUY B,
&m_di_trans..PKO_DELIVERY D,
&m_di_trans..PKO_STORE_NEED N
 
WHERE B.PURCHASE_ORDER_PLAN_SK IN (SELECT PURCHASE_ORDER_PLAN_SK FROM &m_di_trans..PKO_PURCHASE_ORDER_PLAN)
AND D.BUY_SK=B.BUY_SK
AND N.DELIVERY_SK=D.DELIVERY_SK
AND P.PURCHASE_ORDER_PLAN_SK=B.PURCHASE_ORDER_PLAN_SK
GROUP BY B.PURCHASE_ORDER_PLAN_SK ;
 
 
 
UPDATE &m_di_trans..PKO_PURCHASE_ORDER_PLAN SET HAS_NEED = 1
WHERE PURCHASE_ORDER_PLAN_SK IN (SELECT PURCHASE_ORDER_PLAN_SK
FROM WORK.TMP_PLAN_UPDT1 WHERE NEED_COUNT > 0);
 
 
 
DROP TABLE WORK.TMP_PLAN_UPDT1;
 
 
quit;
 
 
 
proc sql noprint;
 
 
 
CREATE TABLE WORK.TMP_PLAN_UPDT2 AS
SELECT PURCHASE_ORDER_PLAN_SK,
SUM(STORE_NEED) AS SUM_NEED
FROM &m_di_trans..PKO_STORE_NEED SN,
&m_di_trans..PKO_DELIVERY D,
&m_di_trans..PKO_BUY B
WHERE PURCHASE_ORDER_PLAN_SK IN (SELECT PURCHASE_ORDER_PLAN_SK FROM &m_di_trans..PKO_PURCHASE_ORDER_PLAN)
AND SN.DELIVERY_SK=D.DELIVERY_SK
AND B.BUY_SK=D.BUY_SK
GROUP BY PURCHASE_ORDER_PLAN_SK;
 
 
 
UPDATE &m_di_trans..PKO_PURCHASE_ORDER_PLAN P
SET TOTAL_NEED = ( SELECT SUM_NEED FROM WORK.TMP_PLAN_UPDT2 PT
WHERE PT.SUM_NEED IS NOT MISSING AND PT.PURCHASE_ORDER_PLAN_SK = P.PURCHASE_ORDER_PLAN_SK)
WHERE EXISTS ( SELECT . FROM WORK.TMP_PLAN_UPDT2 PT WHERE PT.SUM_NEED IS NOT MISSING
AND PT.PURCHASE_ORDER_PLAN_SK = P.PURCHASE_ORDER_PLAN_SK);
 
 
 
 
DROP TABLE WORK.TMP_PLAN_UPDT2;
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID838719B;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID838719B;
%put ERROR- Description                              : Loading plans for larger number of plans is slow due to metric calculations;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 01MAR2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID838719B;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID838719B",
"Loading plans for larger number of plans is slow due to metric calculations",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID838719B:;
 
 
* End of changes for CHANGE_ID:ID838719B;
 
 
***********************************************************************************************;
*************************************  End Change ID838719B ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0833697 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0833697;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0833697")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..VEHICLE_CATEGORY))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..VEHICLE_CATEGORY;
%put NOTE: Change ID                             :ID0833697;
%goto ID0833697;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0833697;
%goto ID0833697;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0833697;
* Insert record into change management table for CHANGE_ID: ID0833697;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0833697",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0833697;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let _cnt_psy_points=0;
 
 
 
proc sql noprint;
 
 
select count(*)
into :_cnt_psy_points
from &m_di_trans..vehicle_category
where vehicle_category_sk=198
;
 
 
quit;
 
 
 
%if &_cnt_psy_points = 0 %then
%do;
 
 
 
proc sql noprint;
 
 
 
INSERT INTO &m_di_trans..vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG,
PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (198, 'TPR_ONLY', 'Temporary price reduction (Do not use for promotions!)', 0, 0, 'TPR_ONLY');
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%let _cnt_psy_points=0;
 
 
 
proc sql noprint;
 
 
select count(*)
into :_cnt_psy_points
from &m_di_trans..vehicle_category
where vehicle_category_sk=198
;
 
 
quit;
 
 
 
%if &_cnt_psy_points = 0 %then
%do;
 
 
 
proc sql noprint;
 
 
 
INSERT INTO &m_di_trans..vehicle_category (VEHICLE_CATEGORY_SK,VEHICLE_CATEGORY_NM,VEHICLE_CATEGORY_DESC, ACTIVE_FLG,
PRICE_FLG, VEHICLE_CATEGORY_TYPE)
VALUES  (198, 'TPR_ONLY', 'Temporary price reduction (Do not use for promotions!)', 0, 0, 'TPR_ONLY');
 
 
quit;
 
 
 
%end;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0833697;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0833697;
%put ERROR- Description                              : Vehicle category seed for psychological points;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 09MAR2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0833697;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0833697",
"Vehicle category seed for psychological points",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0833697:;
 
 
* End of changes for CHANGE_ID:ID0833697;
 
 
***********************************************************************************************;
*************************************  End Change ID0833697 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID841925 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID841925;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID841925")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PRF_CONFIG))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_CONFIG;
%put NOTE: Change ID                             :ID841925;
%goto ID841925;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID841925;
%goto ID841925;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID841925;
* Insert record into change management table for CHANGE_ID: ID841925;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID841925",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID841925;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG
WHERE PRF_CONFIG_SK=-1 AND PRF_CONFIG_TYPE = 1 AND SPEC_NM = 'imputation_method'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 1, 'imputation_method', '8', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG
WHERE  PRF_CONFIG_SK=-1 AND PRF_CONFIG_TYPE = 1 AND SPEC_NM = 'use_model_geo_prod_status'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 1, 'use_model_geo_prod_status', '0', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG
WHERE  PRF_CONFIG_SK=-1 AND PRF_CONFIG_TYPE = 4 AND SPEC_NM = 'mgps_prod_group_lvl'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 4, 'mgps_prod_group_lvl', '1', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG
WHERE  PRF_CONFIG_SK=-1 AND PRF_CONFIG_TYPE = 4 AND SPEC_NM = 'mgps_use_clearance_status'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 4, 'mgps_use_clearance_status', '0', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG
WHERE  PRF_CONFIG_SK=-1 AND PRF_CONFIG_TYPE = 4 AND SPEC_NM = 'mgps_max_status_change'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 4, 'mgps_max_status_change', '30', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG
WHERE  PRF_CONFIG_SK=-1 AND PRF_CONFIG_TYPE = 4 AND SPEC_NM = 'mgps_inactive_duration'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 4, 'mgps_inactive_duration', '3', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM PRF_CONFIG
WHERE PRF_CONFIG_SK=-1 AND PRF_CONFIG_TYPE = 1 AND SPEC_NM = 'imputation_method';
 
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 1, 'imputation_method', '8', 'INTEGER');
 
 
 
DELETE FROM PRF_CONFIG
WHERE  PRF_CONFIG_SK=-1 AND PRF_CONFIG_TYPE = 1 AND SPEC_NM = 'use_model_geo_prod_status' ;
 
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 1, 'use_model_geo_prod_status', '0', 'INTEGER');
 
 
 
DELETE FROM PRF_CONFIG
WHERE  PRF_CONFIG_SK=-1 AND PRF_CONFIG_TYPE = 4 AND SPEC_NM = 'mgps_prod_group_lvl' ;
 
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 4, 'mgps_prod_group_lvl', '1', 'INTEGER');
 
 
 
DELETE FROM PRF_CONFIG
WHERE  PRF_CONFIG_SK=-1 AND PRF_CONFIG_TYPE = 4 AND SPEC_NM = 'mgps_use_clearance_status' ;
 
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 4, 'mgps_use_clearance_status', '0', 'INTEGER');
 
 
 
DELETE FROM PRF_CONFIG
WHERE  PRF_CONFIG_SK=-1 AND PRF_CONFIG_TYPE = 4 AND SPEC_NM = 'mgps_max_status_change' ;
 
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 4, 'mgps_max_status_change', '30', 'INTEGER');
 
 
 
DELETE FROM PRF_CONFIG
WHERE  PRF_CONFIG_SK=-1 AND PRF_CONFIG_TYPE = 4 AND SPEC_NM = 'mgps_inactive_duration' ;
 
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 4, 'mgps_inactive_duration', '3', 'INTEGER');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID841925;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID841925;
%put ERROR- Description                              : SIZE PROFILING 3.2 SCHEMA CHANGES;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 21MAR2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID841925;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID841925",
"SIZE PROFILING 3.2 SCHEMA CHANGES",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID841925:;
 
 
* End of changes for CHANGE_ID:ID841925;
 
 
***********************************************************************************************;
*************************************  End Change ID841925 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID845616 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID845616;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID845616")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID845616;
%goto ID845616;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC;
%put NOTE: Change ID                             :ID845616;
%goto ID845616;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID845616;
%goto ID845616;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID845616;
* Insert record into change management table for CHANGE_ID: ID845616;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID845616",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID845616;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'HALO_FLG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'HALO_FLG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'HALO_GEO_LVL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'HALO_GEO_LVL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'HALO_FLG';
 
 
delete from MODEL_SPEC where SPEC_NM = 'HALO_FLG';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'HALO_GEO_LVL';
 
 
delete from MODEL_SPEC where SPEC_NM = 'HALO_GEO_LVL';
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID845616;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID845616;
%put ERROR- Description                              : Remove Halo Editor and halo specs from Workbench;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 20MAR2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID845616;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID845616",
"Remove Halo Editor and halo specs from Workbench",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID845616:;
 
 
* End of changes for CHANGE_ID:ID845616;
 
 
***********************************************************************************************;
*************************************  End Change ID845616 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID850044 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID850044;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID850044")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID850044;
%goto ID850044;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC;
%put NOTE: Change ID                             :ID850044;
%goto ID850044;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID850044;
%goto ID850044;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID850044;
* Insert record into change management table for CHANGE_ID: ID850044;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID850044",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID850044;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'MODEL_TYPE_CD' and MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'MODEL_TYPE_CD' and MODEL_COMP_NM = 'TS' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'TS','MODEL_TYPE_CD','2','ARIMA_WINTERS',NULL,NULL,'MIGRATE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'MODEL_TYPE_CD' and MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MODEL_TYPE_CD' and MODEL_COMP_NM = 'TS' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('TS','MODEL_TYPE_CD','2','ARIMA_WINTERS',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'MODEL_TYPE_CD' and MODEL_COMP_NM = 'TS';
 
 
delete from MODEL_SPEC where SPEC_NM = 'MODEL_TYPE_CD' and MODEL_COMP_NM = 'TS' and SPEC_TYPE = '2';
 
 
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'TS','MODEL_TYPE_CD','2','ARIMA_WINTERS',NULL,NULL,'MIGRATE');
 
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'MODEL_TYPE_CD' and MODEL_COMP_NM = 'TS';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MODEL_TYPE_CD' and MODEL_COMP_NM = 'TS' and SPEC_TYPE = '2';
 
 
insert into MODEL_SPEC_DEFAULT (MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('TS','MODEL_TYPE_CD','2','ARIMA_WINTERS',NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID850044;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID850044;
%put ERROR- Description                              : Change model spec MODEL_TYPE_CD for TS to be separate for direct and share models;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 06APR2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID850044;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID850044",
"Change model spec MODEL_TYPE_CD for TS to be separate for direct and share models",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID850044:;
 
 
* End of changes for CHANGE_ID:ID850044;
 
 
***********************************************************************************************;
*************************************  End Change ID850044 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID853326 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID853326;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID853326")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID853326;
%goto ID853326;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID853326;
* Insert record into change management table for CHANGE_ID: ID853326;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID853326",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID853326;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
drop table &m_di_trans..HISTORICAL_FIT;;
 
 
drop table &m_di_trans..HISTORICAL_FIT_ACCURACY;
 
 
drop table &m_di_trans..HOLDOUT_FORECAST;
 
 
drop table &m_di_trans..HOLDOUT_FORECAST_ACCURACY;
 
 
quit;
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
drop table &m_di_trans..HISTORICAL_FIT;;
 
 
drop table &m_di_trans..HISTORICAL_FIT_ACCURACY;
 
 
drop table &m_di_trans..HOLDOUT_FORECAST;
 
 
drop table &m_di_trans..HOLDOUT_FORECAST_ACCURACY;
 
 
quit;
 
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID853326;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID853326;
%put ERROR- Description                              : Drop tables that are no longer used;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 18APR2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID853326;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID853326",
"Drop tables that are no longer used",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID853326:;
 
 
* End of changes for CHANGE_ID:ID853326;
 
 
***********************************************************************************************;
*************************************  End Change ID853326 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID856193 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID856193;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID856193")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID856193;
%goto ID856193;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID856193;
* Insert record into change management table for CHANGE_ID: ID856193;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID856193",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID856193;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%local  m_lcp_curve_type_1_cnt m_lcp_curve_type_2_cnt;
 
 
 
/* check if specs exist in model_spec table */
proc sql noprint;
 
 
 
select count(*) into :m_lcp_curve_type_1_cnt
from &m_di_trans..model_spec
where SPEC_NM="LCP_CURVE_TYPE"
and SPEC_TYPE='1'
and MODEL_GROUP_ID = -1
;
 
 
 
select count(*) into :m_lcp_curve_type_2_cnt
from &m_di_trans..model_spec
where SPEC_NM="LCP_CURVE_TYPE"
and SPEC_TYPE='2'
and MODEL_GROUP_ID = -1
;
 
 
 
quit;
 
 
 
/* if no default spec exists for LCP_CURVE_TYPE then seed it with the default value */
%if ( &m_lcp_curve_type_1_cnt<1) %then
%do;
 
 
proc sql noprint;
 
 
INSERT INTO &m_di_trans..model_spec (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
VALUES  (-1,'REG','LCP_CURVE_TYPE','1','GAMMA',NULL,NULL,'SEED');
 
 
quit;
 
 
%end;
 
 
 
%if ( &m_lcp_curve_type_2_cnt<1) %then
%do;
 
 
proc sql noprint;
 
 
INSERT INTO &m_di_trans..model_spec (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
VALUES  (-1,'REG','LCP_CURVE_TYPE','2','GAMMA',NULL,NULL,'SEED');
 
 
quit;
 
 
%end;
 
 
 
/* update any bad default specs that already existed */
proc sql noprint;
 
 
update &m_di_trans..model_spec set SPEC_VALUE = 'GAMMA' where MODEL_GROUP_ID = -1 and SPEC_VALUE = 'BETA';
 
 
quit;
 
 
 
/* delete mg-specific bad spec value entries and redundant-to-default entries */
proc sql noprint;
 
 
delete from &m_di_trans..model_spec where SPEC_NM = 'LCP_CURVE_TYPE' and SPEC_VALUE = 'BETA';
 
 
delete from &m_di_trans..model_spec where SPEC_NM = 'LCP_CURVE_TYPE' and SPEC_VALUE = 'GAMMA' and MODEL_GROUP_ID NE -1;
 
 
quit;
 
 
 
 
 
/* check if specs exist in model_spec_default table */
proc sql noprint;
 
 
 
select count(*) into :m_lcp_curve_type_1_cnt
from &m_di_trans..model_spec_default
where SPEC_NM="LCP_CURVE_TYPE"
and SPEC_TYPE='1'
;
 
 
 
select count(*) into :m_lcp_curve_type_2_cnt
from &m_di_trans..model_spec_default
where SPEC_NM="LCP_CURVE_TYPE"
and SPEC_TYPE='2'
;
 
 
 
quit;
 
 
 
/* if no default spec exists for LCP_CURVE_TYPE then seed it with the default value */
%if ( &m_lcp_curve_type_1_cnt<1) %then
%do;
 
 
proc sql noprint;
 
 
INSERT INTO &m_di_trans..model_spec_default (MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES  ('REG','LCP_CURVE_TYPE','1','GAMMA',NULL);
 
 
quit;
 
 
%end;
 
 
 
%if ( &m_lcp_curve_type_2_cnt<1) %then
%do;
 
 
proc sql noprint;
 
 
INSERT INTO &m_di_trans..model_spec_default (MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES  ('REG','LCP_CURVE_TYPE','2','GAMMA',NULL);
 
 
quit;
 
 
%end;
 
 
 
/* update any bad default specs that already existed */
proc sql noprint;
 
 
update &m_di_trans..model_spec_default set DEFAULT_SPEC_VALUE = 'GAMMA' where DEFAULT_SPEC_VALUE = 'BETA';
 
 
quit;
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%local  m_lcp_curve_type_1_cnt m_lcp_curve_type_2_cnt;
 
 
 
/* check if specs exist in model_spec table */
proc sql noprint;
 
 
 
select count(*) into :m_lcp_curve_type_1_cnt
from &m_di_trans..model_spec
where SPEC_NM="LCP_CURVE_TYPE"
and SPEC_TYPE='1'
and MODEL_GROUP_ID = -1
;
 
 
 
select count(*) into :m_lcp_curve_type_2_cnt
from &m_di_trans..model_spec
where SPEC_NM="LCP_CURVE_TYPE"
and SPEC_TYPE='2'
and MODEL_GROUP_ID = -1
;
 
 
 
quit;
 
 
 
/* if no default spec exists for LCP_CURVE_TYPE then seed it with the default value */
%if ( &m_lcp_curve_type_1_cnt<1) %then
%do;
 
 
proc sql noprint;
 
 
INSERT INTO &m_di_trans..model_spec (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
VALUES  (-1,'REG','LCP_CURVE_TYPE','1','GAMMA',NULL,NULL,'SEED');
 
 
quit;
 
 
%end;
 
 
 
%if ( &m_lcp_curve_type_2_cnt<1) %then
%do;
 
 
proc sql noprint;
 
 
INSERT INTO &m_di_trans..model_spec (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
VALUES  (-1,'REG','LCP_CURVE_TYPE','2','GAMMA',NULL,NULL,'SEED');
 
 
quit;
 
 
%end;
 
 
 
/* update any bad default specs that already existed */
proc sql noprint;
 
 
update &m_di_trans..model_spec set SPEC_VALUE = 'GAMMA' where MODEL_GROUP_ID = -1 and SPEC_VALUE = 'BETA';
 
 
quit;
 
 
 
/* delete mg-specific bad spec value entries and redundant-to-default entries */
proc sql noprint;
 
 
delete from &m_di_trans..model_spec where SPEC_NM = 'LCP_CURVE_TYPE' and SPEC_VALUE = 'BETA';
 
 
delete from &m_di_trans..model_spec where SPEC_NM = 'LCP_CURVE_TYPE' and SPEC_VALUE = 'GAMMA' and MODEL_GROUP_ID NE -1;
 
 
quit;
 
 
 
 
 
/* check if specs exist in model_spec_default table */
proc sql noprint;
 
 
 
select count(*) into :m_lcp_curve_type_1_cnt
from &m_di_trans..model_spec_default
where SPEC_NM="LCP_CURVE_TYPE"
and SPEC_TYPE='1'
;
 
 
 
select count(*) into :m_lcp_curve_type_2_cnt
from &m_di_trans..model_spec_default
where SPEC_NM="LCP_CURVE_TYPE"
and SPEC_TYPE='2'
;
 
 
 
quit;
 
 
 
/* if no default spec exists for LCP_CURVE_TYPE then seed it with the default value */
%if ( &m_lcp_curve_type_1_cnt<1) %then
%do;
 
 
proc sql noprint;
 
 
INSERT INTO &m_di_trans..model_spec_default (MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES  ('REG','LCP_CURVE_TYPE','1','GAMMA',NULL);
 
 
quit;
 
 
%end;
 
 
 
%if ( &m_lcp_curve_type_2_cnt<1) %then
%do;
 
 
proc sql noprint;
 
 
INSERT INTO &m_di_trans..model_spec_default (MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
VALUES  ('REG','LCP_CURVE_TYPE','2','GAMMA',NULL);
 
 
quit;
 
 
%end;
 
 
 
/* update any bad default specs that already existed */
proc sql noprint;
 
 
update &m_di_trans..model_spec_default set DEFAULT_SPEC_VALUE = 'GAMMA' where DEFAULT_SPEC_VALUE = 'BETA';
 
 
quit;
 
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID856193;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID856193;
%put ERROR- Description                              : Add LCP_CURVE_TYPE model spec back in;
%put ERROR- Version                                  : D3MICM521;
%put ERROR- Date of Change                           : 24APR2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID856193;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID856193",
"Add LCP_CURVE_TYPE model spec back in",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID856193:;
 
 
* End of changes for CHANGE_ID:ID856193;
 
 
***********************************************************************************************;
*************************************  End Change ID856193 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID855245 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID855245;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID855245")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID855245;
%goto ID855245;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID855245;
%goto ID855245;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID855245;
* Insert record into change management table for CHANGE_ID: ID855245;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID855245",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID855245;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'MODEL_VAR' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MODEL_VAR' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'MODEL_VAR' and SPEC_TYPE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_TYPE = '-1' where SPEC_NM = 'MODEL_VAR' and SPEC_TYPE = '1'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where SPEC_NM = 'MODEL_VAR' and SPEC_TYPE = '1'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '-1' where SPEC_NM = 'MODEL_VAR' and SPEC_TYPE = '1'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC where SPEC_NM = 'MODEL_VAR' and SPEC_TYPE = '2';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MODEL_VAR' and SPEC_TYPE = '2';
 
 
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'MODEL_VAR' and SPEC_TYPE = '2';
 
 
 
update MODEL_SPEC set SPEC_TYPE = '-1' where SPEC_NM = 'MODEL_VAR' and SPEC_TYPE = '1';
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where SPEC_NM = 'MODEL_VAR' and SPEC_TYPE = '1';
 
 
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '-1' where SPEC_NM = 'MODEL_VAR' and SPEC_TYPE = '1';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID855245;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID855245;
%put ERROR- Description                              : Change model spec MODEL_VAR to all models, not direct and share;
%put ERROR- Version                                  : D3MICM521;
%put ERROR- Date of Change                           : 20APR2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID855245;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID855245",
"Change model spec MODEL_VAR to all models, not direct and share",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID855245:;
 
 
* End of changes for CHANGE_ID:ID855245;
 
 
***********************************************************************************************;
*************************************  End Change ID855245 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID851165 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID851165;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID851165")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID851165;
%goto ID851165;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID851165;
* Insert record into change management table for CHANGE_ID: ID851165;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID851165",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID851165;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%di_util_delete_sequence(m_sequence_name=%str(SEQ_PACK_OPT_PROD_DC_SET_SK), m_schema_name=%str(&di_trans_schema));
 
 
 
%di_util_delete_sequence(m_sequence_name=%str(SEQ_PACK_OPT_PROD_SET_SK), m_schema_name=%str(&di_trans_schema));
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID851165;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID851165;
%put ERROR- Description                              : Drop sequences that are not in use;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 25APR2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID851165;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID851165",
"Drop sequences that are not in use",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID851165:;
 
 
* End of changes for CHANGE_ID:ID851165;
 
 
***********************************************************************************************;
*************************************  End Change ID851165 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID857667 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID857667;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID857667")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID857667;
%goto ID857667;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID857667;
* Insert record into change management table for CHANGE_ID: ID857667;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID857667",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID857667;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
DROP TABLE RPP_METRICS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE TABLE RPP_METRICS
(
OBJECT_CAT_SK   INTEGER NOT NULL,
OBJECT_CAT_TYPE INTEGER NOT NULL,
PROD_HIER_SK    INTEGER NOT NULL,
GEO_HIER_SK     INTEGER NOT NULL,
START_DT        DATE NOT NULL,
END_DT          DATE NOT NULL,
KPI             INTEGER NOT NULL,
KPI_TYPE        INTEGER NOT NULL,
KPI_VALUE       NUMERIC(20,3) NOT NULL,
PRIMARY KEY (OBJECT_CAT_SK,OBJECT_CAT_TYPE,PROD_HIER_SK,GEO_HIER_SK,START_DT,END_DT,KPI,KPI_TYPE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
DROP TABLE RPP_METRICS;
 
 
 
CREATE TABLE RPP_METRICS
(
OBJECT_CAT_SK   INTEGER NOT NULL,
OBJECT_CAT_TYPE INTEGER NOT NULL,
PROD_HIER_SK    INTEGER NOT NULL,
GEO_HIER_SK     INTEGER NOT NULL,
START_DT        DATE NOT NULL,
END_DT          DATE NOT NULL,
KPI             INTEGER NOT NULL,
KPI_TYPE        INTEGER NOT NULL,
KPI_VALUE       NUMERIC(20,3) NOT NULL
)
;
 
 
ALTER TABLE RPP_METRICS add CONSTRAINT RPP_METRICS_PK
PRIMARY KEY (OBJECT_CAT_SK,OBJECT_CAT_TYPE,PROD_HIER_SK,GEO_HIER_SK,START_DT,END_DT,KPI,KPI_TYPE);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID857667;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID857667;
%put ERROR- Description                              : Modify Primary key of RPP_Metrics table;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 30APR2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID857667;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID857667",
"Modify Primary key of RPP_Metrics table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID857667:;
 
 
* End of changes for CHANGE_ID:ID857667;
 
 
***********************************************************************************************;
*************************************  End Change ID857667 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID858683 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID858683;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID858683")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..VEHICLE_CATEGORY))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..VEHICLE_CATEGORY;
%put NOTE: Change ID                             :ID858683;
%goto ID858683;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID858683;
%goto ID858683;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID858683;
* Insert record into change management table for CHANGE_ID: ID858683;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID858683",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID858683;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let _AutoPassThruApplied=0;
 
 
 
proc sql noprint;
 
 
select count(*)
into :_AutoPassThruApplied
from &m_di_trans..CAT_CUSTOM_ATTR
where CAT_CUSTOM_ATTR_SK=-170
;
 
 
quit;
 
 
 
%if &_AutoPassThruApplied = 0 %then
%do;
 
 
 
proc sql noprint;
 
 
 
insert into CAT_CUSTOM_ATTR
(CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM,
ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE)
VALUES
(-170, 1, 7,'AutoPassThruApplied', '', 2);
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%let _AutoPassThruApplied=0;
 
 
 
proc sql noprint;
 
 
select count(*)
into :_AutoPassThruApplied
from &m_di_trans..CAT_CUSTOM_ATTR
where CAT_CUSTOM_ATTR_SK=-170
;
 
 
quit;
 
 
 
%if &_AutoPassThruApplied = 0 %then
%do;
 
 
 
proc sql noprint;
 
 
 
insert into CAT_CUSTOM_ATTR
(CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM,
ATTR_DEFAULT_VALUE, ATTR_VALUE_TYPE)
VALUES
(-170, 1, 7,'AutoPassThruApplied', '', 2);
 
 
quit;
 
 
 
%end;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID858683;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID858683;
%put ERROR- Description                              : Definition needed by Evaluation;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 02MAY2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID858683;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID858683",
"Definition needed by Evaluation",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID858683:;
 
 
* End of changes for CHANGE_ID:ID858683;
 
 
***********************************************************************************************;
*************************************  End Change ID858683 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID863114 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID863114;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID863114")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID863114;
%goto ID863114;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID863114;
* Insert record into change management table for CHANGE_ID: ID863114;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID863114",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID863114;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC set spec_value = 'DIRECT_SHARE' where spec_nm = 'DEMAND_MODEL_TYPE'
and spec_value = 'SHARE_DIRECT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_TEMPLATE set spec_value = 'DIRECT_SHARE' where spec_nm = 'DEMAND_MODEL_TYPE'
and spec_value = 'SHARE_DIRECT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC set spec_value = 'DIRECT_SHARE' where spec_nm = 'DEMAND_MODEL_TYPE'
and spec_value = 'SHARE_DIRECT';
 
 
update MODEL_SPEC_TEMPLATE set spec_value = 'DIRECT_SHARE' where spec_nm = 'DEMAND_MODEL_TYPE'
and spec_value = 'SHARE_DIRECT';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID863114;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID863114;
%put ERROR- Description                              : Modify DEMAND_MODEL_TYPE model spec configuration to support migration;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 16MAY2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID863114;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID863114",
"Modify DEMAND_MODEL_TYPE model spec configuration to support migration",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID863114:;
 
 
* End of changes for CHANGE_ID:ID863114;
 
 
***********************************************************************************************;
*************************************  End Change ID863114 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0867051 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0867051;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0867051")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%put NOTE: This change will be applied on every run : ID0867051;
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql noprint;
 
 
select spec_value into :prod_partition_lvl from &m_di_data..global_setting
where upcase(spec_nm) = 'PROD_PARTITION_LVL';
 
 
quit;
 
 
 
 
/* Find out objective_sk.products which either contain Products from more than one partition or defined above PROD_PARTITION_LVL */
%let sql_st = %bquote(select plan.plan_sk from &m_di_trans..Rpp_plan plan, &m_di_trans..scope_detail det,
&m_di_trans..product_hier_assoc_dm p Where plan.objective_sk = det.scope_sk and det.prod_hier_sk = p.prod_hier_sk
and p.prod_hier_assoc_cd = 1 and p.parent_prod_lvl = &prod_partition_lvl
group by plan.plan_sk having count(distinct(parent_prod_hier_sk)) > 1
union all
select distinct plan.plan_sk from &m_di_trans..Rpp_plan plan, &m_di_trans..scope_detail det,
&m_di_trans..product_dm p Where plan.objective_sk = det.scope_sk and det.prod_hier_sk = p.prod_hier_sk
and p.std_hier_prod_lvl < &prod_partition_lvl);
 
 
 
%di_dm_trans_exe(
pass_through_sql=%str(&sql_st),
_output_table=work.obj_scope_high_lvl_prods,
debug_flag=1);
 
 
 
proc sort data = work.obj_scope_high_lvl_prods
out  = work.plans_in_multi_partitions
nodupkey;
 
 
by plan_sk;
 
 
run;
 
 
 
/* Set the EVAL_OPT_REQ_CD to 0 (Don't evaluate/optimize) */
%di_dm_trans_update(
upload_lib=work,
upload_table=plans_in_multi_partitions,
update_table=rpp_plan,
sql= %str(update &m_di_trans..rpp_plan p1 set EVAL_OPT_REQ_CD = (select 0 from work.plans_in_multi_partitions where p1.plan_sk = plan_sk)
where plan_sk in (SELECT plan_sk FROM work.plans_in_multi_partitions))
);
 
 
 
data work.high_lvl_prods;
 
 
set work.plans_in_multi_partitions &m_di_mon..stg_rpp_plan_x(obs=0);
 
 
PLAN_ID = cats('PLAN_SK=',plan_sk);
 
 
 
etls_exception_cond = 'Product in Objective scope is above PROD_PARTITION_LVL or plan spans more than one partition. Plan blocked from eval/opt';
 
 
 
etl_error_jobruntime = datetime();
 
 
drop plan_sk;
 
 
run;
 
 
 
proc append base=&m_di_mon..stg_rpp_plan_x data=work.high_lvl_prods force;
 
 
run;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
select spec_value into :prod_partition_lvl from &m_di_data..global_setting
where upcase(spec_nm) = 'PROD_PARTITION_LVL';
 
 
quit;
 
 
 
 
/* Find out objective_sk.products which either contain Products from more than one partition or defined above PROD_PARTITION_LVL */
%let sql_st = %bquote(select plan.plan_sk from &m_di_trans..Rpp_plan plan, &m_di_trans..scope_detail det,
&m_di_trans..product_hier_assoc_dm p Where plan.objective_sk = det.scope_sk and det.prod_hier_sk = p.prod_hier_sk
and p.prod_hier_assoc_cd = 1 and p.parent_prod_lvl = &prod_partition_lvl
group by plan.plan_sk having count(distinct(parent_prod_hier_sk)) > 1
union all
select distinct plan.plan_sk from &m_di_trans..Rpp_plan plan, &m_di_trans..scope_detail det,
&m_di_trans..product_dm p Where plan.objective_sk = det.scope_sk and det.prod_hier_sk = p.prod_hier_sk
and p.std_hier_prod_lvl < &prod_partition_lvl);
 
 
 
%di_dm_trans_exe(
pass_through_sql=%str(&sql_st),
_output_table=work.obj_scope_high_lvl_prods,
debug_flag=1);
 
 
 
proc sort data = work.obj_scope_high_lvl_prods
out  = work.plans_in_multi_partitions
nodupkey;
 
 
by plan_sk;
 
 
run;
 
 
 
/* Set the EVAL_OPT_REQ_CD to 0 (Don't evaluate/optimize) */
%di_dm_trans_update(
upload_lib=work,
upload_table=plans_in_multi_partitions,
update_table=rpp_plan,
sql= %str(update &m_di_trans..rpp_plan p1 set EVAL_OPT_REQ_CD = (select 0 from work.plans_in_multi_partitions where p1.plan_sk = plan_sk)
where plan_sk in (SELECT plan_sk FROM work.plans_in_multi_partitions))
);
 
 
 
data work.high_lvl_prods;
 
 
set work.plans_in_multi_partitions &m_di_mon..stg_rpp_plan_x(obs=0);
 
 
PLAN_ID = cats('PLAN_SK=',plan_sk);
 
 
 
etls_exception_cond = 'Product in Objective scope is above PROD_PARTITION_LVL or plan spans more than one partition. Plan blocked from eval/opt';
 
 
 
etl_error_jobruntime = datetime();
 
 
drop plan_sk;
 
 
run;
 
 
 
proc append base=&m_di_mon..stg_rpp_plan_x data=work.high_lvl_prods force;
 
 
run;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0867051;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0867051;
%put ERROR- Description                              : Prevent Promotion plans from eval/opt if they span more than one partition;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 29MAY2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0867051;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0867051",
"Prevent Promotion plans from eval/opt if they span more than one partition",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0867051:;
 
 
* End of changes for CHANGE_ID:ID0867051;
 
 
***********************************************************************************************;
*************************************  End Change ID0867051 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change GLOBAL_CONSTANTS_RUN_ONCE ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: GLOBAL_CONSTANTS_RUN_ONCE;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("GLOBAL_CONSTANTS_RUN_ONCE")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_data.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_data.;
%put NOTE: Change ID                             :GLOBAL_CONSTANTS_RUN_ONCE;
%goto GLOBAL_CONSTANTS_RUN_ONCE;
 
%end;
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :GLOBAL_CONSTANTS_RUN_ONCE;
%goto GLOBAL_CONSTANTS_RUN_ONCE;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..ma_spec_seed))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..ma_spec_seed;
%put NOTE: Change ID                             :GLOBAL_CONSTANTS_RUN_ONCE;
%goto GLOBAL_CONSTANTS_RUN_ONCE;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : GLOBAL_CONSTANTS_RUN_ONCE;
%goto GLOBAL_CONSTANTS_RUN_ONCE;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : GLOBAL_CONSTANTS_RUN_ONCE;
* Insert record into change management table for CHANGE_ID: GLOBAL_CONSTANTS_RUN_ONCE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"GLOBAL_CONSTANTS_RUN_ONCE",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto GLOBAL_CONSTANTS_RUN_ONCE;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let DI_MISC_PATH=%di_util_misc_path();
 
 
 
%include  "&DI_MISC_PATH/seed/seed_global_constants.sas";
 
 
 
%let m_refresh=%nrstr(proc sql; delete * from &m_di_trans..&m_tn;
 
 
create table work.z as select * from &m_di_trans..&m_tn outer union corr select * from work.&m_tn;
 
 
insert into &m_di_trans..&m_tn select * from work.z; quit;);
 
 
 
 
%let m_tn=global_setting_details;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_setting_group;
 
 
%unquote(&m_refresh);
 
;
 
 
%let m_tn=global_setting_group_member;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_setting_values;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=ma_spec_seed;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_geo_prod_status_details;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_geo_prod_status_values;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_spec_details;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_spec_values;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_spec_workflow;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=scoring_param_config;
 
 
%unquote(&m_refresh);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%let DI_MISC_PATH=%di_util_misc_path();
 
 
 
%include  "&DI_MISC_PATH/seed/seed_global_constants.sas";
 
 
 
%let m_refresh=%nrstr(proc sql; delete * from &m_di_trans..&m_tn;
 
 
create table work.z as select * from &m_di_trans..&m_tn outer union corr select * from work.&m_tn;
 
 
insert into &m_di_trans..&m_tn select * from work.z; quit;);
 
 
 
 
%let m_tn=global_setting_details;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_setting_group;
 
 
%unquote(&m_refresh);
 
;
 
 
%let m_tn=global_setting_group_member;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_setting_values;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=ma_spec_seed;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_geo_prod_status_details;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_geo_prod_status_values;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_spec_details;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_spec_values;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_spec_workflow;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=scoring_param_config;
 
 
%unquote(&m_refresh);
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: GLOBAL_CONSTANTS_RUN_ONCE;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: GLOBAL_CONSTANTS_RUN_ONCE;
%put ERROR- Description                              : Refresh Global Constants;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 15FEB2011;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: GLOBAL_CONSTANTS_RUN_ONCE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"GLOBAL_CONSTANTS_RUN_ONCE",
"Refresh Global Constants",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%GLOBAL_CONSTANTS_RUN_ONCE:;
 
 
* End of changes for CHANGE_ID:GLOBAL_CONSTANTS_RUN_ONCE;
 
 
***********************************************************************************************;
*************************************  End Change GLOBAL_CONSTANTS_RUN_ONCE ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change GLOBAL_CONSTANTS ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: GLOBAL_CONSTANTS;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("GLOBAL_CONSTANTS")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : GLOBAL_CONSTANTS;
%goto GLOBAL_CONSTANTS;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : GLOBAL_CONSTANTS;
* Insert record into change management table for CHANGE_ID: GLOBAL_CONSTANTS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"GLOBAL_CONSTANTS",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto GLOBAL_CONSTANTS;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
options user=work;
 
 
 
%if "&m_delete_and_start_fresh"="TRUE"  %then
%do;
 
 
 
%let DI_MISC_PATH=%di_util_misc_path();
 
 
 
%include  "&DI_MISC_PATH/seed/seed_global_constants.sas";
 
 
 
%let m_refresh=%nrstr(proc sql; delete * from &m_di_trans..&m_tn;
 
 
create table work.z as select * from &m_di_trans..&m_tn outer union corr select * from work.&m_tn;
 
 
insert into &m_di_trans..&m_tn select * from work.z; quit;);
 
 
 
%let m_tn=model_spec_default;
 
 
%unquote(&m_refresh);
 
 
 
 
%end;
 
 
%else
%do;
 
 
 
 
%di_util_mig_op_arp_rrp();
 
 
 
%let DI_MISC_PATH=%di_util_misc_path;
 
 
%di_dm_workbench(m_di_data   = di_data,
m_di_trans  = di_trans,
m_di_mon    = di_mon,
m_benchmark = %str(&DI_MISC_PATH/dbmsc/GLOBAL_CONSTANTS.CPORT)
);
 
 
 
%end;
 
 
 
options user=di_trans;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
options user=work;
 
 
 
%if "&m_delete_and_start_fresh"="TRUE"  %then
%do;
 
 
 
%let DI_MISC_PATH=%di_util_misc_path();
 
 
 
%include  "&DI_MISC_PATH/seed/seed_global_constants.sas";
 
 
 
%let m_refresh=%nrstr(proc sql; delete * from &m_di_trans..&m_tn;
 
 
create table work.z as select * from &m_di_trans..&m_tn outer union corr select * from work.&m_tn;
 
 
insert into &m_di_trans..&m_tn select * from work.z; quit;);
 
 
 
%let m_tn=model_spec_default;
 
 
%unquote(&m_refresh);
 
 
 
 
%end;
 
 
%else
%do;
 
 
 
 
%di_util_mig_op_arp_rrp();
 
 
 
%let DI_MISC_PATH=%di_util_misc_path;
 
 
%di_dm_workbench(m_di_data   = di_data,
m_di_trans  = di_trans,
m_di_mon    = di_mon,
m_benchmark = %str(&DI_MISC_PATH/dbmsc/GLOBAL_CONSTANTS.CPORT)
);
 
 
 
%end;
 
 
 
options user=di_trans;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: GLOBAL_CONSTANTS;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: GLOBAL_CONSTANTS;
%put ERROR- Description                              : Migrate model/FA specs (includes ID848869 and ID848072);
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 06JUN2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: GLOBAL_CONSTANTS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"GLOBAL_CONSTANTS",
"Migrate model/FA specs (includes ID848869 and ID848072)",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%GLOBAL_CONSTANTS:;
 
 
* End of changes for CHANGE_ID:GLOBAL_CONSTANTS;
 
 
***********************************************************************************************;
*************************************  End Change GLOBAL_CONSTANTS ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID871452 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID871452;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID871452")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID871452;
%goto ID871452;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID871452;
* Insert record into change management table for CHANGE_ID: ID871452;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID871452",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID871452;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
update model_spec_default msd set default_spec_value =
(select spec_value from model_spec ms where
ms.spec_nm = msd.spec_nm
and ms.spec_type = msd.spec_type
and ms.model_comp_nm = msd.model_comp_nm
and ms.model_group_id = -1)
where
(select spec_value from model_spec ms2 where
ms2.spec_nm = msd.spec_nm
and ms2.spec_type = msd.spec_type
and ms2.model_comp_nm = msd.model_comp_nm
and ms2.model_group_id = -1)
^= msd.default_spec_value
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
update model_spec_default msd set default_spec_value =
(select spec_value from model_spec ms where
ms.spec_nm = msd.spec_nm
and ms.spec_type = msd.spec_type
and ms.model_comp_nm = msd.model_comp_nm
and ms.model_group_id = -1)
where
(select spec_value from model_spec ms2 where
ms2.spec_nm = msd.spec_nm
and ms2.spec_type = msd.spec_type
and ms2.model_comp_nm = msd.model_comp_nm
and ms2.model_group_id = -1)
^= msd.default_spec_value;
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID871452;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID871452;
%put ERROR- Description                              : Must sync model_spec_default from model_spec after migration;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 15JUN2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID871452;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID871452",
"Must sync model_spec_default from model_spec after migration",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID871452:;
 
 
* End of changes for CHANGE_ID:ID871452;
 
 
***********************************************************************************************;
*************************************  End Change ID871452 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID872715 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID872715;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID872715")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID872715;
%goto ID872715;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID872715;
* Insert record into change management table for CHANGE_ID: ID872715;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID872715",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID872715;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from ma_spec_seed where spec_nm = 'LAST_INSAMPLE_WEEK'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into ma_spec_seed (model_group_id,spec_nm,spec_value,user_nm)
values (-1,'LAST_INSAMPLE_WEEK',NULL,'SEED')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from ma_spec_seed where spec_nm = 'LAST_INSAMPLE_WEEK';
 
 
insert into ma_spec_seed (model_group_id,spec_nm,spec_value,user_nm)
values (-1,'LAST_INSAMPLE_WEEK',NULL,'SEED');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID872715;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID872715;
%put ERROR- Description                              : MA_SPEC_SEED table is missing last_insample_week spec;
%put ERROR- Version                                  : D3MICM52;
%put ERROR- Date of Change                           : 15JUN2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID872715;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID872715",
"MA_SPEC_SEED table is missing last_insample_week spec",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID872715:;
 
 
* End of changes for CHANGE_ID:ID872715;
 
 
***********************************************************************************************;
*************************************  End Change ID872715 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID882658 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID882658;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID882658")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID882658;
%goto ID882658;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID882658;
* Insert record into change management table for CHANGE_ID: ID882658;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID882658",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID882658;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where MODEL_COMP_NM = 'REG' and SPEC_NM = 'INV_ADJ' and SPEC_VALUE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_VALUES (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG','INV_ADJ','2','auto_select.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_VALUES where MODEL_COMP_NM = 'REG' and SPEC_NM = 'INV_ADJ' and SPEC_VALUE = '2';
 
 
insert into MODEL_SPEC_VALUES (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG','INV_ADJ','2','auto_select.txt');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID882658;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID882658;
%put ERROR- Description                              : Add value 2 for REG spec INV_ADJ;
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 02AUG2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID882658;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID882658",
"Add value 2 for REG spec INV_ADJ",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID882658:;
 
 
* End of changes for CHANGE_ID:ID882658;
 
 
***********************************************************************************************;
*************************************  End Change ID882658 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID880469 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID880469;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID880469")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID880469;
%goto ID880469;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID880469;
* Insert record into change management table for CHANGE_ID: ID880469;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID880469",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID880469;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update SCORING_PARAM_CONFIG set EFFECT_CATEGORY = 'CPRICE' where EFFECT_CATEGORY = 'CP'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update SCORING_PARAM_DEFAULT set EFFECT_CATEGORY = 'CPRICE' where EFFECT_CATEGORY = 'CP'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update SCORING_PARAM_CONFIG set EFFECT_CATEGORY = 'CPRICE' where EFFECT_CATEGORY = 'CP';
 
 
update SCORING_PARAM_DEFAULT set EFFECT_CATEGORY = 'CPRICE' where EFFECT_CATEGORY = 'CP';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID880469;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID880469;
%put ERROR- Description                              : Change scoring param default categories CP to CPRICE;
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 02AUG2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID880469;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID880469",
"Change scoring param default categories CP to CPRICE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID880469:;
 
 
* End of changes for CHANGE_ID:ID880469;
 
 
***********************************************************************************************;
*************************************  End Change ID880469 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID880455 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID880455;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID880455")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID880455;
%goto ID880455;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID880455;
* Insert record into change management table for CHANGE_ID: ID880455;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID880455",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID880455;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from SCORING_PARAM_CONFIG where EFFECT_CATEGORY in ('CARP','CRRP','ARP','M_ARP','RRP')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY in ('CARP','CRRP','ARP','M_ARP','RRP')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from SCORING_PARAM_CONFIG where EFFECT_CATEGORY in ('CARP','CRRP','ARP','M_ARP','RRP');
 
 
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY in ('CARP','CRRP','ARP','M_ARP','RRP');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID880455;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID880455;
%put ERROR- Description                              : Drop several scoring parameter default categories which are no longer valid;
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 02AUG2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID880455;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID880455",
"Drop several scoring parameter default categories which are no longer valid",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID880455:;
 
 
* End of changes for CHANGE_ID:ID880455;
 
 
***********************************************************************************************;
*************************************  End Change ID880455 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID872973 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID872973;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID872973")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID872973;
%goto ID872973;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID872973;
* Insert record into change management table for CHANGE_ID: ID872973;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID872973",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID872973;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC_DETAILS set SPEC_VALUE_LIST_DELIMITER = '_' where SPEC_NM = 'FCST_BESTN_LIST'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DETAILS set SPEC_VALUE_LIST_DELIMITER = '_' where SPEC_NM = 'FCST_BESTS_LIST'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC_DETAILS set SPEC_VALUE_LIST_DELIMITER = '_' where SPEC_NM = 'FCST_BESTN_LIST';
 
 
update MODEL_SPEC_DETAILS set SPEC_VALUE_LIST_DELIMITER = '_' where SPEC_NM = 'FCST_BESTS_LIST';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID872973;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID872973;
%put ERROR- Description                              : FCST_BESTN_LIST and FCST_BESTS_LIST should support multiple underscore-separated values;
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 03AUG2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID872973;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID872973",
"FCST_BESTN_LIST and FCST_BESTS_LIST should support multiple underscore-separated values",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID872973:;
 
 
* End of changes for CHANGE_ID:ID872973;
 
 
***********************************************************************************************;
*************************************  End Change ID872973 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID886888_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID886888_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID886888_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID886888_2;
%goto ID886888_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID886888_2;
* Insert record into change management table for CHANGE_ID: ID886888_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID886888_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID886888_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
 
update &m_di_data..GLOBAL_SETTING set SPEC_VALUE = 'DefaultAuth'
where SPEC_NM ='ETL_WEBSERVICE_AUTHDOMAIN' and APP = 'ALL' and SPEC_VALUE = 'SOAPAuthDomain';
 
 
 
update &m_di_trans..GLOBAL_SETTING_DETAILS set DEFAULT_SPEC_VALUE = 'DefaultAuth'
where SPEC_NM ='ETL_WEBSERVICE_AUTHDOMAIN' and APP = 'ALL';
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
update &m_di_data..GLOBAL_SETTING set SPEC_VALUE = 'DefaultAuth'
where SPEC_NM ='ETL_WEBSERVICE_AUTHDOMAIN' and APP = 'ALL' and SPEC_VALUE = 'SOAPAuthDomain';
 
 
 
update &m_di_trans..GLOBAL_SETTING_DETAILS set DEFAULT_SPEC_VALUE = 'DefaultAuth'
where SPEC_NM ='ETL_WEBSERVICE_AUTHDOMAIN' and APP = 'ALL';
 
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID886888_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID886888_2;
%put ERROR- Description                              : Ensure ETL_WEBSERVICE_AUTHDOMAIN global setting value is DefaultAuth;
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 15AUG2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID886888_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID886888_2",
"Ensure ETL_WEBSERVICE_AUTHDOMAIN global setting value is DefaultAuth",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID886888_2:;
 
 
* End of changes for CHANGE_ID:ID886888_2;
 
 
***********************************************************************************************;
*************************************  End Change ID886888_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID888676 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID888676;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID888676")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID888676;
%goto ID888676;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID888676;
* Insert record into change management table for CHANGE_ID: ID888676;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID888676",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID888676;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC_DETAILS set GENERATE_PREFIX_NM = 'PS_'
where SPEC_NM ='PS_1' and MODEL_COMP_NM = 'ALL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DETAILS set GENERATE_SUFFIX_MAX = 'PS_TOTAL_LENGTH'
where SPEC_NM ='PS_1' and MODEL_COMP_NM = 'ALL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DETAILS set GENERATE_PREFIX_NM = 'CPS_'
where SPEC_NM ='CPS_1' and MODEL_COMP_NM = 'REG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DETAILS set GENERATE_SUFFIX_MAX = 'PS_TOTAL_LENGTH'
where SPEC_NM ='CPS_1' and MODEL_COMP_NM = 'REG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DETAILS set GENERATE_PREFIX_NM = 'HOLIDAY_'
where SPEC_NM ='HOLIDAY_1' and MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DETAILS set GENERATE_SUFFIX_MAX = 'HD_TOTAL_LENGTH'
where SPEC_NM ='HOLIDAY_1' and MODEL_COMP_NM = 'TS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DETAILS set GENERATE_PREFIX_NM = 'HOLIDAY_'
where SPEC_NM ='HOLIDAY_1' and MODEL_COMP_NM = 'REG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DETAILS set GENERATE_SUFFIX_MAX = 'HD_TOTAL_LENGTH'
where SPEC_NM ='HOLIDAY_1' and MODEL_COMP_NM = 'REG'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC_DETAILS set GENERATE_PREFIX_NM = 'PS_'
where SPEC_NM ='PS_1' and MODEL_COMP_NM = 'ALL';
 
 
update MODEL_SPEC_DETAILS set GENERATE_SUFFIX_MAX = 'PS_TOTAL_LENGTH'
where SPEC_NM ='PS_1' and MODEL_COMP_NM = 'ALL';
 
 
 
update MODEL_SPEC_DETAILS set GENERATE_PREFIX_NM = 'CPS_'
where SPEC_NM ='CPS_1' and MODEL_COMP_NM = 'REG';
 
 
update MODEL_SPEC_DETAILS set GENERATE_SUFFIX_MAX = 'PS_TOTAL_LENGTH'
where SPEC_NM ='CPS_1' and MODEL_COMP_NM = 'REG';
 
 
 
update MODEL_SPEC_DETAILS set GENERATE_PREFIX_NM = 'HOLIDAY_'
where SPEC_NM ='HOLIDAY_1' and MODEL_COMP_NM = 'TS';
 
 
update MODEL_SPEC_DETAILS set GENERATE_SUFFIX_MAX = 'HD_TOTAL_LENGTH'
where SPEC_NM ='HOLIDAY_1' and MODEL_COMP_NM = 'TS';
 
 
 
update MODEL_SPEC_DETAILS set GENERATE_PREFIX_NM = 'HOLIDAY_'
where SPEC_NM ='HOLIDAY_1' and MODEL_COMP_NM = 'REG';
 
 
update MODEL_SPEC_DETAILS set GENERATE_SUFFIX_MAX = 'HD_TOTAL_LENGTH'
where SPEC_NM ='HOLIDAY_1' and MODEL_COMP_NM = 'REG';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID888676;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID888676;
%put ERROR- Description                              : Fix PS_1, CPS_1, HOLIDAY_1 model spec details;
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 15AUG2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID888676;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID888676",
"Fix PS_1, CPS_1, HOLIDAY_1 model spec details",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID888676:;
 
 
* End of changes for CHANGE_ID:ID888676;
 
 
***********************************************************************************************;
*************************************  End Change ID888676 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID892275 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID892275;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID892275")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID892275;
%goto ID892275;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID892275;
* Insert record into change management table for CHANGE_ID: ID892275;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID892275",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID892275;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
proc sort data=di_dm2.fa_scoring_range_rule out=work.fa_scoring_range_rule_init;
 
 
by fa_scoring_rule_sk range_start_value range_end_value;
 
 
run;
 
 
 
 
data work.fa_scoring_range_rule;
 
 
set work.fa_scoring_range_rule_init;
 
 
drop prev_end_value;
 
 
by fa_scoring_rule_sk;
 
 
 
attrib precision length=8.;
 
 
drop precision;
 
 
retain prev_end_value;
 
 
 
 
precision=range_start_value-int(range_start_value);
 
 
precision=precision*100-int(precision*100/10)*10;
 
 
if int(precision)=1 then do;
 
 
range_start_value=int(range_start_value*10)/10+0.0001;
 
 
end;
 
 
 
/* This takes care of changes of the types from -1.99 to -1.9999 */
if not first.fa_scoring_rule_sk then do;
 
 
range_start_value=prev_end_value;
 
 
end;
 
 
 
prev_end_value=range_end_value+0.0001;
 
 
 
run;
 
 
 
 
 
proc sql;
 
 
 
update  di_dm2.fa_scoring_range_rule as T1
set range_start_value=(select range_start_value
from work.fa_scoring_range_rule as workTab
where T1.FA_SCORING_RANGE_RULE_SK=workTab.FA_SCORING_RANGE_RULE_SK
);
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
proc sort data=di_dm2.fa_scoring_range_rule out=work.fa_scoring_range_rule_init;
 
 
by fa_scoring_rule_sk range_start_value range_end_value;
 
 
run;
 
 
 
 
data work.fa_scoring_range_rule;
 
 
set work.fa_scoring_range_rule_init;
 
 
drop prev_end_value;
 
 
by fa_scoring_rule_sk;
 
 
 
attrib precision length=8.;
 
 
drop precision;
 
 
retain prev_end_value;
 
 
 
 
precision=range_start_value-int(range_start_value);
 
 
precision=precision*100-int(precision*100/10)*10;
 
 
if int(precision)=1 then do;
 
 
range_start_value=int(range_start_value*10)/10+0.0001;
 
 
end;
 
 
 
/* This takes care of changes of the types from -1.99 to -1.9999 */
if not first.fa_scoring_rule_sk then do;
 
 
range_start_value=prev_end_value;
 
 
end;
 
 
 
prev_end_value=range_end_value+0.0001;
 
 
 
run;
 
 
 
 
 
proc sql;
 
 
 
update  di_dm2.fa_scoring_range_rule as T1
set range_start_value=(select range_start_value
from work.fa_scoring_range_rule as workTab
where T1.FA_SCORING_RANGE_RULE_SK=workTab.FA_SCORING_RANGE_RULE_SK
);
 
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID892275;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID892275;
%put ERROR- Description                              : Scoring rules precision needs to be changed to 4 decimal places;
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 29AUG2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID892275;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID892275",
"Scoring rules precision needs to be changed to 4 decimal places",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID892275:;
 
 
* End of changes for CHANGE_ID:ID892275;
 
 
***********************************************************************************************;
*************************************  End Change ID892275 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID894017 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID894017;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID894017")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID894017;
%goto ID894017;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID894017;
* Insert record into change management table for CHANGE_ID: ID894017;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID894017",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID894017;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
 
update purge_query
set purge_order=13
where table_nm='GEO_PROD_STATUS'
and purge_order=12;
 
 
 
update purge_query
set purge_order=12
where table_nm='GEO_PROD'
and purge_order=13;
 
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
update purge_query
set purge_order=13
where table_nm='GEO_PROD_STATUS'
and purge_order=12;
 
 
 
update purge_query
set purge_order=12
where table_nm='GEO_PROD'
and purge_order=13;
 
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID894017;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID894017;
%put ERROR- Description                              : Change the purge order of Geo_Prod and Geo_prod_status in Purge_Query;
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 4SEP2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID894017;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID894017",
"Change the purge order of Geo_Prod and Geo_prod_status in Purge_Query",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID894017:;
 
 
* End of changes for CHANGE_ID:ID894017;
 
 
***********************************************************************************************;
*************************************  End Change ID894017 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID896165 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID896165;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID896165")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID896165;
%goto ID896165;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID896165;
* Insert record into change management table for CHANGE_ID: ID896165;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID896165",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID896165;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%if "&m_delete_and_start_fresh"^="TRUE" %then %do;
 
 
 
proc sql noprint;
 
 
select spec_value into :ps_val
from &m_di_data..global_setting
where upcase(spec_nm)='PS_TOTAL_LENGTH';
 
 
quit;
 
 
 
/* check if ps_val > 1 */
%if (&ps_val > 1) %then %do;
 
 
%do j = 2 %to &ps_val;
 
 
%let x = %sysfunc(compress('PS_', "'"))&j ;
 
 
 
proc sql;
 
 
delete from &m_di_trans..model_spec_values where spec_nm = 'PS_1' and MODEL_COMP_NM = 'REG' and SPEC_VALUE = '2';
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG','PS_1','2','auto_select.txt');
 
 
delete from &m_di_trans..model_spec_values where spec_nm = "&x";
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'1','include_force.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'2','auto_select.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'3','use_TS_level_estimates.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'4','force_effect_estimate.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'1','include_force.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'2','auto_select.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'4','force_effect_estimate.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'1','include_force.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'2','auto_select.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'4','force_effect_estimate.txt');
 
 
quit;
 
 
 
%end;
 
 
%end;
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%if "&m_delete_and_start_fresh"^="TRUE" %then %do;
 
 
 
proc sql noprint;
 
 
select spec_value into :ps_val
from &m_di_data..global_setting
where upcase(spec_nm)='PS_TOTAL_LENGTH';
 
 
quit;
 
 
 
/* check if ps_val > 1 */
%if (&ps_val > 1) %then %do;
 
 
%do j = 2 %to &ps_val;
 
 
%let x = %sysfunc(compress('PS_', "'"))&j ;
 
 
 
proc sql;
 
 
delete from &m_di_trans..model_spec_values where spec_nm = 'PS_1' and MODEL_COMP_NM = 'REG' and SPEC_VALUE = '2';
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG','PS_1','2','auto_select.txt');
 
 
delete from &m_di_trans..model_spec_values where spec_nm = "&x";
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'1','include_force.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'2','auto_select.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'3','use_TS_level_estimates.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'4','force_effect_estimate.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'1','include_force.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'2','auto_select.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'4','force_effect_estimate.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'1','include_force.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'2','auto_select.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'4','force_effect_estimate.txt');
 
 
quit;
 
 
 
%end;
 
 
%end;
 
 
 
%end;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID896165;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID896165;
%put ERROR- Description                              : Autogen spec expansion for PS_xx needs to include TS,REG components for model_spec_values;
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 11SEP2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID896165;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID896165",
"Autogen spec expansion for PS_xx needs to include TS,REG components for model_spec_values",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID896165:;
 
 
* End of changes for CHANGE_ID:ID896165;
 
 
***********************************************************************************************;
*************************************  End Change ID896165 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID903559 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID903559;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID903559")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID903559;
%goto ID903559;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID903559;
* Insert record into change management table for CHANGE_ID: ID903559;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID903559",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID903559;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-186, 2, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-171, 3, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-172, 5, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-173, 6, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-174, 7, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-175, 8, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-176,40, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-177,41, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-178,42, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-179,43, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-180,44, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-181,45, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-182,46, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-183,47, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-184,48, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-185,49, 7,'RegularPriceOverride', 1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-186, 2, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-171, 3, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-172, 5, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-173, 6, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-174, 7, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-175, 8, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-176,40, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-177,41, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-178,42, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-179,43, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-180,44, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-181,45, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-182,46, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-183,47, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-184,48, 7,'RegularPriceOverride', 1);
 
 
INSERT INTO CAT_CUSTOM_ATTR  (CAT_CUSTOM_ATTR_SK, OBJECT_CAT_SK, OBJECT_CAT_TYPE, ATTR_NM, ATTR_VALUE_TYPE)
VALUES  (-185,49, 7,'RegularPriceOverride', 1);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID903559;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID903559;
%put ERROR- Description                              : Add Support for Base Promotional Price;
%put ERROR- Version                                  : D3MICM521;
%put ERROR- Date of Change                           : 03OCT2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID903559;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID903559",
"Add Support for Base Promotional Price",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID903559:;
 
 
* End of changes for CHANGE_ID:ID903559;
 
 
***********************************************************************************************;
*************************************  End Change ID903559 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID890004 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID890004;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID890004")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID890004;
%goto ID890004;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID890004;
* Insert record into change management table for CHANGE_ID: ID890004;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID890004",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID890004;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from vehicle_category where VEHICLE_CATEGORY_SK = 9
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from vehicle_category where VEHICLE_CATEGORY_SK = 52
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from vehicle_category where VEHICLE_CATEGORY_SK = 54
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from CAT_CUSTOM_ATTR where OBJECT_CAT_TYPE = 7 and OBJECT_CAT_SK = 9
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from CAT_CUSTOM_ATTR where OBJECT_CAT_TYPE = 7 and OBJECT_CAT_SK = 52
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from CAT_CUSTOM_ATTR where OBJECT_CAT_TYPE = 7 and OBJECT_CAT_SK = 54
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from vehicle_category where VEHICLE_CATEGORY_SK = 9;
 
 
delete from vehicle_category where VEHICLE_CATEGORY_SK = 52;
 
 
delete from vehicle_category where VEHICLE_CATEGORY_SK = 54;
 
 
 
delete from CAT_CUSTOM_ATTR where OBJECT_CAT_TYPE = 7 and OBJECT_CAT_SK = 9;
 
 
delete from CAT_CUSTOM_ATTR where OBJECT_CAT_TYPE = 7 and OBJECT_CAT_SK = 52;
 
 
delete from CAT_CUSTOM_ATTR where OBJECT_CAT_TYPE = 7 and OBJECT_CAT_SK = 54;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID890004;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID890004;
%put ERROR- Description                              : Miles and Points not configured correctly by default in seed file for new installations;
%put ERROR- Version                                  : D3MICM521;
%put ERROR- Date of Change                           : 03OCT2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID890004;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID890004",
"Miles and Points not configured correctly by default in seed file for new installations",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID890004:;
 
 
* End of changes for CHANGE_ID:ID890004;
 
 
***********************************************************************************************;
*************************************  End Change ID890004 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID833636 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID833636;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID833636")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID833636;
%goto ID833636;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID833636;
* Insert record into change management table for CHANGE_ID: ID833636;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID833636",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID833636;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from vehicle_category where VEHICLE_CATEGORY_SK = 0
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from vehicle_category where VEHICLE_CATEGORY_SK = 0;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID833636;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID833636;
%put ERROR- Description                              : Removing Regular Price from default vehicle categories;
%put ERROR- Version                                  : D3MICM521;
%put ERROR- Date of Change                           : 03OCT2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID833636;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID833636",
"Removing Regular Price from default vehicle categories",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID833636:;
 
 
* End of changes for CHANGE_ID:ID833636;
 
 
***********************************************************************************************;
*************************************  End Change ID833636 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID903559_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID903559_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID903559_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID903559_2;
%goto ID903559_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID903559_2;
* Insert record into change management table for CHANGE_ID: ID903559_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID903559_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID903559_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM CAT_CUSTOM_ATTR WHERE CAT_CUSTOM_ATTR_SK <= -171 and CAT_CUSTOM_ATTR_SK  >= -186
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table RPP_PLAN_PROD_ASGMNT ADD PRICE_OVERRIDE_AMT NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM CAT_CUSTOM_ATTR WHERE CAT_CUSTOM_ATTR_SK <= -171 and CAT_CUSTOM_ATTR_SK  >= -186;
 
 
 
alter table RPP_PLAN_PROD_ASGMNT ADD PRICE_OVERRIDE_AMT NUMERIC(20,3);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID903559_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID903559_2;
%put ERROR- Description                              : Add Support for Base Promotional Price;
%put ERROR- Version                                  : D3MICM521;
%put ERROR- Date of Change                           : 03OCT2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID903559_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID903559_2",
"Add Support for Base Promotional Price",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID903559_2:;
 
 
* End of changes for CHANGE_ID:ID903559_2;
 
 
***********************************************************************************************;
*************************************  End Change ID903559_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID906501 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID906501;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID906501")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID906501;
%goto ID906501;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID906501;
* Insert record into change management table for CHANGE_ID: ID906501;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID906501",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID906501;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%if "&m_delete_and_start_fresh"^="TRUE" %then %do;
 
 
 
proc sql noprint;
 
 
select spec_value into :ps_val
from &m_di_data..global_setting
where upcase(spec_nm)='PS_TOTAL_LENGTH';
 
 
quit;
 
 
 
%do j = 1 %to &ps_val;
 
 
%let x = %sysfunc(compress('PS_', "'"))&j ;
 
 
 
proc sql;
 
 
delete from &m_di_trans..model_spec_values where spec_nm = "&x";
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'1','include_force.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'2','auto_select.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'4','force_effect_estimate.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'1','include_force.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'2','auto_select.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'4','force_effect_estimate.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'1','include_force.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'2','auto_select.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'4','force_effect_estimate.txt');
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%if "&m_delete_and_start_fresh"^="TRUE" %then %do;
 
 
 
proc sql noprint;
 
 
select spec_value into :ps_val
from &m_di_data..global_setting
where upcase(spec_nm)='PS_TOTAL_LENGTH';
 
 
quit;
 
 
 
%do j = 1 %to &ps_val;
 
 
%let x = %sysfunc(compress('PS_', "'"))&j ;
 
 
 
proc sql;
 
 
delete from &m_di_trans..model_spec_values where spec_nm = "&x";
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'1','include_force.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'2','auto_select.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('ALL',"&x",'4','force_effect_estimate.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'1','include_force.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'2','auto_select.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'4','force_effect_estimate.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'1','include_force.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'2','auto_select.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'4','force_effect_estimate.txt');
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID906501;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID906501;
%put ERROR- Description                              : Remove value 3 for PS_xx (ALL) model spec (ensure ALL, TS, REG the same);
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 12OCT2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID906501;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID906501",
"Remove value 3 for PS_xx (ALL) model spec (ensure ALL, TS, REG the same)",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID906501:;
 
 
* End of changes for CHANGE_ID:ID906501;
 
 
***********************************************************************************************;
*************************************  End Change ID906501 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0904989 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0904989;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0904989")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0904989;
%goto ID0904989;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0904989;
* Insert record into change management table for CHANGE_ID: ID0904989;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0904989",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0904989;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
 
%let m_app_user_cnt=0;
 
 
%let m_app_user_group_cnt=0;
 
 
%let m_app_user_perm_cnt=0;
 
 
proc sql noprint;
 
 
select count(*) into :m_app_user_cnt
from app_user where app_user_id = "&m_mi_cfg_sasmietl";
 
 
select count(*) into :m_app_user_group_cnt
from app_group where app_Group_id = "&m_mi_cfg_sasmietl._ug_";
 
 
select count(*) into :m_app_user_perm_cnt
from app_group where app_Group_id = "&m_mi_cfg_sasmietl._ep_";
 
 
quit;
 
 
 
%if ( %eval(&m_app_user_cnt) = 0) %then
%do;
 
 
 
proc sql noprint;
 
 
select max(app_user_sk)+1 into :m_app_user_sk from app_user where app_user_sk<99000;
 
 
 
 
INSERT INTO app_user (app_user_sk, app_user_id, app_user_nm, last_login_dttm)
VALUES (&m_app_user_sk, "&m_mi_cfg_sasmietl", 'SAS MI ETL User', '04NOV2004:07:00:00'dt);
 
 
quit;
 
 
 
%end;
 
 
 
%if ( %eval(&m_app_user_group_cnt) = 0 ) %then
%do;
 
 
proc sql noprint;
 
 
select max(app_group_sk)+1 into :m_mi_cfg_sasmietl_sk from app_group  where app_group_sk<99000;
 
 
 
INSERT INTO app_group(app_group_sk, app_Group_id, app_group_name, user_group_flg )
VALUES( &m_mi_cfg_sasmietl_sk, "&m_mi_cfg_sasmietl._ug_", 'SAS MI ETL User Group', 1 ) ;
 
 
select max(auth_sk)+1 into :m_mi_cfg_auth_sk from Data_authorization  where auth_sk<99000;
 
 
INSERT INTO Data_authorization(AUTH_SK, APP_GROUP_SK, PROD_HIER_SK, GEO_HIER_SK, PERMISSION_SK, AUTH_COMMENTS )
VALUES( &m_mi_cfg_auth_sk ,&m_mi_cfg_sasmietl_sk,1,1,1,"&m_mi_cfg_sasmietl gets read permission for all products, everywhere");
 
 
select max(auth_sk)+1 into :m_mi_cfg_auth_sk from Data_authorization  where auth_sk<99000;
 
 
INSERT INTO Data_authorization(AUTH_SK, APP_GROUP_SK, PROD_HIER_SK, GEO_HIER_SK, PERMISSION_SK, AUTH_COMMENTS )
VALUES( &m_mi_cfg_auth_sk  ,&m_mi_cfg_sasmietl_sk,1,1,2,"&m_mi_cfg_sasmietl gets write permission for all products, everywhere");
 
 
quit;
 
 
 
%end;
 
 
 
%if ( %eval(&m_app_user_perm_cnt) = 0 ) %then
%do;
 
 
 
 
proc sql noprint;
 
 
 
select max(app_group_sk)+1 into :m_mi_cfg_sasmietl_sk from app_group  where app_group_sk<99000;
 
 
INSERT INTO app_group(app_group_sk, app_Group_id, app_group_name, user_group_flg )
VALUES( &m_mi_cfg_sasmietl_sk, "&m_mi_cfg_sasmietl._ep_", 'SAS MI ETL User Perms', 2 ) ;
 
 
quit;
 
 
 
%end;
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
 
%let m_app_user_cnt=0;
 
 
%let m_app_user_group_cnt=0;
 
 
%let m_app_user_perm_cnt=0;
 
 
proc sql noprint;
 
 
select count(*) into :m_app_user_cnt
from app_user where app_user_id = "&m_mi_cfg_sasmietl";
 
 
select count(*) into :m_app_user_group_cnt
from app_group where app_Group_id = "&m_mi_cfg_sasmietl._ug_";
 
 
select count(*) into :m_app_user_perm_cnt
from app_group where app_Group_id = "&m_mi_cfg_sasmietl._ep_";
 
 
quit;
 
 
 
%if ( %eval(&m_app_user_cnt) = 0) %then
%do;
 
 
 
proc sql noprint;
 
 
select max(app_user_sk)+1 into :m_app_user_sk from app_user where app_user_sk<99000;
 
 
 
 
INSERT INTO app_user (app_user_sk, app_user_id, app_user_nm, last_login_dttm)
VALUES (&m_app_user_sk, "&m_mi_cfg_sasmietl", 'SAS MI ETL User', '04NOV2004:07:00:00'dt);
 
 
quit;
 
 
 
%end;
 
 
 
%if ( %eval(&m_app_user_group_cnt) = 0 ) %then
%do;
 
 
proc sql noprint;
 
 
select max(app_group_sk)+1 into :m_mi_cfg_sasmietl_sk from app_group  where app_group_sk<99000;
 
 
 
INSERT INTO app_group(app_group_sk, app_Group_id, app_group_name, user_group_flg )
VALUES( &m_mi_cfg_sasmietl_sk, "&m_mi_cfg_sasmietl._ug_", 'SAS MI ETL User Group', 1 ) ;
 
 
select max(auth_sk)+1 into :m_mi_cfg_auth_sk from Data_authorization  where auth_sk<99000;
 
 
INSERT INTO Data_authorization(AUTH_SK, APP_GROUP_SK, PROD_HIER_SK, GEO_HIER_SK, PERMISSION_SK, AUTH_COMMENTS )
VALUES( &m_mi_cfg_auth_sk ,&m_mi_cfg_sasmietl_sk,1,1,1,"&m_mi_cfg_sasmietl gets read permission for all products, everywhere");
 
 
select max(auth_sk)+1 into :m_mi_cfg_auth_sk from Data_authorization  where auth_sk<99000;
 
 
INSERT INTO Data_authorization(AUTH_SK, APP_GROUP_SK, PROD_HIER_SK, GEO_HIER_SK, PERMISSION_SK, AUTH_COMMENTS )
VALUES( &m_mi_cfg_auth_sk  ,&m_mi_cfg_sasmietl_sk,1,1,2,"&m_mi_cfg_sasmietl gets write permission for all products, everywhere");
 
 
quit;
 
 
 
%end;
 
 
 
%if ( %eval(&m_app_user_perm_cnt) = 0 ) %then
%do;
 
 
 
 
proc sql noprint;
 
 
 
select max(app_group_sk)+1 into :m_mi_cfg_sasmietl_sk from app_group  where app_group_sk<99000;
 
 
INSERT INTO app_group(app_group_sk, app_Group_id, app_group_name, user_group_flg )
VALUES( &m_mi_cfg_sasmietl_sk, "&m_mi_cfg_sasmietl._ep_", 'SAS MI ETL User Perms', 2 ) ;
 
 
quit;
 
 
 
%end;
 
 
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0904989;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0904989;
%put ERROR- Description                              : Add SASMIETL to app_user while migrating;
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 19OCT2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0904989;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0904989",
"Add SASMIETL to app_user while migrating",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0904989:;
 
 
* End of changes for CHANGE_ID:ID0904989;
 
 
***********************************************************************************************;
*************************************  End Change ID0904989 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID914459_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID914459_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID914459_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID914459_1;
%goto ID914459_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID914459_1;
* Insert record into change management table for CHANGE_ID: ID914459_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914459_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID914459_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%if "&m_delete_and_start_fresh"^="TRUE" %then %do;
 
 
 
proc sql noprint;
 
 
select spec_value into :hd_val
from &m_di_data..global_setting
where upcase(spec_nm)='HD_TOTAL_LENGTH';
 
 
quit;
 
 
 
%do j = 1 %to &hd_val;
 
 
%let x = %sysfunc(compress('HOLIDAY_', "'"))&j ;
 
 
 
proc sql;
 
 
delete from &m_di_trans..model_spec_values where spec_nm = "&x";
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'1','mspec.HOLIDAY_1.pmeaning.1.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'2','mspec.HOLIDAY_1.pmeaning.2.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'4','force_effect_estimate.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'1','mspec.HOLIDAY_1.pmeaning.1.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'2','mspec.HOLIDAY_1.pmeaning.2.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'4','force_effect_estimate.txt');
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%if "&m_delete_and_start_fresh"^="TRUE" %then %do;
 
 
 
proc sql noprint;
 
 
select spec_value into :hd_val
from &m_di_data..global_setting
where upcase(spec_nm)='HD_TOTAL_LENGTH';
 
 
quit;
 
 
 
%do j = 1 %to &hd_val;
 
 
%let x = %sysfunc(compress('HOLIDAY_', "'"))&j ;
 
 
 
proc sql;
 
 
delete from &m_di_trans..model_spec_values where spec_nm = "&x";
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'1','mspec.HOLIDAY_1.pmeaning.1.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'2','mspec.HOLIDAY_1.pmeaning.2.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('TS',"&x",'4','force_effect_estimate.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'0','do_NOT_include.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'1','mspec.HOLIDAY_1.pmeaning.1.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'2','mspec.HOLIDAY_1.pmeaning.2.txt');
 
 
insert into &m_di_trans..model_spec_values (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG',"&x",'4','force_effect_estimate.txt');
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID914459_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID914459_1;
%put ERROR- Description                              : Ensure values 0, 1, 2 and 4 for HOLIDAY_xx specs;
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 06NO2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID914459_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914459_1",
"Ensure values 0, 1, 2 and 4 for HOLIDAY_xx specs",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID914459_1:;
 
 
* End of changes for CHANGE_ID:ID914459_1;
 
 
***********************************************************************************************;
*************************************  End Change ID914459_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID914459_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID914459_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID914459_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID914459_2;
%goto ID914459_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID914459_2;
* Insert record into change management table for CHANGE_ID: ID914459_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914459_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID914459_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where MODEL_COMP_NM = 'REG' and SPEC_NM = 'LCP' and SPEC_VALUE = '4'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_VALUES (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG','LCP','4','force_effect_estimate_2.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DETAILS set SPEC_DATATYPE = 'MultiValue' where MODEL_COMP_NM = 'REG' and SPEC_NM = 'LCP'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_VALUES where MODEL_COMP_NM = 'REG' and SPEC_NM = 'LCP' and SPEC_VALUE = '4';
 
 
insert into MODEL_SPEC_VALUES (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG','LCP','4','force_effect_estimate_2.txt');
 
 
update MODEL_SPEC_DETAILS set SPEC_DATATYPE = 'MultiValue' where MODEL_COMP_NM = 'REG' and SPEC_NM = 'LCP';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID914459_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID914459_2;
%put ERROR- Description                              : Add value 4 for LCP;
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 06NO2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID914459_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914459_2",
"Add value 4 for LCP",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID914459_2:;
 
 
* End of changes for CHANGE_ID:ID914459_2;
 
 
***********************************************************************************************;
*************************************  End Change ID914459_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID914459_3 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID914459_3;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID914459_3")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID914459_3;
%goto ID914459_3;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M1MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID914459_3;
* Insert record into change management table for CHANGE_ID: ID914459_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914459_3",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID914459_3;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'INV_ADJ' and SPEC_VALUE = '3'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where MODEL_GROUP_ID ^= -1 and (SPEC_NM = 'INV_ADJ' and SPEC_VALUE = '3')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_VALUE = '0'
where (MODEL_GROUP_ID = -1 and SPEC_NM = 'INV_ADJ' and SPEC_VALUE = '3')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '0'
where (SPEC_NM = 'INV_ADJ' and DEFAULT_SPEC_VALUE = '3')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'PL_ADJ' and SPEC_VALUE = '3'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where MODEL_GROUP_ID ^= -1 and (SPEC_NM = 'PL_ADJ' and SPEC_VALUE = '3')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_VALUE = '0'
where (MODEL_GROUP_ID = -1 and SPEC_NM = 'PL_ADJ' and SPEC_VALUE = '3')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '0'
where (SPEC_NM = 'PL_ADJ' and DEFAULT_SPEC_VALUE = '3')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where MODEL_COMP_NM = 'REG' and SPEC_NM = 'PL_ADJ' and SPEC_VALUE = '2'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_VALUES (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG','PL_ADJ','2','auto_select.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'INV_ADJ' and SPEC_VALUE = '3';
 
 
delete from MODEL_SPEC where MODEL_GROUP_ID ^= -1 and (SPEC_NM = 'INV_ADJ' and SPEC_VALUE = '3');
 
 
update MODEL_SPEC set SPEC_VALUE = '0'
where (MODEL_GROUP_ID = -1 and SPEC_NM = 'INV_ADJ' and SPEC_VALUE = '3');
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '0'
where (SPEC_NM = 'INV_ADJ' and DEFAULT_SPEC_VALUE = '3');
 
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'PL_ADJ' and SPEC_VALUE = '3';
 
 
delete from MODEL_SPEC where MODEL_GROUP_ID ^= -1 and (SPEC_NM = 'PL_ADJ' and SPEC_VALUE = '3');
 
 
update MODEL_SPEC set SPEC_VALUE = '0'
where (MODEL_GROUP_ID = -1 and SPEC_NM = 'PL_ADJ' and SPEC_VALUE = '3');
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '0'
where (SPEC_NM = 'PL_ADJ' and DEFAULT_SPEC_VALUE = '3');
 
 
delete from MODEL_SPEC_VALUES where MODEL_COMP_NM = 'REG' and SPEC_NM = 'PL_ADJ' and SPEC_VALUE = '2';
 
 
insert into MODEL_SPEC_VALUES (MODEL_COMP_NM,SPEC_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('REG','PL_ADJ','2','auto_select.txt');
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID914459_3;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID914459_3;
%put ERROR- Description                              : Remove value 3 for INV_ADJ and PL_ADJ;
%put ERROR- Version                                  : M1MICM521;
%put ERROR- Date of Change                           : 06NO2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID914459_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914459_3",
"Remove value 3 for INV_ADJ and PL_ADJ",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID914459_3:;
 
 
* End of changes for CHANGE_ID:ID914459_3;
 
 
***********************************************************************************************;
*************************************  End Change ID914459_3 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0868950_0 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0868950_0;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0868950_0")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0868950_0;
%goto ID0868950_0;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0868950_0;
* Insert record into change management table for CHANGE_ID: ID0868950_0;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0868950_0",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0868950_0;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD USE_PACK_DEFAULTS INTEGER DEFAULT 0 NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD USE_PACK_DEFAULTS INTEGER DEFAULT 0 NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
data &m_di_trans..PKO_BUY;
 
 
set &m_di_trans..PKO_BUY;
 
 
ATTRIB USE_PACK_DEFAULTS LENGTH=4;
 
 
USE_PACK_DEFAULTS=0;
 
 
RUN;
 
 
 
proc sql;
 
 
alter table &m_di_trans..PKO_BUY add NOT NULL (USE_PACK_DEFAULTS);
 
 
quit;
 
 
 
data &m_di_trans..PKO_DELIVERY;
 
 
set &m_di_trans..PKO_DELIVERY;
 
 
ATTRIB USE_PACK_DEFAULTS LENGTH=4;
 
 
USE_PACK_DEFAULTS=1;
 
 
RUN;
 
 
 
proc sql;
 
 
alter table &m_di_trans..PKO_DELIVERY add NOT NULL (USE_PACK_DEFAULTS);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0868950_0;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0868950_0;
%put ERROR- Description                              : Set defaults by geo x prod x delivery-type;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 25JAN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0868950_0;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0868950_0",
"Set defaults by geo x prod x delivery-type",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0868950_0:;
 
 
* End of changes for CHANGE_ID:ID0868950_0;
 
 
***********************************************************************************************;
*************************************  End Change ID0868950_0 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0868950_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0868950_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0868950_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0868950_1;
%goto ID0868950_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0868950_1;
* Insert record into change management table for CHANGE_ID: ID0868950_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0868950_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0868950_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE PKO_PACK_DEFAULT
(
PACK_DEFAULT_SK                    INTEGER NOT NULL,
DELIVERY_TYPE_ID                   INTEGER,
PROD_HIER_SK                       INTEGER NOT NULL,
LOOKUP_PACKS                       INTEGER NOT NULL,
ALLOW_PRIOR_DELIVERY_PACKS         INTEGER,
REC_MULTICOLOR                     INTEGER,
BREAK_PACKS                        INTEGER,
USE_SHARED_PACK_CONFIGS            INTEGER,
NUM_PACK_REC_MAX                   INTEGER,
SIZE_OF_OUTER_MAX                  INTEGER,
OPEN_COST_PER_INNER                NUMERIC(20,3),
OUTER_HANDLE_DSCT_RATE             NUMERIC(12,4),
PRIMARY KEY (PACK_DEFAULT_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_PACK_DEFAULT_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX PKO_PACK_DEFAULT_IX1 ON PKO_PACK_DEFAULT
(
PROD_HIER_SK
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX PKO_PACK_DEFAULT_IX2 ON PKO_PACK_DEFAULT
(
DELIVERY_TYPE_ID
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PKO_PACKREC_INNER_DEFAULT
(
PACKREC_INNER_DEFAULT_SK           INTEGER NOT NULL,
PACK_DEFAULT_SK                    INTEGER,
SIZE_OF_INNER                      INTEGER NOT NULL,
INNER_HANDLE_COST                  NUMERIC(20,3),
PRIMARY KEY (PACKREC_INNER_DEFAULT_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_PACKREC_INNER_DEFAULT_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PKO_BULK_PACK_SIZE_DEFAULT
(
BULK_PACK_SIZE_DEFAULT_SK          INTEGER NOT NULL,
PACK_DEFAULT_SK                    INTEGER,
BULKSIZE                           INTEGER NOT NULL,
INNER_PACK_HANDLE_COST             NUMERIC(20,3),
OUTER_PACK_HANDLE_COST             NUMERIC(20,3),
OPENING_COST                       NUMERIC(20,3),
PRIMARY KEY (BULK_PACK_SIZE_DEFAULT_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_BULK_PACK_SIZE_DEFAULT_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PKO_LIMIT_PACK_DEFAULT
(
LIMIT_PACK_DEFAULT_SK              INTEGER NOT NULL,
PACK_DEFAULT_SK                    INTEGER,
PACK_SK                            INTEGER NOT NULL,
PRIMARY KEY (LIMIT_PACK_DEFAULT_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_LIMIT_PACK_DEFAULT_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
PROC SQL;
 
 
 
CREATE TABLE PKO_PACK_DEFAULT
(
PACK_DEFAULT_SK                    INTEGER NOT NULL,
DELIVERY_TYPE_ID                   INTEGER,
PROD_HIER_SK                       INTEGER NOT NULL,
LOOKUP_PACKS                       INTEGER NOT NULL,
ALLOW_PRIOR_DELIVERY_PACKS         INTEGER,
REC_MULTICOLOR                     INTEGER,
BREAK_PACKS                        INTEGER,
USE_SHARED_PACK_CONFIGS            INTEGER,
NUM_PACK_REC_MAX                   INTEGER,
SIZE_OF_OUTER_MAX                  INTEGER,
OPEN_COST_PER_INNER                NUMERIC(20,3),
OUTER_HANDLE_DSCT_RATE             NUMERIC(12,4)
)
;
 
 
 
ALTER TABLE PKO_PACK_DEFAULT add CONSTRAINT PRIM_KEY PRIMARY KEY (PACK_DEFAULT_SK);
 
 
 
CREATE TABLE PKO_PACKREC_INNER_DEFAULT
(
PACKREC_INNER_DEFAULT_SK           INTEGER NOT NULL,
PACK_DEFAULT_SK                    INTEGER,
SIZE_OF_INNER                      INTEGER NOT NULL,
INNER_HANDLE_COST                  NUMERIC(20,3)
)
;
 
 
 
ALTER TABLE PKO_PACKREC_INNER_DEFAULT add CONSTRAINT PRIM_KEY PRIMARY KEY (PACKREC_INNER_DEFAULT_SK);
 
 
 
CREATE TABLE PKO_BULK_PACK_SIZE_DEFAULT
(
BULK_PACK_SIZE_DEFAULT_SK          INTEGER NOT NULL,
PACK_DEFAULT_SK                    INTEGER,
BULKSIZE                           INTEGER NOT NULL,
INNER_PACK_HANDLE_COST             NUMERIC(20,3),
OUTER_PACK_HANDLE_COST             NUMERIC(20,3),
OPENING_COST                       NUMERIC(20,3)
)
;
 
 
 
ALTER TABLE PKO_BULK_PACK_SIZE_DEFAULT add CONSTRAINT PRIM_KEY PRIMARY KEY (BULK_PACK_SIZE_DEFAULT_SK);
 
 
 
CREATE TABLE PKO_LIMIT_PACK_DEFAULT
(
LIMIT_PACK_DEFAULT_SK              INTEGER NOT NULL,
PACK_DEFAULT_SK                    INTEGER,
PACK_SK                            INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE PKO_LIMIT_PACK_DEFAULT add CONSTRAINT PRIM_KEY PRIMARY KEY (LIMIT_PACK_DEFAULT_SK);
 
 
 
QUIT;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0868950_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0868950_1;
%put ERROR- Description                              : Set defaults by geo x prod x delivery-type;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 25JAN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0868950_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0868950_1",
"Set defaults by geo x prod x delivery-type",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0868950_1:;
 
 
* End of changes for CHANGE_ID:ID0868950_1;
 
 
***********************************************************************************************;
*************************************  End Change ID0868950_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID938932 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID938932;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID938932")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID938932;
%goto ID938932;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID938932;
* Insert record into change management table for CHANGE_ID: ID938932;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID938932",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID938932;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN ADD PRICE_CHG_DIRECTION INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN ADD TARGET_CPI_MIN NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN ADD TARGET_CPI_MAX NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE RPO_PLAN ADD PRICE_CHG_DIRECTION INTEGER;
 
 
 
ALTER TABLE RPO_PLAN ADD TARGET_CPI_MIN NUMERIC(12,4);
 
 
ALTER TABLE RPO_PLAN ADD TARGET_CPI_MAX NUMERIC(12,4);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID938932;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID938932;
%put ERROR- Description                              : see defect S0938932;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 02FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID938932;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID938932",
"see defect S0938932",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID938932:;
 
 
* End of changes for CHANGE_ID:ID938932;
 
 
***********************************************************************************************;
*************************************  End Change ID938932 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID914979_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID914979_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID914979_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID914979_1;
%goto ID914979_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID914979_1;
* Insert record into change management table for CHANGE_ID: ID914979_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914979_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID914979_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
create table data_config_template_bk as select * from data_config_template
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from data_config_template
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table data_config_template modify config_template_nm varchar2(100)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table data_config_template modify config_template_desc varchar2(500)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into data_config_template (CONFIG_TEMPLATE_ID,CONFIG_TEMPLATE_NM,CONFIG_TEMPLATE_DESC,
TS_GEO_LVL,TS_PROD_LVL,TS_BY_GEO_LVL,TS_BY_PROD_LVL,REG_GEO_LVL,REG_PROD_LVL,REG_BY_GEO_LVL,REG_BY_PROD_LVL,
DOW_GEO_LVL,DOW_PROD_LVL,DOW_BY_GEO_LVL,DOW_BY_PROD_LVL,CREATED_BY,CREATED_DTTM)
(select CONFIG_TEMPLATE_ID,CONFIG_TEMPLATE_NM,CONFIG_TEMPLATE_DESC,
TS_GEO_LVL,TS_PROD_LVL,TS_BY_GEO_LVL,TS_BY_PROD_LVL,REG_GEO_LVL,REG_PROD_LVL,REG_BY_GEO_LVL,REG_BY_PROD_LVL,
DOW_GEO_LVL,DOW_PROD_LVL,DOW_BY_GEO_LVL,DOW_BY_PROD_LVL,CREATED_BY,CREATED_DTTM from data_config_template_bk)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
drop table data_config_template_bk
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
create table DATA_CONFIG_TEMPLATE_BK as select * from &m_di_trans..DATA_CONFIG_TEMPLATE;
 
 
drop table &m_di_trans..DATA_CONFIG_TEMPLATE;
 
 
create table &m_di_trans..DATA_CONFIG_TEMPLATE
(
CONFIG_TEMPLATE_ID          INTEGER NOT NULL,
CONFIG_TEMPLATE_NM          VARCHAR(100),
CONFIG_TEMPLATE_DESC        VARCHAR(500),
TS_GEO_LVL                  INTEGER,
TS_PROD_LVL                 INTEGER,
TS_BY_GEO_LVL               INTEGER,
TS_BY_PROD_LVL              INTEGER,
REG_GEO_LVL                 INTEGER,
REG_PROD_LVL                INTEGER,
REG_BY_GEO_LVL              INTEGER,
REG_BY_PROD_LVL             INTEGER,
DOW_GEO_LVL                 INTEGER,
DOW_PROD_LVL                INTEGER,
DOW_BY_GEO_LVL              INTEGER,
DOW_BY_PROD_LVL             INTEGER,
CREATED_BY                  VARCHAR(20),
CREATED_DTTM                DATE
)
;
 
 
alter table &m_di_trans..DATA_CONFIG_TEMPLATE add CONSTRAINT PRIM_KEY PRIMARY KEY (CONFIG_TEMPLATE_ID);
 
 
insert into &m_di_trans..DATA_CONFIG_TEMPLATE (CONFIG_TEMPLATE_ID,CONFIG_TEMPLATE_NM,CONFIG_TEMPLATE_DESC,
TS_GEO_LVL,TS_PROD_LVL,TS_BY_GEO_LVL,TS_BY_PROD_LVL,REG_GEO_LVL,REG_PROD_LVL,REG_BY_GEO_LVL,REG_BY_PROD_LVL,
DOW_GEO_LVL,DOW_PROD_LVL,DOW_BY_GEO_LVL,DOW_BY_PROD_LVL,CREATED_BY,CREATED_DTTM)
(select CONFIG_TEMPLATE_ID,CONFIG_TEMPLATE_NM,CONFIG_TEMPLATE_DESC,
TS_GEO_LVL,TS_PROD_LVL,TS_BY_GEO_LVL,TS_BY_PROD_LVL,REG_GEO_LVL,REG_PROD_LVL,REG_BY_GEO_LVL,REG_BY_PROD_LVL,
DOW_GEO_LVL,DOW_PROD_LVL,DOW_BY_GEO_LVL,DOW_BY_PROD_LVL,CREATED_BY,CREATED_DTTM from DATA_CONFIG_TEMPLATE_BK);
 
 
drop table DATA_CONFIG_TEMPLATE_BK;
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID914979_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID914979_1;
%put ERROR- Description                              : Support additional default model group templates - schema change;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 03FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID914979_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914979_1",
"Support additional default model group templates - schema change",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID914979_1:;
 
 
* End of changes for CHANGE_ID:ID914979_1;
 
 
***********************************************************************************************;
*************************************  End Change ID914979_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID914979_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID914979_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID914979_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID914979_2;
%goto ID914979_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID914979_2;
* Insert record into change management table for CHANGE_ID: ID914979_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914979_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID914979_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
options lrecl=2000;
 
 
%include "%di_util_misc_path()/dbmsc/default_model_group_templates.sas";
 
 
 
proc sql noprint;
 
 
update &m_di_trans..DATA_CONFIG_TEMPLATE set CREATED_DTTM = '03FEB2013:00:00:00.00'dt;
 
 
update &m_di_trans..MODEL_SPEC_TEMPLATE set CREATED_DTTM = '03FEB2013:00:00:00.00'dt;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
options lrecl=2000;
 
 
%include "%di_util_misc_path()/dbmsc/default_model_group_templates.sas";
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID914979_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID914979_2;
%put ERROR- Description                              : Support additional default model group templates - template inserts;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 03FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID914979_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914979_2",
"Support additional default model group templates - template inserts",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID914979_2:;
 
 
* End of changes for CHANGE_ID:ID914979_2;
 
 
***********************************************************************************************;
*************************************  End Change ID914979_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID914979_3 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID914979_3;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID914979_3")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID914979_3;
%goto ID914979_3;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID914979_3;
* Insert record into change management table for CHANGE_ID: ID914979_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914979_3",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID914979_3;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql noprint;
 
 
select spec_value into :hd_val from &m_di_data..global_setting where upcase(spec_nm)='HD_TOTAL_LENGTH';
 
 
select spec_value into :ps_val from &m_di_data..global_setting where upcase(spec_nm)='PS_TOTAL_LENGTH';
 
 
quit;
 
 
 
%do j = 2 %to &hd_val;
 
 
%let x = %sysfunc(compress('HOLIDAY_', "'"))&j ;
 
 
 
proc sql;
 
 
delete from &m_di_trans..model_spec_template where SPEC_NM = "&x" and MODEL_SPEC_ID in (2,3,4,5,6,7,8);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (2,'TS',"&x",'-1', '2',NULL,'CWB Seed','03FEB2013:00:00:00.00'dt);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (3,'TS',"&x",'-1', '2',NULL,'CWB Seed','03FEB2013:00:00:00.00'dt);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (4,'TS',"&x",'-1', '2',NULL,'CWB Seed','03FEB2013:00:00:00.00'dt);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (5,'TS',"&x",'-1', '2',NULL,'CWB Seed','03FEB2013:00:00:00.00'dt);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (6,'TS',"&x",'-1', '2',NULL,'CWB Seed','03FEB2013:00:00:00.00'dt);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (7,'TS',"&x",'-1', '2',NULL,'CWB Seed','03FEB2013:00:00:00.00'dt);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (8,'TS',"&x",'-1', '2',NULL,'CWB Seed','03FEB2013:00:00:00.00'dt);
 
 
quit;
 
 
 
%end;
 
 
 
%do k = 2 %to &ps_val;
 
 
%let y = %sysfunc(compress('PS_', "'"))&k ;
 
 
 
proc sql;
 
 
delete from &m_di_trans..model_spec_template where SPEC_NM = "&y" and MODEL_SPEC_ID in (5,6,7,8);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (5,'ALL',"&y",'2','2',NULL,'CWB Seed','03FEB2013:00:00:00.00'dt);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (6,'ALL',"&y",'1','2',NULL,'CWB Seed','03FEB2013:00:00:00.00'dt);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (7,'ALL',"&y",'1','2',NULL,'CWB Seed','03FEB2013:00:00:00.00'dt);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (8,'ALL',"&y",'1','4',NULL,'CWB Seed','03FEB2013:00:00:00.00'dt);
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
select spec_value into :hd_val from &m_di_data..global_setting where upcase(spec_nm)='HD_TOTAL_LENGTH';
 
 
select spec_value into :ps_val from &m_di_data..global_setting where upcase(spec_nm)='PS_TOTAL_LENGTH';
 
 
quit;
 
 
 
%do j = 2 %to &hd_val;
 
 
%let x = %sysfunc(compress('HOLIDAY_', "'"))&j ;
 
 
 
proc sql;
 
 
delete from &m_di_trans..model_spec_template where SPEC_NM = "&x" and MODEL_SPEC_ID in (2,3,4,5,6,7,8);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (2,'TS',"&x",'-1', '2',NULL,'CWB Seed','03-FEB-13'd);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (3,'TS',"&x",'-1', '2',NULL,'CWB Seed','03-FEB-13'd);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (4,'TS',"&x",'-1', '2',NULL,'CWB Seed','03-FEB-13'd);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (5,'TS',"&x",'-1', '2',NULL,'CWB Seed','03-FEB-13'd);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (6,'TS',"&x",'-1', '2',NULL,'CWB Seed','03-FEB-13'd);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (7,'TS',"&x",'-1', '2',NULL,'CWB Seed','03-FEB-13'd);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE, SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (8,'TS',"&x",'-1', '2',NULL,'CWB Seed','03-FEB-13'd);
 
 
quit;
 
 
 
%end;
 
 
 
%do k = 2 %to &ps_val;
 
 
%let y = %sysfunc(compress('PS_', "'"))&k ;
 
 
 
proc sql;
 
 
delete from &m_di_trans..model_spec_template where SPEC_NM = "&y" and MODEL_SPEC_ID in (5,6,7,8);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (5,'ALL',"&y",'2','2',NULL,'CWB Seed','03-FEB-13'd);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (6,'ALL',"&y",'1','2',NULL,'CWB Seed','03-FEB-13'd);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (7,'ALL',"&y",'1','2',NULL,'CWB Seed','03-FEB-13'd);
 
 
insert into &m_di_trans..model_spec_template (MODEL_SPEC_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_BY,CREATED_DTTM)
values (8,'ALL',"&y",'1','4',NULL,'CWB Seed','03-FEB-13'd);
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID914979_3;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID914979_3;
%put ERROR- Description                              : Support additional default model group templates - HOLIDAY and PS expansion;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 03FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID914979_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914979_3",
"Support additional default model group templates - HOLIDAY and PS expansion",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID914979_3:;
 
 
* End of changes for CHANGE_ID:ID914979_3;
 
 
***********************************************************************************************;
*************************************  End Change ID914979_3 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID914979_4 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID914979_4;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID914979_4")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID914979_4;
%goto ID914979_4;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID914979_4;
* Insert record into change management table for CHANGE_ID: ID914979_4;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914979_4",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID914979_4;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE MODEL_SPEC_TEMPLATE SET SPEC_VALUE = '1' WHERE (MODEL_SPEC_ID = 5
and SPEC_NM = 'FCST_DISAGG_GEO_LVL_OFFSET')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
UPDATE MODEL_SPEC_TEMPLATE SET SPEC_VALUE = '1' WHERE (MODEL_SPEC_ID = 5
and SPEC_NM = 'FCST_DISAGG_GEO_LVL_OFFSET');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID914979_4;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID914979_4;
%put ERROR- Description                              : Correction to template 5 - FCST_DISAGG_GEO_LVL_OFFSET;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 07FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID914979_4;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914979_4",
"Correction to template 5 - FCST_DISAGG_GEO_LVL_OFFSET",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID914979_4:;
 
 
* End of changes for CHANGE_ID:ID914979_4;
 
 
***********************************************************************************************;
*************************************  End Change ID914979_4 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0868950_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0868950_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0868950_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0868950_2;
%goto ID0868950_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0868950_2;
* Insert record into change management table for CHANGE_ID: ID0868950_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0868950_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0868950_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE PKO_DELIVERY_STORE_GROUP
(
DELIVERY_STORE_GROUP_SK               INTEGER NOT NULL,
DELIVERY_SK                           INTEGER,
GEO_GROUP_SK                          INTEGER,
STORE_GROUP_NM                        VARCHAR(40),
PRIMARY KEY (DELIVERY_STORE_GROUP_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_DELIVERY_STORE_GROUP_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
PROC SQL;
 
 
 
CREATE TABLE PKO_DELIVERY_STORE_GROUP
(
DELIVERY_STORE_GROUP_SK               INTEGER NOT NULL,
DELIVERY_SK                           INTEGER,
GEO_GROUP_SK                          INTEGER,
STORE_GROUP_NM                        VARCHAR(40)
)
;
 
 
 
ALTER TABLE PKO_DELIVERY_STORE_GROUP add CONSTRAINT PRIM_KEY PRIMARY KEY (DELIVERY_STORE_GROUP_SK);
 
 
 
QUIT;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0868950_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0868950_2;
%put ERROR- Description                              : Set planned quantities by style/color/location in manual plans;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 09FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0868950_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0868950_2",
"Set planned quantities by style/color/location in manual plans",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0868950_2:;
 
 
* End of changes for CHANGE_ID:ID0868950_2;
 
 
***********************************************************************************************;
*************************************  End Change ID0868950_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID943853_GPSTATUS_create ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID943853_GPSTATUS_create;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID943853_GPSTATUS_create")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID943853_GPSTATUS_create;
%goto ID943853_GPSTATUS_create;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID943853_GPSTATUS_create;
* Insert record into change management table for CHANGE_ID: ID943853_GPSTATUS_create;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID943853_GPSTATUS_create",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID943853_GPSTATUS_create;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE GLOBAL_GEO_PROD_STATUS_RULE
(
PROD_HIER_SK                INTEGER NOT NULL,
RULE_NM                     VARCHAR(32) NOT NULL,
RULE_VALUE                  VARCHAR(100),
SPEC_VALUE                  VARCHAR(200),
CREATED_DTTM                DATE,
CREATED_BY                  VARCHAR(20),
PRIMARY KEY (PROD_HIER_SK,RULE_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE GLOBAL_GEO_PROD_STATUS_SPEC
(
SPEC_NM                     VARCHAR(32) NOT NULL,
SPEC_VALUE                  VARCHAR(100),
CREATED_DTTM                DATE,
CREATED_BY                  VARCHAR(20),
PRIMARY KEY (SPEC_NM)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE GLOBAL_GEO_PROD_STATUS_DETAILS
(
SPEC_NM                     VARCHAR(32) NOT NULL,
SPEC_RULE_FLG               INTEGER NOT NULL,
DEFAULT_SPEC_VALUE          VARCHAR(100),
SPEC_DATATYPE               VARCHAR(40),
SPEC_DATATYPE_EXT           VARCHAR(40),
SPEC_VALUE_MIN              NUMERIC(12,4),
SPEC_VALUE_MAX              NUMERIC(12,4),
SPEC_VALUE_INCR             NUMERIC(12,4),
REF_QUERY                   VARCHAR(500),
SPEC_VALUE_LIST_DELIMITER   VARCHAR(3),
DESC_KEY                    VARCHAR(100),
PRIMARY KEY (SPEC_NM,SPEC_RULE_FLG)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE GLOBAL_GEO_PROD_STATUS_VALUES
(
SPEC_NM                     VARCHAR(32) NOT NULL,
SPEC_RULE_FLG               INTEGER NOT NULL,
SPEC_VALUE                  VARCHAR(100) NOT NULL,
SPEC_VALUE_DESC_KEY         VARCHAR(100),
PRIMARY KEY (SPEC_NM,SPEC_RULE_FLG,SPEC_VALUE)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
data GLOBAL_GEO_PROD_STATUS_RULE;
 
 
attrib PROD_HIER_SK                        length=6                                            ;
 
 
attrib RULE_NM                             length=$32                                          ;
 
 
attrib RULE_VALUE                          length=$100                                         ;
 
 
attrib CREATED_DTTM                        length=8      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT  ;
 
 
attrib CREATED_BY                          length=$20                                          ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table GLOBAL_GEO_PROD_STATUS_RULE add CONSTRAINT PRIM_KEY PRIMARY KEY (PROD_HIER_SK, RULE_NM);
 
 
quit;
 
 
 
data GLOBAL_GEO_PROD_STATUS_SPEC;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib SPEC_VALUE                          length=$100                                         ;
 
 
attrib CREATED_DTTM                        length=8      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT  ;
 
 
attrib CREATED_BY                          length=$20                                          ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table GLOBAL_GEO_PROD_STATUS_SPEC add CONSTRAINT PRIM_KEY PRIMARY KEY (SPEC_NM);
 
 
quit;
 
 
 
data GLOBAL_GEO_PROD_STATUS_DETAILS;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib SPEC_RULE_FLG                       length=4                                            ;
 
 
attrib DEFAULT_SPEC_VALUE                  length=$100                                         ;
 
 
attrib SPEC_DATATYPE                       length=$40                                          ;
 
 
attrib SPEC_DATATYPE_EXT                   length=$40                                          ;
 
 
attrib SPEC_VALUE_MIN                      length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib SPEC_VALUE_MAX                      length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib SPEC_VALUE_INCR                     length=8      FORMAT=NLNUM12.2   INFORMAT=NLNUM12.2 ;
 
 
attrib REF_QUERY                           length=$500                                         ;
 
 
attrib SPEC_VALUE_LIST_DELIMITER           length=$3                                           ;
 
 
attrib DESC_KEY                            length=$100                                         ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table GLOBAL_GEO_PROD_STATUS_DETAILS add CONSTRAINT PRIM_KEY PRIMARY KEY (SPEC_NM, SPEC_RULE_FLG);
 
 
quit;
 
 
 
data GLOBAL_GEO_PROD_STATUS_VALUES;
 
 
attrib SPEC_NM                             length=$32                                          ;
 
 
attrib SPEC_RULE_FLG                       length=4                                            ;
 
 
attrib SPEC_VALUE                          length=$100                                         ;
 
 
attrib SPEC_VALUE_DESC_KEY                 length=$100                                         ;
 
 
stop; run;
 
 
 
proc sql;
 
 
alter table GLOBAL_GEO_PROD_STATUS_VALUES add CONSTRAINT PRIM_KEY PRIMARY KEY (SPEC_NM, SPEC_RULE_FLG, SPEC_VALUE);
 
 
quit;
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID943853_GPSTATUS_create;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID943853_GPSTATUS_create;
%put ERROR- Description                              : New tables GLOBAL_GEO_PROD_STATUS_RULE, ..._SPEC, ..._DETAILS, ..._VALUES;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 18FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID943853_GPSTATUS_create;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID943853_GPSTATUS_create",
"New tables GLOBAL_GEO_PROD_STATUS_RULE, ..._SPEC, ..._DETAILS, ..._VALUES",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID943853_GPSTATUS_create:;
 
 
* End of changes for CHANGE_ID:ID943853_GPSTATUS_create;
 
 
***********************************************************************************************;
*************************************  End Change ID943853_GPSTATUS_create ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID943853_GPSTATUS_seed ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID943853_GPSTATUS_seed;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID943853_GPSTATUS_seed")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID943853_GPSTATUS_seed;
%goto ID943853_GPSTATUS_seed;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID943853_GPSTATUS_seed;
* Insert record into change management table for CHANGE_ID: ID943853_GPSTATUS_seed;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID943853_GPSTATUS_seed",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID943853_GPSTATUS_seed;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM GLOBAL_GEO_PROD_STATUS_RULE WHERE PROD_HIER_SK = 1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
DELETE FROM GLOBAL_GEO_PROD_STATUS_SPEC
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'GP_STATUS_RULE','1',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'GP_STATUS_FACT_DATA','1',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'MIN_INV_UNITS','1',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'MIN_STORE_PCT','0.2',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'MIN_INV_COST_AMT','100',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'MIN_SALES_AMT','100',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'ONE_ACTIVE_PER_SEASON','1',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'SEASON_ACTIVE_COEFF','0.3',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'INACTIVE_CNT_VAL','3',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'EXCLUDE_SEASON_START_WKS','2',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'EXCLUDE_SEASON_END_WKS','2',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'EXCLUDE_CLOSING_STORE_WKS','4',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'SEASON_INACTIVE_DURATION','',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_SPEC (SPEC_NM,SPEC_VALUE,CREATED_DTTM,CREATED_BY)
VALUES ('GEO_GROUP_LVL','1',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_SPEC (SPEC_NM,SPEC_VALUE,CREATED_DTTM,CREATED_BY)
VALUES ('GP_STATUS_HISTORY','104',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GLOBAL_GEO_PROD_STATUS_SPEC (SPEC_NM,SPEC_VALUE,CREATED_DTTM,CREATED_BY)
VALUES ('SEASON_FLG','1',null,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
DELETE FROM GLOBAL_GEO_PROD_STATUS_RULE WHERE PROD_HIER_SK = 1;
 
 
DELETE FROM GLOBAL_GEO_PROD_STATUS_SPEC;
 
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'GP_STATUS_RULE','1',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'GP_STATUS_FACT_DATA','1',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'MIN_INV_UNITS','1',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'MIN_STORE_PCT','0.2',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'MIN_INV_COST_AMT','100',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'MIN_SALES_AMT','100',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'ONE_ACTIVE_PER_SEASON','1',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'SEASON_ACTIVE_COEFF','0.3',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'INACTIVE_CNT_VAL','3',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'EXCLUDE_SEASON_START_WKS','2',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'EXCLUDE_SEASON_END_WKS','2',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'EXCLUDE_CLOSING_STORE_WKS','4',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK, RULE_NM, RULE_VALUE, CREATED_DTTM, CREATED_BY)
VALUES (1,'SEASON_INACTIVE_DURATION','',null,'CWB Seed');
 
 
quit;
 
 
 
proc sql;
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_SPEC (SPEC_NM,SPEC_VALUE,CREATED_DTTM,CREATED_BY)
VALUES ('GEO_GROUP_LVL','1',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_SPEC (SPEC_NM,SPEC_VALUE,CREATED_DTTM,CREATED_BY)
VALUES ('GP_STATUS_HISTORY','104',null,'CWB Seed');
 
 
INSERT INTO GLOBAL_GEO_PROD_STATUS_SPEC (SPEC_NM,SPEC_VALUE,CREATED_DTTM,CREATED_BY)
VALUES ('SEASON_FLG','1',null,'CWB Seed');
 
 
quit;
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID943853_GPSTATUS_seed;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID943853_GPSTATUS_seed;
%put ERROR- Description                              : Seed tables GLOBAL_GEO_PROD_STATUS_RULE, GLOBAL_GEO_PROD_STATUS_SPEC;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 27MAR2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID943853_GPSTATUS_seed;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID943853_GPSTATUS_seed",
"Seed tables GLOBAL_GEO_PROD_STATUS_RULE, GLOBAL_GEO_PROD_STATUS_SPEC",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID943853_GPSTATUS_seed:;
 
 
* End of changes for CHANGE_ID:ID943853_GPSTATUS_seed;
 
 
***********************************************************************************************;
*************************************  End Change ID943853_GPSTATUS_seed ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change IDS0943919 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: IDS0943919;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("IDS0943919")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : IDS0943919;
%goto IDS0943919;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : IDS0943919;
* Insert record into change management table for CHANGE_ID: IDS0943919;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"IDS0943919",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto IDS0943919;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE UNIQUE INDEX PKOPT_PLANNED_QTY_IX3 ON PKOPT_PLANNED_QTY (IMPORT_ID, PROD_ID, GEO_ID)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
CREATE UNIQUE INDEX PKOPT_PLANNED_QTY_IX3 ON PKOPT_PLANNED_QTY (IMPORT_ID, PROD_ID, GEO_ID) ;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: IDS0943919;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: IDS0943919;
%put ERROR- Description                              : PKOPT_PLANNED_QTY Needs Unique Index Constraint;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 15FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: IDS0943919;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"IDS0943919",
"PKOPT_PLANNED_QTY Needs Unique Index Constraint",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%IDS0943919:;
 
 
* End of changes for CHANGE_ID:IDS0943919;
 
 
***********************************************************************************************;
*************************************  End Change IDS0943919 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID943853_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID943853_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID943853_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID943853_1;
%goto ID943853_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID943853_1;
* Insert record into change management table for CHANGE_ID: ID943853_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID943853_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID943853_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from GLOBAL_GEO_PROD_STATUS_SPEC where SPEC_NM = 'MAX_STATUS_CHANGE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into GLOBAL_GEO_PROD_STATUS_SPEC (SPEC_NM,SPEC_VALUE,CREATED_DTTM,CREATED_BY)
values ('MAX_STATUS_CHANGE','30',NULL,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from GLOBAL_GEO_PROD_STATUS_SPEC where SPEC_NM = 'USE_MARKDOWN_STATUS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into GLOBAL_GEO_PROD_STATUS_SPEC (SPEC_NM,SPEC_VALUE,CREATED_DTTM,CREATED_BY)
values ('USE_MARKDOWN_STATUS','1',NULL,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
update GLOBAL_GEO_PROD_STATUS_SPEC set SPEC_VALUE = '156' where SPEC_NM = 'GP_STATUS_HISTORY'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
update GLOBAL_GEO_PROD_STATUS_SPEC set CREATED_DTTM = NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update GLOBAL_GEO_PROD_STATUS_RULE set CREATED_DTTM = NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from GLOBAL_GEO_PROD_STATUS_SPEC where SPEC_NM = 'MAX_STATUS_CHANGE';
 
 
insert into GLOBAL_GEO_PROD_STATUS_SPEC (SPEC_NM,SPEC_VALUE,CREATED_DTTM,CREATED_BY)
values ('MAX_STATUS_CHANGE','30',NULL,'CWB Seed');
 
 
delete from GLOBAL_GEO_PROD_STATUS_SPEC where SPEC_NM = 'USE_MARKDOWN_STATUS';
 
 
insert into GLOBAL_GEO_PROD_STATUS_SPEC (SPEC_NM,SPEC_VALUE,CREATED_DTTM,CREATED_BY)
values ('USE_MARKDOWN_STATUS','1',NULL,'CWB Seed');
 
 
 
update GLOBAL_GEO_PROD_STATUS_SPEC set SPEC_VALUE = '156' where SPEC_NM = 'GP_STATUS_HISTORY';
 
 
 
update GLOBAL_GEO_PROD_STATUS_SPEC set CREATED_DTTM = NULL;
 
 
update GLOBAL_GEO_PROD_STATUS_RULE set CREATED_DTTM = NULL;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID943853_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID943853_1;
%put ERROR- Description                              : Add USE_MARKDOWN_STATUS and MAX_STATUS_CHANGE global gp status specs;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 25FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID943853_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID943853_1",
"Add USE_MARKDOWN_STATUS and MAX_STATUS_CHANGE global gp status specs",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID943853_1:;
 
 
* End of changes for CHANGE_ID:ID943853_1;
 
 
***********************************************************************************************;
*************************************  End Change ID943853_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID944725 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID944725;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID944725")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID944725;
%goto ID944725;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID944725;
* Insert record into change management table for CHANGE_ID: ID944725;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID944725",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID944725;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PRICING_RELATION ADD ATTR_VALUE_LIST1_TYPE INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRICING_RELATION ADD ATTR_VALUE_LIST2_TYPE INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRICING_RELN_MATCH_ATTR ADD MATCH_ATTR_VALUE_LIST_TYPE INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PRICING_RELATION ADD ATTR_VALUE_LIST1_TYPE INTEGER;
 
 
ALTER TABLE PRICING_RELATION ADD ATTR_VALUE_LIST2_TYPE INTEGER;
 
 
ALTER TABLE PRICING_RELN_MATCH_ATTR ADD MATCH_ATTR_VALUE_LIST_TYPE INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID944725;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID944725;
%put ERROR- Description                              : see defect S0944725;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 25FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID944725;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID944725",
"see defect S0944725",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID944725:;
 
 
* End of changes for CHANGE_ID:ID944725;
 
 
***********************************************************************************************;
*************************************  End Change ID944725 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change GEO_PROD_OVERRIDE ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: GEO_PROD_OVERRIDE;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("GEO_PROD_OVERRIDE")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : GEO_PROD_OVERRIDE;
%goto GEO_PROD_OVERRIDE;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : GEO_PROD_OVERRIDE;
* Insert record into change management table for CHANGE_ID: GEO_PROD_OVERRIDE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"GEO_PROD_OVERRIDE",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto GEO_PROD_OVERRIDE;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_PROD_OVERRIDE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
insert into TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
values ('GEO_PROD_OVERRIDE',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_PROD_STATUS_OVERRIDE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
insert into TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
values ('GEO_PROD_STATUS_OVERRIDE',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK VALID_FROM_DT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_PROD_OVERRIDE';
 
 
 
insert into TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
values ('GEO_PROD_OVERRIDE',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK');
 
 
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_PROD_STATUS_OVERRIDE';
 
 
 
insert into TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
values ('GEO_PROD_STATUS_OVERRIDE',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK VALID_FROM_DT');
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: GEO_PROD_OVERRIDE;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: GEO_PROD_OVERRIDE;
%put ERROR- Description                              : Add GEO_PROD_OVERRIDE in TABLE_PARTITION_META;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 20FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: GEO_PROD_OVERRIDE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"GEO_PROD_OVERRIDE",
"Add GEO_PROD_OVERRIDE in TABLE_PARTITION_META",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%GEO_PROD_OVERRIDE:;
 
 
* End of changes for CHANGE_ID:GEO_PROD_OVERRIDE;
 
 
***********************************************************************************************;
*************************************  End Change GEO_PROD_OVERRIDE ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID931744 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID931744;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID931744")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID931744;
%goto ID931744;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID931744;
* Insert record into change management table for CHANGE_ID: ID931744;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID931744",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID931744;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql noprint;
 
 
select count (*) into :_cnt_rules from &m_di_trans..fa_scoring_rule;
 
 
select count (*) into :_cnt_mod_rules from &m_di_trans..fa_scoring_rule where weight ^= 0;
 
 
select count (*) into :_cnt_range_rules from &m_di_trans..fa_scoring_range_rule;
 
 
select count (*) into :_cnt_mod_range_rules from &m_di_trans..fa_scoring_range_rule
where range_value ^= 0 OR range_start_value ^= -99999999.99
OR range_end_value ^= 99999999.99;
 
 
quit;
 
 
 
%if &_cnt_rules = 17 &_cnt_mod_rules = 0
and &_cnt_range_rules = 17 and &_cnt_mod_range_rules = 0 %then %do;
 
 
 
%include "%di_util_misc_path()/dbmsc/default_fa_scoring_rules.sas";
 
 
 
%end;
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
select count (*) into :_cnt_rules from &m_di_trans..fa_scoring_rule;
 
 
select count (*) into :_cnt_mod_rules from &m_di_trans..fa_scoring_rule where weight ^= 0;
 
 
select count (*) into :_cnt_range_rules from &m_di_trans..fa_scoring_range_rule;
 
 
select count (*) into :_cnt_mod_range_rules from &m_di_trans..fa_scoring_range_rule
where range_value ^= 0 OR range_start_value ^= -99999999.99
OR range_end_value ^= 99999999.99;
 
 
quit;
 
 
 
%if &_cnt_rules = 17 &_cnt_mod_rules = 0
and &_cnt_range_rules = 17 and &_cnt_mod_range_rules = 0 %then %do;
 
 
 
%include "%di_util_misc_path()/dbmsc/default_fa_scoring_rules.sas";
 
 
 
%end;
 
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID931744;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID931744;
%put ERROR- Description                              : Add default scoring rules (seed table for new customers);
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 28FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID931744;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID931744",
"Add default scoring rules (seed table for new customers)",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID931744:;
 
 
* End of changes for CHANGE_ID:ID931744;
 
 
***********************************************************************************************;
*************************************  End Change ID931744 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID943853_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID943853_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID943853_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID943853_2;
%goto ID943853_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID943853_2;
* Insert record into change management table for CHANGE_ID: ID943853_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID943853_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID943853_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_GEO_PROD_STATUS_RULE where RULE_NM = 'MIN_CLR_DISC_PCT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_GEO_PROD_STATUS_RULE (PROD_HIER_SK,RULE_NM,RULE_VALUE,CREATED_DTTM,CREATED_BY)
values (1,'MIN_CLR_DISC_PCT','0.5',NULL,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from GLOBAL_GEO_PROD_STATUS_RULE where RULE_NM = 'MIN_CLR_DISC_PCT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK,RULE_NM,RULE_VALUE,CREATED_DTTM,CREATED_BY)
values (1,'MIN_CLR_DISC_PCT','0.5',NULL,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from GLOBAL_GEO_PROD_STATUS_SPEC where SPEC_NM = 'GP_STATUS_GRACE_PERIOD'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into GLOBAL_GEO_PROD_STATUS_SPEC (SPEC_NM,SPEC_VALUE,CREATED_DTTM,CREATED_BY)
values ('GP_STATUS_GRACE_PERIOD','12',NULL,'CWB Seed')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_GEO_PROD_STATUS_RULE where RULE_NM = 'MIN_CLR_DISC_PCT';
 
 
insert into MODEL_GEO_PROD_STATUS_RULE (PROD_HIER_SK,RULE_NM,RULE_VALUE,CREATED_DTTM,CREATED_BY)
values (1,'MIN_CLR_DISC_PCT','0.5',NULL,'CWB Seed');
 
 
 
delete from GLOBAL_GEO_PROD_STATUS_RULE where RULE_NM = 'MIN_CLR_DISC_PCT';
 
 
insert into GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK,RULE_NM,RULE_VALUE,CREATED_DTTM,CREATED_BY)
values (1,'MIN_CLR_DISC_PCT','0.5',NULL,'CWB Seed');
 
 
 
delete from GLOBAL_GEO_PROD_STATUS_SPEC where SPEC_NM = 'GP_STATUS_GRACE_PERIOD';
 
 
insert into GLOBAL_GEO_PROD_STATUS_SPEC (SPEC_NM,SPEC_VALUE,CREATED_DTTM,CREATED_BY)
values ('GP_STATUS_GRACE_PERIOD','12',NULL,'CWB Seed');
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID943853_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID943853_2;
%put ERROR- Description                              : Add MIN_CLR_DISC_PCT gp status rule and GP_STATUS_GRACE_PERIOD gp status spec;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 04MAR2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID943853_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID943853_2",
"Add MIN_CLR_DISC_PCT gp status rule and GP_STATUS_GRACE_PERIOD gp status spec",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID943853_2:;
 
 
* End of changes for CHANGE_ID:ID943853_2;
 
 
***********************************************************************************************;
*************************************  End Change ID943853_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0940746 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0940746;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0940746")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0940746;
%goto ID0940746;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0940746;
* Insert record into change management table for CHANGE_ID: ID0940746;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0940746",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0940746;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE GLOBAL TEMPORARY TABLE gtt_pko_filter_size_trans (prod_hier_sk integer) ON COMMIT PRESERVE ROWS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE GLOBAL TEMPORARY TABLE gtt_pko_filter_prod_list (prod_hier_sk integer, prod_lvl integer) ON COMMIT PRESERVE ROWS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE GLOBAL TEMPORARY TABLE gtt_pko_filter_profile_req (profile_id integer) ON COMMIT PRESERVE ROWS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE GLOBAL TEMPORARY TABLE gtt_pko_filter_profile (profile_id integer) ON COMMIT PRESERVE ROWS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE GLOBAL TEMPORARY TABLE gtt_pko_filter_prod_geo (prod_hier_sk integer, prod_lvl integer, geo_hier_sk integer, geo_lvl integer) ON COMMIT PRESERVE ROWS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE GLOBAL TEMPORARY TABLE gtt_pko_filter_prod_hier (prod_hier_sk integer, prod_lvl integer, parent_prod_hier_sk integer, parent_prod_lvl integer) ON COMMIT PRESERVE ROWS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE GLOBAL TEMPORARY TABLE gtt_pko_append_res_message (
REQUEST_ID     INTEGER,
DELIVERY_ID    INTEGER,
PROD_ID        VARCHAR(32),
GEO_ID         VARCHAR(32),
MESSAGE_SK     INTEGER,
MESSAGE_TEXT   VARCHAR(255)
) ON COMMIT PRESERVE ROWS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE GLOBAL TEMPORARY TABLE gtt_pko_update_plk_stats (
PROFILE_ID     INTEGER,
NUM_EXPIRED    INTEGER,
NUM            INTEGER
) ON COMMIT PRESERVE ROWS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
create table &m_di_trans..GTT_PKO_APPEND_RES_MESSAGE  (
REQUEST_ID integer,
DELIVERY_ID integer,
PROD_ID varchar(32),
GEO_ID varchar(32),
MESSAGE_SK integer,
MESSAGE_TEXT varchar(255)
);
 
 
 
create table &m_di_trans..GTT_PKO_FILTER_PROD_GEO  (
PROD_HIER_SK integer,
PROD_LVL integer,
GEO_HIER_SK integer,
GEO_LVL integer
);
 
 
 
create table &m_di_trans..GTT_PKO_FILTER_PROD_HIER  (
PROD_HIER_SK integer,
PROD_LVL integer,
PARENT_PROD_HIER_SK integer,
PARENT_PROD_LVL integer
);
 
 
 
create table &m_di_trans..GTT_PKO_FILTER_PROD_LIST  (
PROD_HIER_SK integer,
PROD_LVL integer
);
 
 
 
create table &m_di_trans..GTT_PKO_FILTER_PROFILE  (
PROFILE_ID integer
);
 
 
 
create table &m_di_trans..GTT_PKO_FILTER_PROFILE_REQ  (
PROFILE_ID integer
);
 
 
 
create table &m_di_trans..GTT_PKO_FILTER_SIZE_TRANS  (
PROD_HIER_SK integer
);
 
 
 
create table &m_di_trans..GTT_PKO_UPDATE_PLK_STATS (
PROFILE_ID     INTEGER,
NUM_EXPIRED    INTEGER,
NUM            INTEGER
);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0940746;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0940746;
%put ERROR- Description                              : performance improvements for pack optimization in MR2;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 19FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0940746;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0940746",
"performance improvements for pack optimization in MR2",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0940746:;
 
 
* End of changes for CHANGE_ID:ID0940746;
 
 
***********************************************************************************************;
*************************************  End Change ID0940746 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID_0949494_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID_0949494_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID_0949494_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID_0949494_2;
%goto ID_0949494_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID_0949494_2;
* Insert record into change management table for CHANGE_ID: ID_0949494_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID_0949494_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID_0949494_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PRICING_RELATION ADD CARTESIAN_PROD_FLG INTEGER DEFAULT 0 NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN ADD NUM_PRICE_CHG_PCT_MAX NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
alter table PRICING_RELATION add CARTESIAN_PROD_FLG INTEGER ;
 
 
update PRICING_RELATION set CARTESIAN_PROD_FLG=0;
 
 
alter table PRICING_RELATION add NOT NULL (CARTESIAN_PROD_FLG);
 
 
ALTER TABLE RPO_PLAN ADD NUM_PRICE_CHG_PCT_MAX NUMERIC(12,4);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID_0949494_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID_0949494_2;
%put ERROR- Description                              : see defect S0949494;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 06MAR2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID_0949494_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID_0949494_2",
"see defect S0949494",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID_0949494_2:;
 
 
* End of changes for CHANGE_ID:ID_0949494_2;
 
 
***********************************************************************************************;
*************************************  End Change ID_0949494_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID939752 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID939752;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID939752")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID939752;
%goto ID939752;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC;
%put NOTE: Change ID                             :ID939752;
%goto ID939752;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID939752;
%goto ID939752;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID939752;
* Insert record into change management table for CHANGE_ID: ID939752;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID939752",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID939752;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'PRICE_RATIO_PRECISION'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('PRICE_RATIO_PRECISION','ALL','-1','0.0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'PRICE_RATIO_PRECISION'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'ALL','PRICE_RATIO_PRECISION','-1','0.0',NULL,NULL,'SEED')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'PRICE_RATIO_PRECISION'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('ALL','PRICE_RATIO_PRECISION','Double','decimalPts:2',0,1,
0.01,1,NULL,NULL,NULL,NULL,NULL,'mspec.PRICE_RATIO_PRECISION.description.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'PRICE_RATIO_PRECISION';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('PRICE_RATIO_PRECISION','ALL','-1','0.0',NULL);
 
 
delete from MODEL_SPEC where SPEC_NM = 'PRICE_RATIO_PRECISION';
 
 
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'ALL','PRICE_RATIO_PRECISION','-1','0.0',NULL,NULL,'SEED');
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'PRICE_RATIO_PRECISION';
 
 
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('ALL','PRICE_RATIO_PRECISION','Double','decimalPts:2',0,1,
0.01,1,NULL,NULL,NULL,NULL,NULL,'mspec.PRICE_RATIO_PRECISION.description.txt');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID939752;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID939752;
%put ERROR- Description                              : Add model spec PRICE_RATIO_PRECISION;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 05MAR2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID939752;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID939752",
"Add model spec PRICE_RATIO_PRECISION",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID939752:;
 
 
* End of changes for CHANGE_ID:ID939752;
 
 
***********************************************************************************************;
*************************************  End Change ID939752 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID914979_5 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID914979_5;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID914979_5")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID914979_5;
%goto ID914979_5;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID914979_5;
* Insert record into change management table for CHANGE_ID: ID914979_5;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914979_5",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID914979_5;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update DATA_CONFIG_TEMPLATE set CONFIG_TEMPLATE_NM = 'Grocery or Other Basic Products with Substitution'
where CONFIG_TEMPLATE_ID = 5
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update DATA_CONFIG_TEMPLATE set CONFIG_TEMPLATE_NM = 'Grocery or Other Basic Products with Substitution'
where CONFIG_TEMPLATE_ID = 5;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID914979_5;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID914979_5;
%put ERROR- Description                              : Correction to template 5 name;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 07MAR2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID914979_5;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID914979_5",
"Correction to template 5 name",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID914979_5:;
 
 
* End of changes for CHANGE_ID:ID914979_5;
 
 
***********************************************************************************************;
*************************************  End Change ID914979_5 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID905615 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID905615;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID905615")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID905615;
%goto ID905615;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID905615;
* Insert record into change management table for CHANGE_ID: ID905615;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID905615",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID905615;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT RENAME COLUMN EXP_COMP_PRICE_INDEX TO EXP_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT ADD EXP_COMP_PRICE_INDEX NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_RESULT SET EXP_COMP_PRICE_INDEX = EXP_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN EXP_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT RENAME COLUMN EXP_COMP_PRICE_INDEX_RI TO EXP_COMP_PRICE_INDEX_RI_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT ADD EXP_COMP_PRICE_INDEX_RI NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_RESULT SET EXP_COMP_PRICE_INDEX_RI = EXP_COMP_PRICE_INDEX_RI_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN EXP_COMP_PRICE_INDEX_RI_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT RENAME COLUMN EXP_COMP_PRICE_INDEX_PM TO EXP_COMP_PRICE_INDEX_PM_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT ADD EXP_COMP_PRICE_INDEX_PM NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_RESULT SET EXP_COMP_PRICE_INDEX_PM = EXP_COMP_PRICE_INDEX_PM_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN EXP_COMP_PRICE_INDEX_PM_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT RENAME COLUMN EXP_COMP_PRICE_INDEX_CE TO EXP_COMP_PRICE_INDEX_CE_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT ADD EXP_COMP_PRICE_INDEX_CE NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_RESULT SET EXP_COMP_PRICE_INDEX_CE = EXP_COMP_PRICE_INDEX_CE_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN EXP_COMP_PRICE_INDEX_CE_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT RENAME COLUMN EXP_COMP_PRICE_INDEX_PMRI TO EXP_COMP_PRICE_INDEX_PMRI_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT ADD EXP_COMP_PRICE_INDEX_PMRI NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_RESULT SET EXP_COMP_PRICE_INDEX_PMRI = EXP_COMP_PRICE_INDEX_PMRI_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN EXP_COMP_PRICE_INDEX_PMRI_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT RENAME COLUMN BASE_COMP_PRICE_INDEX TO BASE_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT ADD BASE_COMP_PRICE_INDEX NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_RESULT SET BASE_COMP_PRICE_INDEX = BASE_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN BASE_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT RENAME COLUMN BASE_COMP_PRICE_INDEX_RI TO BASE_COMP_PRICE_INDEX_RI_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT ADD BASE_COMP_PRICE_INDEX_RI NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_RESULT SET BASE_COMP_PRICE_INDEX_RI = BASE_COMP_PRICE_INDEX_RI_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN BASE_COMP_PRICE_INDEX_RI_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT RENAME COLUMN BASE_COMP_PRICE_INDEX_PM TO BASE_COMP_PRICE_INDEX_PM_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT ADD BASE_COMP_PRICE_INDEX_PM NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_RESULT SET BASE_COMP_PRICE_INDEX_PM = BASE_COMP_PRICE_INDEX_PM_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN BASE_COMP_PRICE_INDEX_PM_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT RENAME COLUMN BASE_COMP_PRICE_INDEX_CE TO BASE_COMP_PRICE_INDEX_CE_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT ADD BASE_COMP_PRICE_INDEX_CE NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_RESULT SET BASE_COMP_PRICE_INDEX_CE = BASE_COMP_PRICE_INDEX_CE_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN BASE_COMP_PRICE_INDEX_CE_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT RENAME COLUMN BASE_COMP_PRICE_INDEX_PMRI TO BASE_COMP_PRICE_INDEX_PMRI_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT ADD BASE_COMP_PRICE_INDEX_PMRI NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_RESULT SET BASE_COMP_PRICE_INDEX_PMRI = BASE_COMP_PRICE_INDEX_PMRI_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN BASE_COMP_PRICE_INDEX_PMRI_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_RESULT RENAME COLUMN BASE_COMP_PRICE_INDEX TO BASE_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_RESULT ADD BASE_COMP_PRICE_INDEX NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_MEMBER_RESULT SET BASE_COMP_PRICE_INDEX = BASE_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_RESULT DROP COLUMN BASE_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_RESULT RENAME COLUMN EXP_COMP_PRICE_INDEX TO EXP_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_RESULT ADD EXP_COMP_PRICE_INDEX NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_MEMBER_RESULT SET EXP_COMP_PRICE_INDEX = EXP_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_RESULT DROP COLUMN EXP_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_AGG RENAME COLUMN BASE_COMP_PRICE_INDEX TO BASE_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_AGG ADD BASE_COMP_PRICE_INDEX NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_MEMBER_AGG SET BASE_COMP_PRICE_INDEX = BASE_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_AGG DROP COLUMN BASE_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_AGG RENAME COLUMN EXP_COMP_PRICE_INDEX TO EXP_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_AGG ADD EXP_COMP_PRICE_INDEX NUMERIC(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE RPO_PLAN_MEMBER_AGG SET EXP_COMP_PRICE_INDEX = EXP_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_AGG DROP COLUMN EXP_COMP_PRICE_INDEX_x
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc datasets library=&m_di_trans nolist;
 
 
 
modify RPO_PLAN_RESULT ;
 
 
rename EXP_COMP_PRICE_INDEX=EXP_COMP_PRICE_INDEX_x;
 
 
rename EXP_COMP_PRICE_INDEX_RI=EXP_COMP_PRICE_INDEX_RI_x;
 
 
rename EXP_COMP_PRICE_INDEX_PM=EXP_COMP_PRICE_INDEX_PM_x;
 
 
rename EXP_COMP_PRICE_INDEX_CE=EXP_COMP_PRICE_INDEX_CE_x;
 
 
rename EXP_COMP_PRICE_INDEX_PMRI=EXP_COMP_PRICE_INDEX_PMRI_x;
 
 
rename BASE_COMP_PRICE_INDEX=BASE_COMP_PRICE_INDEX_x;
 
 
rename BASE_COMP_PRICE_INDEX_RI=BASE_COMP_PRICE_INDEX_RI_x;
 
 
rename BASE_COMP_PRICE_INDEX_PM=BASE_COMP_PRICE_INDEX_PM_x;
 
 
rename BASE_COMP_PRICE_INDEX_CE=BASE_COMP_PRICE_INDEX_CE_x;
 
 
rename BASE_COMP_PRICE_INDEX_PMRI=BASE_COMP_PRICE_INDEX_PMRI_x;
 
 
 
quit;
 
 
 
proc datasets library=&m_di_trans nolist;
 
 
 
modify RPO_PLAN_MEMBER_RESULT ;
 
 
rename BASE_COMP_PRICE_INDEX=BASE_COMP_PRICE_INDEX_x;
 
 
rename EXP_COMP_PRICE_INDEX=EXP_COMP_PRICE_INDEX_x;
 
 
 
quit;
 
 
 
proc datasets library=&m_di_trans nolist;
 
 
 
modify RPO_PLAN_MEMBER_AGG ;
 
 
rename BASE_COMP_PRICE_INDEX=BASE_COMP_PRICE_INDEX_x;
 
 
rename EXP_COMP_PRICE_INDEX=EXP_COMP_PRICE_INDEX_x;
 
 
 
quit;
 
 
 
 
 
proc sql;
 
 
ALTER TABLE RPO_PLAN_RESULT ADD EXP_COMP_PRICE_INDEX NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_RESULT SET EXP_COMP_PRICE_INDEX = EXP_COMP_PRICE_INDEX_x;
 
 
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN EXP_COMP_PRICE_INDEX_x;
 
 
 
ALTER TABLE RPO_PLAN_RESULT ADD EXP_COMP_PRICE_INDEX_RI NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_RESULT SET EXP_COMP_PRICE_INDEX_RI = EXP_COMP_PRICE_INDEX_RI_x;
 
 
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN EXP_COMP_PRICE_INDEX_RI_x;
 
 
 
ALTER TABLE RPO_PLAN_RESULT ADD EXP_COMP_PRICE_INDEX_PM NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_RESULT SET EXP_COMP_PRICE_INDEX_PM = EXP_COMP_PRICE_INDEX_PM_x;
 
 
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN EXP_COMP_PRICE_INDEX_PM_x;
 
 
 
ALTER TABLE RPO_PLAN_RESULT ADD EXP_COMP_PRICE_INDEX_CE NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_RESULT SET EXP_COMP_PRICE_INDEX_CE = EXP_COMP_PRICE_INDEX_CE_x;
 
 
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN EXP_COMP_PRICE_INDEX_CE_x;
 
 
 
ALTER TABLE RPO_PLAN_RESULT ADD EXP_COMP_PRICE_INDEX_PMRI NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_RESULT SET EXP_COMP_PRICE_INDEX_PMRI = EXP_COMP_PRICE_INDEX_PMRI_x;
 
 
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN EXP_COMP_PRICE_INDEX_PMRI_x;
 
 
 
ALTER TABLE RPO_PLAN_RESULT ADD BASE_COMP_PRICE_INDEX NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_RESULT SET BASE_COMP_PRICE_INDEX = BASE_COMP_PRICE_INDEX_x;
 
 
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN BASE_COMP_PRICE_INDEX_x;
 
 
 
ALTER TABLE RPO_PLAN_RESULT ADD BASE_COMP_PRICE_INDEX_RI NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_RESULT SET BASE_COMP_PRICE_INDEX_RI = BASE_COMP_PRICE_INDEX_RI_x;
 
 
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN BASE_COMP_PRICE_INDEX_RI_x;
 
 
 
ALTER TABLE RPO_PLAN_RESULT ADD BASE_COMP_PRICE_INDEX_PM NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_RESULT SET BASE_COMP_PRICE_INDEX_PM = BASE_COMP_PRICE_INDEX_PM_x;
 
 
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN BASE_COMP_PRICE_INDEX_PM_x;
 
 
 
ALTER TABLE RPO_PLAN_RESULT ADD BASE_COMP_PRICE_INDEX_CE NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_RESULT SET BASE_COMP_PRICE_INDEX_CE = BASE_COMP_PRICE_INDEX_CE_x;
 
 
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN BASE_COMP_PRICE_INDEX_CE_x;
 
 
 
ALTER TABLE RPO_PLAN_RESULT ADD BASE_COMP_PRICE_INDEX_PMRI NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_RESULT SET BASE_COMP_PRICE_INDEX_PMRI = BASE_COMP_PRICE_INDEX_PMRI_x;
 
 
ALTER TABLE RPO_PLAN_RESULT DROP COLUMN BASE_COMP_PRICE_INDEX_PMRI_x;
 
 
 
 
ALTER TABLE RPO_PLAN_MEMBER_RESULT ADD BASE_COMP_PRICE_INDEX NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_MEMBER_RESULT SET BASE_COMP_PRICE_INDEX = BASE_COMP_PRICE_INDEX_x;
 
 
ALTER TABLE RPO_PLAN_MEMBER_RESULT DROP COLUMN BASE_COMP_PRICE_INDEX_x;
 
 
 
ALTER TABLE RPO_PLAN_MEMBER_RESULT ADD EXP_COMP_PRICE_INDEX NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_MEMBER_RESULT SET EXP_COMP_PRICE_INDEX = EXP_COMP_PRICE_INDEX_x;
 
 
ALTER TABLE RPO_PLAN_MEMBER_RESULT DROP COLUMN EXP_COMP_PRICE_INDEX_x;
 
 
 
 
ALTER TABLE RPO_PLAN_MEMBER_AGG ADD BASE_COMP_PRICE_INDEX NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_MEMBER_AGG SET BASE_COMP_PRICE_INDEX = BASE_COMP_PRICE_INDEX_x;
 
 
ALTER TABLE RPO_PLAN_MEMBER_AGG DROP COLUMN BASE_COMP_PRICE_INDEX_x;
 
 
 
ALTER TABLE RPO_PLAN_MEMBER_AGG ADD EXP_COMP_PRICE_INDEX NUMERIC(12,4);
 
 
UPDATE RPO_PLAN_MEMBER_AGG SET EXP_COMP_PRICE_INDEX = EXP_COMP_PRICE_INDEX_x;
 
 
ALTER TABLE RPO_PLAN_MEMBER_AGG DROP COLUMN EXP_COMP_PRICE_INDEX_x;
 
 
 
quit;
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID905615;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID905615;
%put ERROR- Description                              : see defect S0905615;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 14MAR2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID905615;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID905615",
"see defect S0905615",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID905615:;
 
 
* End of changes for CHANGE_ID:ID905615;
 
 
***********************************************************************************************;
*************************************  End Change ID905615 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID935474 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID935474;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID935474")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID935474;
%goto ID935474;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID935474;
* Insert record into change management table for CHANGE_ID: ID935474;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID935474",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID935474;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
create table &m_di_trans..RPP_PRICE_PLAN_INPUT (
PLAN_SK     INTEGER,
PARTITION_ID    INTEGER
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
create table &m_di_trans..RPP_PRICE_PLAN_INPUT (
PLAN_SK     INTEGER,
PARTITION_ID    INTEGER
);
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID935474;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID935474;
%put ERROR- Description                              : Add table for promotion plans.  To be used as input for calling scoring.;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 18MAR2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID935474;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID935474",
"Add table for promotion plans.  To be used as input for calling scoring.",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID935474:;
 
 
* End of changes for CHANGE_ID:ID935474;
 
 
***********************************************************************************************;
*************************************  End Change ID935474 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change FIX_DTTM_FMTS_SAS_ONLY ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: FIX_DTTM_FMTS_SAS_ONLY;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("FIX_DTTM_FMTS_SAS_ONLY")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : FIX_DTTM_FMTS_SAS_ONLY;
%goto FIX_DTTM_FMTS_SAS_ONLY;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : FIX_DTTM_FMTS_SAS_ONLY;
* Insert record into change management table for CHANGE_ID: FIX_DTTM_FMTS_SAS_ONLY;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"FIX_DTTM_FMTS_SAS_ONLY",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto FIX_DTTM_FMTS_SAS_ONLY;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
proc datasets library=&m_di_trans nolist;
 
 
 
modify CALENDAR ;
 
 
format ACTION_RESULT_DTTM NLDATM21.;
 
 
informat ACTION_RESULT_DTTM NLDATM21.;
 
 
 
format EVAL_OPT_RESULT_DTTM NLDATM21.;
 
 
informat EVAL_OPT_RESULT_DTTM NLDATM21.;
 
 
 
modify CATEGORY_PLAN ;
 
 
format ACTION_RESULT_DTTM NLDATM21.;
 
 
informat ACTION_RESULT_DTTM NLDATM21.;
 
 
 
format EVAL_OPT_RESULT_DTTM NLDATM21.;
 
 
informat EVAL_OPT_RESULT_DTTM NLDATM21.;
 
 
 
modify DATA_CONFIG_TEMPLATE ;
 
 
format CREATED_DTTM NLDATM21.;
 
 
informat CREATED_DTTM NLDATM21.;
 
 
 
modify RPO_PLAN ;
 
 
format PROCESS_RUN_DTTM NLDATM21.;
 
 
informat PROCESS_RUN_DTTM NLDATM21.;
 
 
 
modify RPP_PLAN ;
 
 
format ACTION_RESULT_DTTM NLDATM21.;
 
 
informat ACTION_RESULT_DTTM NLDATM21.;
 
 
 
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: FIX_DTTM_FMTS_SAS_ONLY;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: FIX_DTTM_FMTS_SAS_ONLY;
%put ERROR- Description                              : This change does not affect production systems;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 20MAR2012;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: FIX_DTTM_FMTS_SAS_ONLY;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"FIX_DTTM_FMTS_SAS_ONLY",
"This change does not affect production systems",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%FIX_DTTM_FMTS_SAS_ONLY:;
 
 
* End of changes for CHANGE_ID:FIX_DTTM_FMTS_SAS_ONLY;
 
 
***********************************************************************************************;
*************************************  End Change FIX_DTTM_FMTS_SAS_ONLY ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0640535 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0640535;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0640535")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0640535;
%goto ID0640535;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0640535;
* Insert record into change management table for CHANGE_ID: ID0640535;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0640535",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0640535;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD ALLOW_NEAR_MATCH_FLG INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD USE_PROFILE_ATTR_FLG INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_BUY ADD ALLOW_NEAR_MATCH_FLG INTEGER;
 
 
ALTER TABLE PKO_BUY ADD USE_PROFILE_ATTR_FLG INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0640535;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0640535;
%put ERROR- Description                              : Allow request level fields to be set on buys;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 01MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0640535;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0640535",
"Allow request level fields to be set on buys",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0640535:;
 
 
* End of changes for CHANGE_ID:ID0640535;
 
 
***********************************************************************************************;
*************************************  End Change ID0640535 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0868953 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0868953;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0868953")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0868953;
%goto ID0868953;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0868953;
* Insert record into change management table for CHANGE_ID: ID0868953;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0868953",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0868953;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD MISMATCH_THRESHOLD_PCT NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD MISMATCH_UNDER_PCT NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD MISMATCH_OVER_PCT NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD MISMATCH_THRESHOLD_PCT NUMERIC(20,3);
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD MISMATCH_UNDER_PCT NUMERIC(20,3);
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD MISMATCH_OVER_PCT NUMERIC(20,3);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0868953;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0868953;
%put ERROR- Description                              : Mismatch Alerts, Flagging;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 01MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0868953;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0868953",
"Mismatch Alerts, Flagging",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0868953:;
 
 
* End of changes for CHANGE_ID:ID0868953;
 
 
***********************************************************************************************;
*************************************  End Change ID0868953 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0868952 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0868952;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0868952")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0868952;
%goto ID0868952;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0868952;
* Insert record into change management table for CHANGE_ID: ID0868952;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0868952",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0868952;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD SUBSETTING_ATTR_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD SUBSETTING_ATTR_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PACK_PRODUCT_SETTING ADD SUBSETTING_ATTR_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PACK_DEFAULT ADD SUBSETTING_ATTR_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_SETTING ADD SUBSETTING_ATTR_NM VARCHAR(40)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_BUY ADD SUBSETTING_ATTR_SK INTEGER;
 
 
ALTER TABLE PKO_DELIVERY ADD SUBSETTING_ATTR_SK INTEGER;
 
 
ALTER TABLE PKO_PACK_PRODUCT_SETTING ADD SUBSETTING_ATTR_SK INTEGER;
 
 
ALTER TABLE PKO_PACK_DEFAULT ADD SUBSETTING_ATTR_SK INTEGER;
 
 
 
ALTER TABLE REQ_PACKREC_SETTING ADD SUBSETTING_ATTR_NM VARCHAR(40);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0868952;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0868952;
%put ERROR- Description                              : Sub-setting of Size Sets for Pack Optimization;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 01MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0868952;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0868952",
"Sub-setting of Size Sets for Pack Optimization",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0868952:;
 
 
* End of changes for CHANGE_ID:ID0868952;
 
 
***********************************************************************************************;
*************************************  End Change ID0868952 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0868951 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0868951;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0868951")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0868951;
%goto ID0868951;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0868951;
* Insert record into change management table for CHANGE_ID: ID0868951;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0868951",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0868951;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD REC_PACK_ORDER_MIN INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD REC_PACK_ORDER_MIN INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PACK_PRODUCT_SETTING ADD REC_PACK_ORDER_MIN INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PACK_DEFAULT ADD REC_PACK_ORDER_MIN INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_SETTING ADD REC_PACK_ORDER_MIN INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_BUY ADD REC_PACK_ORDER_MIN INTEGER;
 
 
ALTER TABLE PKO_DELIVERY ADD REC_PACK_ORDER_MIN INTEGER;
 
 
ALTER TABLE PKO_PACK_PRODUCT_SETTING ADD REC_PACK_ORDER_MIN INTEGER;
 
 
ALTER TABLE PKO_PACK_DEFAULT ADD REC_PACK_ORDER_MIN INTEGER;
 
 
 
ALTER TABLE REQ_PACKREC_SETTING ADD REC_PACK_ORDER_MIN INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0868951;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0868951;
%put ERROR- Description                              : Rec Pack Order Mins for Pack Optimization;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 01MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0868951;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0868951",
"Rec Pack Order Mins for Pack Optimization",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0868951:;
 
 
* End of changes for CHANGE_ID:ID0868951;
 
 
***********************************************************************************************;
*************************************  End Change ID0868951 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0865873 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0865873;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0865873")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0865873;
%goto ID0865873;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0865873;
* Insert record into change management table for CHANGE_ID: ID0865873;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0865873",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0865873;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_QTY_PERCENT_MIN NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_QTY_PERCENT_MAX NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN SET TOTAL_QTY_PERCENT_MIN=TOTAL_QTY_PERCENT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN SET TOTAL_QTY_PERCENT_MAX=TOTAL_QTY_PERCENT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD TOTAL_QTY_PERCENT_MIN NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD TOTAL_QTY_PERCENT_MAX NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD TOTAL_QTY_PERCENT_MIN NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD TOTAL_QTY_PERCENT_MAX NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_QTY_PERCENT_MIN NUMERIC(20,3);
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_QTY_PERCENT_MAX NUMERIC(20,3);
 
 
UPDATE PKO_PURCHASE_ORDER_PLAN SET TOTAL_QTY_PERCENT_MIN=TOTAL_QTY_PERCENT;
 
 
UPDATE PKO_PURCHASE_ORDER_PLAN SET TOTAL_QTY_PERCENT_MAX=TOTAL_QTY_PERCENT;
 
 
 
ALTER TABLE PKO_BUY ADD TOTAL_QTY_PERCENT_MIN NUMERIC(20,3);
 
 
ALTER TABLE PKO_BUY ADD TOTAL_QTY_PERCENT_MAX NUMERIC(20,3);
 
 
ALTER TABLE PKO_DELIVERY ADD TOTAL_QTY_PERCENT_MIN NUMERIC(20,3);
 
 
ALTER TABLE PKO_DELIVERY ADD TOTAL_QTY_PERCENT_MAX NUMERIC(20,3);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0865873;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0865873;
%put ERROR- Description                              : Allow order quantity threshold to apply to minimum and/or maximum units to order;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 01MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0865873;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0865873",
"Allow order quantity threshold to apply to minimum and/or maximum units to order",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0865873:;
 
 
* End of changes for CHANGE_ID:ID0865873;
 
 
***********************************************************************************************;
*************************************  End Change ID0865873 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0909604 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0909604;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0909604")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0909604;
%goto ID0909604;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0909604;
* Insert record into change management table for CHANGE_ID: ID0909604;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0909604",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0909604;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE PRF_RSLT_STORE_GROUP_RMSD (
PROFILING_PROJECT_SK        INTEGER         NOT NULL,
SIZESET_ID                  INTEGER         NOT NULL,
STORE_GROUP_ID              INTEGER         NOT NULL,
PRELIM_PROFILE_RMSD         NUMERIC(12,4)   NOT NULL,
PRIMARY KEY (PROFILING_PROJECT_SK, SIZESET_ID, STORE_GROUP_ID)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PRF_RSLT_PROFILE_RMSD (
PROFILE_SK                  INTEGER         NOT NULL,
STORE_GROUP_ID              INTEGER         NOT NULL,
PROFILE_RMSD                NUMERIC(12,4)   NOT NULL,
PRIMARY KEY (PROFILE_SK, STORE_GROUP_ID)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
 
CREATE TABLE PRF_RSLT_STORE_GROUP_RMSD (
PROFILING_PROJECT_SK        INTEGER         NOT NULL,
SIZESET_ID                  INTEGER         NOT NULL,
STORE_GROUP_ID              INTEGER         NOT NULL,
PRELIM_PROFILE_RMSD         NUMERIC(12,4)   NOT NULL,
constraint PRIM_KEY PRIMARY KEY (PROFILING_PROJECT_SK, SIZESET_ID, STORE_GROUP_ID)
);
 
 
 
CREATE TABLE PRF_RSLT_PROFILE_RMSD (
PROFILE_SK                  INTEGER         NOT NULL,
STORE_GROUP_ID              INTEGER         NOT NULL,
PROFILE_RMSD                NUMERIC(12,4)   NOT NULL,
constraint PRIM_KEY PRIMARY KEY (PROFILE_SK, STORE_GROUP_ID)
);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0909604;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0909604;
%put ERROR- Description                              : Schema changes for Size Profiling 3.2M3;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 29APR2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0909604;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0909604",
"Schema changes for Size Profiling 3.2M3",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0909604:;
 
 
* End of changes for CHANGE_ID:ID0909604;
 
 
***********************************************************************************************;
*************************************  End Change ID0909604 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID912629 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID912629;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID912629")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID912629;
%goto ID912629;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM62);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID912629;
* Insert record into change management table for CHANGE_ID: ID912629;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID912629",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID912629;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PRF_STORE_GROUP ADD COPY_FROM_OVERALL_DIST_FLG INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PRF_STORE_GROUP ADD COPY_FROM_OVERALL_DIST_FLG INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID912629;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID912629;
%put ERROR- Description                              : Size Profiling 3.2M3 - Support copy from overall flag;
%put ERROR- Version                                  : D3MICM62;
%put ERROR- Date of Change                           : 29APR2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID912629;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID912629",
"Size Profiling 3.2M3 - Support copy from overall flag",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID912629:;
 
 
* End of changes for CHANGE_ID:ID912629;
 
 
***********************************************************************************************;
*************************************  End Change ID912629 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID881597 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID881597;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID881597")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID881597;
%goto ID881597;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID881597;
* Insert record into change management table for CHANGE_ID: ID881597;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID881597",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID881597;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
create table CURRENCY_DM
(
GEO_HIER_SK                        INTEGER NOT NULL,
CURRENCY_ID                        VARCHAR(3) NOT NULL,
LOCAL_TO_GLOBAL_CONV_RATE          NUMERIC(12,4) NOT NULL,
INHERITED_FLG                      INTEGER NOT NULL,
PRIMARY KEY (GEO_HIER_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
create table CURRENCY_DM
(
GEO_HIER_SK                        INTEGER NOT NULL,
CURRENCY_ID                        VARCHAR(3) NOT NULL,
LOCAL_TO_GLOBAL_CONV_RATE          NUMERIC(12,4) NOT NULL,
INHERITED_FLG                      INTEGER NOT NULL
)
;
 
 
ALTER TABLE CURRENCY_DM  add CONSTRAINT PRIM_KEY  PRIMARY KEY (GEO_HIER_SK);
 
 
 
quit;
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID881597;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID881597;
%put ERROR- Description                              : Currency Dimension table;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 30APR2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID881597;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID881597",
"Currency Dimension table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID881597:;
 
 
* End of changes for CHANGE_ID:ID881597;
 
 
***********************************************************************************************;
*************************************  End Change ID881597 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID912629_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID912629_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID912629_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID912629_2;
%goto ID912629_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID912629_2;
* Insert record into change management table for CHANGE_ID: ID912629_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID912629_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID912629_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE PRF_STORE_GROUP SET COPY_FROM_OVERALL_DIST_FLG=0
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRF_STORE_GROUP MODIFY COPY_FROM_OVERALL_DIST_FLG INTEGER DEFAULT 0 NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
alter table PRF_STORE_GROUP add COPY_FROM_OVERALL_DIST_FLG INTEGER ;
 
 
update PRF_STORE_GROUP set COPY_FROM_OVERALL_DIST_FLG=0;
 
 
alter table PRF_STORE_GROUP add NOT NULL (COPY_FROM_OVERALL_DIST_FLG);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID912629_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID912629_2;
%put ERROR- Description                              : Size Profiling 3.2M3 - Support copy from overall flag -- default value;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 30APR2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID912629_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID912629_2",
"Size Profiling 3.2M3 - Support copy from overall flag -- default value",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID912629_2:;
 
 
* End of changes for CHANGE_ID:ID912629_2;
 
 
***********************************************************************************************;
*************************************  End Change ID912629_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0865873_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0865873_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0865873_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0865873_2;
%goto ID0865873_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D3MICM62);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0865873_2;
* Insert record into change management table for CHANGE_ID: ID0865873_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0865873_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0865873_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN DROP COLUMN TOTAL_QTY_PERCENT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN DROP COLUMN TOTAL_QTY_PERCENT;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0865873_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0865873_2;
%put ERROR- Description                              : Allow order quantity threshold to apply to minimum and/or maximum units to order;
%put ERROR- Version                                  : D3MICM62;
%put ERROR- Date of Change                           : 01MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0865873_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0865873_2",
"Allow order quantity threshold to apply to minimum and/or maximum units to order",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0865873_2:;
 
 
* End of changes for CHANGE_ID:ID0865873_2;
 
 
***********************************************************************************************;
*************************************  End Change ID0865873_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID931747 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID931747;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID931747")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID931747;
%goto ID931747;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID931747;
%goto ID931747;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID931747;
* Insert record into change management table for CHANGE_ID: ID931747;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID931747",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID931747;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'CROSS_WEIGHT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'CROSS_WEIGHT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'CROSS_WEIGHT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'CROSS_WEIGHT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'CROSS_WEIGHT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC where SPEC_NM = 'CROSS_WEIGHT';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'CROSS_WEIGHT';
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'CROSS_WEIGHT';
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'CROSS_WEIGHT';
 
 
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'CROSS_WEIGHT';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID931747;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID931747;
%put ERROR- Description                              : Remove model spec CROSS_WEIGHT;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 06MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID931747;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID931747",
"Remove model spec CROSS_WEIGHT",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID931747:;
 
 
* End of changes for CHANGE_ID:ID931747;
 
 
***********************************************************************************************;
*************************************  End Change ID931747 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID945161 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID945161;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID945161")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID945161;
%goto ID945161;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID945161;
%goto ID945161;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID945161;
* Insert record into change management table for CHANGE_ID: ID945161;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID945161",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID945161;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC where SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS';
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS';
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS';
 
 
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'SALES_INTRO_FROM_GPSTATUS';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID945161;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID945161;
%put ERROR- Description                              : Remove model spec SALES_INTRO_FROM_GPSTATUS;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 06MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID945161;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID945161",
"Remove model spec SALES_INTRO_FROM_GPSTATUS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID945161:;
 
 
* End of changes for CHANGE_ID:ID945161;
 
 
***********************************************************************************************;
*************************************  End Change ID945161 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID906970 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID906970;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID906970")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID906970;
%goto ID906970;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID906970;
%goto ID906970;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID906970;
* Insert record into change management table for CHANGE_ID: ID906970;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID906970",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID906970;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'FCST_ZEROMISS' and (MODEL_GROUP_ID ^= -1 and SPEC_VALUE = 'RIGHT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'FCST_ZEROMISS' and (MODEL_GROUP_ID ^= -1 and SPEC_VALUE = 'BOTH')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_VALUE = 'NONE' where (MODEL_GROUP_ID = -1 and SPEC_VALUE = 'RIGHT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_VALUE = 'NONE' where (MODEL_GROUP_ID = -1 and SPEC_VALUE = 'BOTH')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = 'NONE' where (SPEC_NM = 'FCST_ZEROMISS' and DEFAULT_SPEC_VALUE = 'RIGHT')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = 'NONE' where (SPEC_NM = 'FCST_ZEROMISS' and DEFAULT_SPEC_VALUE = 'BOTH')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'FCST_ZEROMISS' and SPEC_VALUE = 'RIGHT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'FCST_ZEROMISS' and SPEC_VALUE = 'BOTH'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC where SPEC_NM = 'FCST_ZEROMISS' and (MODEL_GROUP_ID ^= -1 and SPEC_VALUE = 'RIGHT');
 
 
delete from MODEL_SPEC where SPEC_NM = 'FCST_ZEROMISS' and (MODEL_GROUP_ID ^= -1 and SPEC_VALUE = 'BOTH');
 
 
update MODEL_SPEC set SPEC_VALUE = 'NONE' where (MODEL_GROUP_ID = -1 and SPEC_VALUE = 'RIGHT');
 
 
update MODEL_SPEC set SPEC_VALUE = 'NONE' where (MODEL_GROUP_ID = -1 and SPEC_VALUE = 'BOTH');
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = 'NONE' where (SPEC_NM = 'FCST_ZEROMISS' and DEFAULT_SPEC_VALUE = 'RIGHT');
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = 'NONE' where (SPEC_NM = 'FCST_ZEROMISS' and DEFAULT_SPEC_VALUE = 'BOTH');
 
 
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'FCST_ZEROMISS' and SPEC_VALUE = 'RIGHT';
 
 
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'FCST_ZEROMISS' and SPEC_VALUE = 'BOTH';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID906970;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID906970;
%put ERROR- Description                              : Remove model spec FCST_ZEROMISS values RIGHT, BOTH;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 06MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID906970;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID906970",
"Remove model spec FCST_ZEROMISS values RIGHT, BOTH",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID906970:;
 
 
* End of changes for CHANGE_ID:ID906970;
 
 
***********************************************************************************************;
*************************************  End Change ID906970 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID905917 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID905917;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID905917")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID905917;
%goto ID905917;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID905917;
%goto ID905917;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID905917;
* Insert record into change management table for CHANGE_ID: ID905917;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID905917",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID905917;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where (SPEC_NM = 'DOW_PROFILE' and SPEC_TYPE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_TYPE = '-1' where (SPEC_NM = 'DOW_PROFILE'
and SPEC_TYPE = '1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where (SPEC_NM = 'DOW_PROFILE' and SPEC_TYPE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where (SPEC_NM = 'DOW_PROFILE'
and SPEC_TYPE = '1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where (SPEC_NM = 'DOW_PROFILE' and SPEC_TYPE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '-1' where (SPEC_NM = 'DOW_PROFILE'
and SPEC_TYPE = '1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC where (SPEC_NM = 'DOW_PROFILE' and SPEC_TYPE = '2');
 
 
update MODEL_SPEC set SPEC_TYPE = '-1' where (SPEC_NM = 'DOW_PROFILE'
and SPEC_TYPE = '1');
 
 
delete from MODEL_SPEC_DEFAULT where (SPEC_NM = 'DOW_PROFILE' and SPEC_TYPE = '2');
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where (SPEC_NM = 'DOW_PROFILE'
and SPEC_TYPE = '1');
 
 
delete from MODEL_SPEC_TEMPLATE where (SPEC_NM = 'DOW_PROFILE' and SPEC_TYPE = '2');
 
 
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '-1' where (SPEC_NM = 'DOW_PROFILE'
and SPEC_TYPE = '1');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID905917;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID905917;
%put ERROR- Description                              : Change DOW_PROFILE model spec type to -1;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 06MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID905917;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID905917",
"Change DOW_PROFILE model spec type to -1",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID905917:;
 
 
* End of changes for CHANGE_ID:ID905917;
 
 
***********************************************************************************************;
*************************************  End Change ID905917 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID936652 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID936652;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID936652")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID936652;
%goto ID936652;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID936652;
%goto ID936652;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID936652;
* Insert record into change management table for CHANGE_ID: ID936652;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID936652",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID936652;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from FA_SPEC where SPEC_NM = 'BENCHMARK_PRIORITY'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BENCHMARK_PRIORITY'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'BENCHMARK_PRIORITY'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'BENCHMARK_PRIORITY'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from FA_SPEC where SPEC_NM = 'BENCHMARK_PRIORITY';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BENCHMARK_PRIORITY';
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'BENCHMARK_PRIORITY';
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'BENCHMARK_PRIORITY';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID936652;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID936652;
%put ERROR- Description                              : Remove FA spec BENCHMARK_PRIORITY;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 06MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID936652;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID936652",
"Remove FA spec BENCHMARK_PRIORITY",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID936652:;
 
 
* End of changes for CHANGE_ID:ID936652;
 
 
***********************************************************************************************;
*************************************  End Change ID936652 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID936457 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID936457;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID936457")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..SCORING_PARAM_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..SCORING_PARAM_DEFAULT;
%put NOTE: Change ID                             :ID936457;
%goto ID936457;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID936457;
%goto ID936457;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID936457;
* Insert record into change management table for CHANGE_ID: ID936457;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID936457",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID936457;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CINV_ADJ'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CINV_ADJ',1,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CINV_ADJ',2,0,0,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CPL_ADJ'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CPL_ADJ',1,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CPL_ADJ',2,0,null,null)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CINV_ADJ';
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CINV_ADJ',1,0,null,null);
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CINV_ADJ',2,0,0,null);
 
 
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CPL_ADJ';
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CPL_ADJ',1,0,null,null);
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CPL_ADJ',2,0,null,null);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID936457;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID936457;
%put ERROR- Description                              : Add CPL_ADJ and CINV_ADJ scoring parameter default;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 08MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID936457;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID936457",
"Add CPL_ADJ and CINV_ADJ scoring parameter default",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID936457:;
 
 
* End of changes for CHANGE_ID:ID936457;
 
 
***********************************************************************************************;
*************************************  End Change ID936457 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID919779 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID919779;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID919779")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID919779;
%goto ID919779;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID919779;
%goto ID919779;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID919779;
* Insert record into change management table for CHANGE_ID: ID919779;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID919779",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID919779;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'MIN_HIST_INV'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MIN_HIST_INV'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'MIN_HIST_INV'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'MIN_HIST_INV'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC where SPEC_NM = 'MIN_HIST_INV';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'MIN_HIST_INV';
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'MIN_HIST_INV';
 
 
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'MIN_HIST_INV';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID919779;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID919779;
%put ERROR- Description                              : Remove model spec MIN_HIST_INV;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 09MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID919779;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID919779",
"Remove model spec MIN_HIST_INV",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID919779:;
 
 
* End of changes for CHANGE_ID:ID919779;
 
 
***********************************************************************************************;
*************************************  End Change ID919779 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID949364 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID949364;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID949364")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID949364;
%goto ID949364;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID949364;
%goto ID949364;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID949364;
* Insert record into change management table for CHANGE_ID: ID949364;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID949364",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID949364;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'NON_COMP_DISCARD_PERIOD'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'NON_COMP_DISCARD_PERIOD'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'NON_COMP_DISCARD_PERIOD'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'NON_COMP_DISCARD_PERIOD'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC where SPEC_NM = 'NON_COMP_DISCARD_PERIOD';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'NON_COMP_DISCARD_PERIOD';
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'NON_COMP_DISCARD_PERIOD';
 
 
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'NON_COMP_DISCARD_PERIOD';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID949364;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID949364;
%put ERROR- Description                              : Remove model spec NON_COMP_DISCARD_PERIOD;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 09MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID949364;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID949364",
"Remove model spec NON_COMP_DISCARD_PERIOD",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID949364:;
 
 
* End of changes for CHANGE_ID:ID949364;
 
 
***********************************************************************************************;
*************************************  End Change ID949364 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID0968520 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID0968520;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID0968520")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID0968520;
%goto ID0968520;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID0968520;
* Insert record into change management table for CHANGE_ID: ID0968520;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0968520",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID0968520;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_STORES INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_STYLECOLORS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD OPTIMIZED_QUANTITY INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD RES_MSG_COUNT INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_BUYS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_DELIVERIES INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_PLANNED INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE NSTORES_TMP AS SELECT P.PURCHASE_ORDER_PLAN_SK, COUNT(*) AS TOTAL_STORES
FROM GEOGRAPHY_HIER_ASSOC_DM HIER, PKO_PURCHASE_ORDER_PLAN_LOC PL, GEOGRAPHY_DM G, PKO_PURCHASE_ORDER_PLAN P
WHERE (HIER.GEO_HIER_ASSOC_CD=1) AND (HIER.GEO_LVL=(SELECT MAX(STD_HIER_GEO_LVL) FROM GEOGRAPHY_DM))
AND (HIER.PARENT_GEO_HIER_SK=PL.GEO_HIER_SK) AND G.GEO_HIER_SK=HIER.GEO_HIER_SK
AND (G.CLOSING_DT IS NULL OR G.CLOSING_DT >= P.START_DT) AND (G.OPEN_DT IS NULL OR G.OPEN_DT <= P.END_DT)
AND G.FACILITY_TYPE=1 AND G.STD_HIER_GEO_LVL=(SELECT MAX(STD_HIER_GEO_LVL) FROM GEOGRAPHY_DM)
AND P.PURCHASE_ORDER_PLAN_SK=PL.PURCHASE_ORDER_PLAN_SK
GROUP BY P.PURCHASE_ORDER_PLAN_SK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN
SET TOTAL_STORES=(SELECT TOTAL_STORES FROM NSTORES_TMP
WHERE NSTORES_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DROP TABLE NSTORES_TMP
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE NSTYLECOLORS_TMP AS SELECT P.PURCHASE_ORDER_PLAN_SK, COUNT(*) AS NS
FROM PKO_PRODUCT_HIER_ASSOC_DM_ALL HIER, PKO_PURCHASE_ORDER_PLAN_PROD PP, PKO_PURCHASE_ORDER_PLAN P
WHERE (HIER.PROD_HIER_ASSOC_CD=1) AND (HIER.PROD_LVL=(SELECT (MAX(STD_HIER_PROD_LVL)-1) FROM PRODUCT_DM))
AND (HIER.PARENT_PROD_HIER_SK=PP.PROD_HIER_SK) AND (P.PURCHASE_ORDER_PLAN_SK=PP.PURCHASE_ORDER_PLAN_SK)
GROUP BY P.PURCHASE_ORDER_PLAN_SK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN
SET TOTAL_STYLECOLORS=(SELECT NS FROM NSTYLECOLORS_TMP
WHERE NSTYLECOLORS_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DROP TABLE NSTYLECOLORS_TMP
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN SET OPTIMIZED_QUANTITY=NULL WHERE PLAN_STATUS_CD IN (0, 3, 7, 8, 9)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE OPT_TMP AS SELECT P.PURCHASE_ORDER_PLAN_SK, SUM(Q.NUM_PLANNED_ORDER) AS OPT_QTY
FROM PKO_PURCHASE_ORDER_PLAN P, PKO_BUY B, PKO_RES_PROD_GEO_SIZE_QTY Q
WHERE (P.PLAN_STATUS_CD IN (2, 4, 5))
AND P.PURCHASE_ORDER_PLAN_SK=B.PURCHASE_ORDER_PLAN_SK AND B.BUY_SK=Q.BUY_SK GROUP BY P.PURCHASE_ORDER_PLAN_SK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN
SET OPTIMIZED_QUANTITY=(SELECT OPT_QTY FROM OPT_TMP
WHERE OPT_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DROP TABLE OPT_TMP
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN SET RES_MSG_COUNT=NULL WHERE PLAN_STATUS_CD IN (0, 7, 8, 9)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MSG_TMP AS SELECT P.PURCHASE_ORDER_PLAN_SK, COUNT(*) AS RES_COUNT
FROM PKO_PURCHASE_ORDER_PLAN P, PKO_BUY B, PKO_RES_MESSAGE T
WHERE P.PURCHASE_ORDER_PLAN_SK=B.PURCHASE_ORDER_PLAN_SK AND B.BUY_SK=T.BUY_SK AND (P.PLAN_STATUS_CD IN(2, 3, 4, 5))
GROUP BY P.PURCHASE_ORDER_PLAN_SK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN
SET RES_MSG_COUNT=(SELECT RES_COUNT FROM MSG_TMP
WHERE MSG_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DROP TABLE MSG_TMP
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE BUY_TMP AS SELECT PURCHASE_ORDER_PLAN_SK, COUNT(*) AS BUY_COUNT
FROM PKO_BUY GROUP BY PURCHASE_ORDER_PLAN_SK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN
SET TOTAL_BUYS=(SELECT BUY_COUNT FROM BUY_TMP
WHERE BUY_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DROP TABLE BUY_TMP
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE DEL_TMP AS SELECT PURCHASE_ORDER_PLAN_SK, COUNT(*) AS DEL_COUNT
FROM PKO_BUY PKOB, PKO_DELIVERY PKOD
WHERE PKOB.BUY_SK=PKOD.BUY_SK GROUP BY PURCHASE_ORDER_PLAN_SK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN
SET TOTAL_DELIVERIES=(SELECT DEL_COUNT FROM DEL_TMP
WHERE DEL_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DROP TABLE DEL_TMP
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE TOTAL_PLANNED_TMP AS SELECT PURCHASE_ORDER_PLAN_SK, TOTAL
FROM PKO_IMPORTED_NEED
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN
SET TOTAL_PLANNED=(SELECT TOTAL FROM TOTAL_PLANNED_TMP
WHERE TOTAL_PLANNED_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DROP TABLE TOTAL_PLANNED_TMP
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_STORES INTEGER;
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_STYLECOLORS INTEGER;
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD OPTIMIZED_QUANTITY INTEGER;
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD RES_MSG_COUNT INTEGER;
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_BUYS INTEGER;
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_DELIVERIES INTEGER;
 
 
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD TOTAL_PLANNED INTEGER;
 
 
 
CREATE TABLE NSTORES_TMP AS SELECT P.PURCHASE_ORDER_PLAN_SK, COUNT(*) AS TOTAL_STORES
FROM GEOGRAPHY_HIER_ASSOC_DM HIER, PKO_PURCHASE_ORDER_PLAN_LOC PL, GEOGRAPHY_DM G, PKO_PURCHASE_ORDER_PLAN P
WHERE (HIER.GEO_HIER_ASSOC_CD=1) AND (HIER.GEO_LVL=(SELECT MAX(STD_HIER_GEO_LVL) FROM GEOGRAPHY_DM))
AND (HIER.PARENT_GEO_HIER_SK=PL.GEO_HIER_SK) AND G.GEO_HIER_SK=HIER.GEO_HIER_SK
AND (G.CLOSING_DT IS NULL OR G.CLOSING_DT >= P.START_DT) AND (G.OPEN_DT IS NULL OR G.OPEN_DT <= P.END_DT)
AND G.FACILITY_TYPE=1 AND G.STD_HIER_GEO_LVL=(SELECT MAX(STD_HIER_GEO_LVL) FROM GEOGRAPHY_DM)
AND P.PURCHASE_ORDER_PLAN_SK=PL.PURCHASE_ORDER_PLAN_SK
GROUP BY P.PURCHASE_ORDER_PLAN_SK;
 
 
 
UPDATE PKO_PURCHASE_ORDER_PLAN
SET TOTAL_STORES=(SELECT TOTAL_STORES FROM NSTORES_TMP
WHERE NSTORES_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK);
 
 
 
DROP TABLE NSTORES_TMP ;
 
 
 
CREATE TABLE NSTYLECOLORS_TMP AS SELECT P.PURCHASE_ORDER_PLAN_SK, COUNT(*) AS NS
FROM PKO_PRODUCT_HIER_ASSOC_DM_ALL HIER, PKO_PURCHASE_ORDER_PLAN_PROD PP, PKO_PURCHASE_ORDER_PLAN P
WHERE (HIER.PROD_HIER_ASSOC_CD=1) AND (HIER.PROD_LVL=(SELECT (MAX(STD_HIER_PROD_LVL)-1) FROM PRODUCT_DM))
AND (HIER.PARENT_PROD_HIER_SK=PP.PROD_HIER_SK) AND (P.PURCHASE_ORDER_PLAN_SK=PP.PURCHASE_ORDER_PLAN_SK)
GROUP BY P.PURCHASE_ORDER_PLAN_SK;
 
 
 
UPDATE PKO_PURCHASE_ORDER_PLAN
SET TOTAL_STYLECOLORS=(SELECT NS FROM NSTYLECOLORS_TMP
WHERE NSTYLECOLORS_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK);
 
 
 
DROP TABLE NSTYLECOLORS_TMP ;
 
 
 
UPDATE PKO_PURCHASE_ORDER_PLAN SET OPTIMIZED_QUANTITY=NULL WHERE PLAN_STATUS_CD IN (0, 3, 7, 8, 9) ;
 
 
 
CREATE TABLE OPT_TMP AS SELECT P.PURCHASE_ORDER_PLAN_SK, SUM(Q.NUM_PLANNED_ORDER) AS OPT_QTY
FROM PKO_PURCHASE_ORDER_PLAN P, PKO_BUY B, PKO_RES_PROD_GEO_SIZE_QTY Q
WHERE (P.PLAN_STATUS_CD IN (2, 4, 5))
AND P.PURCHASE_ORDER_PLAN_SK=B.PURCHASE_ORDER_PLAN_SK AND B.BUY_SK=Q.BUY_SK GROUP BY P.PURCHASE_ORDER_PLAN_SK ;
 
 
 
UPDATE PKO_PURCHASE_ORDER_PLAN
SET OPTIMIZED_QUANTITY=(SELECT OPT_QTY FROM OPT_TMP
WHERE OPT_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK);
 
 
 
DROP TABLE OPT_TMP ;
 
 
 
UPDATE PKO_PURCHASE_ORDER_PLAN SET RES_MSG_COUNT=NULL WHERE PLAN_STATUS_CD IN (0, 7, 8, 9) ;
 
 
 
CREATE TABLE MSG_TMP AS SELECT P.PURCHASE_ORDER_PLAN_SK, COUNT(*) AS RES_COUNT
FROM PKO_PURCHASE_ORDER_PLAN P, PKO_BUY B, PKO_RES_MESSAGE T
WHERE P.PURCHASE_ORDER_PLAN_SK=B.PURCHASE_ORDER_PLAN_SK AND B.BUY_SK=T.BUY_SK AND (P.PLAN_STATUS_CD IN(2, 3, 4, 5))
GROUP BY P.PURCHASE_ORDER_PLAN_SK;
 
 
 
UPDATE PKO_PURCHASE_ORDER_PLAN
SET RES_MSG_COUNT=(SELECT RES_COUNT FROM MSG_TMP
WHERE MSG_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK);
 
 
 
DROP TABLE MSG_TMP ;
 
 
 
CREATE TABLE BUY_TMP AS SELECT PURCHASE_ORDER_PLAN_SK, COUNT(*) AS BUY_COUNT
FROM PKO_BUY GROUP BY PURCHASE_ORDER_PLAN_SK ;
 
 
 
UPDATE PKO_PURCHASE_ORDER_PLAN
SET TOTAL_BUYS=(SELECT BUY_COUNT FROM BUY_TMP
WHERE BUY_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK);
 
 
 
DROP TABLE BUY_TMP ;
 
 
 
CREATE TABLE DEL_TMP AS SELECT PURCHASE_ORDER_PLAN_SK, COUNT(*) AS DEL_COUNT
FROM PKO_BUY PKOB, PKO_DELIVERY PKOD
WHERE PKOB.BUY_SK=PKOD.BUY_SK GROUP BY PURCHASE_ORDER_PLAN_SK;
 
 
 
UPDATE PKO_PURCHASE_ORDER_PLAN
SET TOTAL_DELIVERIES=(SELECT DEL_COUNT FROM DEL_TMP
WHERE DEL_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK);
 
 
 
DROP TABLE DEL_TMP ;
 
 
 
CREATE TABLE TOTAL_PLANNED_TMP AS SELECT PURCHASE_ORDER_PLAN_SK, TOTAL
FROM PKO_IMPORTED_NEED;
 
 
 
UPDATE PKO_PURCHASE_ORDER_PLAN
SET TOTAL_PLANNED=(SELECT TOTAL FROM TOTAL_PLANNED_TMP
WHERE TOTAL_PLANNED_TMP.PURCHASE_ORDER_PLAN_SK=PKO_PURCHASE_ORDER_PLAN.PURCHASE_ORDER_PLAN_SK);
 
 
 
DROP TABLE TOTAL_PLANNED_TMP ;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID0968520;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID0968520;
%put ERROR- Description                              : CRP PERFORMANCE:Need faster load of large number of purchase order plans;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 14MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID0968520;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID0968520",
"CRP PERFORMANCE:Need faster load of large number of purchase order plans",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID0968520:;
 
 
* End of changes for CHANGE_ID:ID0968520;
 
 
***********************************************************************************************;
*************************************  End Change ID0968520 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID886306 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID886306;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID886306")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PURGE_QUERY))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PURGE_QUERY;
%put NOTE: Change ID                             :ID886306;
%goto ID886306;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID886306;
%goto ID886306;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID886306;
* Insert record into change management table for CHANGE_ID: ID886306;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID886306",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID886306;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update purge_query
set partition_flg=1
where table_nm in (
'CALENDAR_MWW', 'PRF_GEO_PROD_STATUS_PARTIAL',  'PRF_SALES_FACT_PARTIAL',  'PRF_STOCKOUT_FACT_PARTIAL',
'SAME_PRICE_SET_TBLS_STP', 'PROCESS_MESSAGE_DETAIL_RPO',  'CLEAN_ATTR_HIER_GEO',  'CLEAN_ATTR_HIER_PROD',
'COMP_PRICE_RULE_RESULT_PLN', 'MARGIN_RULE_RESULT_PLN',  'MPLN_MTS', 'NON_ACTIVE_CLEAN_METRICS',
'ORPHAN_CLEAN_METRICS')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from purge_query
where table_nm in (
'PROD_DATA_CONFIG', 'PROMOTION_FACT_FUTURE', 'SCORING_PARAM_DEFAULT', 'ATTR_SPEC', 'CONFIG_AUDIT_TRAIL',
'DATA_CONFIG', 'DATA_CONFIG_TEMPLATE', 'FA_ALERT', 'FA_ALERT_STATUS', 'FA_ARCHIVE', 'FA_MODEL_GROUP',
'FA_MONITORING_FILTER_PROD_GEO', 'FA_MONITORING_GEO', 'FA_MONITORING_PROD', 'FA_PRESEASON_FILTER_PROD_GEO',
'FA_PRESEASON_GEO', 'FA_PRESEASON_PROD', 'FA_SCENARIO', 'FA_SCENARIO_SPEC', 'FA_SCENARIO_STATUS', 'FA_SCORE',
'FA_SPEC', 'IDX_SCORING_PARAM_AVG ', 'IDX_MODEL_DATA', 'IDX_MODEL_DATA_CALIB', 'IDX_PROMO_FACTOR',
'IDX_PROMO_FACTOR_DECOM', 'IDX_SCORING_PARAM', 'Inventory_Sparse', 'Inventory_Sparse_Refresh', 'MG_PARTITIONS',
'MODEL_DATA', 'MODEL_DATA_CALIB', 'MODEL_DATA_CALIB_PS','MODEL_GEO_PROD_STATUS_RULE', 'MODEL_GEO_PROD_STATUS_SPEC',
'MODEL_GROUP','MODEL_SPEC', 'MODEL_SPEC_TEMPLATE', 'SCORING_PARAM_DEFAULT','PROMO_FACTOR','PROMO_FACTOR_DECOMP')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
update purge_query
set database_nm='RDBMS'
where table_nm in ('PKO_PURCHASE_ORDER_PLAN')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update purge_query
set partition_flg=1
where table_nm in (
'CALENDAR_MWW', 'PRF_GEO_PROD_STATUS_PARTIAL',  'PRF_SALES_FACT_PARTIAL',  'PRF_STOCKOUT_FACT_PARTIAL',
'SAME_PRICE_SET_TBLS_STP', 'PROCESS_MESSAGE_DETAIL_RPO',  'CLEAN_ATTR_HIER_GEO',  'CLEAN_ATTR_HIER_PROD',
'COMP_PRICE_RULE_RESULT_PLN', 'MARGIN_RULE_RESULT_PLN',  'MPLN_MTS', 'NON_ACTIVE_CLEAN_METRICS',
'ORPHAN_CLEAN_METRICS');
 
 
 
delete from purge_query
where table_nm in (
'PROD_DATA_CONFIG', 'PROMOTION_FACT_FUTURE', 'SCORING_PARAM_DEFAULT', 'ATTR_SPEC', 'CONFIG_AUDIT_TRAIL',
'DATA_CONFIG', 'DATA_CONFIG_TEMPLATE', 'FA_ALERT', 'FA_ALERT_STATUS', 'FA_ARCHIVE', 'FA_MODEL_GROUP',
'FA_MONITORING_FILTER_PROD_GEO', 'FA_MONITORING_GEO', 'FA_MONITORING_PROD', 'FA_PRESEASON_FILTER_PROD_GEO',
'FA_PRESEASON_GEO', 'FA_PRESEASON_PROD', 'FA_SCENARIO', 'FA_SCENARIO_SPEC', 'FA_SCENARIO_STATUS', 'FA_SCORE',
'FA_SPEC', 'IDX_SCORING_PARAM_AVG ', 'IDX_MODEL_DATA', 'IDX_MODEL_DATA_CALIB', 'IDX_PROMO_FACTOR',
'IDX_PROMO_FACTOR_DECOM', 'IDX_SCORING_PARAM', 'Inventory_Sparse', 'Inventory_Sparse_Refresh', 'MG_PARTITIONS',
'MODEL_DATA', 'MODEL_DATA_CALIB', 'MODEL_DATA_CALIB_PS','MODEL_GEO_PROD_STATUS_RULE', 'MODEL_GEO_PROD_STATUS_SPEC',
'MODEL_GROUP','MODEL_SPEC', 'MODEL_SPEC_TEMPLATE', 'SCORING_PARAM_DEFAULT','PROMO_FACTOR','PROMO_FACTOR_DECOMP');
 
 
 
update purge_query
set database_nm='RDBMS'
where table_nm in ('PKO_PURCHASE_ORDER_PLAN');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID886306;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID886306;
%put ERROR- Description                              : Error occurs while running di_maintain_job;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 15MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID886306;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID886306",
"Error occurs while running di_maintain_job",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID886306:;
 
 
* End of changes for CHANGE_ID:ID886306;
 
 
***********************************************************************************************;
*************************************  End Change ID886306 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID906970_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID906970_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID906970_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_VALUES))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_VALUES;
%put NOTE: Change ID                             :ID906970_1;
%goto ID906970_1;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID906970_1;
%goto ID906970_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID906970_1;
* Insert record into change management table for CHANGE_ID: ID906970_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID906970_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID906970_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'FCST_ZEROMISS' and SPEC_VALUE = 'RIGHT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'FCST_ZEROMISS' and SPEC_VALUE = 'BOTH'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'FCST_ZEROMISS' and SPEC_VALUE = 'RIGHT';
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'FCST_ZEROMISS' and SPEC_VALUE = 'BOTH';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID906970_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID906970_1;
%put ERROR- Description                              : Remove model spec FCST_ZEROMISS values RIGHT, BOTH;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 20MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID906970_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID906970_1",
"Remove model spec FCST_ZEROMISS values RIGHT, BOTH",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID906970_1:;
 
 
* End of changes for CHANGE_ID:ID906970_1;
 
 
***********************************************************************************************;
*************************************  End Change ID906970_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID974262 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID974262;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID974262")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_GEO_PROD_STATUS_RULE))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_GEO_PROD_STATUS_RULE;
%put NOTE: Change ID                             :ID974262;
%goto ID974262;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID974262;
%goto ID974262;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID974262;
* Insert record into change management table for CHANGE_ID: ID974262;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID974262",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID974262;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
insert into MODEL_GEO_PROD_STATUS_RULE (PROD_HIER_SK,RULE_NM) values (1,'GEO_GROUP_LVL')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_GEO_PROD_STATUS_RULE r set RULE_VALUE
= (select s.SPEC_VALUE from MODEL_GEO_PROD_STATUS_SPEC s where s.SPEC_NM = 'GEO_GROUP_LVL')
where r.RULE_NM = 'GEO_GROUP_LVL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_GEO_PROD_STATUS_RULE r set CREATED_DTTM
= (select s.CREATED_DTTM from MODEL_GEO_PROD_STATUS_SPEC s where s.SPEC_NM = 'GEO_GROUP_LVL')
where r.RULE_NM = 'GEO_GROUP_LVL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_GEO_PROD_STATUS_RULE r set CREATED_BY
= (select s.CREATED_BY from MODEL_GEO_PROD_STATUS_SPEC s where s.SPEC_NM = 'GEO_GROUP_LVL')
where r.RULE_NM = 'GEO_GROUP_LVL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_GEO_PROD_STATUS_SPEC where SPEC_NM = 'GEO_GROUP_LVL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
insert into GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK,RULE_NM) values (1,'GEO_GROUP_LVL')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update GLOBAL_GEO_PROD_STATUS_RULE r set RULE_VALUE
= (select s.SPEC_VALUE from GLOBAL_GEO_PROD_STATUS_SPEC s where s.SPEC_NM = 'GEO_GROUP_LVL')
where r.RULE_NM = 'GEO_GROUP_LVL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update GLOBAL_GEO_PROD_STATUS_RULE r set CREATED_DTTM
= (select s.CREATED_DTTM from GLOBAL_GEO_PROD_STATUS_SPEC s where s.SPEC_NM = 'GEO_GROUP_LVL')
where r.RULE_NM = 'GEO_GROUP_LVL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update GLOBAL_GEO_PROD_STATUS_RULE r set CREATED_BY
= (select s.CREATED_BY from GLOBAL_GEO_PROD_STATUS_SPEC s where s.SPEC_NM = 'GEO_GROUP_LVL')
where r.RULE_NM = 'GEO_GROUP_LVL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from GLOBAL_GEO_PROD_STATUS_SPEC where SPEC_NM = 'GEO_GROUP_LVL'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
insert into MODEL_GEO_PROD_STATUS_RULE (PROD_HIER_SK,RULE_NM) values (1,'GEO_GROUP_LVL');
 
 
update MODEL_GEO_PROD_STATUS_RULE r set RULE_VALUE
= (select s.SPEC_VALUE from MODEL_GEO_PROD_STATUS_SPEC s where s.SPEC_NM = 'GEO_GROUP_LVL')
where r.RULE_NM = 'GEO_GROUP_LVL';
 
 
update MODEL_GEO_PROD_STATUS_RULE r set CREATED_DTTM
= (select s.CREATED_DTTM from MODEL_GEO_PROD_STATUS_SPEC s where s.SPEC_NM = 'GEO_GROUP_LVL')
where r.RULE_NM = 'GEO_GROUP_LVL';
 
 
update MODEL_GEO_PROD_STATUS_RULE r set CREATED_BY
= (select s.CREATED_BY from MODEL_GEO_PROD_STATUS_SPEC s where s.SPEC_NM = 'GEO_GROUP_LVL')
where r.RULE_NM = 'GEO_GROUP_LVL';
 
 
delete from MODEL_GEO_PROD_STATUS_SPEC where SPEC_NM = 'GEO_GROUP_LVL';
 
 
 
insert into GLOBAL_GEO_PROD_STATUS_RULE (PROD_HIER_SK,RULE_NM) values (1,'GEO_GROUP_LVL');
 
 
update GLOBAL_GEO_PROD_STATUS_RULE r set RULE_VALUE
= (select s.SPEC_VALUE from GLOBAL_GEO_PROD_STATUS_SPEC s where s.SPEC_NM = 'GEO_GROUP_LVL')
where r.RULE_NM = 'GEO_GROUP_LVL';
 
 
update GLOBAL_GEO_PROD_STATUS_RULE r set CREATED_DTTM
= (select s.CREATED_DTTM from GLOBAL_GEO_PROD_STATUS_SPEC s where s.SPEC_NM = 'GEO_GROUP_LVL')
where r.RULE_NM = 'GEO_GROUP_LVL';
 
 
update GLOBAL_GEO_PROD_STATUS_RULE r set CREATED_BY
= (select s.CREATED_BY from GLOBAL_GEO_PROD_STATUS_SPEC s where s.SPEC_NM = 'GEO_GROUP_LVL')
where r.RULE_NM = 'GEO_GROUP_LVL';
 
 
delete from GLOBAL_GEO_PROD_STATUS_SPEC where SPEC_NM = 'GEO_GROUP_LVL';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID974262;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID974262;
%put ERROR- Description                              : Move GEO_GROUP_LVL from status spec to status rule;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 21MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID974262;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID974262",
"Move GEO_GROUP_LVL from status spec to status rule",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID974262:;
 
 
* End of changes for CHANGE_ID:ID974262;
 
 
***********************************************************************************************;
*************************************  End Change ID974262 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID975860 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID975860;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID975860")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID975860;
%goto ID975860;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC;
%put NOTE: Change ID                             :ID975860;
%goto ID975860;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID975860;
%goto ID975860;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID975860;
* Insert record into change management table for CHANGE_ID: ID975860;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID975860;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AG_DENORM'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('AG_DENORM','REG','-1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'AG_DENORM'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'REG','AG_DENORM','-1','0',NULL,NULL,'SEED')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AG_DENORM'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('REG','AG_DENORM','Boolean',null,null,null,
null,0,NULL,NULL,NULL,NULL,NULL,'mspec.AG_DENORM.description.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'AG_DENORM'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('AG_DENORM','REG','1','mspec.AG_DENORM.truemeans.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('AG_DENORM','REG','0','mspec.AG_DENORM.falsemeans.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AG_MIN_OBS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('AG_MIN_OBS','REG','-1','30',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'AG_MIN_OBS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'REG','AG_MIN_OBS','-1','30',NULL,NULL,'SEED')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AG_MIN_OBS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('REG','AG_MIN_OBS','Integer',null,1,null,
null,0,NULL,NULL,NULL,NULL,NULL,'mspec.AG_MIN_OBS.description.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AG_GRP_TYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('AG_GRP_TYPE','REG','-1','N',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'AG_GRP_TYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'REG','AG_GRP_TYPE','-1','N',NULL,NULL,'SEED')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AG_GRP_TYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('REG','AG_GRP_TYPE','MultiValue',null,null,null,
null,0,NULL,NULL,NULL,NULL,NULL,'mspec.AG_GRP_TYPE.description.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'AG_GRP_TYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('AG_GRP_TYPE','REG','P','mspec.AG_GRP_TYPE.pmeaning.P.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('AG_GRP_TYPE','REG','N','mspec.AG_GRP_TYPE.pmeaning.N.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AG_MIN_CORR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('AG_MIN_CORR','REG','-1','0.3',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'AG_MIN_CORR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'REG','AG_MIN_CORR','-1','0.3',NULL,NULL,'SEED')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AG_MIN_CORR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('REG','AG_MIN_CORR','Double',null,0,1,
0.01,0,NULL,NULL,NULL,NULL,NULL,'mspec.AG_MIN_CORR.description.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AUTO_CROSS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('AUTO_CROSS','REG','-1','0',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'AUTO_CROSS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'REG','AUTO_CROSS','-1','0',NULL,NULL,'SEED')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AUTO_CROSS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('REG','AUTO_CROSS','Boolean',null,null,null,
null,0,NULL,NULL,NULL,NULL,NULL,'mspec.AUTO_CROSS.description.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'AUTO_CROSS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('AUTO_CROSS','REG','1','mspec.AUTO_CROSS.truemeans.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('AUTO_CROSS','REG','0','mspec.AUTO_CROSS.falsemeans.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AG_DENORM';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('AG_DENORM','REG','-1','0',NULL);
 
 
delete from MODEL_SPEC where SPEC_NM = 'AG_DENORM';
 
 
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'REG','AG_DENORM','-1','0',NULL,NULL,'SEED');
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AG_DENORM';
 
 
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('REG','AG_DENORM','Boolean',null,null,null,
null,0,NULL,NULL,NULL,NULL,NULL,'mspec.AG_DENORM.description.txt');
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'AG_DENORM';
 
 
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('AG_DENORM','REG','1','mspec.AG_DENORM.truemeans.txt');
 
 
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('AG_DENORM','REG','0','mspec.AG_DENORM.falsemeans.txt');
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AG_MIN_OBS';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('AG_MIN_OBS','REG','-1','30',NULL);
 
 
delete from MODEL_SPEC where SPEC_NM = 'AG_MIN_OBS';
 
 
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'REG','AG_MIN_OBS','-1','30',NULL,NULL,'SEED');
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AG_MIN_OBS';
 
 
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('REG','AG_MIN_OBS','Integer',null,1,null,
null,0,NULL,NULL,NULL,NULL,NULL,'mspec.AG_MIN_OBS.description.txt');
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AG_GRP_TYPE';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('AG_GRP_TYPE','REG','-1','N',NULL);
 
 
delete from MODEL_SPEC where SPEC_NM = 'AG_GRP_TYPE';
 
 
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'REG','AG_GRP_TYPE','-1','N',NULL,NULL,'SEED');
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AG_GRP_TYPE';
 
 
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('REG','AG_GRP_TYPE','MultiValue',null,null,null,
null,0,NULL,NULL,NULL,NULL,NULL,'mspec.AG_GRP_TYPE.description.txt');
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'AG_GRP_TYPE';
 
 
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('AG_GRP_TYPE','REG','P','mspec.AG_GRP_TYPE.pmeaning.P.txt');
 
 
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('AG_GRP_TYPE','REG','N','mspec.AG_GRP_TYPE.pmeaning.N.txt');
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AG_MIN_CORR';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('AG_MIN_CORR','REG','-1','0.3',NULL);
 
 
delete from MODEL_SPEC where SPEC_NM = 'AG_MIN_CORR';
 
 
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'REG','AG_MIN_CORR','-1','0.3',NULL,NULL,'SEED');
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AG_MIN_CORR';
 
 
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('REG','AG_MIN_CORR','Double',null,0,1,
0.01,0,NULL,NULL,NULL,NULL,NULL,'mspec.AG_MIN_CORR.description.txt');
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AUTO_CROSS';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('AUTO_CROSS','REG','-1','0',NULL);
 
 
delete from MODEL_SPEC where SPEC_NM = 'AUTO_CROSS';
 
 
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'REG','AUTO_CROSS','-1','0',NULL,NULL,'SEED');
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AUTO_CROSS';
 
 
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('REG','AUTO_CROSS','Boolean',null,null,null,
null,0,NULL,NULL,NULL,NULL,NULL,'mspec.AUTO_CROSS.description.txt');
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'AUTO_CROSS';
 
 
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('AUTO_CROSS','REG','1','mspec.AUTO_CROSS.truemeans.txt');
 
 
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('AUTO_CROSS','REG','0','mspec.AUTO_CROSS.falsemeans.txt');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID975860;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID975860;
%put ERROR- Description                              : Add model specs to support affinity groups;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 23MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID975860;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860",
"Add model specs to support affinity groups",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID975860:;
 
 
* End of changes for CHANGE_ID:ID975860;
 
 
***********************************************************************************************;
*************************************  End Change ID975860 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID975860_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID975860_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID975860_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DETAILS))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DETAILS;
%put NOTE: Change ID                             :ID975860_1;
%goto ID975860_1;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID975860_1;
%goto ID975860_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID975860_1;
* Insert record into change management table for CHANGE_ID: ID975860_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID975860_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC_DETAILS set SPEC_VALUE_MIN = 2 where SPEC_NM = 'AG_MIN_OBS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC_DETAILS set SPEC_VALUE_MIN = 2 where SPEC_NM = 'AG_MIN_OBS';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID975860_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID975860_1;
%put ERROR- Description                              : Change min value for model spec AG_MIN_OBS;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 23MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID975860_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_1",
"Change min value for model spec AG_MIN_OBS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID975860_1:;
 
 
* End of changes for CHANGE_ID:ID975860_1;
 
 
***********************************************************************************************;
*************************************  End Change ID975860_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID958790_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID958790_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID958790_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID958790_1;
%goto ID958790_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID958790_1;
* Insert record into change management table for CHANGE_ID: ID958790_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID958790_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID958790_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%if not (%sysfunc(exist(&m_di_trans..RPP_PLAN_METRIC_PART))) %then
%do;
 
 
 
%let m_sql_statement = %str(
CREATE TABLE &m_di_trans..RPP_PLAN_METRIC_PART
(
PLAN_SK                            INTEGER NOT NULL,
PARTITION_ID                       INTEGER NOT NULL,
KPI_SK                             INTEGER NOT NULL,
FCST_KPI_VALUE                     NUMERIC(20,3),
BASE_KPI_VALUE                     NUMERIC(20,3),
ACTUAL_KPI_VALUE                   NUMERIC(20,3),
PRIMARY KEY (PLAN_SK,KPI_SK,PARTITION_ID)
)
 
);
 
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
 
 
%if not (%sysfunc(exist(&m_di_trans..RPP_PLAN_PROD_METRICS_PART))) %then
%do;
 
 
 
%let m_sql_statement = %str(
CREATE TABLE &m_di_trans..RPP_PLAN_PROD_METRICS_PART
(
PLAN_SK                            INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
KPI_SK                             INTEGER NOT NULL,
PARTITION_ID                       INTEGER NOT NULL,
FCST_KPI_VALUE                     NUMERIC(20,3),
BASE_KPI_VALUE                     NUMERIC(20,3),
ACTUAL_KPI_VALUE                   NUMERIC(20,3),
PRIMARY KEY (PLAN_SK,PROD_HIER_SK,KPI_SK,PARTITION_ID)
)
 
);
 
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%if not (%sysfunc(exist(&m_di_trans..RPP_PLAN_METRIC_PART))) %then
%do;
 
 
 
proc sql;
 
 
CREATE TABLE RPP_PLAN_METRIC_PART
(
PLAN_SK                            INTEGER NOT NULL,
KPI_SK                             INTEGER NOT NULL,
PARTITION_ID                       INTEGER NOT NULL,
FCST_KPI_VALUE                     NUMERIC(20,3),
BASE_KPI_VALUE                     NUMERIC(20,3),
ACTUAL_KPI_VALUE                   NUMERIC(20,3)
)
;
 
 
 
ALTER TABLE RPP_PLAN_METRIC_PART  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PLAN_SK,KPI_SK,PARTITION_ID);
 
 
quit;
 
 
%end;
 
 
 
 
%if not (%sysfunc(exist(&m_di_trans..RPP_PLAN_PROD_METRICS_PART))) %then
%do;
 
 
 
proc sql;
 
 
CREATE TABLE RPP_PLAN_PROD_METRICS_PART
(
PLAN_SK                            INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
KPI_SK                             INTEGER NOT NULL,
PARTITION_ID                       INTEGER NOT NULL,
FCST_KPI_VALUE                     NUMERIC(20,3),
BASE_KPI_VALUE                     NUMERIC(20,3),
ACTUAL_KPI_VALUE                   NUMERIC(20,3)
)
;
 
 
 
ALTER TABLE RPP_PLAN_PROD_METRICS_PART  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PLAN_SK,PROD_HIER_SK,KPI_SK,PARTITION_ID);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID958790_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID958790_1;
%put ERROR- Description                              : Add 2 partitioned metrics tables to support evaluation of promotions spanning multiple partitions.;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 30MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID958790_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID958790_1",
"Add 2 partitioned metrics tables to support evaluation of promotions spanning multiple partitions.",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID958790_1:;
 
 
* End of changes for CHANGE_ID:ID958790_1;
 
 
***********************************************************************************************;
*************************************  End Change ID958790_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID954672 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID954672;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID954672")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID954672;
%goto ID954672;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID954672;
* Insert record into change management table for CHANGE_ID: ID954672;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID954672",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID954672;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%if not (%sysfunc(exist(&m_di_trans..CUSTOM_ATTR_PART))) %then
%do;
 
 
 
%let m_sql_statement = %str(
CREATE TABLE &m_di_trans..CUSTOM_ATTR_PART
(
OBJECT_SK                          INTEGER NOT NULL,
CAT_CUSTOM_ATTR_SK                 INTEGER NOT NULL,
ATTR_VALUE                         VARCHAR(40),
 
PRIMARY KEY (OBJECT_SK,CAT_CUSTOM_ATTR_SK)
)
 
);
 
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%if not (%sysfunc(exist(&m_di_trans..CUSTOM_ATTR_PART))) %then
%do;
 
 
 
proc sql;
 
 
CREATE TABLE CUSTOM_ATTR_PART
(
OBJECT_SK                          INTEGER NOT NULL,
CAT_CUSTOM_ATTR_SK                 INTEGER NOT NULL,
ATTR_VALUE                         VARCHAR(40)
)
;
 
 
 
ALTER TABLE CUSTOM_ATTR_PART  add CONSTRAINT PRIM_KEY
PRIMARY KEY (OBJECT_SK,CAT_CUSTOM_ATTR_SK);
 
 
 
quit;
 
 
%end;
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID954672;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID954672;
%put ERROR- Description                              : Create table identical to CUSTOM_ATTR to resolve price deletion issues;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 30AUG2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID954672;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID954672",
"Create table identical to CUSTOM_ATTR to resolve price deletion issues",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID954672:;
 
 
* End of changes for CHANGE_ID:ID954672;
 
 
***********************************************************************************************;
*************************************  End Change ID954672 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID975860_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID975860_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID975860_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID975860_2;
%goto ID975860_2;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID975860_2;
%goto ID975860_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID975860_2;
* Insert record into change management table for CHANGE_ID: ID975860_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID975860_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '0.4'
where (SPEC_NM = 'AG_MIN_CORR' and DEFAULT_SPEC_VALUE = '0.3')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_VALUE = '0.4'
where (MODEL_GROUP_ID = -1 and SPEC_NM = 'AG_MIN_CORR' and SPEC_VALUE = '0.3')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AG_P_CUTOFF'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('AG_P_CUTOFF','REG','-1','0.1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'AG_P_CUTOFF'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'REG','AG_P_CUTOFF','-1','0.1',NULL,NULL,'SEED')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AG_P_CUTOFF'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('REG','AG_P_CUTOFF','Double',null,0,1,
0.01,0,NULL,NULL,NULL,NULL,NULL,'mspec.AG_P_CUTOFF.description.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC_DEFAULT set DEFAULT_SPEC_VALUE = '0.4'
where (SPEC_NM = 'AG_MIN_CORR' and DEFAULT_SPEC_VALUE = '0.3');
 
 
update MODEL_SPEC set SPEC_VALUE = '0.4'
where (MODEL_GROUP_ID = -1 and SPEC_NM = 'AG_MIN_CORR' and SPEC_VALUE = '0.3');
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AG_P_CUTOFF';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('AG_P_CUTOFF','REG','-1','0.1',NULL);
 
 
delete from MODEL_SPEC where SPEC_NM = 'AG_P_CUTOFF';
 
 
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'REG','AG_P_CUTOFF','-1','0.1',NULL,NULL,'SEED');
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AG_P_CUTOFF';
 
 
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('REG','AG_P_CUTOFF','Double',null,0,1,
0.01,0,NULL,NULL,NULL,NULL,NULL,'mspec.AG_P_CUTOFF.description.txt');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID975860_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID975860_2;
%put ERROR- Description                              : Change default value for AG_MIN_CORR, add spec AG_P_CUTOFF;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 03JUN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID975860_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_2",
"Change default value for AG_MIN_CORR, add spec AG_P_CUTOFF",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID975860_2:;
 
 
* End of changes for CHANGE_ID:ID975860_2;
 
 
***********************************************************************************************;
*************************************  End Change ID975860_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID978101 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID978101;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID978101")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID978101;
%goto ID978101;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID978101;
* Insert record into change management table for CHANGE_ID: ID978101;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID978101",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID978101;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE PROD_SCOPE_DETAIL
(
SCOPE_SK                           INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
PRIMARY KEY (SCOPE_SK, PROD_HIER_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE GEO_SCOPE_DETAIL
(
SCOPE_SK                           INTEGER NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL,
PRIMARY KEY (SCOPE_SK, GEO_HIER_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
CREATE TABLE PROD_SCOPE_DETAIL
(
SCOPE_SK                           INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE PROD_SCOPE_DETAIL  add CONSTRAINT PRIM_KEY  PRIMARY KEY (SCOPE_SK, PROD_HIER_SK);
 
 
 
CREATE TABLE GEO_SCOPE_DETAIL
(
SCOPE_SK                           INTEGER NOT NULL,
GEO_HIER_SK                        INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE GEO_SCOPE_DETAIL  add CONSTRAINT PRIM_KEY  PRIMARY KEY (SCOPE_SK, GEO_HIER_SK);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID978101;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID978101;
%put ERROR- Description                              : Add 2 partitioned metrics tables to support evaluation of promotions spanning multiple partitions.;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 31MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID978101;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID978101",
"Add 2 partitioned metrics tables to support evaluation of promotions spanning multiple partitions.",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID978101:;
 
 
* End of changes for CHANGE_ID:ID978101;
 
 
***********************************************************************************************;
*************************************  End Change ID978101 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID978101_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID978101_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID978101_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID978101_2;
%goto ID978101_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID978101_2;
* Insert record into change management table for CHANGE_ID: ID978101_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID978101_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID978101_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
insert into PROD_SCOPE_DETAIL
select distinct scope_sk, prod_hier_sk from scope_detail
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
insert into GEO_SCOPE_DETAIL
select distinct scope_sk, geo_hier_sk from scope_detail
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
insert into PROD_SCOPE_DETAIL
select distinct scope_sk, prod_hier_sk from scope_detail;
 
 
 
insert into GEO_SCOPE_DETAIL
select distinct scope_sk, geo_hier_sk from scope_detail;
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID978101_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID978101_2;
%put ERROR- Description                              : Get values into new tables from existing tables;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 31MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID978101_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID978101_2",
"Get values into new tables from existing tables",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID978101_2:;
 
 
* End of changes for CHANGE_ID:ID978101_2;
 
 
***********************************************************************************************;
*************************************  End Change ID978101_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID975860_3 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID975860_3;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID975860_3")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID975860_3;
%goto ID975860_3;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID975860_3;
%goto ID975860_3;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID975860_3;
* Insert record into change management table for CHANGE_ID: ID975860_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_3",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID975860_3;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AG_DENORM'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'AG_DENORM'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AG_DENORM'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'AG_DENORM'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'AG_DENORM';
 
 
delete from MODEL_SPEC where SPEC_NM = 'AG_DENORM';
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'AG_DENORM';
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'AG_DENORM';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID975860_3;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID975860_3;
%put ERROR- Description                              : Remove AG_DENORM model spec;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 06JUN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID975860_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_3",
"Remove AG_DENORM model spec",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID975860_3:;
 
 
* End of changes for CHANGE_ID:ID975860_3;
 
 
***********************************************************************************************;
*************************************  End Change ID975860_3 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID918433_ETL_02 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID918433_ETL_02;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID918433_ETL_02")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID918433_ETL_02;
%goto ID918433_ETL_02;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID918433_ETL_02;
* Insert record into change management table for CHANGE_ID: ID918433_ETL_02;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID918433_ETL_02",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID918433_ETL_02;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let check_id918433=0;
 
 
Proc sql noprint;
 
 
select count(*) into :check_id918433
from &m_di_trans..rdbms_dm_change_management
where upper(CHANGE_ID) eq upper('ID918433_ETL');
 
 
quit;
 
 
 
%let check_id918433_01=0;
 
 
Proc sql noprint;
 
 
select count(*) into :check_id918433_01
from &m_di_trans..rdbms_dm_change_management
where upper(CHANGE_ID) eq upper('ID918433_ETL_01');
 
 
quit;
 
 
 
%if &check_id918433 gt 0 and &check_id918433_01 eq 0 %then %do;
 
 
 
%let m_sql_statement=%str(ALTER TABLE LANG_FIELD_LOOKUP_VALUES MODIFY FIELD_VALUE_DESC NULL );
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement=%str(ALTER TABLE LANG_FIELD_LOOKUP_VALUES MODIFY FIELD_VALUE_NM NULL );
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
proc sql;
 
 
insert  into &m_di_trans..Rdbms_DM_change_management
values (
"ID918433_ETL_01",
"MULTILANGUAGE PERSISTENT TABLE",
%sysfunc(datetime()),
"&m_user"
);
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%let check_id918433=0;
 
 
Proc sql noprint;
 
 
select count(*) into :check_id918433
from &m_di_trans..rdbms_dm_change_management
where upper(CHANGE_ID) eq upper('ID918433_ETL');
 
 
quit;
 
 
 
%let check_id918433_01=0;
 
 
Proc sql noprint;
 
 
select count(*) into :check_id918433_01
from &m_di_trans..rdbms_dm_change_management
where upper(CHANGE_ID) eq upper('ID918433_ETL_01');
 
 
quit;
 
 
 
%if &check_id918433 gt 0 and &check_id918433_01 eq 0 %then %do;
 
 
 
proc sql;
 
 
CREATE TABLE LANG_FIELD_LOOKUP_VALUES
(
FIELD_NM VARCHAR(32) NOT NULL,
TABLE_NAME VARCHAR(32) NOT NULL,
FIELD_VALUE VARCHAR(100) NOT NULL,
LANG_CD VARCHAR(11) NOT NULL,
FIELD_VALUE_NM VARCHAR(100),
FIELD_VALUE_DESC VARCHAR(100)
);
 
 
 
ALTER TABLE LANG_FIELD_LOOKUP_VALUES add CONSTRAINT PRIM_KEY PRIMARY KEY (FIELD_NM, TABLE_NAME, FIELD_VALUE,LANG_CD);
 
 
quit;
 
 
 
proc sql;
 
 
insert  into &m_di_trans..Rdbms_DM_change_management
values (
"ID918433_ETL_01",
"MULTILANGUAGE PERSISTENT TABLE",
%sysfunc(datetime()),
"&m_user"
);
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID918433_ETL_02;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID918433_ETL_02;
%put ERROR- Description                              : Change FIELD_VALUE_DESC FIELD_VALUE_NM to NULL;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 07AUG2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID918433_ETL_02;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID918433_ETL_02",
"Change FIELD_VALUE_DESC FIELD_VALUE_NM to NULL",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID918433_ETL_02:;
 
 
* End of changes for CHANGE_ID:ID918433_ETL_02;
 
 
***********************************************************************************************;
*************************************  End Change ID918433_ETL_02 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID918433_ETL_01 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID918433_ETL_01;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID918433_ETL_01")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID918433_ETL_01;
%goto ID918433_ETL_01;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID918433_ETL_01;
* Insert record into change management table for CHANGE_ID: ID918433_ETL_01;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID918433_ETL_01",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID918433_ETL_01;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE TABLE LANG_ATTRIBUTE
(
ATTR_SK INTEGER NOT NULL,
LANG_CD VARCHAR2(11 CHAR) NOT NULL,
ATTR_NM VARCHAR2(40 CHAR) NOT NULL,
PRIMARY KEY (ATTR_SK,LANG_CD)
 
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE LANG_GEOGRAPHY_DM
(
GEO_HIER_SK INTEGER NOT NULL,
LANG_CD VARCHAR2(11 CHAR) NOT NULL,
GEO_NM VARCHAR2(40 CHAR),
STREET_ADDRESS VARCHAR2(100 CHAR),
CITY VARCHAR2(20 CHAR),
STATE VARCHAR2(20 CHAR),
ZIP_CODE VARCHAR2(20 CHAR),
COUNTRY VARCHAR2(20 CHAR),
PRIMARY KEY (GEO_HIER_SK,LANG_CD)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE LANG_GEOGRAPHY_ATTRIBUTES
(
GEO_HIER_SK INTEGER NOT NULL,
GEO_ATTR_SK INTEGER NOT NULL,
LANG_CD VARCHAR2(11 CHAR) NOT NULL,
GEO_ATTR_VALUE VARCHAR2(40 CHAR) NOT NULL,
PRIMARY KEY (GEO_HIER_SK,GEO_ATTR_SK,LANG_CD)
 
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE LANG_PRODUCT_ATTRIBUTES
(
PROD_HIER_SK INTEGER NOT NULL,
PROD_ATTR_SK INTEGER NOT NULL,
LANG_CD VARCHAR2(11 CHAR) NOT NULL,
PROD_ATTR_VALUE VARCHAR2(40 CHAR) NOT NULL,
PRIMARY KEY (PROD_HIER_SK,PROD_ATTR_SK,LANG_CD)
 
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE LANG_PRODUCT_DM
(
PROD_HIER_SK INTEGER NOT NULL,
LANG_CD VARCHAR2(11 CHAR) NOT NULL,
PROD_NM VARCHAR2(40 CHAR),
PROD_DESC VARCHAR2(100 CHAR),
VOLUME_BASE_UOM VARCHAR2(20 CHAR),
BRAND_NM VARCHAR2(40 CHAR),
PRIMARY KEY (PROD_HIER_SK,LANG_CD)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE LANG_PRICE_CHANGE_PRIORITY
(
PRICE_CHG_PRIORITY INTEGER NOT NULL,
LANG_CD VARCHAR2(11 CHAR) NOT NULL,
PRICE_CHG_PRIORITY_NM VARCHAR2(40 CHAR) not null,
PRIMARY KEY (PRICE_CHG_PRIORITY,LANG_CD)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE LANG_FIELD_LOOKUP_VALUES
(
FIELD_NM VARCHAR2(32 CHAR) not null,
TABLE_NAME VARCHAR2(32 CHAR) not null,
FIELD_VALUE VARCHAR2(100 CHAR) not null,
LANG_CD VARCHAR2(11 CHAR) NOT NULL,
FIELD_VALUE_NM VARCHAR2(100 CHAR),
FIELD_VALUE_DESC VARCHAR2(100 CHAR),
PRIMARY KEY (FIELD_NM, TABLE_NAME, FIELD_VALUE,LANG_CD)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
 
CREATE TABLE LANG_ATTRIBUTE
(
ATTR_SK INTEGER NOT NULL,
LANG_CD VARCHAR(11) NOT NULL,
ATTR_NM VARCHAR(40) NOT NULL
);
 
 
 
ALTER TABLE LANG_ATTRIBUTE add CONSTRAINT PRIM_KEY  PRIMARY KEY (ATTR_SK,LANG_CD);
 
 
 
 
CREATE TABLE LANG_GEOGRAPHY_DM
(
GEO_HIER_SK INTEGER NOT NULL,
LANG_CD VARCHAR(11) NOT NULL,
GEO_NM VARCHAR(40),
STREET_ADDRESS VARCHAR(100),
CITY VARCHAR(20),
STATE VARCHAR(20),
ZIP_CODE VARCHAR(20),
COUNTRY VARCHAR(20)
);
 
 
 
ALTER TABLE LANG_GEOGRAPHY_DM add CONSTRAINT PRIM_KEY  PRIMARY KEY (GEO_HIER_SK,LANG_CD);
 
 
 
 
 
CREATE TABLE LANG_GEOGRAPHY_ATTRIBUTES
(
GEO_HIER_SK INTEGER NOT NULL,
GEO_ATTR_SK INTEGER NOT NULL,
LANG_CD VARCHAR(11) NOT NULL,
GEO_ATTR_VALUE VARCHAR(40) NOT NULL
);
 
 
 
ALTER TABLE LANG_GEOGRAPHY_ATTRIBUTES add CONSTRAINT PRIM_KEY  PRIMARY KEY (GEO_HIER_SK,GEO_ATTR_SK,LANG_CD);
 
 
 
 
 
CREATE TABLE LANG_PRODUCT_ATTRIBUTES
(
PROD_HIER_SK INTEGER NOT NULL,
PROD_ATTR_SK INTEGER NOT NULL,
LANG_CD VARCHAR(11) NOT NULL,
PROD_ATTR_VALUE VARCHAR(40) NOT NULL
);
 
 
 
ALTER TABLE LANG_PRODUCT_ATTRIBUTES add CONSTRAINT PRIM_KEY  PRIMARY KEY (PROD_HIER_SK,PROD_ATTR_SK,LANG_CD);
 
 
 
 
CREATE TABLE LANG_PRODUCT_DM
(
PROD_HIER_SK INTEGER NOT NULL,
LANG_CD VARCHAR(11) NOT NULL,
PROD_NM VARCHAR(40),
PROD_DESC VARCHAR(100),
VOLUME_BASE_UOM VARCHAR(20 ),
BRAND_NM VARCHAR(40)
);
 
 
 
ALTER TABLE LANG_PRODUCT_DM add CONSTRAINT PRIM_KEY PRIMARY KEY (PROD_HIER_SK,LANG_CD);
 
 
 
 
 
CREATE TABLE LANG_PRICE_CHANGE_PRIORITY
(
PRICE_CHG_PRIORITY INTEGER NOT NULL,
LANG_CD VARCHAR(11) NOT NULL,
PRICE_CHG_PRIORITY_NM VARCHAR(40) NOT NULL
);
 
 
 
ALTER TABLE LANG_PRICE_CHANGE_PRIORITY add CONSTRAINT PRIM_KEY PRIMARY KEY (PRICE_CHG_PRIORITY,LANG_CD);
 
 
 
CREATE TABLE LANG_FIELD_LOOKUP_VALUES
(
FIELD_NM VARCHAR(32) NOT NULL,
TABLE_NAME VARCHAR(32) NOT NULL,
FIELD_VALUE VARCHAR(100) NOT NULL,
LANG_CD VARCHAR(11) NOT NULL,
FIELD_VALUE_NM VARCHAR(100),
FIELD_VALUE_DESC VARCHAR(100)
);
 
 
 
ALTER TABLE LANG_FIELD_LOOKUP_VALUES add CONSTRAINT PRIM_KEY PRIMARY KEY (FIELD_NM, TABLE_NAME, FIELD_VALUE,LANG_CD);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID918433_ETL_01;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID918433_ETL_01;
%put ERROR- Description                              : MULTILANGUAGE PERSISTENT TABLE;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 31MAY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID918433_ETL_01;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID918433_ETL_01",
"MULTILANGUAGE PERSISTENT TABLE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID918433_ETL_01:;
 
 
* End of changes for CHANGE_ID:ID918433_ETL_01;
 
 
***********************************************************************************************;
*************************************  End Change ID918433_ETL_01 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID900227_GPSETTING ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID900227_GPSETTING;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID900227_GPSETTING")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID900227_GPSETTING;
%goto ID900227_GPSETTING;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID900227_GPSETTING;
* Insert record into change management table for CHANGE_ID: ID900227_GPSETTING;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID900227_GPSETTING",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID900227_GPSETTING;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 36
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GEO_PROD_SETTING
(GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,
SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (36,1,1,1,57,1,1,1,2,1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 37
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GEO_PROD_SETTING
(GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,
SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (37,1,1,1,58,0,1,0,99999,1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 38
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GEO_PROD_SETTING
(GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,
SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (38,1,1,1,59,0,1,0,99.9,1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 36 ;
 
 
INSERT INTO GEO_PROD_SETTING
(GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,
SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (36,1,1,1,57,1,1,1,2,1);
 
 
 
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 37 ;
 
 
INSERT INTO GEO_PROD_SETTING
(GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,
SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (37,1,1,1,58,0,1,0,99999,1);
 
 
 
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 38 ;
 
 
INSERT INTO GEO_PROD_SETTING
(GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,
SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (38,1,1,1,59,0,1,0,99.9,1);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID900227_GPSETTING;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID900227_GPSETTING;
%put ERROR- Description                              : Add post-plan-markdown settings to geo_prod_setting;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 10JUN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID900227_GPSETTING;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID900227_GPSETTING",
"Add post-plan-markdown settings to geo_prod_setting",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID900227_GPSETTING:;
 
 
* End of changes for CHANGE_ID:ID900227_GPSETTING;
 
 
***********************************************************************************************;
*************************************  End Change ID900227_GPSETTING ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID918433_DATA_MIGRATION_01 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID918433_DATA_MIGRATION_01;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID918433_DATA_MIGRATION_01")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID918433_DATA_MIGRATION_01;
%goto ID918433_DATA_MIGRATION_01;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID918433_DATA_MIGRATION_01;
* Insert record into change management table for CHANGE_ID: ID918433_DATA_MIGRATION_01;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID918433_DATA_MIGRATION_01",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID918433_DATA_MIGRATION_01;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%if NOT %sysfunc(exist(&m_di_trans..PRICE_CHANGE_PRIORITY)) %then %do;
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PRICE_CHANGE_PRIORITY
(
PRICE_CHG_PRIORITY INTEGER NOT NULL,
PRICE_CHG_PRIORITY_NM VARCHAR2(40 CHAR) not null,
APPROVAL_LEAD_TIME INTEGER,
USED_BY_APP INTEGER not null,
PRIMARY KEY (PRICE_CHG_PRIORITY)
)
);
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%else %do;
 
 
 
%let m_sql_statement = %str(TRUNCATE TABLE PRICE_CHANGE_PRIORITY);
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
 
%let no_of_obs_bfr =%di_util_nobs(&m_di_data..PRICE_CHANGE_PRIORITY);
 
 
 
%di_dm_trans_append
(
di_trans=&m_di_trans.,
trans_table=PRICE_CHANGE_PRIORITY,
append_table=&m_di_data..PRICE_CHANGE_PRIORITY
);
 
 
 
%let no_of_obs_after=0;
 
 
 
proc sql noprint;
 
 
Select count(*) into :no_of_obs_after
from &m_di_trans..PRICE_CHANGE_PRIORITY;
 
 
quit;
 
 
 
%if &no_of_obs_bfr = &no_of_obs_after %then %do;
 
 
 
Proc sql;
 
 
DROP TABLE &m_di_data..PRICE_CHANGE_PRIORITY;
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%if NOT %sysfunc(exist(&m_di_trans..PRICE_CHANGE_PRIORITY)) %then %do;
 
 
 
proc sql;
 
 
CREATE TABLE PRICE_CHANGE_PRIORITY
(
PRICE_CHG_PRIORITY INTEGER NOT NULL,
PRICE_CHG_PRIORITY_NM VARCHAR(40) not null,
APPROVAL_LEAD_TIME INTEGER,
USED_BY_APP INTEGER not null
)
;
 
 
 
ALTER TABLE PRICE_CHANGE_PRIORITY add CONSTRAINT PRIM_KEY PRIMARY KEY (PRICE_CHG_PRIORITY);
 
 
 
quit;
 
 
 
%end;
 
 
%else %do;
 
 
 
%di_util_truncate_table(&m_di_trans..PRICE_CHANGE_PRIORITY);
 
 
 
%end;
 
 
 
%let no_of_obs_bfr =%di_util_nobs(&m_di_data..PRICE_CHANGE_PRIORITY);
 
 
 
%di_dm_trans_append
(
di_trans=&m_di_trans.,
trans_table=PRICE_CHANGE_PRIORITY,
append_table=&m_di_data..PRICE_CHANGE_PRIORITY
);
 
 
 
%let no_of_obs_after=0;
 
 
 
proc sql noprint;
 
 
Select count(*) into :no_of_obs_after
from &m_di_trans..PRICE_CHANGE_PRIORITY;
 
 
quit;
 
 
 
%if &no_of_obs_bfr = &no_of_obs_after %then %do;
 
 
 
Proc sql;
 
 
DROP TABLE &m_di_data..PRICE_CHANGE_PRIORITY;
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID918433_DATA_MIGRATION_01;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID918433_DATA_MIGRATION_01;
%put ERROR- Description                              : Move  PRICE_CHANGE_PRIORITY from SAS to RDBMS;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 12JUN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID918433_DATA_MIGRATION_01;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID918433_DATA_MIGRATION_01",
"Move  PRICE_CHANGE_PRIORITY from SAS to RDBMS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID918433_DATA_MIGRATION_01:;
 
 
* End of changes for CHANGE_ID:ID918433_DATA_MIGRATION_01;
 
 
***********************************************************************************************;
*************************************  End Change ID918433_DATA_MIGRATION_01 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID975860_4 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID975860_4;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID975860_4")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID975860_4;
%goto ID975860_4;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID975860_4;
%goto ID975860_4;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID975860_4;
* Insert record into change management table for CHANGE_ID: ID975860_4;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_4",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID975860_4;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'AG_MIN_OBS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'AG_MIN_OBS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '1' where SPEC_NM = 'AG_MIN_OBS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'AG_GRP_TYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'AG_GRP_TYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '1' where SPEC_NM = 'AG_GRP_TYPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'AG_MIN_CORR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'AG_MIN_CORR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '1' where SPEC_NM = 'AG_MIN_CORR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'AG_P_CUTOFF'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'AG_P_CUTOFF'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '1' where SPEC_NM = 'AG_P_CUTOFF'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'AUTO_CROSS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'AUTO_CROSS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '1' where SPEC_NM = 'AUTO_CROSS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'AG_MIN_OBS';
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'AG_MIN_OBS';
 
 
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '1' where SPEC_NM = 'AG_MIN_OBS';
 
 
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'AG_GRP_TYPE';
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'AG_GRP_TYPE';
 
 
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '1' where SPEC_NM = 'AG_GRP_TYPE';
 
 
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'AG_MIN_CORR';
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'AG_MIN_CORR';
 
 
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '1' where SPEC_NM = 'AG_MIN_CORR';
 
 
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'AG_P_CUTOFF';
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'AG_P_CUTOFF';
 
 
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '1' where SPEC_NM = 'AG_P_CUTOFF';
 
 
update MODEL_SPEC set SPEC_TYPE = '1' where SPEC_NM = 'AUTO_CROSS';
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '1' where SPEC_NM = 'AUTO_CROSS';
 
 
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '1' where SPEC_NM = 'AUTO_CROSS';
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID975860_4;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID975860_4;
%put ERROR- Description                              : Change AG_xx and AUTO_CROSS specs to DIRECT model only;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 14JUN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID975860_4;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_4",
"Change AG_xx and AUTO_CROSS specs to DIRECT model only",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID975860_4:;
 
 
* End of changes for CHANGE_ID:ID975860_4;
 
 
***********************************************************************************************;
*************************************  End Change ID975860_4 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID984010 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID984010;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID984010")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID984010;
%goto ID984010;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID984010;
%goto ID984010;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID984010;
* Insert record into change management table for CHANGE_ID: ID984010;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID984010",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID984010;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'DEREG_TOLERANCE_FACTOR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DEREG_TOLERANCE_FACTOR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'DEREG_TOLERANCE_FACTOR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'DEREG_TOLERANCE_FACTOR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'DEREG_TOLERANCE_FACTOR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'DEREG_TOLERANCE_FACTOR_MINOBS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DEREG_TOLERANCE_FACTOR_MINOBS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'DEREG_TOLERANCE_FACTOR_MINOBS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'DEREG_TOLERANCE_FACTOR_MINOBS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'DEREG_TOLERANCE_FACTOR_MINOBS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'DEREG_MIN_FACTOR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DEREG_MIN_FACTOR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'DEREG_MIN_FACTOR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'DEREG_MIN_FACTOR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'DEREG_MIN_FACTOR'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'LCP_FACTOR_UPPER_BOUND'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'LCP_FACTOR_UPPER_BOUND'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'LCP_FACTOR_UPPER_BOUND'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'LCP_FACTOR_UPPER_BOUND'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'LCP_FACTOR_UPPER_BOUND'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC where SPEC_NM = 'DEREG_TOLERANCE_FACTOR';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DEREG_TOLERANCE_FACTOR';
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'DEREG_TOLERANCE_FACTOR';
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'DEREG_TOLERANCE_FACTOR';
 
 
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'DEREG_TOLERANCE_FACTOR';
 
 
 
delete from MODEL_SPEC where SPEC_NM = 'DEREG_TOLERANCE_FACTOR_MINOBS';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DEREG_TOLERANCE_FACTOR_MINOBS';
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'DEREG_TOLERANCE_FACTOR_MINOBS';
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'DEREG_TOLERANCE_FACTOR_MINOBS';
 
 
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'DEREG_TOLERANCE_FACTOR_MINOBS';
 
 
 
delete from MODEL_SPEC where SPEC_NM = 'DEREG_MIN_FACTOR';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'DEREG_MIN_FACTOR';
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'DEREG_MIN_FACTOR';
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'DEREG_MIN_FACTOR';
 
 
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'DEREG_MIN_FACTOR';
 
 
 
delete from MODEL_SPEC where SPEC_NM = 'LCP_FACTOR_UPPER_BOUND';
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'LCP_FACTOR_UPPER_BOUND';
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'LCP_FACTOR_UPPER_BOUND';
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'LCP_FACTOR_UPPER_BOUND';
 
 
delete from MODEL_SPEC_TEMPLATE where SPEC_NM = 'LCP_FACTOR_UPPER_BOUND';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID984010;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID984010;
%put ERROR- Description                              : Remove 4 model specs that are no longer needed;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 17JUN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID984010;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID984010",
"Remove 4 model specs that are no longer needed",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID984010:;
 
 
* End of changes for CHANGE_ID:ID984010;
 
 
***********************************************************************************************;
*************************************  End Change ID984010 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID943681 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID943681;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID943681")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID943681;
%goto ID943681;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID943681;
* Insert record into change management table for CHANGE_ID: ID943681;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID943681",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID943681;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_PROD_ATTR_LOOKUP'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_PROD_ATTRIBUTES'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_PROD_ATTR_LOOKUP';
 
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'GEO_PROD_ATTRIBUTES';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID943681;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID943681;
%put ERROR- Description                              : Remove GEO_PROD_ATTR_LOOKUP and GEO_PROD_ATTRIBUTES in TABLE_PARTITION_META;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 19JUN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID943681;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID943681",
"Remove GEO_PROD_ATTR_LOOKUP and GEO_PROD_ATTRIBUTES in TABLE_PARTITION_META",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID943681:;
 
 
* End of changes for CHANGE_ID:ID943681;
 
 
***********************************************************************************************;
*************************************  End Change ID943681 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID943853_GPSTATUS_modify_1 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID943853_GPSTATUS_modify_1;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID943853_GPSTATUS_modify_1")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID943853_GPSTATUS_modify_1;
%goto ID943853_GPSTATUS_modify_1;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID943853_GPSTATUS_modify_1;
* Insert record into change management table for CHANGE_ID: ID943853_GPSTATUS_modify_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID943853_GPSTATUS_modify_1",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID943853_GPSTATUS_modify_1;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MODEL_GEO_PROD_STATUS_RULE set RULE_VALUE = '26'
where (RULE_NM = 'SEASON_INACTIVE_DURATION' and RULE_VALUE IS NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update GLOBAL_GEO_PROD_STATUS_RULE set RULE_VALUE = '26'
where (RULE_NM = 'SEASON_INACTIVE_DURATION' and RULE_VALUE IS NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update MODEL_GEO_PROD_STATUS_RULE set RULE_VALUE = '26'
where (RULE_NM = 'SEASON_INACTIVE_DURATION' and RULE_VALUE IS NULL);
 
 
update GLOBAL_GEO_PROD_STATUS_RULE set RULE_VALUE = '26'
where (RULE_NM = 'SEASON_INACTIVE_DURATION' and RULE_VALUE IS NULL);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID943853_GPSTATUS_modify_1;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID943853_GPSTATUS_modify_1;
%put ERROR- Description                              : Modify default for SEASON_INACTIVE_DURATION;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 20JUN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID943853_GPSTATUS_modify_1;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID943853_GPSTATUS_modify_1",
"Modify default for SEASON_INACTIVE_DURATION",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID943853_GPSTATUS_modify_1:;
 
 
* End of changes for CHANGE_ID:ID943853_GPSTATUS_modify_1;
 
 
***********************************************************************************************;
*************************************  End Change ID943853_GPSTATUS_modify_1 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID975860_5 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID975860_5;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID975860_5")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..SCORING_PARAM_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..SCORING_PARAM_DEFAULT;
%put NOTE: Change ID                             :ID975860_5;
%goto ID975860_5;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID975860_5;
%goto ID975860_5;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID975860_5;
* Insert record into change management table for CHANGE_ID: ID975860_5;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_5",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID975860_5;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CP_AG_N'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CP_AG_N',1,0,0,-3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CP_AG_N',2,0,0,-3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CP_AG_P'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CP_AG_P',1,0,3,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CP_AG_P',2,0,3,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CPL_AG_N'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CPL_AG_N',1,0,0,-3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CPL_AG_N',2,0,0,-3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CPL_AG_P'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CPL_AG_P',1,0,3,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CPL_AG_P',2,0,3,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CINV_AG_N'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CINV_AG_N',1,0,0,-3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CINV_AG_N',2,0,0,-3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CINV_AG_P'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CINV_AG_P',1,0,3,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CINV_AG_P',2,0,3,0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CP_AG_N';
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CP_AG_N',1,0,0,-3);
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CP_AG_N',2,0,0,-3);
 
 
 
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CP_AG_P';
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CP_AG_P',1,0,3,0);
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CP_AG_P',2,0,3,0);
 
 
 
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CPL_AG_N';
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CPL_AG_N',1,0,0,-3);
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CPL_AG_N',2,0,0,-3);
 
 
 
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CPL_AG_P';
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CPL_AG_P',1,0,3,0);
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CPL_AG_P',2,0,3,0);
 
 
 
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CINV_AG_N';
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CINV_AG_N',1,0,0,-3);
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CINV_AG_N',2,0,0,-3);
 
 
 
delete from SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = 'CINV_AG_P';
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CINV_AG_P',1,0,3,0);
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS','CINV_AG_P',2,0,3,0);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID975860_5;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID975860_5;
%put ERROR- Description                              : Add affinity group scoring parameter defaults;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 21JUN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID975860_5;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_5",
"Add affinity group scoring parameter defaults",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID975860_5:;
 
 
* End of changes for CHANGE_ID:ID975860_5;
 
 
***********************************************************************************************;
*************************************  End Change ID975860_5 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID975860_6 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID975860_6;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID975860_6")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID975860_6;
%goto ID975860_6;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID975860_6;
* Insert record into change management table for CHANGE_ID: ID975860_6;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_6",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID975860_6;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%if "&m_delete_and_start_fresh"^="TRUE" %then %do;
 
 
 
proc sql noprint;
 
 
select spec_value into :hd_val
from &m_di_data..global_setting
where upcase(spec_nm)='PS_TOTAL_LENGTH';
 
 
quit;
 
 
 
%do j = 1 %to &hd_val;
 
 
%let x = %sysfunc(compress('CPS_AG_N_', "'"))&j ;
 
 
proc sql;
 
 
delete from &m_di_trans..SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = "&x";
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS',"&x",0,0,0,-3);
 
 
quit;
 
 
 
%let y = %sysfunc(compress('CPS_AG_P_', "'"))&j ;
 
 
proc sql;
 
 
delete from &m_di_trans..SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = "&y";
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS',"&y",0,0,3,0);
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%if "&m_delete_and_start_fresh"^="TRUE" %then %do;
 
 
 
proc sql noprint;
 
 
select spec_value into :hd_val
from &m_di_data..global_setting
where upcase(spec_nm)='PS_TOTAL_LENGTH';
 
 
quit;
 
 
 
%do j = 1 %to &hd_val;
 
 
%let x = %sysfunc(compress('CPS_AG_N_', "'"))&j ;
 
 
proc sql;
 
 
delete from &m_di_trans..SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = "&x";
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS',"&x",0,0,0,-3);
 
 
quit;
 
 
 
%let y = %sysfunc(compress('CPS_AG_P_', "'"))&j ;
 
 
proc sql;
 
 
delete from &m_di_trans..SCORING_PARAM_DEFAULT where EFFECT_CATEGORY = "&y";
 
 
insert into SCORING_PARAM_DEFAULT (GEO_HIER_SK,PROD_HIER_SK,EFFECT_TYPE,EFFECT_CATEGORY,
TSF_TYPE,EFFECT_EST,EFFECT_EST_U,EFFECT_EST_L)
values (1,1,'CROSS',"&y",0,0,3,0);
 
 
quit;
 
 
 
%end;
 
 
 
%end;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID975860_6;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID975860_6;
%put ERROR- Description                              : Add expanded affinity group scoring parameter defaults;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 21JUN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID975860_6;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_6",
"Add expanded affinity group scoring parameter defaults",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID975860_6:;
 
 
* End of changes for CHANGE_ID:ID975860_6;
 
 
***********************************************************************************************;
*************************************  End Change ID975860_6 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID918433_DATA_MIGRATION_02 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID918433_DATA_MIGRATION_02;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID918433_DATA_MIGRATION_02")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID918433_DATA_MIGRATION_02;
%goto ID918433_DATA_MIGRATION_02;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID918433_DATA_MIGRATION_02;
* Insert record into change management table for CHANGE_ID: ID918433_DATA_MIGRATION_02;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID918433_DATA_MIGRATION_02",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID918433_DATA_MIGRATION_02;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
%if %sysfunc(exist(&m_di_trans..FIELD_LOOKUP_VALUES)) %then %do;
 
 
 
 
%let m_sql_statement=%str(DROP TABLE FIELD_LOOKUP_VALUES);
 
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE FIELD_LOOKUP_VALUES
(
FIELD_NM    VARCHAR2(32 CHAR) not null,
TABLE_NAME  VARCHAR2(32 CHAR) not null,
FIELD_VALUE VARCHAR2(100 CHAR) not null,
FIELD_VALUE_NM VARCHAR2(100 CHAR),
FIELD_VALUE_DESC VARCHAR2(100 CHAR),
FIELD_DATATYPE VARCHAR2(40 CHAR),
PRIMARY KEY (FIELD_NM, TABLE_NAME, FIELD_VALUE)
)
);
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%di_dm_trans_append
(
di_trans=&m_di_trans.,
trans_table=FIELD_LOOKUP_VALUES,
append_table=&m_di_data..FIELD_LOOKUP_VALUES
);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%if %sysfunc(exist(&m_di_trans..FIELD_LOOKUP_VALUES)) %then %do;
 
 
Proc sql;
 
 
DROP TABLE FIELD_LOOKUP_VALUES;
 
 
quit;
 
 
%end;
 
 
 
proc sql;
 
 
CREATE TABLE FIELD_LOOKUP_VALUES
(
FIELD_NM VARCHAR(32) not null,
TABLE_NAME VARCHAR(32) not null,
FIELD_VALUE VARCHAR(100) not null,
FIELD_VALUE_NM VARCHAR(100),
FIELD_VALUE_DESC VARCHAR(100),
FIELD_DATATYPE VARCHAR(40)
);
 
 
 
ALTER TABLE FIELD_LOOKUP_VALUES add CONSTRAINT PRIM_KEY PRIMARY KEY (FIELD_NM, TABLE_NAME, FIELD_VALUE);
 
 
 
quit;
 
 
 
%di_dm_trans_append
(
di_trans=&m_di_trans.,
trans_table=FIELD_LOOKUP_VALUES,
append_table=&m_di_data..FIELD_LOOKUP_VALUES
);
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID918433_DATA_MIGRATION_02;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID918433_DATA_MIGRATION_02;
%put ERROR- Description                              : Move FIELD_LOOKUP_VALUES from SAS to RDBMS;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 24JUN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID918433_DATA_MIGRATION_02;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID918433_DATA_MIGRATION_02",
"Move FIELD_LOOKUP_VALUES from SAS to RDBMS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID918433_DATA_MIGRATION_02:;
 
 
* End of changes for CHANGE_ID:ID918433_DATA_MIGRATION_02;
 
 
***********************************************************************************************;
*************************************  End Change ID918433_DATA_MIGRATION_02 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID985903 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID985903;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID985903")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID985903;
%goto ID985903;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID985903;
* Insert record into change management table for CHANGE_ID: ID985903;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID985903",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID985903;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
%if not (%sysfunc(exist(&m_di_trans..RPP_PLAN_ACTUALS_PART))) %then
%do;
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE RPP_PLAN_ACTUALS_PART
(
PLAN_SK                            INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
KPI_SK                             INTEGER NOT NULL,
PARTITION_ID                       INTEGER NOT NULL,
ACTUAL_KPI_VALUE                   NUMERIC(20,3),
PRIMARY KEY (PLAN_SK,PROD_HIER_SK,KPI_SK,PARTITION_ID)
)
 
);
 
 
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%if not (%sysfunc(exist(&m_di_trans..RPP_PLAN_ACTUALS_PART))) %then
%do;
 
 
 
 
PROC SQL;
 
 
 
CREATE TABLE RPP_PLAN_ACTUALS_PART
(
PLAN_SK                            INTEGER NOT NULL,
PROD_HIER_SK                       INTEGER NOT NULL,
KPI_SK                             INTEGER NOT NULL,
PARTITION_ID                       INTEGER NOT NULL,
ACTUAL_KPI_VALUE                   NUMERIC(20,3)
)
;
 
 
 
ALTER TABLE RPP_PLAN_ACTUALS_PART add CONSTRAINT RPP_PLAN_ACTUALS_PART_PK
PRIMARY KEY (PLAN_SK,PROD_HIER_SK,KPI_SK,PARTITION_ID);
 
 
 
QUIT;
 
 
 
%end;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID985903;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID985903;
%put ERROR- Description                              : actuals for rpp plans crossing parts shldnt read existing rows, output to RPP_PLAN_ACTUALS_PART;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 26JUN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID985903;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID985903",
"actuals for rpp plans crossing parts shldnt read existing rows, output to RPP_PLAN_ACTUALS_PART",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID985903:;
 
 
* End of changes for CHANGE_ID:ID985903;
 
 
***********************************************************************************************;
*************************************  End Change ID985903 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID968483 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID968483;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID968483")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID968483;
%goto ID968483;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC;
%put NOTE: Change ID                             :ID968483;
%goto ID968483;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID968483;
%goto ID968483;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID968483;
* Insert record into change management table for CHANGE_ID: ID968483;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID968483",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID968483;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BY_REFERENCE_PRICE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('BY_REFERENCE_PRICE','ALL','-1','1',NULL)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where SPEC_NM = 'BY_REFERENCE_PRICE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'ALL','BY_REFERENCE_PRICE','-1','1',NULL,NULL,'SEED')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'BY_REFERENCE_PRICE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('ALL','BY_REFERENCE_PRICE','Boolean',null,null,null,
null,0,NULL,NULL,NULL,NULL,NULL,'mspec.BY_REFERENCE_PRICE.description.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_VALUES where SPEC_NM = 'BY_REFERENCE_PRICE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('BY_REFERENCE_PRICE','ALL','1','mspec.BY_REFERENCE_PRICE.truemeans.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('BY_REFERENCE_PRICE','ALL','0','mspec.BY_REFERENCE_PRICE.falsemeans.txt')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC_DEFAULT where SPEC_NM = 'BY_REFERENCE_PRICE';
 
 
insert into MODEL_SPEC_DEFAULT (SPEC_NM,MODEL_COMP_NM,SPEC_TYPE,DEFAULT_SPEC_VALUE,PRIORITY)
values ('BY_REFERENCE_PRICE','ALL','-1','1',NULL);
 
 
delete from MODEL_SPEC where SPEC_NM = 'BY_REFERENCE_PRICE';
 
 
insert into MODEL_SPEC (MODEL_GROUP_ID,MODEL_COMP_NM,SPEC_NM,SPEC_TYPE,SPEC_VALUE,PRIORITY,CREATED_DTTM,CREATED_BY)
values (-1,'ALL','BY_REFERENCE_PRICE','-1','1',NULL,NULL,'SEED');
 
 
delete from MODEL_SPEC_DETAILS where SPEC_NM = 'BY_REFERENCE_PRICE';
 
 
insert into MODEL_SPEC_DETAILS (MODEL_COMP_NM,SPEC_NM,SPEC_DATATYPE,SPEC_DATATYPE_EXT,SPEC_VALUE_MIN,SPEC_VALUE_MAX,
SPEC_VALUE_INCR,HIDDEN_FLG,OVERRIDE_MODEL_COMP_NM_LIST,REF_QUERY,GENERATE_PREFIX_NM,GENERATE_SUFFIX_MAX,
SPEC_VALUE_LIST_DELIMITER,DESC_KEY)
values ('ALL','BY_REFERENCE_PRICE','Boolean',null,null,null,
null,0,NULL,NULL,NULL,NULL,NULL,'mspec.BY_REFERENCE_PRICE.description.txt');
 
 
delete from MODEL_SPEC_VALUES where SPEC_NM = 'BY_REFERENCE_PRICE';
 
 
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('BY_REFERENCE_PRICE','ALL','1','mspec.BY_REFERENCE_PRICE.truemeans.txt');
 
 
insert into MODEL_SPEC_VALUES (SPEC_NM,MODEL_COMP_NM,SPEC_VALUE,SPEC_VALUE_DESC_KEY)
values ('BY_REFERENCE_PRICE','ALL','0','mspec.BY_REFERENCE_PRICE.falsemeans.txt');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID968483;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID968483;
%put ERROR- Description                              : Add model spec BY_REFERENCE_PRICE;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 28JUN2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID968483;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID968483",
"Add model spec BY_REFERENCE_PRICE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID968483:;
 
 
* End of changes for CHANGE_ID:ID968483;
 
 
***********************************************************************************************;
*************************************  End Change ID968483 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID883824 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID883824;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID883824")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID883824;
%goto ID883824;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID883824;
* Insert record into change management table for CHANGE_ID: ID883824;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID883824",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID883824;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN DROP COLUMN PROCESS_CD
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN DROP COLUMN APPR_AGG_PROCESS_CD
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN DROP COLUMN APPR_AGG_PROCESS_DTTM
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN DROP COLUMN SCHEDULING_TAG
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN ADD MULTI_OBJ_INV_WEIGHT NUMERIC(12,2)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE MPLN_MULTI_OBJ_RESULT
(
MDO_PLAN_SK INTEGER NOT NULL,
MULTI_OBJ_INV_WEIGHT NUMERIC(12,2),
REVENUE_AMT NUMERIC(20,3),
INV_AT_RISK_UNITS NUMERIC(12,2),
SALES_UNITS NUMERIC(12,2),
SPEND NUMERIC(20,3),
PRIMARY KEY(MDO_PLAN_SK, MULTI_OBJ_INV_WEIGHT)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT
ADD
(
MULTI_OBJ_PLAN_FCN_VAL NUMERIC(12,2),
MULTI_OBJ_DELAY_PLAN_FCN_VAL NUMERIC(12,2),
MAX_REV_REVENUE_AMT NUMERIC(20,3),
MAX_REV_INV_AT_RISK_UNITS NUMERIC(12,2),
MAX_REV_SALES_UNITS NUMERIC(12,2),
MAX_REV_SPEND NUMERIC(20,3),
MIN_IAR_REVENUE_AMT NUMERIC(20,3),
MIN_IAR_INV_AT_RISK_UNITS NUMERIC(12,2),
MIN_IAR_SALES_UNITS NUMERIC(12,2),
MIN_IAR_SPEND NUMERIC(20,3)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT
ADD
(
MULTI_OBJ_PLAN_FCN_VAL NUMERIC(12,2),
MULTI_OBJ_DELAY_PLAN_FCN_VAL NUMERIC(12,2),
MAX_REV_REVENUE_AMT NUMERIC(20,3),
MAX_REV_INV_AT_RISK_UNITS NUMERIC(12,2),
MAX_REV_SALES_UNITS NUMERIC(12,2),
MAX_REV_SPEND NUMERIC(20,3),
MIN_IAR_REVENUE_AMT NUMERIC(20,3),
MIN_IAR_INV_AT_RISK_UNITS NUMERIC(12,2),
MIN_IAR_SALES_UNITS NUMERIC(12,2),
MIN_IAR_SPEND NUMERIC(20,3)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
ALTER TABLE MDO_PLAN DROP COLUMN PROCESS_CD;
 
 
ALTER TABLE MDO_PLAN DROP COLUMN APPR_AGG_PROCESS_CD;
 
 
ALTER TABLE MDO_PLAN DROP COLUMN APPR_AGG_PROCESS_DTTM;
 
 
ALTER TABLE MDO_PLAN DROP COLUMN SCHEDULING_TAG;
 
 
 
ALTER TABLE MDO_PLAN ADD MULTI_OBJ_INV_WEIGHT NUMERIC(12,2);
 
 
 
CREATE TABLE MPLN_MULTI_OBJ_RESULT
(
MDO_PLAN_SK INTEGER NOT NULL,
MULTI_OBJ_INV_WEIGHT NUMERIC(12,2),
REVENUE_AMT NUMERIC(20,3),
INV_AT_RISK_UNITS NUMERIC(12,2),
SALES_UNITS NUMERIC(12,2),
SPEND NUMERIC(20,3)
);
 
 
 
ALTER TABLE MPLN_MULTI_OBJ_RESULT add CONSTRAINT PRIM_KEY PRIMARY KEY (MDO_PLAN_SK, MULTI_OBJ_INV_WEIGHT);
 
 
 
 
ALTER TABLE MPLN_RESULT ADD MULTI_OBJ_PLAN_FCN_VAL NUMERIC(12,2);
 
 
ALTER TABLE MPLN_RESULT ADD    MULTI_OBJ_DELAY_PLAN_FCN_VAL NUMERIC(12,2);
 
 
ALTER TABLE MPLN_RESULT ADD    MAX_REV_REVENUE_AMT NUMERIC(20,3);
 
 
ALTER TABLE MPLN_RESULT ADD    MAX_REV_INV_AT_RISK_UNITS NUMERIC(12,2);
 
 
ALTER TABLE MPLN_RESULT ADD    MAX_REV_SALES_UNITS NUMERIC(12,2);
 
 
ALTER TABLE MPLN_RESULT ADD    MAX_REV_SPEND NUMERIC(20,3);
 
 
ALTER TABLE MPLN_RESULT ADD    MIN_IAR_REVENUE_AMT NUMERIC(20,3);
 
 
ALTER TABLE MPLN_RESULT ADD    MIN_IAR_INV_AT_RISK_UNITS NUMERIC(12,2);
 
 
ALTER TABLE MPLN_RESULT ADD    MIN_IAR_SALES_UNITS NUMERIC(12,2);
 
 
ALTER TABLE MPLN_RESULT ADD    MIN_IAR_SPEND NUMERIC(20,3);
 
 
 
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD    MULTI_OBJ_PLAN_FCN_VAL NUMERIC(12,2);
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD    MULTI_OBJ_DELAY_PLAN_FCN_VAL NUMERIC(12,2);
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD    MAX_REV_REVENUE_AMT NUMERIC(20,3);
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD    MAX_REV_INV_AT_RISK_UNITS NUMERIC(12,2);
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD    MAX_REV_SALES_UNITS NUMERIC(12,2);
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD    MAX_REV_SPEND NUMERIC(20,3);
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD    MIN_IAR_REVENUE_AMT NUMERIC(20,3);
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD    MIN_IAR_INV_AT_RISK_UNITS NUMERIC(12,2);
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD    MIN_IAR_SALES_UNITS NUMERIC(12,2);
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD    MIN_IAR_SPEND NUMERIC(20,3);
 
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID883824;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID883824;
%put ERROR- Description                              : Multi-objective markdown optimization;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 05JUL2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID883824;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID883824",
"Multi-objective markdown optimization",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID883824:;
 
 
* End of changes for CHANGE_ID:ID883824;
 
 
***********************************************************************************************;
*************************************  End Change ID883824 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID888392 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID888392;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID888392")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID888392;
%goto ID888392;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID888392;
* Insert record into change management table for CHANGE_ID: ID888392;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID888392",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID888392;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 31
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO GEO_PROD_SETTING(GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,
SETTING_TYPE,SETTING_VAL,SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (31,1,1,1,56,0,1,0,99999 ,1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 31 ;
 
 
 
INSERT INTO GEO_PROD_SETTING(GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,
SETTING_TYPE,SETTING_VAL,SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (31,1,1,1,56,0,1,0,99999 ,1);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID888392;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID888392;
%put ERROR- Description                              : Add multi-objective markdown setting to GEO_PROD_SETTING;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 05JUL2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID888392;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID888392",
"Add multi-objective markdown setting to GEO_PROD_SETTING",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID888392:;
 
 
* End of changes for CHANGE_ID:ID888392;
 
 
***********************************************************************************************;
*************************************  End Change ID888392 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID906007 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID906007;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID906007")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID906007;
%goto ID906007;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID906007;
* Insert record into change management table for CHANGE_ID: ID906007;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID906007",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID906007;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT ADD DELAY_REVENUE_AMT NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT ADD DELAY_NET_REVENUE_AMT NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT ADD DELAY_END_INV_AT_RISK_VAL NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT ADD DELAY_PLAN_FLGS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT ADD DELAY_REVENUE_AMT NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT ADD DELAY_NET_REVENUE_AMT NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT ADD DELAY_END_INV_AT_RISK_VAL NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT ADD DELAY_PLAN_FLGS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE MPLN_RESULT ADD DELAY_REVENUE_AMT NUMERIC(20,3);
 
 
ALTER TABLE MPLN_RESULT ADD DELAY_NET_REVENUE_AMT NUMERIC(20,3);
 
 
ALTER TABLE MPLN_RESULT ADD DELAY_END_INV_AT_RISK_VAL NUMERIC(20,3);
 
 
ALTER TABLE MPLN_RESULT ADD DELAY_PLAN_FLGS INTEGER;
 
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD DELAY_REVENUE_AMT NUMERIC(20,3);
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD DELAY_NET_REVENUE_AMT NUMERIC(20,3);
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD DELAY_END_INV_AT_RISK_VAL NUMERIC(20,3);
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT ADD DELAY_PLAN_FLGS INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID906007;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID906007;
%put ERROR- Description                              : Delay metrics for non-optimized plans;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 09JUL2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID906007;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID906007",
"Delay metrics for non-optimized plans",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID906007:;
 
 
* End of changes for CHANGE_ID:ID906007;
 
 
***********************************************************************************************;
*************************************  End Change ID906007 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID906007_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID906007_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID906007_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID906007_2;
%goto ID906007_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID906007_2;
* Insert record into change management table for CHANGE_ID: ID906007_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID906007_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID906007_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT DROP COLUMN OPP_COST_DELAY_UNITS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_GEO_PROD_RESULT DROP COLUMN OPP_COST_DELAY_AMT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT DROP COLUMN OPP_COST_DELAY_UNITS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE MPLN_RESULT DROP COLUMN OPP_COST_DELAY_AMT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT DROP COLUMN OPP_COST_DELAY_UNITS;
 
 
ALTER TABLE MPLN_GEO_PROD_RESULT DROP COLUMN OPP_COST_DELAY_AMT;
 
 
 
ALTER TABLE MPLN_RESULT DROP COLUMN OPP_COST_DELAY_UNITS;
 
 
ALTER TABLE MPLN_RESULT DROP COLUMN OPP_COST_DELAY_AMT;
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID906007_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID906007_2;
%put ERROR- Description                              : Drop columns OPP_COST_DELAY_* from MPLN_RESULT and MPLN_GEO_PROD_RESULT;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 24JUL2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID906007_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID906007_2",
"Drop columns OPP_COST_DELAY_* from MPLN_RESULT and MPLN_GEO_PROD_RESULT",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID906007_2:;
 
 
* End of changes for CHANGE_ID:ID906007_2;
 
 
***********************************************************************************************;
*************************************  End Change ID906007_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID975860_7 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID975860_7;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID975860_7")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..SCORING_PARAM_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..SCORING_PARAM_DEFAULT;
%put NOTE: Change ID                             :ID975860_7;
%goto ID975860_7;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID975860_7;
%goto ID975860_7;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID975860_7;
* Insert record into change management table for CHANGE_ID: ID975860_7;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_7",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID975860_7;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update SCORING_PARAM_DEFAULT set EFFECT_EST_L = 0 where (GEO_HIER_SK = 1
and PROD_HIER_SK = 1 and EFFECT_CATEGORY = 'CP_AG_N')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update SCORING_PARAM_DEFAULT set EFFECT_EST_U = 3 where (GEO_HIER_SK = 1
and PROD_HIER_SK = 1 and EFFECT_CATEGORY = 'CP_AG_N')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
update SCORING_PARAM_DEFAULT set EFFECT_EST_L = -3 where (GEO_HIER_SK = 1
and PROD_HIER_SK = 1 and EFFECT_CATEGORY = 'CP_AG_P')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update SCORING_PARAM_DEFAULT set EFFECT_EST_U = 0 where (GEO_HIER_SK = 1
and PROD_HIER_SK = 1 and EFFECT_CATEGORY = 'CP_AG_P')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
update SCORING_PARAM_DEFAULT set EFFECT_EST_L = 0 where (GEO_HIER_SK = 1
and PROD_HIER_SK = 1 and EFFECT_CATEGORY = 'CP_AG_N');
 
 
update SCORING_PARAM_DEFAULT set EFFECT_EST_U = 3 where (GEO_HIER_SK = 1
and PROD_HIER_SK = 1 and EFFECT_CATEGORY = 'CP_AG_N');
 
 
 
update SCORING_PARAM_DEFAULT set EFFECT_EST_L = -3 where (GEO_HIER_SK = 1
and PROD_HIER_SK = 1 and EFFECT_CATEGORY = 'CP_AG_P');
 
 
update SCORING_PARAM_DEFAULT set EFFECT_EST_U = 0 where (GEO_HIER_SK = 1
and PROD_HIER_SK = 1 and EFFECT_CATEGORY = 'CP_AG_P');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID975860_7;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID975860_7;
%put ERROR- Description                              : Fix affinity group scoring parameter default limits for CP_AG_P and CP_AG_N;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 16JUL2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID975860_7;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID975860_7",
"Fix affinity group scoring parameter default limits for CP_AG_P and CP_AG_N",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID975860_7:;
 
 
* End of changes for CHANGE_ID:ID975860_7;
 
 
***********************************************************************************************;
*************************************  End Change ID975860_7 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID934410 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID934410;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID934410")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID934410;
%goto ID934410;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID934410;
* Insert record into change management table for CHANGE_ID: ID934410;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID934410",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID934410;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_RESULT ADD PLAN_START_PRICE NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
 
ALTER TABLE RPO_PLAN_MEMBER_RESULT ADD PLAN_START_PRICE NUMERIC(20,3);
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID934410;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID934410;
%put ERROR- Description                              : Show regular price at plan start date in the UI;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 16JULY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID934410;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID934410",
"Show regular price at plan start date in the UI",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID934410:;
 
 
* End of changes for CHANGE_ID:ID934410;
 
 
***********************************************************************************************;
*************************************  End Change ID934410 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID934410_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID934410_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID934410_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID934410_2;
%goto ID934410_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID934410_2;
* Insert record into change management table for CHANGE_ID: ID934410_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID934410_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID934410_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_RESULT DROP COLUMN PLAN_START_PRICE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_RESULT ADD PLAN_START_PRICE_MIN NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE RPO_PLAN_MEMBER_RESULT ADD PLAN_START_PRICE_MAX NUMERIC(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
 
ALTER TABLE RPO_PLAN_MEMBER_RESULT DROP COLUMN PLAN_START_PRICE;
 
 
ALTER TABLE RPO_PLAN_MEMBER_RESULT ADD PLAN_START_PRICE_MIN NUMERIC(20,3);
 
 
ALTER TABLE RPO_PLAN_MEMBER_RESULT ADD PLAN_START_PRICE_MAX NUMERIC(20,3);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID934410_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID934410_2;
%put ERROR- Description                              : Show regular price at plan start date in the UI (need a range);
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 18JULY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID934410_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID934410_2",
"Show regular price at plan start date in the UI (need a range)",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID934410_2:;
 
 
* End of changes for CHANGE_ID:ID934410_2;
 
 
***********************************************************************************************;
*************************************  End Change ID934410_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID_0949494_3 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID_0949494_3;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID_0949494_3")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID_0949494_3;
%goto ID_0949494_3;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID_0949494_3;
* Insert record into change management table for CHANGE_ID: ID_0949494_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID_0949494_3",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID_0949494_3;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PRICING_RELATION ADD ATTR_ORIGIN INTEGER DEFAULT 0 NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
alter table PRICING_RELATION add ATTR_ORIGIN INTEGER ;
 
 
update PRICING_RELATION set ATTR_ORIGIN=0;
 
 
alter table PRICING_RELATION add NOT NULL (ATTR_ORIGIN);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID_0949494_3;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID_0949494_3;
%put ERROR- Description                              : see defect S0949494;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 22JULY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID_0949494_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID_0949494_3",
"see defect S0949494",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID_0949494_3:;
 
 
* End of changes for CHANGE_ID:ID_0949494_3;
 
 
***********************************************************************************************;
*************************************  End Change ID_0949494_3 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID991992 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID991992;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID991992")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID991992;
%goto ID991992;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(F2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID991992;
* Insert record into change management table for CHANGE_ID: ID991992;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID991992",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID991992;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE INDEX PKO_DELIVERY_LOCATION_IDX1     ON PKO_DELIVERY_LOCATION  (DELIVERY_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE INDEX PKO_DELIVERY_STORE_IDX1        ON PKO_DELIVERY_STORE (DELIVERY_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE INDEX PKO_DELIVERY_STYLECOLOR_IDX1   ON PKO_DELIVERY_STYLECOLOR (DELIVERY_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE INDEX PKO_EXTERNAL_NEED_SUMMARY_IDX1 ON PKO_EXTERNAL_NEED_SUMMARY (PKO_NEED_LOCATION_GROUP_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE INDEX PKO_NEED_LOCATION_IDX1         ON PKO_NEED_LOCATION (PKO_NEED_LOCATION_GROUP_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE INDEX PKO_PO_PLAN_LOC_IDX1           ON PKO_PURCHASE_ORDER_PLAN_LOC (PURCHASE_ORDER_PLAN_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE INDEX PKO_RES_PACK_IDX1              ON PKO_RES_PACK (RES_PACK_HIER_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE INDEX PKO_RES_PROD_GEO_SIZE_QTY_IDX1 ON PKO_RES_PROD_GEO_SIZE_QTY (DELIVERY_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE INDEX PKO_RES_PROD_GEO_SIZE_QTY_IDX2 ON PKO_RES_PROD_GEO_SIZE_QTY (BUY_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE INDEX REQ_PROD_SIZE_IDX1             ON REQ_PROD_SIZE (REQUEST_ID)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE INDEX RES_PG_SIZE_QTY_IDX1           ON RES_PROD_GEO_SIZE_QTY (REQUEST_ID)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
CREATE INDEX DELIVERY_SK                ON PKO_DELIVERY_LOCATION  (DELIVERY_SK);
 
 
CREATE INDEX DELIVERY_SK                ON PKO_DELIVERY_STORE (DELIVERY_SK);
 
 
CREATE INDEX DELIVERY_SK                ON PKO_DELIVERY_STYLECOLOR (DELIVERY_SK);
 
 
CREATE INDEX PKO_NEED_LOCATION_GROUP_SK ON PKO_EXTERNAL_NEED_SUMMARY (PKO_NEED_LOCATION_GROUP_SK);
 
 
CREATE INDEX PKO_NEED_LOCATION_GROUP_SK ON PKO_NEED_LOCATION (PKO_NEED_LOCATION_GROUP_SK);
 
 
CREATE INDEX PURCHASE_ORDER_PLAN_SK     ON PKO_PURCHASE_ORDER_PLAN_LOC (PURCHASE_ORDER_PLAN_SK);
 
 
CREATE INDEX RES_PACK_HIER_SK           ON PKO_RES_PACK (RES_PACK_HIER_SK);
 
 
CREATE INDEX DELIVERY_SK                ON PKO_RES_PROD_GEO_SIZE_QTY (DELIVERY_SK);
 
 
CREATE INDEX BUY_SK                     ON PKO_RES_PROD_GEO_SIZE_QTY (BUY_SK);
 
 
CREATE INDEX REQUEST_ID                 ON REQ_PROD_SIZE (REQUEST_ID);
 
 
CREATE INDEX REQUEST_ID                 ON RES_PROD_GEO_SIZE_QTY (REQUEST_ID);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID991992;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID991992;
%put ERROR- Description                              : New Indices are needed for PKO performance;
%put ERROR- Version                                  : F2MICM521;
%put ERROR- Date of Change                           : 18JULY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID991992;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID991992",
"New Indices are needed for PKO performance",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID991992:;
 
 
* End of changes for CHANGE_ID:ID991992;
 
 
***********************************************************************************************;
*************************************  End Change ID991992 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID917127 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID917127;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID917127")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID917127;
%goto ID917127;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID917127;
* Insert record into change management table for CHANGE_ID: ID917127;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID917127",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID917127;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN add ALLOW_MARKDN_BELOW_COST_CD integer
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE MDO_PLAN add ALLOW_MARKDN_BELOW_COST_CD integer;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID917127;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID917127;
%put ERROR- Description                              : Add plan setting ALLOW_MARKDN_BELOW_COST_CD to MDO PLAN;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 22JUL2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID917127;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID917127",
"Add plan setting ALLOW_MARKDN_BELOW_COST_CD to MDO PLAN",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID917127:;
 
 
* End of changes for CHANGE_ID:ID917127;
 
 
***********************************************************************************************;
*************************************  End Change ID917127 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID917127_GPSETTING ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID917127_GPSETTING;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID917127_GPSETTING")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID917127_GPSETTING;
%goto ID917127_GPSETTING;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID917127_GPSETTING;
* Insert record into change management table for CHANGE_ID: ID917127_GPSETTING;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID917127_GPSETTING",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID917127_GPSETTING;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 35
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO GEO_PROD_SETTING
(GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,
SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (35,1,1,1,63,1,1,1,2,1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 35 ;
 
 
INSERT INTO GEO_PROD_SETTING
(GEO_PROD_SETTING_SK,GEO_HIER_SK,PROD_HIER_SK,USED_BY_APP,SETTING_TYPE,SETTING_VAL,
SETTING_OVERRIDE_FLG,SETTING_FLOOR,SETTING_CEIL,GEO_HIER_ASSOC_CD)
VALUES (35,1,1,1,63,1,1,1,2,1);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID917127_GPSETTING;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID917127_GPSETTING;
%put ERROR- Description                              : Add allow-markdn-below-cost settings to geo_prod_setting;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 22JUL2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID917127_GPSETTING;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID917127_GPSETTING",
"Add allow-markdn-below-cost settings to geo_prod_setting",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID917127_GPSETTING:;
 
 
* End of changes for CHANGE_ID:ID917127_GPSETTING;
 
 
***********************************************************************************************;
*************************************  End Change ID917127_GPSETTING ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID917127_DEFAULT_VALUES ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID917127_DEFAULT_VALUES;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID917127_DEFAULT_VALUES")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID917127_DEFAULT_VALUES;
%goto ID917127_DEFAULT_VALUES;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID917127_DEFAULT_VALUES;
* Insert record into change management table for CHANGE_ID: ID917127_DEFAULT_VALUES;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID917127_DEFAULT_VALUES",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID917127_DEFAULT_VALUES;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
update MDO_PLAN
set ALLOW_MARKDN_BELOW_COST_CD = coalesce(ALLOW_MARKDN_BELOW_COST_CD,1)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
data &m_di_trans..MDO_PLAN;
 
 
modify &m_di_trans..MDO_PLAN;
 
 
ALLOW_MARKDN_BELOW_COST_CD = coalesce(ALLOW_MARKDN_BELOW_COST_CD,1);
 
 
run;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID917127_DEFAULT_VALUES;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID917127_DEFAULT_VALUES;
%put ERROR- Description                              : Set default values for the plan setting ALLOW_MARKDN_BELOW_COST_CD;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 11SEP2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID917127_DEFAULT_VALUES;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID917127_DEFAULT_VALUES",
"Set default values for the plan setting ALLOW_MARKDN_BELOW_COST_CD",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID917127_DEFAULT_VALUES:;
 
 
* End of changes for CHANGE_ID:ID917127_DEFAULT_VALUES;
 
 
***********************************************************************************************;
*************************************  End Change ID917127_DEFAULT_VALUES ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID917127_ALLOWED_PERIODS ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID917127_ALLOWED_PERIODS;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID917127_ALLOWED_PERIODS")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID917127_ALLOWED_PERIODS;
%goto ID917127_ALLOWED_PERIODS;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M2MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID917127_ALLOWED_PERIODS;
* Insert record into change management table for CHANGE_ID: ID917127_ALLOWED_PERIODS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID917127_ALLOWED_PERIODS",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID917127_ALLOWED_PERIODS;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE MDO_PLAN ADD ALLOW_MARKDN_BELOW_COST_PRDS VARCHAR2(255)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
ALTER TABLE MDO_PLAN ADD ALLOW_MARKDN_BELOW_COST_PRDS VARCHAR(255);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID917127_ALLOWED_PERIODS;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID917127_ALLOWED_PERIODS;
%put ERROR- Description                              : Add a column to specify marddown below cost allowed periods for an MDO plan;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 25JUL2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID917127_ALLOWED_PERIODS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID917127_ALLOWED_PERIODS",
"Add a column to specify marddown below cost allowed periods for an MDO plan",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID917127_ALLOWED_PERIODS:;
 
 
* End of changes for CHANGE_ID:ID917127_ALLOWED_PERIODS;
 
 
***********************************************************************************************;
*************************************  End Change ID917127_ALLOWED_PERIODS ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID918433_THREE ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID918433_THREE;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID918433_THREE")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID918433_THREE;
%goto ID918433_THREE;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID918433_THREE;
* Insert record into change management table for CHANGE_ID: ID918433_THREE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID918433_THREE",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID918433_THREE;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE TABLE GEOGRAPHY_ATTR_LOOKUP
(
GEO_HIER_SK      INTEGER NOT NULL,
GEO_ATTR_SK      INTEGER NOT NULL,
PRIMARY KEY (GEO_HIER_SK,GEO_ATTR_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE INDEX GEOGRAPHY_ATTR_LOOKUP_IX1 ON GEOGRAPHY_ATTR_LOOKUP
(
GEO_ATTR_SK
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PRODUCT_ATTR_LOOKUP
(
PROD_HIER_SK      INTEGER NOT NULL,
PROD_ATTR_SK      INTEGER NOT NULL,
PRIMARY KEY (PROD_HIER_SK,PROD_ATTR_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE INDEX PRODUCT_ATTR_LOOKUP_IX1 ON PRODUCT_ATTR_LOOKUP
(
PROD_ATTR_SK
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
CREATE TABLE GEOGRAPHY_ATTR_LOOKUP
(
GEO_HIER_SK      INTEGER NOT NULL,
GEO_ATTR_SK      INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE GEOGRAPHY_ATTR_LOOKUP  add CONSTRAINT PRIM_KEY  PRIMARY KEY (GEO_HIER_SK,GEO_ATTR_SK);
 
 
 
CREATE INDEX GEO_ATTR_SK ON GEOGRAPHY_ATTR_LOOKUP
(
GEO_ATTR_SK
)
;
 
 
 
 
CREATE TABLE PRODUCT_ATTR_LOOKUP
(
PROD_HIER_SK      INTEGER NOT NULL,
PROD_ATTR_SK      INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE PRODUCT_ATTR_LOOKUP  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PROD_HIER_SK,PROD_ATTR_SK);
 
 
 
CREATE INDEX PROD_ATTR_SK ON PRODUCT_ATTR_LOOKUP
(
PROD_ATTR_SK
)
;
 
 
 
 
quit;
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID918433_THREE;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID918433_THREE;
%put ERROR- Description                              : Multi Language Replicate tables GEOGRAPHY_ATTR_LOOKUP and PRODUCT_ATTR_LOOKUP;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 24JUL2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID918433_THREE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID918433_THREE",
"Multi Language Replicate tables GEOGRAPHY_ATTR_LOOKUP and PRODUCT_ATTR_LOOKUP",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID918433_THREE:;
 
 
* End of changes for CHANGE_ID:ID918433_THREE;
 
 
***********************************************************************************************;
*************************************  End Change ID918433_THREE ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID918433_FOUR ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID918433_FOUR;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID918433_FOUR")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID918433_FOUR;
%goto ID918433_FOUR;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID918433_FOUR;
* Insert record into change management table for CHANGE_ID: ID918433_FOUR;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID918433_FOUR",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID918433_FOUR;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
proc sql noprint;
 
 
delete * from di_trans.PRODUCT_ATTR_LOOKUP;
 
 
insert into di_trans.PRODUCT_ATTR_LOOKUP
select * from di_data.PRODUCT_ATTR_LOOKUP
;
 
 
quit;
 
 
proc sql noprint;
 
 
delete * from di_trans.GEOGRAPHY_ATTR_LOOKUP;
 
 
insert into di_trans.GEOGRAPHY_ATTR_LOOKUP
select * from di_data.GEOGRAPHY_ATTR_LOOKUP
;
 
 
quit;
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
proc sql noprint;
 
 
delete * from di_trans.PRODUCT_ATTR_LOOKUP;
 
 
insert into di_trans.PRODUCT_ATTR_LOOKUP
select * from di_data.PRODUCT_ATTR_LOOKUP
;
 
 
quit;
 
 
proc sql noprint;
 
 
delete * from di_trans.GEOGRAPHY_ATTR_LOOKUP;
 
 
insert into di_trans.GEOGRAPHY_ATTR_LOOKUP
select * from di_data.GEOGRAPHY_ATTR_LOOKUP
;
 
 
quit;
 
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID918433_FOUR;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID918433_FOUR;
%put ERROR- Description                              : Get Data from SAS Side;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 24JUL2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID918433_FOUR;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID918433_FOUR",
"Get Data from SAS Side",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID918433_FOUR:;
 
 
* End of changes for CHANGE_ID:ID918433_FOUR;
 
 
***********************************************************************************************;
*************************************  End Change ID918433_FOUR ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID_S0988608 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID_S0988608;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID_S0988608")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID_S0988608;
%goto ID_S0988608;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID_S0988608;
* Insert record into change management table for CHANGE_ID: ID_S0988608;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID_S0988608",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID_S0988608;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PRICING_RELN_MATCH_ATTR ADD MATCH_ATTR_ORIGIN INTEGER DEFAULT 0 NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
alter table PRICING_RELN_MATCH_ATTR add MATCH_ATTR_ORIGIN INTEGER ;
 
 
update PRICING_RELN_MATCH_ATTR set MATCH_ATTR_ORIGIN=0;
 
 
alter table PRICING_RELN_MATCH_ATTR add NOT NULL (MATCH_ATTR_ORIGIN);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID_S0988608;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID_S0988608;
%put ERROR- Description                              : see defect S0988608;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 26JULY2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID_S0988608;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID_S0988608",
"see defect S0988608",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID_S0988608:;
 
 
* End of changes for CHANGE_ID:ID_S0988608;
 
 
***********************************************************************************************;
*************************************  End Change ID_S0988608 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change SET_IX6_IX7_DROP ***********************************;
***********************************************************************************************;
 
%let m_reset_syscc=&syscc;
 
* Check to see if this change has already been applied. CHANGE_ID: SET_IX6_IX7_DROP;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("SET_IX6_IX7_DROP")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : SET_IX6_IX7_DROP;
%goto SET_IX6_IX7_DROP;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : SET_IX6_IX7_DROP;
* Insert record into change management table for CHANGE_ID: SET_IX6_IX7_DROP;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"SET_IX6_IX7_DROP",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto SET_IX6_IX7_DROP;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%di_util_rdbms_drop_index(m_lib=di_trans, m_table=PRODUCT_HIER_ASSOC_DM,m_index_name=PROD_HIER_IX6);
 
 
%di_util_rdbms_drop_index(m_lib=di_trans, m_table=PRODUCT_HIER_ASSOC_DM,m_index_name=PROD_HIER_IX7);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
%end;
 
 
 
 
%let syscc=&m_reset_syscc;
 
 
* Insert record into change management table for CHANGE_ID: SET_IX6_IX7_DROP;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"SET_IX6_IX7_DROP",
"Set indexes IX6 and IX7 on  PRODUCT_HIER_ASSOC_DM",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%SET_IX6_IX7_DROP:;
 
 
* End of changes for CHANGE_ID:SET_IX6_IX7_DROP;
 
 
***********************************************************************************************;
*************************************  End Change SET_IX6_IX7_DROP ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change SET_IX6_IX7_CREATE ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: SET_IX6_IX7_CREATE;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("SET_IX6_IX7_CREATE")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : SET_IX6_IX7_CREATE;
%goto SET_IX6_IX7_CREATE;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : SET_IX6_IX7_CREATE;
* Insert record into change management table for CHANGE_ID: SET_IX6_IX7_CREATE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"SET_IX6_IX7_CREATE",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto SET_IX6_IX7_CREATE;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE INDEX PROD_HIER_IX6 ON PRODUCT_HIER_ASSOC_DM
(
PROD_HIER_SK,
PARENT_PROD_LVL
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX PROD_HIER_IX7 ON PRODUCT_HIER_ASSOC_DM
(
PROD_HIER_ASSOC_CD,
PARENT_PROD_HIER_SK,
PROD_HIER_SK
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
select count(*)
into :_cnt_idx_ix6
from sashelp.vindex
where upcase(libname)=upcase("&m_di_data.")
and upcase(memname) = "PRODUCT_HIER_ASSOC_DM"
and upcase(indxname) = "PROD_HIER_IX6"
;
 
 
 
select count(*)
into :_cnt_idx_ix7
from sashelp.vindex
where upcase(libname)=upcase("&m_di_data.")
and upcase(memname) = "PRODUCT_HIER_ASSOC_DM"
and upcase(indxname) = "PROD_HIER_IX7"
;
 
 
quit;
 
 
 
%if &_cnt_idx_ix7 = 0 %then
%do;
 
 
 
%if &_cnt_idx_ix6 >0 %then
%do;
 
 
 
proc sql noprint;
 
 
 
DROP INDEX PROD_HIER_IX6 FROM &m_di_data..PRODUCT_HIER_ASSOC_DM;
 
 
 
quit;
 
 
 
%end;
 
 
 
proc sql noprint;
 
 
 
 
CREATE INDEX PROD_HIER_IX6 ON &m_di_data..PRODUCT_HIER_ASSOC_DM
(
PROD_HIER_SK,
PARENT_PROD_LVL
)
;
 
 
 
CREATE INDEX PROD_HIER_IX7 ON &m_di_data..PRODUCT_HIER_ASSOC_DM
(
PROD_HIER_ASSOC_CD,
PARENT_PROD_HIER_SK,
PROD_HIER_SK
)
;
 
 
quit;
 
 
 
%end;
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: SET_IX6_IX7_CREATE;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: SET_IX6_IX7_CREATE;
%put ERROR- Description                              : Set indexes IX6 and IX7 on  PRODUCT_HIER_ASSOC_DM;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 07JUL2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: SET_IX6_IX7_CREATE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"SET_IX6_IX7_CREATE",
"Set indexes IX6 and IX7 on  PRODUCT_HIER_ASSOC_DM",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%SET_IX6_IX7_CREATE:;
 
 
* End of changes for CHANGE_ID:SET_IX6_IX7_CREATE;
 
 
***********************************************************************************************;
*************************************  End Change SET_IX6_IX7_CREATE ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change DROP_PRICE_CHG_PRIORITY_PURGE ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: DROP_PRICE_CHG_PRIORITY_PURGE;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("DROP_PRICE_CHG_PRIORITY_PURGE")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : DROP_PRICE_CHG_PRIORITY_PURGE;
%goto DROP_PRICE_CHG_PRIORITY_PURGE;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : DROP_PRICE_CHG_PRIORITY_PURGE;
* Insert record into change management table for CHANGE_ID: DROP_PRICE_CHG_PRIORITY_PURGE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_PRICE_CHG_PRIORITY_PURGE",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto DROP_PRICE_CHG_PRIORITY_PURGE;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM PURGE_QUERY
WHERE table_nm in ('PRICE_CHANGE_PRIORITY')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM PURGE_QUERY
WHERE table_nm in ('PRICE_CHANGE_PRIORITY');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: DROP_PRICE_CHG_PRIORITY_PURGE;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: DROP_PRICE_CHG_PRIORITY_PURGE;
%put ERROR- Description                              : Delete Price_change_priority from purge_query as it has moved to RDBMS;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 31JUL2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: DROP_PRICE_CHG_PRIORITY_PURGE;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"DROP_PRICE_CHG_PRIORITY_PURGE",
"Delete Price_change_priority from purge_query as it has moved to RDBMS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%DROP_PRICE_CHG_PRIORITY_PURGE:;
 
 
* End of changes for CHANGE_ID:DROP_PRICE_CHG_PRIORITY_PURGE;
 
 
***********************************************************************************************;
*************************************  End Change DROP_PRICE_CHG_PRIORITY_PURGE ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID847904_A ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID847904_A;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID847904_A")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID847904_A;
%goto ID847904_A;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID847904_A;
* Insert record into change management table for CHANGE_ID: ID847904_A;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID847904_A",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID847904_A;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
alter table PRICING_RELN_MATCH_ATTR modify MATCH_ATTR_VALUE_LIST VARCHAR(4000)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
alter table PRICING_RELN_MATCH_ATTR modify MATCH_ATTR_VALUE_LIST VARCHAR(4000);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID847904_A;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID847904_A;
%put ERROR- Description                              : see defect S0847904;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 08AUG2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID847904_A;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID847904_A",
"see defect S0847904",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID847904_A:;
 
 
* End of changes for CHANGE_ID:ID847904_A;
 
 
***********************************************************************************************;
*************************************  End Change ID847904_A ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ATTR_PROD_HIER_KEYS_DTTM ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ATTR_PROD_HIER_KEYS_DTTM;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ATTR_PROD_HIER_KEYS_DTTM")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ATTR_PROD_HIER_KEYS_DTTM;
%goto ATTR_PROD_HIER_KEYS_DTTM;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ATTR_PROD_HIER_KEYS_DTTM;
* Insert record into change management table for CHANGE_ID: ATTR_PROD_HIER_KEYS_DTTM;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ATTR_PROD_HIER_KEYS_DTTM",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ATTR_PROD_HIER_KEYS_DTTM;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
proc datasets library=&m_di_trans nolist;
 
 
 
modify ATTR_PROD_HIER_KEYS ;
 
 
format DTTM NLDATM21.;
 
 
informat DTTM NLDATM21.;
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ATTR_PROD_HIER_KEYS_DTTM;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ATTR_PROD_HIER_KEYS_DTTM;
%put ERROR- Description                              : This change is for internal users and does not affect production systems.;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 14AUG2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ATTR_PROD_HIER_KEYS_DTTM;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ATTR_PROD_HIER_KEYS_DTTM",
"This change is for internal users and does not affect production systems.",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ATTR_PROD_HIER_KEYS_DTTM:;
 
 
* End of changes for CHANGE_ID:ATTR_PROD_HIER_KEYS_DTTM;
 
 
***********************************************************************************************;
*************************************  End Change ATTR_PROD_HIER_KEYS_DTTM ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change GLOBAL_CONSTANTS_RUN_ALWAYS ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: GLOBAL_CONSTANTS_RUN_ALWAYS;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("GLOBAL_CONSTANTS_RUN_ALWAYS")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(libref(&m_di_data.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_data.;
%put NOTE: Change ID                             :GLOBAL_CONSTANTS_RUN_ALWAYS;
%goto GLOBAL_CONSTANTS_RUN_ALWAYS;
 
%end;
%if not (%sysfunc(libref(&m_di_trans.)) = 0) %then
%do;
%put NOTE: Skip this change since this library is not assigned: &m_di_trans.;
%put NOTE: Change ID                             :GLOBAL_CONSTANTS_RUN_ALWAYS;
%goto GLOBAL_CONSTANTS_RUN_ALWAYS;
 
%end;
%if not (%sysfunc(exist(&m_di_trans..ma_spec_seed))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..ma_spec_seed;
%put NOTE: Change ID                             :GLOBAL_CONSTANTS_RUN_ALWAYS;
%goto GLOBAL_CONSTANTS_RUN_ALWAYS;
 
%end;
%put NOTE: This change will be applied on every run : GLOBAL_CONSTANTS_RUN_ALWAYS;
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let DI_MISC_PATH=%di_util_misc_path();
 
 
 
%include  "&DI_MISC_PATH/seed/seed_global_constants.sas";
 
 
 
%let m_refresh=%nrstr(proc sql; delete * from &m_di_trans..&m_tn;
 
 
create table work.z as select * from &m_di_trans..&m_tn outer union corr select * from work.&m_tn;
 
 
insert into &m_di_trans..&m_tn select * from work.z; quit;);
 
 
 
%let m_tn=global_geo_prod_status_details;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_geo_prod_status_values;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_setting_details;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_setting_group;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_setting_group_member;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_setting_values;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=ma_spec_seed;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_geo_prod_status_details;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_geo_prod_status_values;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_spec_workflow;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=scoring_param_config;
 
 
%unquote(&m_refresh);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%let DI_MISC_PATH=%di_util_misc_path();
 
 
 
%include  "&DI_MISC_PATH/seed/seed_global_constants.sas";
 
 
 
%let m_refresh=%nrstr(proc sql; delete * from &m_di_trans..&m_tn;
 
 
create table work.z as select * from &m_di_trans..&m_tn outer union corr select * from work.&m_tn;
 
 
insert into &m_di_trans..&m_tn select * from work.z; quit;);
 
 
 
%let m_tn=global_geo_prod_status_details;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_geo_prod_status_values;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_setting_details;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_setting_group;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_setting_group_member;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=global_setting_values;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=ma_spec_seed;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_geo_prod_status_details;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_geo_prod_status_values;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=model_spec_workflow;
 
 
%unquote(&m_refresh);
 
 
 
%let m_tn=scoring_param_config;
 
 
%unquote(&m_refresh);
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: GLOBAL_CONSTANTS_RUN_ALWAYS;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: GLOBAL_CONSTANTS_RUN_ALWAYS;
%put ERROR- Description                              : Refresh non-user-editable CWB configuration tables;
%put ERROR- Version                                  : M2MICM521;
%put ERROR- Date of Change                           : 18FEB2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: GLOBAL_CONSTANTS_RUN_ALWAYS;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"GLOBAL_CONSTANTS_RUN_ALWAYS",
"Refresh non-user-editable CWB configuration tables",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%GLOBAL_CONSTANTS_RUN_ALWAYS:;
 
 
* End of changes for CHANGE_ID:GLOBAL_CONSTANTS_RUN_ALWAYS;
 
 
***********************************************************************************************;
*************************************  End Change GLOBAL_CONSTANTS_RUN_ALWAYS ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1002183 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1002183;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1002183")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PRF_CONFIG))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_CONFIG;
%put NOTE: Change ID                             :ID1002183;
%goto ID1002183;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1002183;
%goto ID1002183;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1002183;
* Insert record into change management table for CHANGE_ID: ID1002183;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1002183",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1002183;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=2 and SPEC_NM='super_sizeset_fill_zero_sales'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'super_sizeset_fill_zero_sales', '0', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=2 and SPEC_NM='super_sizeset_fill_zero_sales';
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'super_sizeset_fill_zero_sales', '0', 'INTEGER');
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1002183;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1002183;
%put ERROR- Description                              : Size Profling: add prf_config setting super_sizeset_fill_zero_sales;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 16AUG2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1002183;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1002183",
"Size Profling: add prf_config setting super_sizeset_fill_zero_sales",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1002183:;
 
 
* End of changes for CHANGE_ID:ID1002183;
 
 
***********************************************************************************************;
*************************************  End Change ID1002183 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1000053 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1000053;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1000053")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1000053;
%goto ID1000053;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1000053;
* Insert record into change management table for CHANGE_ID: ID1000053;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1000053",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1000053;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%if %sysfunc(exist(&m_di_trans..PRICE_CHANGE_PRIORITY)) %then %do;
 
 
%let m_sql_statement=%str(CREATE UNIQUE INDEX PRICE_CHG_PRIORITY_NM on PRICE_CHANGE_PRIORITY(PRICE_CHG_PRIORITY_NM));
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%end;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
%if %sysfunc(exist(&m_di_trans..PRICE_CHANGE_PRIORITY)) %then %do;
 
 
proc sql noprint;
 
 
CREATE UNIQUE INDEX PRICE_CHG_PRIORITY_NM on PRICE_CHANGE_PRIORITY(PRICE_CHG_PRIORITY_NM);
 
 
quit;
 
 
%end;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1000053;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1000053;
%put ERROR- Description                              : Create unique index for PRICE_CHANGE_PRIORITY;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 19AUG2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1000053;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1000053",
"Create unique index for PRICE_CHANGE_PRIORITY",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1000053:;
 
 
* End of changes for CHANGE_ID:ID1000053;
 
 
***********************************************************************************************;
*************************************  End Change ID1000053 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change TABLE_PARTITION_META_09 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: TABLE_PARTITION_META_09;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("TABLE_PARTITION_META_09")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : TABLE_PARTITION_META_09;
%goto TABLE_PARTITION_META_09;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : TABLE_PARTITION_META_09;
* Insert record into change management table for CHANGE_ID: TABLE_PARTITION_META_09;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"TABLE_PARTITION_META_09",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto TABLE_PARTITION_META_09;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql noprint;
 
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'CLR_DC_INV_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'CLR_EFF_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'CLR_INV_AGING_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'CLR_ITEM_SEL_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'CLR_MD_PROJECTION_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'CLR_MD_PROJECTION_REPORT_WEEKLY';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'MKDN_APPR_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'PRICE_CHANGE_PRIORITY';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REG_COST_CHG_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REG_COST_HIST_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REG_GM_CHG_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REG_SKU_COST_CHG_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REG_SKU_RETAIL_CHG_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REPORT_DEMAND_DECOM_DATE_SK';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REPORT_MEASURES_DATE_SK';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RETURN_RATE_AVG';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RPP_PGSPOT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RPP_PROMOEFF';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RPP_PROMOPLAN';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RPP_PROMOSUMM';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RPP_VENDOR_FUND';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RPP_VG_SUMMARY';
 
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'ISO_CURRENCY';
 
 
 
insert into DI_DM2.TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
values ('ISO_CURRENCY',1,0,0,0,'');
 
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'PROD_CROSS_RELATION';
 
 
 
insert into DI_DM2.TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
values ('PROD_CROSS_RELATION',1,0,0,0,'');
 
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'VENDOR_SUPPORT';
 
 
insert into DI_DM2.TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
values ('VENDOR_SUPPORT',1,0,0,0,'');
 
 
 
quit;
 
 
 
 
data work.table_partition_meta;
 
 
set di_dm2.table_partition_meta;
 
 
run;
 
 
 
proc sort data=work.table_partition_meta;
 
 
by table_nm;
 
 
run;
 
 
 
proc sql noprint;
 
 
delete * from di_dm2.table_partition_meta;
 
 
insert into di_dm2.table_partition_meta(TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
select TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER
from work.table_partition_meta
;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'CLR_DC_INV_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'CLR_EFF_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'CLR_INV_AGING_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'CLR_ITEM_SEL_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'CLR_MD_PROJECTION_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'CLR_MD_PROJECTION_REPORT_WEEKLY';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'MKDN_APPR_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'PRICE_CHANGE_PRIORITY';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REG_COST_CHG_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REG_COST_HIST_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REG_GM_CHG_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REG_SKU_COST_CHG_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REG_SKU_RETAIL_CHG_REPORT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REPORT_DEMAND_DECOM_DATE_SK';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'REPORT_MEASURES_DATE_SK';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RETURN_RATE_AVG';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RPP_PGSPOT';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RPP_PROMOEFF';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RPP_PROMOPLAN';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RPP_PROMOSUMM';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RPP_VENDOR_FUND';
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'RPP_VG_SUMMARY';
 
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'ISO_CURRENCY';
 
 
 
insert into DI_DM2.TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
values ('ISO_CURRENCY',1,0,0,0,'');
 
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'PROD_CROSS_RELATION';
 
 
 
insert into DI_DM2.TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
values ('PROD_CROSS_RELATION',1,0,0,0,'');
 
 
 
delete from DI_DM2.TABLE_PARTITION_META where TABLE_NM = 'VENDOR_SUPPORT';
 
 
insert into DI_DM2.TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
values ('VENDOR_SUPPORT',1,0,0,0,'');
 
 
 
quit;
 
 
 
 
data work.table_partition_meta;
 
 
set di_dm2.table_partition_meta;
 
 
run;
 
 
 
proc sort data=work.table_partition_meta;
 
 
by table_nm;
 
 
run;
 
 
 
proc sql noprint;
 
 
delete * from di_dm2.table_partition_meta;
 
 
insert into di_dm2.table_partition_meta(TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER)
select TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,ETL_STG2DM,SORT_ORDER
from work.table_partition_meta
;
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: TABLE_PARTITION_META_09;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: TABLE_PARTITION_META_09;
%put ERROR- Description                              : Update TABLE_PARTITION_META;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 03SEP2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: TABLE_PARTITION_META_09;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"TABLE_PARTITION_META_09",
"Update TABLE_PARTITION_META",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%TABLE_PARTITION_META_09:;
 
 
* End of changes for CHANGE_ID:TABLE_PARTITION_META_09;
 
 
***********************************************************************************************;
*************************************  End Change TABLE_PARTITION_META_09 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID989518 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID989518;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID989518")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..MODEL_SPEC_DEFAULT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..MODEL_SPEC_DEFAULT;
%put NOTE: Change ID                             :ID989518;
%goto ID989518;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID989518;
%goto ID989518;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID989518;
* Insert record into change management table for CHANGE_ID: ID989518;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID989518",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID989518;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where (SPEC_NM = 'MIN_PRICE_RATIO' and SPEC_TYPE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_TYPE = '-1' where (SPEC_NM = 'MIN_PRICE_RATIO'
and SPEC_TYPE = '1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where (SPEC_NM = 'MIN_PRICE_RATIO' and SPEC_TYPE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where (SPEC_NM = 'MIN_PRICE_RATIO'
and SPEC_TYPE = '1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where (SPEC_NM = 'MIN_PRICE_RATIO' and SPEC_TYPE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '-1' where (SPEC_NM = 'MIN_PRICE_RATIO'
and SPEC_TYPE = '1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where (SPEC_NM = 'MAX_PRICE_RATIO' and SPEC_TYPE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_TYPE = '-1' where (SPEC_NM = 'MAX_PRICE_RATIO'
and SPEC_TYPE = '1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where (SPEC_NM = 'MAX_PRICE_RATIO' and SPEC_TYPE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where (SPEC_NM = 'MAX_PRICE_RATIO'
and SPEC_TYPE = '1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where (SPEC_NM = 'MAX_PRICE_RATIO' and SPEC_TYPE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '-1' where (SPEC_NM = 'MAX_PRICE_RATIO'
and SPEC_TYPE = '1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC where (SPEC_NM = 'PSY_POINTS' and SPEC_TYPE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC set SPEC_TYPE = '-1' where (SPEC_NM = 'PSY_POINTS'
and SPEC_TYPE = '1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_DEFAULT where (SPEC_NM = 'PSY_POINTS' and SPEC_TYPE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where (SPEC_NM = 'PSY_POINTS'
and SPEC_TYPE = '1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
delete from MODEL_SPEC_TEMPLATE where (SPEC_NM = 'PSY_POINTS' and SPEC_TYPE = '2')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '-1' where (SPEC_NM = 'PSY_POINTS'
and SPEC_TYPE = '1')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
delete from MODEL_SPEC where (SPEC_NM = 'MIN_PRICE_RATIO' and SPEC_TYPE = '2');
 
 
update MODEL_SPEC set SPEC_TYPE = '-1' where (SPEC_NM = 'MIN_PRICE_RATIO'
and SPEC_TYPE = '1');
 
 
delete from MODEL_SPEC_DEFAULT where (SPEC_NM = 'MIN_PRICE_RATIO' and SPEC_TYPE = '2');
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where (SPEC_NM = 'MIN_PRICE_RATIO'
and SPEC_TYPE = '1');
 
 
delete from MODEL_SPEC_TEMPLATE where (SPEC_NM = 'MIN_PRICE_RATIO' and SPEC_TYPE = '2');
 
 
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '-1' where (SPEC_NM = 'MIN_PRICE_RATIO'
and SPEC_TYPE = '1');
 
 
 
delete from MODEL_SPEC where (SPEC_NM = 'MAX_PRICE_RATIO' and SPEC_TYPE = '2');
 
 
update MODEL_SPEC set SPEC_TYPE = '-1' where (SPEC_NM = 'MAX_PRICE_RATIO'
and SPEC_TYPE = '1');
 
 
delete from MODEL_SPEC_DEFAULT where (SPEC_NM = 'MAX_PRICE_RATIO' and SPEC_TYPE = '2');
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where (SPEC_NM = 'MAX_PRICE_RATIO'
and SPEC_TYPE = '1');
 
 
delete from MODEL_SPEC_TEMPLATE where (SPEC_NM = 'MAX_PRICE_RATIO' and SPEC_TYPE = '2');
 
 
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '-1' where (SPEC_NM = 'MAX_PRICE_RATIO'
and SPEC_TYPE = '1');
 
 
 
delete from MODEL_SPEC where (SPEC_NM = 'PSY_POINTS' and SPEC_TYPE = '2');
 
 
update MODEL_SPEC set SPEC_TYPE = '-1' where (SPEC_NM = 'PSY_POINTS'
and SPEC_TYPE = '1');
 
 
delete from MODEL_SPEC_DEFAULT where (SPEC_NM = 'PSY_POINTS' and SPEC_TYPE = '2');
 
 
update MODEL_SPEC_DEFAULT set SPEC_TYPE = '-1' where (SPEC_NM = 'PSY_POINTS'
and SPEC_TYPE = '1');
 
 
delete from MODEL_SPEC_TEMPLATE where (SPEC_NM = 'PSY_POINTS' and SPEC_TYPE = '2');
 
 
update MODEL_SPEC_TEMPLATE set SPEC_TYPE = '-1' where (SPEC_NM = 'PSY_POINTS'
and SPEC_TYPE = '1');
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID989518;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID989518;
%put ERROR- Description                              : Change spec type for MIN_PRICE_RATIO, MAX_PRICE_RATIO and PSY_POINTS to -1;
%put ERROR- Version                                  : M3MICM521;
%put ERROR- Date of Change                           : 27AUG2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID989518;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID989518",
"Change spec type for MIN_PRICE_RATIO, MAX_PRICE_RATIO and PSY_POINTS to -1",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID989518:;
 
 
* End of changes for CHANGE_ID:ID989518;
 
 
***********************************************************************************************;
*************************************  End Change ID989518 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID962538 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID962538;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID962538")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID962538;
%goto ID962538;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID962538;
* Insert record into change management table for CHANGE_ID: ID962538;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID962538",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID962538;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE RPP_PLAN      ADD PARENT_PROCESS_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE CALENDAR      ADD PARENT_PROCESS_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE CATEGORY_PLAN ADD PARENT_PROCESS_SK INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE RPP_PLAN      ADD PARENT_PROCESS_SK INTEGER;
 
 
ALTER TABLE CALENDAR      ADD PARENT_PROCESS_SK INTEGER;
 
 
ALTER TABLE CATEGORY_PLAN ADD PARENT_PROCESS_SK INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID962538;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID962538;
%put ERROR- Description                              : Backend messages in Batch;
%put ERROR- Version                                  : M3MICM52;
%put ERROR- Date of Change                           : 07OCT2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID962538;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID962538",
"Backend messages in Batch",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID962538:;
 
 
* End of changes for CHANGE_ID:ID962538;
 
 
***********************************************************************************************;
*************************************  End Change ID962538 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1033197 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1033197;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1033197")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1033197;
%goto ID1033197;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M3MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1033197;
* Insert record into change management table for CHANGE_ID: ID1033197;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1033197",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1033197;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 20033
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
insert into
geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,
SETTING_CEIL)   values ( 20033, 2, 1, 1, 1, 33, 1, 100.0, 0.00,  100.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 20034
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into
geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,
SETTING_CEIL)   values ( 20034, 2, 1, 1, 1, 34, 1, 100.0, 0.00,  100.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 20035
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into
geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,
SETTING_CEIL)   values ( 20035, 2, 1, 1, 1, 35, 1, 100.0, 0.00,  100.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 20036
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
insert into
geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,
SETTING_CEIL)   values ( 20036, 2, 1, 1, 1, 36, 1, 100.0, 0.00,  100.0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
 
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 20033;
 
 
 
insert into
geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,
SETTING_CEIL)   values ( 20033, 2, 1, 1, 1, 33, 1, 100.0, 0.00,  100.0);
 
 
 
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 20034;
 
 
insert into
geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,
SETTING_CEIL)   values ( 20034, 2, 1, 1, 1, 34, 1, 100.0, 0.00,  100.0);
 
 
 
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 20035;
 
 
insert into
geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,
SETTING_CEIL)   values ( 20035, 2, 1, 1, 1, 35, 1, 100.0, 0.00,  100.0);
 
 
 
DELETE FROM GEO_PROD_SETTING WHERE GEO_PROD_SETTING_SK = 20036;
 
 
insert into
geo_prod_setting(GEO_PROD_SETTING_SK,USED_BY_APP,GEO_HIER_SK,GEO_HIER_ASSOC_CD,
PROD_HIER_SK,SETTING_TYPE,SETTING_OVERRIDE_FLG,SETTING_VAL,SETTING_FLOOR,
SETTING_CEIL)   values ( 20036, 2, 1, 1, 1, 36, 1, 100.0, 0.00,  100.0);
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1033197;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1033197;
%put ERROR- Description                              : Subsidy Cost Adjustment Business Rules;
%put ERROR- Version                                  : M3MICM52;
%put ERROR- Date of Change                           : 07OCT2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1033197;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1033197",
"Subsidy Cost Adjustment Business Rules",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1033197:;
 
 
* End of changes for CHANGE_ID:ID1033197;
 
 
***********************************************************************************************;
*************************************  End Change ID1033197 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1038104 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1038104;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1038104")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1038104;
%goto ID1038104;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1038104;
* Insert record into change management table for CHANGE_ID: ID1038104;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1038104",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1038104;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE PRF_SG_RULE_BASE
(
PRF_SG_RULE_BASE_SK       INTEGER NOT NULL,
PRF_SG_RULE_NM            VARCHAR(100) NOT NULL,
PROD_HIER_SK              INTEGER NOT NULL,
NOTES                     VARCHAR(255),
PRIMARY KEY (PRF_SG_RULE_BASE_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_PRF_SG_RULE_BASE_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PRF_SG_RULE
(
PRF_SG_RULE_SK         INTEGER NOT NULL,
PRF_SG_RULE_BASE_SK    INTEGER NOT NULL,
VERSION_NUM            INTEGER NOT NULL,
CREATED_BY_USER_SK     INTEGER NOT NULL,
CREATED_DTTM           DATE NOT NULL,
PRIMARY KEY (PRF_SG_RULE_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_PRF_SG_RULE_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PRF_SG_RULE_ASSGMT
(
PRF_SG_RULE_ASSGMT_SK         INTEGER NOT NULL,
PRF_SG_RULE_SK                INTEGER NOT NULL,
TARGET_GEO_HIER_SK            INTEGER,
PRIMARY KEY (PRF_SG_RULE_ASSGMT_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_PRF_SG_RULE_ASSGMT_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX PRF_SG_RULE_ASSGMT_IX1 ON PRF_SG_RULE_ASSGMT
(
PRF_SG_RULE_SK
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PRF_SG_RULE_ASSGMT_ELMT
(
PRF_SG_RULE_ASSGMT_SK      INTEGER NOT NULL,
GEO_HIER_SK                INTEGER NOT NULL,
PRIMARY KEY (PRF_SG_RULE_ASSGMT_SK, GEO_HIER_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
proc sql;
 
 
 
CREATE TABLE PRF_SG_RULE_BASE
(
PRF_SG_RULE_BASE_SK       INTEGER NOT NULL,
PRF_SG_RULE_NM            VARCHAR(100) NOT NULL,
PROD_HIER_SK              INTEGER NOT NULL,
NOTES                     VARCHAR(255)
)
;
 
 
ALTER TABLE PRF_SG_RULE_BASE  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PRF_SG_RULE_BASE_SK);
 
 
 
 
CREATE TABLE PRF_SG_RULE
(
PRF_SG_RULE_SK         INTEGER NOT NULL,
PRF_SG_RULE_BASE_SK    INTEGER NOT NULL,
VERSION_NUM            INTEGER NOT NULL,
CREATED_BY_USER_SK     INTEGER NOT NULL,
CREATED_DTTM           DATE NOT NULL
)
;
 
 
ALTER TABLE PRF_SG_RULE  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PRF_SG_RULE_SK);
 
 
 
 
CREATE TABLE PRF_SG_RULE_ASSGMT
(
PRF_SG_RULE_ASSGMT_SK         INTEGER NOT NULL,
PRF_SG_RULE_SK                INTEGER NOT NULL,
TARGET_GEO_HIER_SK            INTEGER
)
;
 
 
 
ALTER TABLE PRF_SG_RULE_ASSGMT  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PRF_SG_RULE_ASSGMT_SK);
 
 
 
 
CREATE INDEX PRF_SG_RULE_SK ON PRF_SG_RULE_ASSGMT ( PRF_SG_RULE_SK )  ;
 
 
 
CREATE TABLE PRF_SG_RULE_ASSGMT_ELMT
(
PRF_SG_RULE_ASSGMT_SK      INTEGER NOT NULL,
GEO_HIER_SK                INTEGER NOT NULL
)
;
 
 
 
 
ALTER TABLE PRF_SG_RULE_ASSGMT_ELMT  add CONSTRAINT PRIM_KEY
PRIMARY KEY (PRF_SG_RULE_ASSGMT_SK,GEO_HIER_SK);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1038104;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1038104;
%put ERROR- Description                              : Add STORE GROUP RULE tables;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 04DEC2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1038104;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1038104",
"Add STORE GROUP RULE tables",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1038104:;
 
 
* End of changes for CHANGE_ID:ID1038104;
 
 
***********************************************************************************************;
*************************************  End Change ID1038104 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1040612 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1040612;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1040612")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1040612;
%goto ID1040612;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1040612;
* Insert record into change management table for CHANGE_ID: ID1040612;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1040612",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1040612;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='PRF_INVENTORY_FACT';
 
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('PRF_INVENTORY_FACT', 'SAS', 11, 9999, '%szpf_purge_prf_inventory_fact(libref=DI_DM);', 365,1,'SZPF');
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='PRF_INVENTORY_FACT';
 
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('PRF_INVENTORY_FACT', 'SAS', 11, 9999, '%szpf_purge_prf_inventory_fact(libref=DI_DM);', 365,1,'SZPF');
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1040612;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1040612;
%put ERROR- Description                              : Add Time based purge routine for PRF_inventory_fact;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 13DEC2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1040612;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1040612",
"Add Time based purge routine for PRF_inventory_fact",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1040612:;
 
 
* End of changes for CHANGE_ID:ID1040612;
 
 
***********************************************************************************************;
*************************************  End Change ID1040612 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1041371 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1041371;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1041371")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..REQ_PACKREC_SETTING))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..REQ_PACKREC_SETTING;
%put NOTE: Change ID                             :ID1041371;
%goto ID1041371;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1041371;
%goto ID1041371;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1041371;
* Insert record into change management table for CHANGE_ID: ID1041371;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1041371",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1041371;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_SETTING ADD NUM_VENDOR_PACK_MAX INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_SETTING ADD NUM_TOTAL_PACK_MAX INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
ALTER TABLE REQ_PACKREC_SETTING ADD NUM_VENDOR_PACK_MAX INTEGER;
 
 
ALTER TABLE REQ_PACKREC_SETTING ADD NUM_TOTAL_PACK_MAX INTEGER;
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1041371;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1041371;
%put ERROR- Description                              : Pack Recommendation Settings to support limits on number of;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 13DEC2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1041371;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1041371",
"Pack Recommendation Settings to support limits on number of",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1041371:;
 
 
* End of changes for CHANGE_ID:ID1041371;
 
 
***********************************************************************************************;
*************************************  End Change ID1041371 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1041376 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1041376;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1041376")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1041376;
%goto ID1041376;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1041376;
* Insert record into change management table for CHANGE_ID: ID1041376;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1041376",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1041376;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE PKO_DELIVERY_STORE_COLOR_SS
(
DELIVERY_STORE_COLOR_SS_SK           INTEGER NOT NULL,
DELIVERY_STORE_SK                    INTEGER NOT NULL,
PKO_SIZESET_SK                       INTEGER NOT NULL,
PROD_HIER_SK                         INTEGER NOT NULL,
PRIMARY KEY (DELIVERY_STORE_COLOR_SS_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_DELIVERY_STORE_COLOR_SS_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PKO_NEED_LOCATION_COLOR_SS
(
NEED_LOCATION_COLOR_SS_SK           INTEGER NOT NULL,
PKO_NEED_LOCATION_SK                INTEGER NOT NULL,
PKO_SIZESET_SK                      INTEGER NOT NULL,
PROD_HIER_SK                        INTEGER NOT NULL,
PRIMARY KEY (NEED_LOCATION_COLOR_SS_SK)
)
 
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_NEED_LOCATION_COLOR_SS_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
proc sql;
 
 
 
CREATE TABLE PKO_DELIVERY_STORE_COLOR_SS
(
DELIVERY_STORE_COLOR_SS_SK           INTEGER NOT NULL,
DELIVERY_STORE_SK                    INTEGER NOT NULL,
PKO_SIZESET_SK                       INTEGER NOT NULL,
PROD_HIER_SK                         INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE PKO_DELIVERY_STORE_COLOR_SS  add CONSTRAINT PRIM_KEY
PRIMARY KEY (DELIVERY_STORE_COLOR_SS_SK);
 
 
 
 
CREATE TABLE PKO_NEED_LOCATION_COLOR_SS
(
NEED_LOCATION_COLOR_SS_SK           INTEGER NOT NULL,
PKO_NEED_LOCATION_SK                INTEGER NOT NULL,
PKO_SIZESET_SK                      INTEGER NOT NULL,
PROD_HIER_SK                        INTEGER NOT NULL
)
;
 
 
 
ALTER TABLE PKO_NEED_LOCATION_COLOR_SS  add CONSTRAINT PRIM_KEY
PRIMARY KEY (NEED_LOCATION_COLOR_SS_SK);
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1041376;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1041376;
%put ERROR- Description                              : Specify Size Sets By Style/Color/Store in Import XML;
%put ERROR- Version                                  : M4MICM52;
%put ERROR- Date of Change                           : 15DEC2013;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1041376;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1041376",
"Specify Size Sets By Style/Color/Store in Import XML",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1041376:;
 
 
* End of changes for CHANGE_ID:ID1041376;
 
 
***********************************************************************************************;
*************************************  End Change ID1041376 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1041371_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1041371_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1041371_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1041371_2;
%goto ID1041371_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM52);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1041371_2;
* Insert record into change management table for CHANGE_ID: ID1041371_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1041371_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1041371_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD NUM_DATAMART_PACK_MAX INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD NUM_TOTAL_PACK_MAX INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD NUM_DATAMART_PACK_MAX INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD NUM_TOTAL_PACK_MAX INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PACK_DEFAULT ADD NUM_DATAMART_PACK_MAX INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PACK_DEFAULT ADD NUM_TOTAL_PACK_MAX INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PACK_PRODUCT_SETTING ADD NUM_DATAMART_PACK_MAX INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PACK_PRODUCT_SETTING ADD NUM_TOTAL_PACK_MAX INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PKO_BUY ADD NUM_DATAMART_PACK_MAX INTEGER;
 
 
ALTER TABLE PKO_BUY ADD NUM_TOTAL_PACK_MAX INTEGER;
 
 
 
ALTER TABLE PKO_DELIVERY ADD NUM_DATAMART_PACK_MAX INTEGER;
 
 
ALTER TABLE PKO_DELIVERY ADD NUM_TOTAL_PACK_MAX INTEGER;
 
 
 
ALTER TABLE PKO_PACK_DEFAULT ADD NUM_DATAMART_PACK_MAX INTEGER;
 
 
ALTER TABLE PKO_PACK_DEFAULT ADD NUM_TOTAL_PACK_MAX INTEGER;
 
 
 
ALTER TABLE PKO_PACK_PRODUCT_SETTING ADD NUM_DATAMART_PACK_MAX INTEGER;
 
 
ALTER TABLE PKO_PACK_PRODUCT_SETTING ADD NUM_TOTAL_PACK_MAX INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1041371_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1041371_2;
%put ERROR- Description                              : Recommend a max number of Vendor Packs;
%put ERROR- Version                                  : M4MICM52;
%put ERROR- Date of Change                           : 07JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1041371_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1041371_2",
"Recommend a max number of Vendor Packs",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1041371_2:;
 
 
* End of changes for CHANGE_ID:ID1041371_2;
 
 
***********************************************************************************************;
*************************************  End Change ID1041371_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1044373_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1044373_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1044373_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1044373_2;
%goto ID1044373_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1044373_2;
* Insert record into change management table for CHANGE_ID: ID1044373_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1044373_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1044373_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG where spec_nm='lrm_starting_group_id'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRF_STORE_GROUP ADD STORE_GROUP_TYPE INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PRF_STORE_GROUP set STORE_GROUP_TYPE = 1 where STORE_GROUP_ID < 2000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PRF_STORE_GROUP set STORE_GROUP_TYPE = 4 where STORE_GROUP_ID >= 2000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRF_STORE_GROUP MODIFY STORE_GROUP_TYPE INTEGER NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM PRF_CONFIG where spec_nm='lrm_starting_group_id';
 
 
ALTER TABLE PRF_STORE_GROUP ADD STORE_GROUP_TYPE INTEGER;
 
 
UPDATE PRF_STORE_GROUP set STORE_GROUP_TYPE = 1 where STORE_GROUP_ID < 2000;
 
 
UPDATE PRF_STORE_GROUP set STORE_GROUP_TYPE = 4 where STORE_GROUP_ID >= 2000;
 
 
ALTER TABLE PRF_STORE_GROUP MODIFY STORE_GROUP_TYPE INTEGER NOT NULL;
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1044373_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1044373_2;
%put ERROR- Description                              : Add Store Group Type to PRF_STORE_GROUP.  Migrate old data to populate this column;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 09JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1044373_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1044373_2",
"Add Store Group Type to PRF_STORE_GROUP.  Migrate old data to populate this column",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1044373_2:;
 
 
* End of changes for CHANGE_ID:ID1044373_2;
 
 
***********************************************************************************************;
*************************************  End Change ID1044373_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1035254 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1035254;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1035254")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1035254;
%goto ID1035254;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(F3MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1035254;
* Insert record into change management table for CHANGE_ID: ID1035254;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1035254",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1035254;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=4 and SPEC_NM='mgps_activate_all_sizes'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 4, 'mgps_activate_all_sizes', '0', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK=-1 and PRF_CONFIG_TYPE=4 and SPEC_NM='mgps_activate_all_sizes';
 
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 4, 'mgps_activate_all_sizes', '0', 'INTEGER');
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1035254;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1035254;
%put ERROR- Description                              : Model gp status should consider all unsold sizes active;
%put ERROR- Version                                  : F3MICM521;
%put ERROR- Date of Change                           : 09JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1035254;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1035254",
"Model gp status should consider all unsold sizes active",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1035254:;
 
 
* End of changes for CHANGE_ID:ID1035254;
 
 
***********************************************************************************************;
*************************************  End Change ID1035254 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1040982 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1040982;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1040982")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1040982;
%goto ID1040982;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1040982;
* Insert record into change management table for CHANGE_ID: ID1040982;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1040982",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1040982;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
alter table VEHICLE_CATEGORY add VG_MASTER_TYPE INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table VEHICLE_CATEGORY add SPOTS_NOT_REQ_FLG INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
alter table VEHICLE_CATEGORY add VG_MASTER_TYPE INTEGER;
 
 
alter table VEHICLE_CATEGORY add SPOTS_NOT_REQ_FLG INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1040982;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1040982;
%put ERROR- Description                              : Approvable Vehicles;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 13JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1040982;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1040982",
"Approvable Vehicles",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1040982:;
 
 
* End of changes for CHANGE_ID:ID1040982;
 
 
***********************************************************************************************;
*************************************  End Change ID1040982 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1047279 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1047279;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1047279")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1047279;
%goto ID1047279;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1047279;
* Insert record into change management table for CHANGE_ID: ID1047279;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1047279",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1047279;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
alter table rpp_section add X integer
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpp_section add Y integer
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpp_section add WIDTH integer
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpp_section add HEIGHT integer
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpp_section add COLOR integer
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpp_section add POSITION integer
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table rpp_layout add COLOR integer
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpp_layout add POSITION integer
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table vehicle add COLOR integer
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table vehicle add POSITION integer
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table rpp_vehicle_group add COLOR integer
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table rpp_vg_master add COLOR integer
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
alter table rpp_section add X integer;
 
 
alter table rpp_section add Y integer;
 
 
alter table rpp_section add WIDTH integer;
 
 
alter table rpp_section add HEIGHT integer;
 
 
alter table rpp_section add COLOR integer;
 
 
alter table rpp_section add POSITION integer;
 
 
 
alter table rpp_layout add COLOR integer;
 
 
alter table rpp_layout add POSITION integer;
 
 
 
alter table vehicle add COLOR integer;
 
 
alter table vehicle add POSITION integer;
 
 
 
alter table rpp_vehicle_group add COLOR integer;
 
 
 
alter table rpp_vg_master add COLOR integer;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1047279;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1047279;
%put ERROR- Description                              : Vehicle Group Visual Editor;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 13JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1047279;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1047279",
"Vehicle Group Visual Editor",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1047279:;
 
 
* End of changes for CHANGE_ID:ID1047279;
 
 
***********************************************************************************************;
*************************************  End Change ID1047279 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1035254_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1035254_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1035254_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..PRF_CONFIG))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..PRF_CONFIG;
%put NOTE: Change ID                             :ID1035254_2;
%goto ID1035254_2;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1035254_2;
%goto ID1035254_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1035254_2;
* Insert record into change management table for CHANGE_ID: ID1035254_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1035254_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1035254_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql noprint;
 
 
select SPEC_VALUE into :activate_all_sizes
from &m_di_trans..PRF_CONFIG
where PRF_CONFIG_TYPE=4 and SPEC_NM='mgps_activate_all_sizes';
 
 
 
%if "&activate_all_sizes"="" %then %do;
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 4, 'mgps_activate_all_sizes', '0', 'INTEGER');
 
 
%end;
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
select SPEC_VALUE into :activate_all_sizes
from &m_di_trans..PRF_CONFIG
where PRF_CONFIG_TYPE=4 and SPEC_NM='mgps_activate_all_sizes';
 
 
 
%if "&activate_all_sizes"="" %then %do;
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 4, 'mgps_activate_all_sizes', '0', 'INTEGER');
 
 
%end;
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1035254_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1035254_2;
%put ERROR- Description                              : SIZE PROFILING M4 SCHEMA CHANGE;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 10JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1035254_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1035254_2",
"SIZE PROFILING M4 SCHEMA CHANGE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1035254_2:;
 
 
* End of changes for CHANGE_ID:ID1035254_2;
 
 
***********************************************************************************************;
*************************************  End Change ID1035254_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1044373_3 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1044373_3;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1044373_3")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1044373_3;
%goto ID1044373_3;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1044373_3;
* Insert record into change management table for CHANGE_ID: ID1044373_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1044373_3",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1044373_3;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PRF_RSLT_STORE_CLSF ADD MANUALLY_ASSIGNED_FLG INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PRF_RSLT_STORE_CLSF SET MANUALLY_ASSIGNED_FLG = 0
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PRF_RSLT_STORE_CLSF ADD MANUALLY_ASSIGNED_FLG INTEGER;
 
 
UPDATE PRF_RSLT_STORE_CLSF SET MANUALLY_ASSIGNED_FLG = 0;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1044373_3;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1044373_3;
%put ERROR- Description                              : Add MANUALLY_ASSIGNED_FLG to PRF_RSLT_STORE_CLSF;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 15JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1044373_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1044373_3",
"Add MANUALLY_ASSIGNED_FLG to PRF_RSLT_STORE_CLSF",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1044373_3:;
 
 
* End of changes for CHANGE_ID:ID1044373_3;
 
 
***********************************************************************************************;
*************************************  End Change ID1044373_3 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1048204 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1048204;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1048204")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1048204;
%goto ID1048204;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1048204;
* Insert record into change management table for CHANGE_ID: ID1048204;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1048204",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1048204;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_GP_RECLASS_PURGE_EVENT_SK MINVALUE 1
INCREMENT BY 1 START WITH 100000 CACHE 20 NOORDER NOCYCLE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1048204;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1048204;
%put ERROR- Description                              : Repair Size Profiling data to handle geo-prod delete and reclass;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 15JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1048204;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1048204",
"Repair Size Profiling data to handle geo-prod delete and reclass",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1048204:;
 
 
* End of changes for CHANGE_ID:ID1048204;
 
 
***********************************************************************************************;
*************************************  End Change ID1048204 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1048204_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1048204_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1048204_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1048204_2;
%goto ID1048204_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1048204_2;
* Insert record into change management table for CHANGE_ID: ID1048204_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1048204_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1048204_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
 
%if %sysfunc(exist(&m_di_trans..AUDIT_TRAIL_GP_RECLASS_PURGE)) %then %do;
 
 
Proc sql;
 
 
DROP TABLE AUDIT_TRAIL_GP_RECLASS_PURGE;
 
 
quit;
 
 
%end;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
 
%if %sysfunc(exist(&m_di_trans..AUDIT_TRAIL_GP_RECLASS_PURGE)) %then %do;
 
 
Proc sql;
 
 
DROP TABLE AUDIT_TRAIL_GP_RECLASS_PURGE;
 
 
quit;
 
 
%end;
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1048204_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1048204_2;
%put ERROR- Description                              : Repair Size Profiling data to handle geo-prod delete and reclass;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 15JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1048204_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1048204_2",
"Repair Size Profiling data to handle geo-prod delete and reclass",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1048204_2:;
 
 
* End of changes for CHANGE_ID:ID1048204_2;
 
 
***********************************************************************************************;
*************************************  End Change ID1048204_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1048204_3 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1048204_3;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1048204_3")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1048204_3;
%goto ID1048204_3;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1048204_3;
* Insert record into change management table for CHANGE_ID: ID1048204_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1048204_3",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1048204_3;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE AUDIT_TRAIL_GP_RECLASS_PURGE
(
GP_RECLASS_PURGE_EVENT_SK  INTEGER NOT NULL,
CONTEXT_NM                 VARCHAR(32),
CONTEXT_SK                 INTEGER ,
IMPACT                     VARCHAR(32),
ACTION                     VARCHAR(32),
PARENT_CONTEXT_NM          VARCHAR(32) ,
PARENT_CONTEXT_SK          INTEGER ,
CREATED_DTTM               DATE NOT NULL,
COMMENT_TEXT               VARCHAR(2048)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE INDEX AUDIT_TRAIL_GP_RP_IX ON AUDIT_TRAIL_GP_RECLASS_PURGE
(
GP_RECLASS_PURGE_EVENT_SK, CONTEXT_NM
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
CREATE TABLE AUDIT_TRAIL_GP_RECLASS_PURGE
(
GP_RECLASS_PURGE_EVENT_SK  INTEGER NOT NULL,
CONTEXT_NM                 VARCHAR(32) ,
CONTEXT_SK                 INTEGER ,
IMPACT                     VARCHAR(32),
ACTION                     VARCHAR(32),
PARENT_CONTEXT_NM          VARCHAR(32) ,
PARENT_CONTEXT_SK          INTEGER,
CREATED_DTTM               DATE NOT NULL,
COMMENT_TEXT               VARCHAR(2048)
);
 
 
 
 
CREATE INDEX AUDIT_TRAIL_GP_RP_IX ON AUDIT_TRAIL_GP_RECLASS_PURGE
(
GP_RECLASS_PURGE_EVENT_SK, CONTEXT_NM
);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1048204_3;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1048204_3;
%put ERROR- Description                              : Repair Size Profiling data to handle geo-prod delete and reclass;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 15JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1048204_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1048204_3",
"Repair Size Profiling data to handle geo-prod delete and reclass",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1048204_3:;
 
 
* End of changes for CHANGE_ID:ID1048204_3;
 
 
***********************************************************************************************;
*************************************  End Change ID1048204_3 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1043886_DROP ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1043886_DROP;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1043886_DROP")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if not (%sysfunc(exist(&m_di_trans..RPP_APPROVED_ASGMNT))) %then
%do;
%put NOTE: Skip this change since this table does not exist: &m_di_trans..RPP_APPROVED_ASGMNT;
%put NOTE: Change ID                             :ID1043886_DROP;
%goto ID1043886_DROP;
 
%end;
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1043886_DROP;
%goto ID1043886_DROP;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1043886_DROP;
* Insert record into change management table for CHANGE_ID: ID1043886_DROP;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1043886_DROP",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1043886_DROP;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DROP TABLE RPP_APPROVED_ASGMNT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM TABLE_META WHERE TABLE_NAME = 'RPP_APPROVED_ASGMNT'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DROP TABLE RPP_APPROVED_ASGMNT;
 
 
 
DELETE FROM TABLE_META WHERE TABLE_NAME = 'RPP_APPROVED_ASGMNT';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1043886_DROP;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1043886_DROP;
%put ERROR- Description                              : DROP Table RPP_APPROVED_ASGMNT;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 14JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1043886_DROP;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1043886_DROP",
"DROP Table RPP_APPROVED_ASGMNT",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1043886_DROP:;
 
 
* End of changes for CHANGE_ID:ID1043886_DROP;
 
 
***********************************************************************************************;
*************************************  End Change ID1043886_DROP ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1044373_4 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1044373_4;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1044373_4")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1044373_4;
%goto ID1044373_4;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1044373_4;
* Insert record into change management table for CHANGE_ID: ID1044373_4;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1044373_4",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1044373_4;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PRF_RSLT_STORE_CLSF ADD ASSIGNMENT_TYPE INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PRF_RSLT_STORE_CLSF SET ASSIGNMENT_TYPE = 2
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PRF_RSLT_STORE_CLSF SET ASSIGNMENT_TYPE = 1 WHERE STORE_GROUP_ID IS NOT NULL
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PRF_RSLT_STORE_CLSF SET ASSIGNMENT_TYPE = 3 WHERE MANUALLY_ASSIGNED_FLG = 1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRF_RSLT_STORE_CLSF DROP COLUMN MANUALLY_ASSIGNED_FLG
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PRF_RSLT_STORE_CLSF ADD ASSIGNMENT_TYPE INTEGER;
 
 
UPDATE PRF_RSLT_STORE_CLSF SET ASSIGNMENT_TYPE = 2;
 
 
UPDATE PRF_RSLT_STORE_CLSF SET ASSIGNMENT_TYPE = 1 WHERE STORE_GROUP_ID IS NOT NULL;
 
 
UPDATE PRF_RSLT_STORE_CLSF SET ASSIGNMENT_TYPE = 3 WHERE MANUALLY_ASSIGNED_FLG = 1;
 
 
ALTER TABLE PRF_RSLT_STORE_CLSF DROP COLUMN MANUALLY_ASSIGNED_FLG;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1044373_4;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1044373_4;
%put ERROR- Description                              : Add MANUALLY_ASSIGNED_FLG to PRF_RSLT_STORE_CLSF;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 16JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1044373_4;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1044373_4",
"Add MANUALLY_ASSIGNED_FLG to PRF_RSLT_STORE_CLSF",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1044373_4:;
 
 
* End of changes for CHANGE_ID:ID1044373_4;
 
 
***********************************************************************************************;
*************************************  End Change ID1044373_4 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1047279_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1047279_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1047279_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1047279_2;
%goto ID1047279_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1047279_2;
* Insert record into change management table for CHANGE_ID: ID1047279_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1047279_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1047279_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
alter table VEHICLE rename column POSITION to POS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table RPP_LAYOUT rename column POSITION to POS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table RPP_SECTION rename column POSITION to POS
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc datasets library=&m_di_trans nolist;
 
 
modify VEHICLE ;
 
 
rename POSITION=POS;
 
 
quit;
 
 
proc datasets library=&m_di_trans nolist;
 
 
modify RPP_LAYOUT ;
 
 
rename POSITION=POS;
 
 
quit;
 
 
proc datasets library=&m_di_trans nolist;
 
 
modify RPP_SECTION ;
 
 
rename POSITION=POS;
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1047279_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1047279_2;
%put ERROR- Description                              : Vehicle Group Visual Editor - changing to avoid FEDsql reserved keyword;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 13JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1047279_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1047279_2",
"Vehicle Group Visual Editor - changing to avoid FEDsql reserved keyword",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1047279_2:;
 
 
* End of changes for CHANGE_ID:ID1047279_2;
 
 
***********************************************************************************************;
*************************************  End Change ID1047279_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1049544_C ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1049544_C;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1049544_C")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1049544_C;
%goto ID1049544_C;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1049544_C;
* Insert record into change management table for CHANGE_ID: ID1049544_C;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1049544_C",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1049544_C;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'PRF_INVENTORY_FACT';
 
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,
ETL_STG2DM,SORT_ORDER) VALUES
('PRF_INVENTORY_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK');
 
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'PRF_INVENTORY_FACT_META';
 
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,
ETL_STG2DM,SORT_ORDER) VALUES
('PRF_INVENTORY_FACT_META',0,0,0,.,'');
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'PRF_INVENTORY_FACT';
 
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,
ETL_STG2DM,SORT_ORDER) VALUES
('PRF_INVENTORY_FACT',0,1,0,1,'PROD_HIER_SK GEO_HIER_SK DATE_SK');
 
 
 
delete from TABLE_PARTITION_META where TABLE_NM = 'PRF_INVENTORY_FACT_META';
 
 
 
INSERT INTO TABLE_PARTITION_META (TABLE_NM,FULL_COPY_FLG,PARTITION_FLG,ESTIMATION_FLG,
ETL_STG2DM,SORT_ORDER) VALUES
('PRF_INVENTORY_FACT_META',0,0,0,.,'');
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1049544_C;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1049544_C;
%put ERROR- Description                              : Adding new row for Prf_inventory_fact table in table_partition_meta.;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 20JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1049544_C;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1049544_C",
"Adding new row for Prf_inventory_fact table in table_partition_meta.",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1049544_C:;
 
 
* End of changes for CHANGE_ID:ID1049544_C;
 
 
***********************************************************************************************;
*************************************  End Change ID1049544_C ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1049105 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1049105;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1049105")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1049105;
%goto ID1049105;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1049105;
* Insert record into change management table for CHANGE_ID: ID1049105;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1049105",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1049105;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE PRF_GEO_PROD_STATUS_SPEC
(
PROD_HIER_SK INTEGER NOT NULL,
SPEC_NM VARCHAR2(32) NOT NULL,
SPEC_VALUE VARCHAR2(32),
CREATED_DTTM DATE,
CREATED_BY VARCHAR2(20),
PRIMARY KEY (PROD_HIER_SK, SPEC_NM)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DELETE FROM PRF_GEO_PROD_STATUS_SPEC WHERE SPEC_NM = 'MAX_ACTIVE_STOCKOUT_WEEKS'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_GEO_PROD_STATUS_SPEC VALUES( 1 ,'MAX_ACTIVE_STOCKOUT_WEEKS', '52', '' , 'ETL - Seeded')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
CREATE TABLE PRF_GEO_PROD_STATUS_SPEC
(
PROD_HIER_SK INTEGER NOT NULL,
SPEC_NM VARCHAR(32) NOT NULL,
SPEC_VALUE VARCHAR(32),
CREATED_DTTM DATE,
CREATED_BY VARCHAR(20)
);
 
 
 
ALTER TABLE PRF_GEO_PROD_STATUS_SPEC  add CONSTRAINT PRIM_KEY
PRIMARY KEY (PROD_HIER_SK, SPEC_NM);
 
 
 
DELETE FROM PRF_GEO_PROD_STATUS_SPEC WHERE SPEC_NM = 'MAX_ACTIVE_STOCKOUT_WEEKS';
 
 
 
INSERT INTO PRF_GEO_PROD_STATUS_SPEC VALUES( 1 ,'MAX_ACTIVE_STOCKOUT_WEEKS', '52', %sysfunc(datetime()), 'ETL - Seeded');
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1049105;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1049105;
%put ERROR- Description                              : Derive Prf_stockout_fact and Prf_geo_prod_status from Prf_inventory_fact;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 20JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1049105;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1049105",
"Derive Prf_stockout_fact and Prf_geo_prod_status from Prf_inventory_fact",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1049105:;
 
 
* End of changes for CHANGE_ID:ID1049105;
 
 
***********************************************************************************************;
*************************************  End Change ID1049105 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1051023 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1051023;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1051023")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1051023;
%goto ID1051023;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1051023;
* Insert record into change management table for CHANGE_ID: ID1051023;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1051023",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1051023;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PRF_SG_RULE_BASE ADD DELETE_FLG INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE PRF_SG_RULE_BASE SET DELETE_FLG = 0
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE PRF_SG_RULE_BASE ADD DELETE_FLG INTEGER;
 
 
UPDATE PRF_SG_RULE_BASE SET DELETE_FLG = 0;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1051023;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1051023;
%put ERROR- Description                              : Support marking a store group rule as deleted;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 24JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1051023;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1051023",
"Support marking a store group rule as deleted",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1051023:;
 
 
* End of changes for CHANGE_ID:ID1051023;
 
 
***********************************************************************************************;
*************************************  End Change ID1051023 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1050802 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1050802;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1050802")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1050802;
%goto ID1050802;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1050802;
* Insert record into change management table for CHANGE_ID: ID1050802;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1050802",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1050802;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 1, 'min_sizeset_products', '0', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 1, 'min_sizeset_sales_units', '0', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 1, 'min_sizeset_sales_amt', '0.00', 'DOUBLE')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PRF_EFFECTIVE_SIZESET_ATTR
(
PROFILING_PROJECT_SK INTEGER NOT NULL,
GEO_ATTR_SK INTEGER NOT NULL,
GEO_ATTR_VALUE VARCHAR(40) NOT NULL,
PRIMARY KEY (PROFILING_PROJECT_SK, GEO_ATTR_SK, GEO_ATTR_VALUE)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
INSERT INTO &m_di_trans..PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 1, 'min_sizeset_products', '0', 'INTEGER');
 
 
 
INSERT INTO &m_di_trans..PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 1, 'min_sizeset_sales_units', '0', 'INTEGER');
 
 
 
INSERT INTO &m_di_trans..PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 1, 'min_sizeset_sales_amt', '0.00', 'DOUBLE');
 
 
 
CREATE TABLE &m_di_trans..PRF_EFFECTIVE_SIZESET_ATTR
(
PROFILING_PROJECT_SK INTEGER NOT NULL,
GEO_ATTR_SK INTEGER NOT NULL,
GEO_ATTR_VALUE VARCHAR(40) NOT NULL
);
 
 
 
ALTER TABLE &m_di_trans..PRF_EFFECTIVE_SIZESET_ATTR
ADD CONSTRAINT PRIM_KEY PRIMARY KEY (PROFILING_PROJECT_SK, GEO_ATTR_SK, GEO_ATTR_VALUE);
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1050802;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1050802;
%put ERROR- Description                              : Schema changes for Detect Effective Size Sets;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 28JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1050802;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1050802",
"Schema changes for Detect Effective Size Sets",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1050802:;
 
 
* End of changes for CHANGE_ID:ID1050802;
 
 
***********************************************************************************************;
*************************************  End Change ID1050802 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1050802_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1050802_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1050802_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1050802_2;
%goto ID1050802_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1050802_2;
* Insert record into change management table for CHANGE_ID: ID1050802_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1050802_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1050802_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE PRF_CONFIG set SPEC_TYPE='INTEGER' where SPEC_NM='min_sizeset_sales_amt'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
UPDATE PRF_CONFIG set SPEC_TYPE='INTEGER' where SPEC_NM='min_sizeset_sales_amt';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1050802_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1050802_2;
%put ERROR- Description                              : Schema changes for Detect Effective Size Sets -- fix datatype;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 31JAN2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1050802_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1050802_2",
"Schema changes for Detect Effective Size Sets -- fix datatype",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1050802_2:;
 
 
* End of changes for CHANGE_ID:ID1050802_2;
 
 
***********************************************************************************************;
*************************************  End Change ID1050802_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1050802_3 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1050802_3;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1050802_3")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1050802_3;
%goto ID1050802_3;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1050802_3;
* Insert record into change management table for CHANGE_ID: ID1050802_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1050802_3",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1050802_3;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE PRF_CONFIG set SPEC_TYPE='INTEGER', SPEC_VALUE='0' where SPEC_NM='min_sizeset_sales_amt'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
UPDATE PRF_CONFIG set SPEC_TYPE='INTEGER', SPEC_VALUE='0' where SPEC_NM='min_sizeset_sales_amt';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1050802_3;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1050802_3;
%put ERROR- Description                              : Schema changes for Detect Effective Size Sets -- fix SPEC_VALUE;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 03Feb2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1050802_3;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1050802_3",
"Schema changes for Detect Effective Size Sets -- fix SPEC_VALUE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1050802_3:;
 
 
* End of changes for CHANGE_ID:ID1050802_3;
 
 
***********************************************************************************************;
*************************************  End Change ID1050802_3 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change IDS1037633 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: IDS1037633;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("IDS1037633")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : IDS1037633;
%goto IDS1037633;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : IDS1037633;
* Insert record into change management table for CHANGE_ID: IDS1037633;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"IDS1037633",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto IDS1037633;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
create index geo_prod_rpp_ix1 on geo_prod_rpp (PLAN_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
create index PLAN_SK on geo_prod_rpp (PLAN_SK);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: IDS1037633;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: IDS1037633;
%put ERROR- Description                              : Add needed index to GEO_PROD_RPP;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 05Feb2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: IDS1037633;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"IDS1037633",
"Add needed index to GEO_PROD_RPP",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%IDS1037633:;
 
 
* End of changes for CHANGE_ID:IDS1037633;
 
 
***********************************************************************************************;
*************************************  End Change IDS1037633 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1049105_B ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1049105_B;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1049105_B")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1049105_B;
%goto ID1049105_B;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1049105_B;
* Insert record into change management table for CHANGE_ID: ID1049105_B;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1049105_B",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1049105_B;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc datasets library=di_trans nolist;
 
 
modify  PRF_GEO_PROD_STATUS_SPEC;
 
 
informat CREATED_DTTM &m_DTTMFMT. ;
 
 
format CREATED_DTTM &m_DTTMFMT.;
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1049105_B;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1049105_B;
%put ERROR- Description                              : Modify format for CREATED_DTTM field in PRF_GEO_PROD_STATUS_SPEC;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 06Feb2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1049105_B;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1049105_B",
"Modify format for CREATED_DTTM field in PRF_GEO_PROD_STATUS_SPEC",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1049105_B:;
 
 
* End of changes for CHANGE_ID:ID1049105_B;
 
 
***********************************************************************************************;
*************************************  End Change ID1049105_B ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1055613 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1055613;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1055613")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1055613;
%goto ID1055613;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1055613;
* Insert record into change management table for CHANGE_ID: ID1055613;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1055613",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1055613;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
proc sql;
 
 
update table_partition_meta
set SORT_ORDER="PROD_HIER_SK GEO_HIER_SK VALID_FROM_DT"
where table_nm="PRF_GEO_PROD_STATUS"
and SORT_ORDER="PROD_HIER_SK GEO_HIER_SK STATUS_VALID_FROM_DT"
;
 
 
quit;
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
update table_partition_meta
set SORT_ORDER="PROD_HIER_SK GEO_HIER_SK VALID_FROM_DT"
where table_nm="PRF_GEO_PROD_STATUS"
and SORT_ORDER="PROD_HIER_SK GEO_HIER_SK STATUS_VALID_FROM_DT"
;
 
 
quit;
 
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1055613;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1055613;
%put ERROR- Description                              : Sort_order in table_partition_meta is incorrect for PRF_GEO_PROD_STATUS_SPEC;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 06Feb2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1055613;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1055613",
"Sort_order in table_partition_meta is incorrect for PRF_GEO_PROD_STATUS_SPEC",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1055613:;
 
 
* End of changes for CHANGE_ID:ID1055613;
 
 
***********************************************************************************************;
*************************************  End Change ID1055613 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1027463_B ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1027463_B;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1027463_B")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1027463_B;
%goto ID1027463_B;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1027463_B;
* Insert record into change management table for CHANGE_ID: ID1027463_B;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1027463_B",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1027463_B;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
update TABLE_PARTITION_META
set partition_flg = 1,
full_copy_flg = 0
where table_nm in ('GEO_PROD','GEO_PROD_STATUS');
 
 
quit;
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
update TABLE_PARTITION_META
set partition_flg = 1,
full_copy_flg = 0
where table_nm in ('GEO_PROD','GEO_PROD_STATUS');
 
 
quit;
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1027463_B;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1027463_B;
%put ERROR- Description                              : FULL_COPY_FLG in TABLE_PARTITION_META set to 1 GEO_PROD and GEO_PROD_STATUS;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 10Feb2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1027463_B;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1027463_B",
"FULL_COPY_FLG in TABLE_PARTITION_META set to 1 GEO_PROD and GEO_PROD_STATUS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1027463_B:;
 
 
* End of changes for CHANGE_ID:ID1027463_B;
 
 
***********************************************************************************************;
*************************************  End Change ID1027463_B ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1057063 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1057063;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1057063")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1057063;
%goto ID1057063;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1057063;
* Insert record into change management table for CHANGE_ID: ID1057063;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1057063",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1057063;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE MODEL_GROUP_EST_STATUS
(
MODEL_GROUP_ID INTEGER NOT NULL,
EST_STATUS_CD INTEGER NOT NULL,
PRIMARY KEY (MODEL_GROUP_ID)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
CREATE TABLE MODEL_GROUP_EST_STATUS
(
MODEL_GROUP_ID INTEGER NOT NULL,
EST_STATUS_CD INTEGER NOT NULL
);
 
 
 
ALTER TABLE MODEL_GROUP_EST_STATUS
ADD CONSTRAINT PRIM_KEY PRIMARY KEY (MODEL_GROUP_ID);
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1057063;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1057063;
%put ERROR- Description                              : New table to store model group estimation status codes;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 11FEB2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1057063;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1057063",
"New table to store model group estimation status codes",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1057063:;
 
 
* End of changes for CHANGE_ID:ID1057063;
 
 
***********************************************************************************************;
*************************************  End Change ID1057063 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1058899 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1058899;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1058899")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1058899;
%goto ID1058899;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(M4MICM521);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1058899;
* Insert record into change management table for CHANGE_ID: ID1058899;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1058899",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1058899;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK = -1 and spec_nm='max_projects_to_apply_rule'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'max_projects_to_apply_rule', '1', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK = -1 and spec_nm='max_projects_to_apply_rule';
 
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'max_projects_to_apply_rule', '1', 'INTEGER');
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1058899;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1058899;
%put ERROR- Description                              : Need to insert the default PRF_CONFIG entry for max_projects_to_apply_rule;
%put ERROR- Version                                  : M4MICM521;
%put ERROR- Date of Change                           : 18FEB2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1058899;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1058899",
"Need to insert the default PRF_CONFIG entry for max_projects_to_apply_rule",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1058899:;
 
 
* End of changes for CHANGE_ID:ID1058899;
 
 
***********************************************************************************************;
*************************************  End Change ID1058899 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change IDS1093081 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: IDS1093081;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("IDS1093081")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : IDS1093081;
%goto IDS1093081;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : IDS1093081;
* Insert record into change management table for CHANGE_ID: IDS1093081;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"IDS1093081",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto IDS1093081;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE rpp_plan_results
(
prod_hier_sk             INTEGER NOT NULL,
geo_hier_sk              INTEGER NOT NULL,
start_dt                 DATE NOT NULL,
end_dt                   DATE NOT NULL,
kpi_type                 INTEGER NOT NULL,
object_sk                INTEGER DEFAULT 0 NOT NULL,
status                   INTEGER NOT NULL,
sales_amt                NUMERIC(20, 3),
units                    NUMERIC(12, 2),
gm_pct                   NUMERIC(12, 4),
gm_amt                   NUMERIC(20, 3),
promo_markdn_amt         NUMERIC(20, 3),
promo_blend_pct          NUMERIC(12, 4),
close_inv_units          NUMERIC(20, 3),
close_inv_val_retail_amt NUMERIC(20, 3),
n_promo_items            NUMERIC(12, 2),
forecast_override        NUMERIC(20, 3)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE rpp_plan_results
ADD CONSTRAINT rpp_plan_results_pk
PRIMARY KEY (prod_hier_sk, geo_hier_sk, start_dt, end_dt, kpi_type, object_sk)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE rpp_message_details
(
rpp_message_details_sk     INTEGER NOT NULL,
start_dt                   DATE NOT NULL,
end_dt                     DATE NOT NULL,
prod_hier_sk               INTEGER NOT NULL,
geo_hier_sk                INTEGER NOT NULL,
message_sk                 INTEGER NOT NULL,
attr1                      VARCHAR(40),
attr2                      VARCHAR(40),
attr3                      VARCHAR(40),
attr4                      VARCHAR(40),
attr5                      VARCHAR(40)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE rpp_message_details
ADD CONSTRAINT rpp_message_details_pk PRIMARY KEY (rpp_message_details_sk)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE seq_rpp_message_details_sk
START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE INDEX rpp_message_details_ix2
ON rpp_message_details(start_dt, end_dt, prod_hier_sk, geo_hier_sk)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE rpp_batch_eval_rules
(
prod_hier_sk           INTEGER NOT NULL,
geo_hier_sk            INTEGER NOT NULL,
start_offset           INTEGER NOT NULL,
end_offset             INTEGER NOT NULL
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE rpp_batch_eval_rules
ADD CONSTRAINT rpp_batch_eval_rules_pk PRIMARY KEY (prod_hier_sk, geo_hier_sk, start_offset)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE rpp_process_status
(
rpp_process_sk         INTEGER NOT NULL,
start_dt               DATE NOT NULL,
end_dt                 DATE NOT NULL,
created_dttm           TIMESTAMP NOT NULL,
submitted_dttm         TIMESTAMP
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE rpp_process_status
ADD CONSTRAINT rpp_process_status_pk PRIMARY KEY (rpp_process_sk)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE seq_rpp_process_pk
START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE rpp_process_prod (
rpp_process_sk       INTEGER NOT NULL,
prod_hier_sk         INTEGER NOT NULL
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE rpp_process_prod
ADD CONSTRAINT rpp_process_prod_pk PRIMARY KEY (rpp_process_sk, prod_hier_sk)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE rpp_process_geo (
rpp_process_sk       INTEGER NOT NULL,
geo_hier_sk          INTEGER NOT NULL
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE rpp_process_geo
ADD CONSTRAINT rpp_process_geo_pk PRIMARY KEY (rpp_process_sk, geo_hier_sk)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
CREATE TABLE rpp_plan_results
(
prod_hier_sk             INTEGER NOT NULL,
geo_hier_sk              INTEGER NOT NULL,
start_dt                 DATE NOT NULL,
end_dt                   DATE NOT NULL,
kpi_type                 INTEGER NOT NULL,
object_sk                INTEGER NOT NULL,
status                   INTEGER NOT NULL,
sales_amt                NUMERIC(20, 3),
units                    NUMERIC(12, 2),
gm_pct                   NUMERIC(12, 4),
gm_amt                   NUMERIC(20, 3),
promo_markdn_amt         NUMERIC(20, 3),
promo_blend_pct          NUMERIC(12, 4),
close_inv_units          NUMERIC(20, 3),
close_inv_val_retail_amt NUMERIC(20, 3),
n_promo_items            NUMERIC(12, 2),
forecast_override        NUMERIC(20, 3)
);
 
 
ALTER TABLE rpp_plan_results
ADD CONSTRAINT rpp_plan_results_pk
PRIMARY KEY (prod_hier_sk, geo_hier_sk, start_dt, end_dt, kpi_type, object_sk);
 
 
 
CREATE TABLE rpp_message_details
(
rpp_message_details_sk     INTEGER NOT NULL,
start_dt                   DATE NOT NULL,
end_dt                     DATE NOT NULL,
prod_hier_sk               INTEGER NOT NULL,
geo_hier_sk                INTEGER NOT NULL,
message_sk                 INTEGER NOT NULL,
attr1                      VARCHAR(40),
attr2                      VARCHAR(40),
attr3                      VARCHAR(40),
attr4                      VARCHAR(40),
attr5                      VARCHAR(40)
);
 
 
ALTER TABLE rpp_message_details
ADD CONSTRAINT rpp_message_details_pk PRIMARY KEY (rpp_message_details_sk);
 
 
 
CREATE INDEX rpp_message_details_ix2
ON rpp_message_details(start_dt, end_dt, prod_hier_sk, geo_hier_sk);
 
 
 
 
CREATE TABLE rpp_batch_eval_rules
(
prod_hier_sk           INTEGER NOT NULL,
geo_hier_sk            INTEGER NOT NULL,
start_offset           INTEGER NOT NULL,
end_offset             INTEGER NOT NULL
);
 
 
ALTER TABLE rpp_batch_eval_rules
ADD CONSTRAINT rpp_batch_eval_rules_pk PRIMARY KEY (prod_hier_sk, geo_hier_sk, start_offset);
 
 
 
 
CREATE TABLE rpp_process_status
(
rpp_process_sk         INTEGER NOT NULL,
start_dt               DATE NOT NULL,
end_dt                 DATE NOT NULL,
created_dttm           DATE NOT NULL,
submitted_dttm         DATE
);
 
 
 
ALTER TABLE rpp_process_status
ADD CONSTRAINT rpp_process_status_pk PRIMARY KEY (rpp_process_sk);
 
 
 
 
CREATE TABLE rpp_process_prod (
rpp_process_sk       INTEGER NOT NULL,
prod_hier_sk         INTEGER NOT NULL
);
 
 
 
ALTER TABLE rpp_process_prod
ADD CONSTRAINT rpp_process_prod_pk PRIMARY KEY (rpp_process_sk, prod_hier_sk);
 
 
 
 
CREATE TABLE rpp_process_geo (
rpp_process_sk       INTEGER NOT NULL,
geo_hier_sk          INTEGER NOT NULL
);
 
 
 
ALTER TABLE rpp_process_geo
ADD CONSTRAINT rpp_process_geo_pk PRIMARY KEY (rpp_process_sk, geo_hier_sk);
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: IDS1093081;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: IDS1093081;
%put ERROR- Description                              : Database Schema Changes to support Common Metrics;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 23Jun2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: IDS1093081;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"IDS1093081",
"Database Schema Changes to support Common Metrics",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%IDS1093081:;
 
 
* End of changes for CHANGE_ID:IDS1093081;
 
 
***********************************************************************************************;
*************************************  End Change IDS1093081 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change IDS1093081_2 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: IDS1093081_2;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("IDS1093081_2")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : IDS1093081_2;
%goto IDS1093081_2;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : IDS1093081_2;
* Insert record into change management table for CHANGE_ID: IDS1093081_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"IDS1093081_2",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto IDS1093081_2;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
alter table
RPP_PLAN
drop column
EVAL_OPT_RESULT_CD
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table
RPP_PLAN
drop column
EVAL_OPT_PROCESS_CD
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table
CATEGORY_PLAN
drop column
EVAL_OPT_RESULT_CD
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table
CATEGORY_PLAN
drop column
EVAL_OPT_PROCESS_CD
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table
RPP_PLAN
add
(
EVAL_OPT_PROCESS_CD INTEGER,
EVAL_OPT_RESULT_CD INTEGER
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table
CATEGORY_PLAN
add
(
EVAL_OPT_PROCESS_CD INTEGER,
EVAL_OPT_RESULT_CD INTEGER
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
drop table rpp_plan;
 
 
 
CREATE TABLE RPP_PLAN
(
PLAN_SK                            INTEGER NOT NULL,
PLAN_ID                            VARCHAR(32),
ACTIVE_PLAN_SK                     INTEGER,
PLAN_TYPE                          INTEGER NOT NULL,
PLAN_NM                            VARCHAR(100) NOT NULL,
START_DT                           DATE      FORMAT=&DTFMT    INFORMAT=&DTFMT   NOT NULL,
END_DT                             DATE      FORMAT=&DTFMT    INFORMAT=&DTFMT  ,
NOTES                              VARCHAR(255),
SCOPE_SK                           INTEGER NOT NULL,
PLAN_DESC                          VARCHAR(100),
EVAL_OPT_REQ_CD                    INTEGER NOT NULL,
EVAL_OPT_RESULT_CD                 INTEGER NOT NULL,
EVAL_OPT_PROCESS_CD                INTEGER NOT NULL,
FCST_UNITS_ADJUST                  NUMERIC(20,3),
APP_USER_SK                        INTEGER,
STATUS_CD                          INTEGER NOT NULL,
DUE_DT                             DATE      FORMAT=&DTFMT    INFORMAT=&DTFMT  ,
OBJECTIVE_CD                       INTEGER,
OBJECTIVE_SK                       INTEGER,
STATE_SERVICE_TOKEN_SK             INTEGER,
CREATED_DTTM                       DATE      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT   NOT NULL,
UPDATED_DTTM                       DATE      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT   NOT NULL,
EVAL_OPT_RESULT_DTTM               DATE      FORMAT=&DTTMFMT    INFORMAT=&DTTMFMT  ,
APPROVAL_STATUS_USER_SK            INTEGER,
CONTEXT_SK                         INTEGER
)
;
 
 
 
ALTER TABLE RPP_PLAN  add CONSTRAINT PRIM_KEY  PRIMARY KEY (PLAN_SK);
 
 
 
CREATE INDEX SCOPE_SK ON RPP_PLAN
(
SCOPE_SK
)
;
 
 
 
ALTER TABLE RPP_PLAN ADD ACTION_RESULT_DTTM DATE FORMAT NLDATM21. INFORMAT NLDATM21.;
 
 
ALTER TABLE RPP_PLAN ADD ACTION_CONTEXT_SK INTEGER;
 
 
ALTER TABLE RPP_PLAN ADD ACTION_NM VARCHAR(40) ;
 
 
ALTER TABLE RPP_PLAN ADD ACTION_PROCESS_CD INTEGER;
 
 
 
ALTER TABLE RPP_PLAN ADD FCST_UNITS_ADJUST_TYPE INTEGER;
 
 
 
ALTER TABLE RPP_PLAN      ADD PARENT_PROCESS_SK INTEGER;
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: IDS1093081_2;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: IDS1093081_2;
%put ERROR- Description                              : Database Schema Changes to support Common Metrics;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 16Jul2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: IDS1093081_2;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"IDS1093081_2",
"Database Schema Changes to support Common Metrics",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%IDS1093081_2:;
 
 
* End of changes for CHANGE_ID:IDS1093081_2;
 
 
***********************************************************************************************;
*************************************  End Change IDS1093081_2 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1108027 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1108027;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1108027")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1108027;
%goto ID1108027;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1108027;
* Insert record into change management table for CHANGE_ID: ID1108027;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1108027",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1108027;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='RPO_GEO_PROD_AGG';
 
 
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt,num_days_preserved ,partition_flg ,app_nm)
VALUES ('RPO_GEO_PROD_AGG','RDBMS', 2, 30,'%di_purge_rpo_geo_prod_agg(libref=di_trans);',921, 0, 'RPO');
 
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='RPO_GEO_PROD_AGG';
 
 
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt,num_days_preserved ,partition_flg ,app_nm)
VALUES ('RPO_GEO_PROD_AGG','RDBMS', 2, 30,'%di_purge_rpo_geo_prod_agg(libref=di_trans);',921, 0, 'RPO');
 
 
 
quit;
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1108027;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1108027;
%put ERROR- Description                              : RPO_GEO_PROD_AGG entry missing from PURGE_QUERY table;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 21AUG2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1108027;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1108027",
"RPO_GEO_PROD_AGG entry missing from PURGE_QUERY table",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1108027:;
 
 
* End of changes for CHANGE_ID:ID1108027;
 
 
***********************************************************************************************;
*************************************  End Change ID1108027 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1111746 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1111746;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1111746")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1111746;
%goto ID1111746;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1111746;
* Insert record into change management table for CHANGE_ID: ID1111746;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1111746",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1111746;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE PKO_SUPPRESS_MESSAGE
(
MESSAGE_SK  INTEGER NOT NULL,
PRIMARY KEY (MESSAGE_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (160)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (161)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (162)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (163)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (164)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (165)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (183)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (169)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (170)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (171)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (172)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (182)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (482)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (174)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (175)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (176)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (444)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (446)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (447)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (455)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (456)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (463)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (464)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (480)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (494)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (497)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (498)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (500)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (516)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (518)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (527)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (533)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (560)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (572)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (577)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (594)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (606)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (615)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (623)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (626)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (644)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (645)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (646)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (647)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (655)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (656)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (657)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (658)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (670)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (671)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (680)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
CREATE TABLE PKO_SUPPRESS_MESSAGE
( MESSAGE_SK  INTEGER NOT NULL
);
 
 
ALTER TABLE PKO_SUPPRESS_MESSAGE add CONSTRAINT PRIM_KEY  PRIMARY KEY (MESSAGE_SK);
 
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (160);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (161);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (162);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (163);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (164);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (165);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (183);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (169);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (170);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (171);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (172);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (182);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (482);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (174);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (175);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (176);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (444);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (446);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (447);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (455);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (456);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (463);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (464);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (480);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (494);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (497);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (498);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (500);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (516);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (518);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (527);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (533);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (560);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (572);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (577);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (594);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (606);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (615);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (623);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (626);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (644);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (645);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (646);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (647);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (655);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (656);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (657);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (658);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (670);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (671);
 
 
INSERT INTO PKO_SUPPRESS_MESSAGE (MESSAGE_SK) VALUES (680);
 
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1111746;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1111746;
%put ERROR- Description                              : Schema Change for Packopt: Messages Keys to Suppress from UI;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 01SEP2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1111746;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1111746",
"Schema Change for Packopt: Messages Keys to Suppress from UI",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1111746:;
 
 
* End of changes for CHANGE_ID:ID1111746;
 
 
***********************************************************************************************;
*************************************  End Change ID1111746 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1100541 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1100541;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1100541")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1100541;
%goto ID1100541;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1100541;
* Insert record into change management table for CHANGE_ID: ID1100541;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1100541",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1100541;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
alter table rpo_plan_member_agg add EXP_COMP_AUR_PRICE_MIN NUMBER(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpo_plan_member_agg add EXP_COMP_AUR_PRICE_MAX NUMBER(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpo_plan_member_agg add BASE_COMP_AUR_PRICE_MIN NUMBER(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpo_plan_member_agg add BASE_COMP_AUR_PRICE_MAX NUMBER(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table rpo_plan_member_agg add BASE_AVG_UNIT_RETAIL_PRICE_MIN NUMBER(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpo_plan_member_agg add BASE_AVG_UNIT_RETAIL_PRICE_MAX NUMBER(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpo_plan_member_agg add EXP_AVG_UNIT_RETAIL_PRICE_MIN NUMBER(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpo_plan_member_agg add EXP_AVG_UNIT_RETAIL_PRICE_MAX NUMBER(20,3)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
alter table rpo_plan_member_agg add BASE_COMP_PRICE_INDEX_MIN NUMBER(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpo_plan_member_agg add BASE_COMP_PRICE_INDEX_MAX NUMBER(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpo_plan_member_agg add EXP_COMP_PRICE_INDEX_MIN NUMBER(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
alter table rpo_plan_member_agg add EXP_COMP_PRICE_INDEX_MAX NUMBER(12,4)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
alter table rpo_plan_member_agg add EXP_COMP_AUR_PRICE_MIN numeric(20,3);
 
 
alter table rpo_plan_member_agg add EXP_COMP_AUR_PRICE_MAX numeric(20,3);
 
 
alter table rpo_plan_member_agg add BASE_COMP_AUR_PRICE_MIN numeric(20,3);
 
 
alter table rpo_plan_member_agg add BASE_COMP_AUR_PRICE_MAX numeric(20,3);
 
 
 
alter table rpo_plan_member_agg add BASE_AVG_UNIT_RETAIL_PRICE_MIN numeric(20,3);
 
 
alter table rpo_plan_member_agg add BASE_AVG_UNIT_RETAIL_PRICE_MAX numeric(20,3);
 
 
alter table rpo_plan_member_agg add EXP_AVG_UNIT_RETAIL_PRICE_MIN numeric(20,3);
 
 
alter table rpo_plan_member_agg add EXP_AVG_UNIT_RETAIL_PRICE_MAX numeric(20,3);
 
 
 
alter table rpo_plan_member_agg add BASE_COMP_PRICE_INDEX_MIN numeric(12,4);
 
 
alter table rpo_plan_member_agg add BASE_COMP_PRICE_INDEX_MAX numeric(12,4);
 
 
alter table rpo_plan_member_agg add EXP_COMP_PRICE_INDEX_MIN numeric(12,4);
 
 
alter table rpo_plan_member_agg add EXP_COMP_PRICE_INDEX_MAX numeric(12,4);
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1100541;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1100541;
%put ERROR- Description                              : Rules based pricing requires additional metrics calculated and displayed in order to be useful;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 8SEP2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1100541;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1100541",
"Rules based pricing requires additional metrics calculated and displayed in order to be useful",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1100541:;
 
 
* End of changes for CHANGE_ID:ID1100541;
 
 
***********************************************************************************************;
*************************************  End Change ID1100541 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1119120 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1119120;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1119120")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1119120;
%goto ID1119120;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1119120;
* Insert record into change management table for CHANGE_ID: ID1119120;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1119120",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1119120;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE REQ_PACKREC_SETTING ADD ALLOW_ADDITIONAL_CONFIGS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE &m_di_trans..REQ_PACKREC_SETTING ADD ALLOW_ADDITIONAL_CONFIGS INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1119120;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1119120;
%put ERROR- Description                              : Packopt Schema Change: Add column ALLOW_ADDITIONAL_CONFIGS;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 23SEP2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1119120;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1119120",
"Packopt Schema Change: Add column ALLOW_ADDITIONAL_CONFIGS",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1119120:;
 
 
* End of changes for CHANGE_ID:ID1119120;
 
 
***********************************************************************************************;
*************************************  End Change ID1119120 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1121164 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1121164;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1121164")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1121164;
%goto ID1121164;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1121164;
* Insert record into change management table for CHANGE_ID: ID1121164;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1121164",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1121164;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PKO_BUY ADD ALLOW_ADDITIONAL_CONFIGS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_DELIVERY ADD ALLOW_ADDITIONAL_CONFIGS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PACK_PRODUCT_SETTING ADD ALLOW_ADDITIONAL_CONFIGS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PACK_DEFAULT ADD ALLOW_ADDITIONAL_CONFIGS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
ALTER TABLE &m_di_trans..PKO_BUY ADD ALLOW_ADDITIONAL_CONFIGS INTEGER ;
 
 
ALTER TABLE &m_di_trans..PKO_DELIVERY ADD ALLOW_ADDITIONAL_CONFIGS INTEGER ;
 
 
ALTER TABLE &m_di_trans..PKO_PACK_PRODUCT_SETTING ADD ALLOW_ADDITIONAL_CONFIGS INTEGER ;
 
 
ALTER TABLE &m_di_trans..PKO_PACK_DEFAULT ADD ALLOW_ADDITIONAL_CONFIGS INTEGER;
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1121164;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1121164;
%put ERROR- Description                              : NF:New column required for multi color pack recommendation feature;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 1OCT2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1121164;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1121164",
"NF:New column required for multi color pack recommendation feature",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1121164:;
 
 
* End of changes for CHANGE_ID:ID1121164;
 
 
***********************************************************************************************;
*************************************  End Change ID1121164 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1121278 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1121278;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1121278")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1121278;
%goto ID1121278;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1121278;
* Insert record into change management table for CHANGE_ID: ID1121278;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1121278",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1121278;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
Delete from FA_SPEC where SPEC_NM='FA_ARCHIVE_PATH'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
Delete from FA_SPEC where SPEC_NM='FA_RESULTS_PATH'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
Delete from &m_di_trans..FA_SPEC where SPEC_NM='FA_ARCHIVE_PATH';
 
 
Delete from &m_di_trans..FA_SPEC where SPEC_NM='FA_RESULTS_PATH';
 
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1121278;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1121278;
%put ERROR- Description                              : CRP:Remove FA_ARCHIVE_PATH and FA_RESULTS_PATH from the FA_SPEC seed file;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 1OCT2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1121278;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1121278",
"CRP:Remove FA_ARCHIVE_PATH and FA_RESULTS_PATH from the FA_SPEC seed file",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1121278:;
 
 
* End of changes for CHANGE_ID:ID1121278;
 
 
***********************************************************************************************;
*************************************  End Change ID1121278 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1088825 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1088825;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1088825")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1088825;
%goto ID1088825;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1088825;
* Insert record into change management table for CHANGE_ID: ID1088825;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1088825",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1088825;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
UPDATE FA_SPEC SET SPEC_VALUE = 'FORECAST.DETAILS_HOLIDAY.ACCURACY' WHERE SPEC_NM = 'HOLDOUT_DETAILS_TABLES' AND SPEC_VALUE = 'HAA_PPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
UPDATE MODEL_SPEC_DEFAULT SET DEFAULT_SPEC_VALUE = 'FORECAST.DETAILS_HOLIDAY.ACCURACY' WHERE SPEC_NM = 'HOLDOUT_DETAILS_TABLES' AND DEFAULT_SPEC_VALUE = 'HAA_PPE'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
UPDATE &m_di_trans..FA_SPEC SET SPEC_VALUE = 'FORECAST.DETAILS_HOLIDAY.ACCURACY' WHERE SPEC_NM = 'HOLDOUT_DETAILS_TABLES' AND SPEC_VALUE = 'HAA_PPE';
 
 
UPDATE &m_di_trans..MODEL_SPEC_DEFAULT SET DEFAULT_SPEC_VALUE = 'FORECAST.DETAILS_HOLIDAY.ACCURACY' WHERE SPEC_NM = 'HOLDOUT_DETAILS_TABLES' AND DEFAULT_SPEC_VALUE = 'HAA_PPE';
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1088825;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1088825;
%put ERROR- Description                              : Change default value for fa spec HOLDOUT_DETAILS_TABLES;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 18NOV2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1088825;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1088825",
"Change default value for fa spec HOLDOUT_DETAILS_TABLES",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1088825:;
 
 
* End of changes for CHANGE_ID:ID1088825;
 
 
***********************************************************************************************;
*************************************  End Change ID1088825 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change S1136150 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: S1136150;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("S1136150")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : S1136150;
%goto S1136150;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : S1136150;
* Insert record into change management table for CHANGE_ID: S1136150;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"S1136150",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto S1136150;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
create index RPP_VENDOR_DEAL_IX5 on RPP_VENDOR_DEAL (abs(PLAN_SK))
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: S1136150;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: S1136150;
%put ERROR- Description                              : Missing index for RPP_VENDOR_DEAL causing poor performance;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 26Nov2014;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: S1136150;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"S1136150",
"Missing index for RPP_VENDOR_DEAL causing poor performance",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%S1136150:;
 
 
* End of changes for CHANGE_ID:S1136150;
 
 
***********************************************************************************************;
*************************************  End Change S1136150 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID838719A ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID838719A;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID838719A")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID838719A;
%goto ID838719A;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID838719A;
* Insert record into change management table for CHANGE_ID: ID838719A;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID838719A",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID838719A;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
CREATE TABLE TMP_PLAN_UPDT1 AS
SELECT COUNT(*) AS NEED_COUNT, B.PURCHASE_ORDER_PLAN_SK FROM PKO_PURCHASE_ORDER_PLAN P, PKO_BUY B, PKO_DELIVERY D, PKO_STORE_NEED N
WHERE B.PURCHASE_ORDER_PLAN_SK IN (SELECT PURCHASE_ORDER_PLAN_SK FROM PKO_PURCHASE_ORDER_PLAN)
AND D.BUY_SK=B.BUY_SK
AND N.DELIVERY_SK=D.DELIVERY_SK
AND P.PURCHASE_ORDER_PLAN_SK=B.PURCHASE_ORDER_PLAN_SK
GROUP BY B.PURCHASE_ORDER_PLAN_SK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN SET HAS_NEED = 1
WHERE PURCHASE_ORDER_PLAN_SK IN (SELECT PURCHASE_ORDER_PLAN_SK FROM TMP_PLAN_UPDT1 WHERE NEED_COUNT > 0)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
COMMIT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
TRUNCATE TABLE TMP_PLAN_UPDT1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DROP TABLE TMP_PLAN_UPDT1
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE TABLE TMP_PLAN_UPDT2 AS
SELECT PURCHASE_ORDER_PLAN_SK, SUM(STORE_NEED) AS SUM_NEED FROM PKO_STORE_NEED SN, PKO_DELIVERY D, PKO_BUY B
WHERE PURCHASE_ORDER_PLAN_SK IN(SELECT PURCHASE_ORDER_PLAN_SK FROM PKO_PURCHASE_ORDER_PLAN)
AND SN.DELIVERY_SK=D.DELIVERY_SK AND B.BUY_SK=D.BUY_SK GROUP BY PURCHASE_ORDER_PLAN_SK
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
UPDATE PKO_PURCHASE_ORDER_PLAN P SET P.TOTAL_NEED = ( SELECT SUM_NEED FROM TMP_PLAN_UPDT2 PT
WHERE PT.SUM_NEED IS NOT NULL AND PT.PURCHASE_ORDER_PLAN_SK = P.PURCHASE_ORDER_PLAN_SK)
WHERE EXISTS ( SELECT NULL FROM TMP_PLAN_UPDT2 PT WHERE PT.SUM_NEED IS NOT NULL
AND PT.PURCHASE_ORDER_PLAN_SK = P.PURCHASE_ORDER_PLAN_SK)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
COMMIT
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
TRUNCATE TABLE TMP_PLAN_UPDT2
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
DROP TABLE TMP_PLAN_UPDT2
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID838719A;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID838719A;
%put ERROR- Description                              : Loading plans for larger number of plans is slow due to metric calculations;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 20Jan2015;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID838719A;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID838719A",
"Loading plans for larger number of plans is slow due to metric calculations",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID838719A:;
 
 
* End of changes for CHANGE_ID:ID838719A;
 
 
***********************************************************************************************;
*************************************  End Change ID838719A ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1153862 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1153862;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1153862")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1153862;
%goto ID1153862;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1153862;
* Insert record into change management table for CHANGE_ID: ID1153862;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1153862",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1153862;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='PACK_OPTIMIZATION_REPORT';
 
 
INSERT INTO PURGE_QUERY (table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('PACK_OPTIMIZATION_REPORT', 'SAS', 1, 9999, '%szpk_purge_po_report(libref=DI_DM);', 180,1,'SZPK');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='SIZE_PROFILING_REPORT';
 
 
INSERT INTO PURGE_QUERY (table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('SIZE_PROFILING_REPORT', 'SAS', 1, 9999, '%szpf_purge_profile_proj_report(libref=DI_DM);', 180,1,'SZPF');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='FACT_ANALYSIS_REPORT';
 
 
INSERT INTO PURGE_QUERY (table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('FACT_ANALYSIS_REPORT', 'SAS', 1, 9999, '%szpf_purge_fact_report(libref=DI_DM);', 180,1,'SZPF');
 
 
 
quit;
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='PACK_OPTIMIZATION_REPORT';
 
 
INSERT INTO PURGE_QUERY (table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('PACK_OPTIMIZATION_REPORT', 'SAS', 1, 9999, '%szpk_purge_po_report(libref=DI_DM);', 180,1,'SZPK');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='SIZE_PROFILING_REPORT';
 
 
INSERT INTO PURGE_QUERY (table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES ('SIZE_PROFILING_REPORT', 'SAS', 1, 9999, '%szpf_purge_profile_proj_report(libref=DI_DM);', 180,1,'SZPF');
 
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='FACT_ANALYSIS_REPORT';
 
 
INSERT INTO PURGE_QUERY (table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('FACT_ANALYSIS_REPORT', 'SAS', 1, 9999, '%szpf_purge_fact_report(libref=DI_DM);', 180,1,'SZPF');
 
 
 
quit;
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1153862;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1153862;
%put ERROR- Description                              : Purge routines for static SO VA reporting tables - seeding for PURGE_QUERY;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 18Feb2015;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1153862;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1153862",
"Purge routines for static SO VA reporting tables - seeding for PURGE_QUERY",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1153862:;
 
 
* End of changes for CHANGE_ID:ID1153862;
 
 
***********************************************************************************************;
*************************************  End Change ID1153862 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1014730 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1014730;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1014730")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1014730;
%goto ID1014730;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1014730;
* Insert record into change management table for CHANGE_ID: ID1014730;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1014730",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1014730;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='COMP_PRICE_FACT';
 
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('COMP_PRICE_FACT', 'SAS', 1, 91, '%di_purge_comp_price_fact(libref=di_data);', 730,0,'RPP RPO');
 
 
quit;
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql;
 
 
 
DELETE FROM PURGE_QUERY WHERE TABLE_NM='COMP_PRICE_FACT';
 
 
 
INSERT INTO purge_query
(table_nm ,database_nm ,purge_order ,purge_frequency ,purge_query_txt, num_days_preserved ,partition_flg ,app_nm)
VALUES  ('COMP_PRICE_FACT', 'SAS', 1, 91, '%di_purge_comp_price_fact(libref=di_data);', 730,0,'RPP RPO');
 
 
quit;
 
 
 
 
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1014730;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1014730;
%put ERROR- Description                              : Purge routines for comp_price_fact;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 27Feb2015;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1014730;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1014730",
"Purge routines for comp_price_fact",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1014730:;
 
 
* End of changes for CHANGE_ID:ID1014730;
 
 
***********************************************************************************************;
*************************************  End Change ID1014730 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1162130 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1162130;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1162130")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1162130;
%goto ID1162130;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1162130;
* Insert record into change management table for CHANGE_ID: ID1162130;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1162130",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1162130;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
 
%let m_sql_statement = %str(
CREATE TABLE PKO_RES_PRF_CLUSTER_CONTRIB
(
PRF_CLUSTER_CONTRIB_SK      INTEGER NOT NULL,
BUY_SK                      INTEGER NOT NULL,
DELIVERY_SK                 INTEGER NOT NULL,
PROFILE_ID                  INTEGER NOT NULL,
CLUSTER_ID                  INTEGER,
PROD_ID                     VARCHAR(32) NOT NULL,
SRC_SIZE_CD                 INTEGER NOT NULL,
CONTRIB_PCT                 NUMERIC(12,4),
PRIMARY KEY (PRF_CLUSTER_CONTRIB_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_PRF_CLUSTER_CONTRIB_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%let m_sql_statement = %str(
CREATE TABLE PKO_RES_PROD_GEO_PROFILE
(
PROD_GEO_PROFILE_SK          INTEGER NOT NULL,
BUY_SK                       INTEGER NOT NULL,
DELIVERY_SK                  INTEGER NOT NULL,
PROFILE_ID                   INTEGER NOT NULL,
CLUSTER_ID                   INTEGER,
PROD_ID                      VARCHAR(32) NOT NULL,
GEO_ID                       VARCHAR(32) NOT NULL,
STORE_CATEGORY               VARCHAR(20),
TOTAL_SCORE                  NUMERIC(12,2),
START_DT                     DATE,
END_DT                       DATE,
NEAR_MATCH_FLG               INTEGER,
PRIMARY KEY (PROD_GEO_PROFILE_SK)
)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
CREATE SEQUENCE SEQ_PROD_GEO_PROFILE_SK START WITH 100000
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
/* No Change */
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1162130;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1162130;
%put ERROR- Description                              : NF:Enhancement to Pack mid-tier to read Profile related data;
%put ERROR- Version                                  : D4MICM54;
%put ERROR- Date of Change                           : 17Mar2015;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1162130;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1162130",
"NF:Enhancement to Pack mid-tier to read Profile related data",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1162130:;
 
 
* End of changes for CHANGE_ID:ID1162130;
 
 
***********************************************************************************************;
*************************************  End Change ID1162130 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1111012 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1111012;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1111012")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1111012;
%goto ID1111012;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(D4micm54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1111012;
* Insert record into change management table for CHANGE_ID: ID1111012;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1111012",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1111012;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK = -1 and spec_nm='im_instore_maxlimit'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_instore_maxlimit', '0', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
DELETE FROM &m_di_trans..PRF_CONFIG WHERE PRF_CONFIG_SK = -1 and spec_nm='im_instore_maxlimit';
 
 
 
INSERT INTO &m_di_trans..PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_instore_maxlimit', '0', 'INTEGER');
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1111012;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1111012;
%put ERROR- Description                              : Need to insert the default PRF_CONFIG entry for im_instore_maxlimit;
%put ERROR- Version                                  : D4micm54;
%put ERROR- Date of Change                           : 24MAR2015;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1111012;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1111012",
"Need to insert the default PRF_CONFIG entry for im_instore_maxlimit",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1111012:;
 
 
* End of changes for CHANGE_ID:ID1111012;
 
 
***********************************************************************************************;
*************************************  End Change ID1111012 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1260888 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1260888;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1260888")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1260888;
%goto ID1260888;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(F0MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1260888;
* Insert record into change management table for CHANGE_ID: ID1260888;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1260888",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1260888;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PRF_PROFILE ADD PROFILE_STATUS_CD INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PRF_PROFILE ADD PROFILE_UPDATED_DTTM DATE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
 
ALTER TABLE &m_di_trans..PRF_PROFILE ADD PROFILE_STATUS_CD INTEGER;
 
 
ALTER TABLE &m_di_trans..PRF_PROFILE ADD PROFILE_UPDATED_DTTM DATE;
 
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1260888;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1260888;
%put ERROR- Description                              : MACYS: PUBLISHED_DT in PROFILE need DATETIME stamp, need publish date and status in PRF_PROFILE;
%put ERROR- Version                                  : F0MICM54;
%put ERROR- Date of Change                           : 15JUN2016;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1260888;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1260888",
"MACYS: PUBLISHED_DT in PROFILE need DATETIME stamp, need publish date and status in PRF_PROFILE",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1260888:;
 
 
* End of changes for CHANGE_ID:ID1260888;
 
 
***********************************************************************************************;
*************************************  End Change ID1260888 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1269699 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1269699;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1269699")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1269699;
%goto ID1269699;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(F0MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1269699;
* Insert record into change management table for CHANGE_ID: ID1269699;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1269699",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1269699;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK = -1 and spec_nm='im_cross_maxlimit'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_cross_maxlimit', '0', 'INTEGER')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql;
 
 
 
DELETE FROM PRF_CONFIG WHERE PRF_CONFIG_SK = -1 and spec_nm='im_cross_maxlimit';
 
 
 
INSERT INTO PRF_CONFIG (PRF_CONFIG_SK, PRF_CONFIG_TYPE, SPEC_NM, SPEC_VALUE, SPEC_TYPE)
VALUES ( -1, 2, 'im_cross_maxlimit', '0', 'INTEGER');
 
 
quit;
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1269699;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1269699;
%put ERROR- Description                              : Need to insert the default PRF_CONFIG entry for im_cross_maxlimit;
%put ERROR- Version                                  : F0MICM54;
%put ERROR- Date of Change                           : 11AUG2016;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1269699;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1269699",
"Need to insert the default PRF_CONFIG entry for im_cross_maxlimit",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1269699:;
 
 
* End of changes for CHANGE_ID:ID1269699;
 
 
***********************************************************************************************;
*************************************  End Change ID1269699 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1284403 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1284403;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1284403")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1284403;
%goto ID1284403;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(F0MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1284403;
* Insert record into change management table for CHANGE_ID: ID1284403;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1284403",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1284403;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
DELETE FROM PRF_GEO_PROD_STATUS_SPEC WHERE SPEC_NM = 'IGNORE_ZERO_INVENTORY_IN_STRT_WK'
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
INSERT INTO PRF_GEO_PROD_STATUS_SPEC VALUES( 1 ,'IGNORE_ZERO_INVENTORY_IN_STRT_WK', '0', '' , 'ETL - Seeded')
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
proc sql noprint;
 
 
 
DELETE FROM PRF_GEO_PROD_STATUS_SPEC WHERE SPEC_NM = 'IGNORE_ZERO_INVENTORY_IN_STRT_WK';
 
 
 
INSERT INTO PRF_GEO_PROD_STATUS_SPEC VALUES( 1 ,'IGNORE_ZERO_INVENTORY_IN_STRT_WK', '0', %sysfunc(datetime()), 'ETL - Seeded');
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1284403;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1284403;
%put ERROR- Description                              : DERIVE_STOCKOUT_GP_STATUS should treat first weeks where OH = 0 as inactive;
%put ERROR- Version                                  : F0MICM54;
%put ERROR- Date of Change                           : 01SEP2016;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1284403;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1284403",
"DERIVE_STOCKOUT_GP_STATUS should treat first weeks where OH = 0 as inactive",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1284403:;
 
 
* End of changes for CHANGE_ID:ID1284403;
 
 
***********************************************************************************************;
*************************************  End Change ID1284403 ************************************;
***********************************************************************************************;
 
 
 
 
***********************************************************************************************;
************************************  Begin Change ID1286333 ***********************************;
***********************************************************************************************;
 
 
* Check to see if this change has already been applied. CHANGE_ID: ID1286333;
%let m_ldate=;
%let m_ldesc=;
%let m_luser=;
 
data _null_;
 
set di_trans.rdbms_DM_change_management (where=(upper(change_id)=upper("ID1286333")));
call symputx("m_ldesc", change_desc);
call symputx("m_ldate", date_change_applied);
call symputx("m_luser", user_applying_change);
 
run;
 
 
%if (%length(&m_ldate)>2) %then
%do;
%put ;
%put NOTE: Skipping!! Already applied change : ID1286333;
%goto ID1286333;
 
%end;
 
%put ;
 
 
 
 
%*global m_version_posn;
%let m_version=%str(F0MICM54);
%di_util_find_word(_list_of_words_to_find=%bquote(&m_baseline_versions),
_string_to_search=%bquote(&m_version),_found_posn=%bquote(m_version_posn), _delim=%bquote(,)  )
%if ( &m_version_posn > 0 ) %then
%do;
%put ;
%put NOTE: Log and Skip!! Baseline schema includes change : ID1286333;
* Insert record into change management table for CHANGE_ID: ID1286333;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1286333",
'Skip!! This change is included in baseline',
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%goto ID1286333;
 
%end;
 
 
 
 
%if (&m_di_trans_vendor in (ORACLE POSTGRE DB2)) %then %do;
 
%let m_sql_statement = %str(
ALTER TABLE PROFILING_PROJECT ADD LOAD_STATUS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PROFILING_PROJECT ADD LOADED_BY VARCHAR(40)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PROFILING_PROJECT ADD DATASET_NM VARCHAR(40)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PROFILING_PROJECT ADD LOAD_DTTM DATE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PROFILING_PROJECT ADD EXTRACT_DTTM DATE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PROFILING_PROJECT ADD REPORT_SCHEDULE INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD LOAD_STATUS INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD LOADED_BY VARCHAR(40)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD DATASET_NM VARCHAR(40)
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD LOAD_DTTM DATE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD EXTRACT_DTTM DATE
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
%let m_sql_statement = %str(
ALTER TABLE PKO_PURCHASE_ORDER_PLAN ADD REPORT_SCHEDULE INTEGER
);
 
 
%di_dm_trans_exe(pass_through_sql=%quote(&m_sql_statement),session_flg=1);
 
 
 
 
%end;
 
 
%if (&m_di_trans_vendor in (SAS)) %then %do;
 
 
proc sql noprint;
 
 
alter table &m_di_trans..PROFILING_PROJECT  add LOAD_STATUS INTEGER ;
 
 
alter table &m_di_trans..PROFILING_PROJECT  add LOADED_BY VARCHAR(40);
 
 
alter table &m_di_trans..PROFILING_PROJECT  add DATASET_NM VARCHAR(40);
 
 
alter table &m_di_trans..PROFILING_PROJECT  add LOAD_DTTM DATE;
 
 
alter table &m_di_trans..PROFILING_PROJECT  add EXTRACT_DTTM DATE ;
 
 
alter table &m_di_trans..PROFILING_PROJECT  add REPORT_SCHEDULE INTEGER ;
 
 
 
 
alter table &m_di_trans..PKO_PURCHASE_ORDER_PLAN  add LOAD_STATUS INTEGER ;
 
 
alter table &m_di_trans..PKO_PURCHASE_ORDER_PLAN  add LOADED_BY VARCHAR(40);
 
 
alter table &m_di_trans..PKO_PURCHASE_ORDER_PLAN  add DATASET_NM VARCHAR(40);
 
 
alter table &m_di_trans..PKO_PURCHASE_ORDER_PLAN  add LOAD_DTTM DATE;
 
 
alter table &m_di_trans..PKO_PURCHASE_ORDER_PLAN  add EXTRACT_DTTM DATE;
 
 
alter table &m_di_trans..PKO_PURCHASE_ORDER_PLAN  add REPORT_SCHEDULE INTEGER ;
 
 
quit;
 
 
 
%end;
 
 
 
 
* Check for errors while processing CHANGE_ID: ID1286333;
%if &syscc > 4 %then %do;
%put ERROR: Error occurred while processing change_id: ID1286333;
%put ERROR- Description                              : CRP:Size Profiling 3.4 VAAR intedgrated reports must be self-service;
%put ERROR- Version                                  : F0MICM54;
%put ERROR- Date of Change                           : 23NOV2016;
%put ERROR-  ;
%put ERROR- The value of syscc is &syscc;
%goto EXIT_RDBMS_DATA_MODEL_CHANGES;
%return;
%end;
 
 
* Insert record into change management table for CHANGE_ID: ID1286333;
proc sql;
insert  into di_trans.rdbms_DM_change_management
values (
"ID1286333",
"CRP:Size Profiling 3.4 VAAR intedgrated reports must be self-service",
%sysfunc(datetime()),
"&m_user"
);
quit;
 
 
%ID1286333:;
 
 
* End of changes for CHANGE_ID:ID1286333;
 
 
***********************************************************************************************;
*************************************  End Change ID1286333 ************************************;
***********************************************************************************************;
 
 
 
 
 
%EXIT_RDBMS_DATA_MODEL_CHANGES:;
 
options user = work;
 
%mend;
 
 
%*apply_rdbms_data_model_changes(
m_di_trans_vendor=%str(&di_trans_vendor),   /* Database vendor */
m_di_trans=di_trans,                 /* libref for rdbms datamart library*/
m_di_data=di_data,                   /* libref for sas datamart library*/
m_di_mon=di_mon,                     /* libref for monitor library */
m_didm_stg=didm_stg,                 /* libref for stage library */
m_DTTMFMT=NLDATM21.,                 /* Date time format */
m_DTFMT=DATE9.,                      /* Date format */
m_experimental_changes=FALSE,        /* For developers only */
m_user=&sysuserid.                   /* Userid */
);
 
 
